(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15123,        422]*)
(*NotebookOutlinePosition[     41362,       1282]*)
(*  CellTagsIndexPosition[     41318,       1278]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Bifurcations VII
Subcritical Hopf Bifurcation\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[299]:="],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input",
  CellLabel->"In[300]:="],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell["\<\
\tIn this notebook, the seventh in a series of notebooks on \
bifurcations, we look at a simple example of a subcritical  Hopf bifurcation. \
 At the bifurcation, an unstable limit cycle is absorbed by a stable spiral \
equilibrium.  The equilibrium becomes unstable, and the system state will \
then jump from the unstable equilibrium to some distant atractor, a possibly \
catastrophic transition.  We construct a movie showing the changes in the \
equilibrium and the limit cycles as the bifurcation parameter changes.\
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Definition of the System", "SectionFirst"],

Cell[TextData[{
  "\tWe consider the following system, depending on one parameter ",
  StyleBox["a",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  "  =  -",
  StyleBox["y",
    FontSlant->"Italic"],
  " + ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " + \[Mu])(1 - ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  ")  ,   ",
  Cell[BoxData[
      \(TraditionalForm\`y\& . \)]],
  "  =   ",
  StyleBox["x",
    FontSlant->"Italic"],
  " + ",
  StyleBox["y",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " + \[Mu])(1 - ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^2\)\(\ \)\)\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  ")"
}], "Text",
  TextAlignment->Center],

Cell["\<\
We begin our analysis by defining the system for DynPac.\
\>", \
"Text"],

Cell[BoxData[{
    \(setstate[{x, y}]; setparm[{\[Mu]}];\), "\[IndentingNewLine]", 
    \(slopevec = \ {\(-y\) + 
          x*\((x\^2 + y\^2\  + \ \[Mu])\)*\((1 - x\^2 - y\^2)\), 
        x + y*\((x\^2 + y\^2\  + \ \[Mu])\)*\((1 - x\^2 - y\^2)\)}; 
    sysname = "\<SubCritical Hopf\>";\)}], "Input",
  CellLabel->"In[301]:="],

Cell["We look for equilibrium states.", "Text"],

Cell[BoxData[
    \(findpolyeq\)], "Input",
  CellLabel->"In[303]:="],

Cell["\<\
It is easy to show that this is the only equilibrium.  For this \
problem, it is useful to obtain the slope functions in polar coordinates.  We \
use the function polartrans to do this.\
\>", "Text"],

Cell[BoxData[
    \(polarslope = polartrans[x, y, r, \[Theta]]\)], "Input",
  CellLabel->"In[304]:="],

Cell[TextData[{
  "We have gotten lucky.  Almost everything we might want to know about this \
system can be read from the radial slope function.  We see that there is a \
limit cycle at ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "= 1, and, for negative \[Mu], another at ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-\[Mu]\)\)]],
  ".  It is easy to check the stability, by looking at the sign of polarslope \
as we move slightly away from the limit cycle.  We get the following results: \
 for \[Mu] < -1, the cycle at ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-\[Mu]\)\)]],
  " is stable, and the cycle at 1 is unstable.  For -1 < \[Mu] < 0, the cycle \
at ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-\[Mu]\)\)]],
  " is unstable, and the cycle at 1 is stable.  Thus we see that as \[Mu] \
passes through -1, we have a transcritical bifurcation of limit cycles.  As \
\[Mu] \[ShortRightArrow] 0-, the unstable cycle is absorbed by the \
equilibrium.  For 0 < \[Mu], we have only the stable cycle at 1.  Let's check \
the stability of the equilibrium point."
}], "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input",
  CellLabel->"In[305]:="],

Cell[TextData[{
  "Thus the equilibrium is a stable spiral for \[Mu] < 0, an unstable spiral \
for \[Mu] > 0, and a center in linearized theory for \[Mu] = 0.  It is not \
hard to show that the equilibrium is unstable for \[Mu] = 0.  The bifurcation \
at \[Mu] = 0 is called a subcritical Hopf bifurcation.  Imagine a system in \
the stable equilibrium state for \[Mu] < 0.  As we increase \[Mu], the \
unstable limit cycle shrinks to the equilibrium.  When \[Mu] reaches zero, \
the equilibrium becomes unstable, and the system will make a finite jump to \
the nearest attractor, namely the limit cycle at ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 1.  Such a large and sudden jump could be catastrophic.  A less \
catastrophic sequence occurs if we start on the stable limit cycle for \[Mu] \
< -1.  Then as we pass through \[Mu] = -1, we switch to the stable cycle at \
",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 1, and remain there as \[Mu] continues to increase.  ",
  "We may visualize this in a bifurcation diagram by plotting the position of \
the equilibria and the amplitude of the limit cycles, using as usual solid \
for stable, dashed for unstable."
}], "Text"],

Cell[BoxData[
    \(\(plot1 = 
        Plot[{0, \@\(-\[Mu]\), 
            1}, {\[Mu], \(-2\), \(-1\)}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-2\), 2}, {\(-1.5\), 
                1.5}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Subcritical \
Hopf\>", \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Mu]\>", "\<x\>"}, 
          Axes \[Rule] False, 
          ImageSize \[Rule] imsize, \[IndentingNewLine]Frame \[Rule] True, 
          DisplayFunction\  \[Rule] \ 
            Identity, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.03, 
                  0.0}], Dashing[{0.03, 
                  0.0}], \[IndentingNewLine]Dashing[{0.03, 
                  0.03}]}];\)\)], "Input",
  CellLabel->"In[306]:="],

Cell[BoxData[
    \(\(plot2 = 
        Plot[{0, \@\(-\[Mu]\), 1}, {\[Mu], \(-1\), 
            0}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2\), 2}, {\(-1.5\), 
                1.5}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Subcritical \
Hopf\>", Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Mu]\>", \
"\<x\>"}, 
          Axes \[Rule] False, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity, ImageSize \[Rule] imsize, 
          PlotStyle \[Rule] {Dashing[{0.03, 0.00}], 
              Dashing[{0.03, 0.03}], \[IndentingNewLine]Dashing[{0.03, 
                  0.0}]}];\)\)], "Input",
  CellLabel->"In[307]:="],

Cell[BoxData[
    \(\(plot3 = 
        Plot[{0, 1}, {\[Mu], 0, 2}, 
          PlotRange \[Rule] {{\(-2\), 2}, {\(-1.5\), 
                1.5}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Subcritical \
Hopf\>", Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Mu]\>", \
"\<x\>"}, 
          Axes \[Rule] False, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity, \[IndentingNewLine]PlotStyle \[Rule] {Dashing[{0.03, 
                  0.03}], Dashing[{0.03, 0.00}]}];\)\)], "Input",
  CellLabel->"In[308]:="],

Cell[BoxData[
    \(\(Show[{plot1, plot2, plot3}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  CellLabel->"In[309]:="],

Cell["\<\
\tIn previous bifurcation sequences, we have constructed a family \
of orbits for each \[Mu], and then tracked the changes with \[Mu].  Because \
there is more going on here with the two limit cycles and the equilibrium, we \
first make a movie showing only the limit cycles and equilibrium.  This shows \
the essential features of the bifurcation.  Then we will make a second movie \
in which we add two orbits near the equilibrium point.  The refgraph we \
define here has the limit cycles and equilibrium as a function of mu.  \
\>", \
"Text"],

Cell[BoxData[
    \(refgraph1 := \ 
      Module[{ans1, ans2, ans3, rad, u}, ptsize = 0.03; 
        rad = Sqrt[\(-First[parmval]\)]; 
        display = False; \[IndentingNewLine]setcolor[{Blue}]; 
        ans1 = \ dots[{{0, 0}}]; 
        lnthick = 0.007; \[IndentingNewLine]ans2 = 
          plotcurve[{{{rad*Cos[u], rad*Sin[u]}, {u, 0, 
                  2\ Pi}}}]; \[IndentingNewLine]setcolor[{Red}]; 
        ans3 = plotcurve[{{{Cos[u], Sin[u]}, {u, 0, 
                  2\ Pi}}}]; \[IndentingNewLine]lnthick = 0.002; {ans1, ans2, 
          ans3}]\)], "Input",
  CellLabel->"In[310]:="],

Cell[BoxData[
    \(refgraph2 := \ 
      Module[{ans1, ans2, ans3, rad, u}, ptsize = 0.03; 
        rad = Sqrt[\(-First[parmval]\)]; 
        display\  = \ False; \[IndentingNewLine]setcolor[{Blue}]; 
        ans1 = \ dots[{{0, 0}}]; 
        lnthick = 0.007; \[IndentingNewLine]ans2 = 
          plotcurve[{{{Cos[u], Sin[u]}, {u, 0, 
                  2\ Pi}}}]; \[IndentingNewLine]setcolor[{Red}]; 
        ans3 = plotcurve[{{{rad*Cos[u], rad*Sin[u]}, {u, 0, 
                  2\ Pi}}}]; \[IndentingNewLine]lnthick = 0.002; {ans1, ans2, 
          ans3}]\)], "Input",
  CellLabel->"In[311]:="],

Cell[BoxData[
    \(refgraph3 := \ 
      Module[{ans1, ans2, u}, 
        ptsize = 0.03; \[IndentingNewLine]display\  = \ 
          False; \[IndentingNewLine]setcolor[{Red}]; 
        ans1 = \ dots[{{0, 0}}]; \[IndentingNewLine]setcolor[{Blue}]; 
        lnthick = 0.007; \[IndentingNewLine]ans2 = 
          plotcurve[{{{Cos[u], Sin[u]}, {u, 0, 
                  2\ Pi}}}]; \[IndentingNewLine]lnthick = 0.002; {ans1, 
          ans2}]\)], "Input",
  CellLabel->"In[312]:="],

Cell[BoxData[
    \(refgraph := 
      Module[{ans, mu}, 
        mu = First[
            parmval]; \[IndentingNewLine]plrange = {{\(-1.5\), 
              1.5}, {\(-1.5\), 1.5}}; 
        asprat = 1; \[IndentingNewLine]labshift = 
          15; \[IndentingNewLine]If[\((mu < \(-1\))\), \((ans\  = \ 
              refgraph1)\), \((If[\((mu\  < \ 0)\), \((ans\  = \ 
                  refgraph2)\), \[IndentingNewLine]\((ans\  = \ 
                  refgraph3)\)\ ])\)]; \ \ \ \
\[IndentingNewLine]setcolor[{Black}]; display = True; ans]\)], "Input",
  CellLabel->"In[313]:="],

Cell["\<\
Now we use a Do loop to construct the movie with just the limit \
cycles and the equilibrium.  As usual we use blue for stable and red for \
unstable.\
\>", "Text"],

Cell[BoxData[
    \(\(Do[parmval = {i*0.05}; 
        show[refgraph], {i, \(-40\), 20}];\)\)], "Input",
  CellLabel->"In[314]:="],

Cell["\<\
\tNow we repeat the graph construction, this time adding two \
orbits.  Because varying number of steps are required for different values of \
\[Mu], we have defined nsteps below to accomplish this. \
\>", "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; initset = {\ {0.1, 0}, {\(-0.1\), 0}};\)], "Input",
  CellLabel->"In[315]:="],

Cell[BoxData[
    \(\(bothdirflag = True;\)\)], "Input",
  CellLabel->"In[316]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/5, 4/5};\)], "Input",
  CellLabel->"In[317]:="],

Cell[BoxData[
    \(\(parmlist = Table[{i*0.05}, {i, \(-40\), 20}];\)\)], "Input",
  CellLabel->"In[324]:="],

Cell[BoxData[
    \(nsteps := 
      Module[{ans, mu}, 
        mu = First[
            parmval]; \[IndentingNewLine]If[\((mu < \(-1.45\))\), \((ans\  = \
\ 350)\), \((If[\((mu\  < \ \(-0.95\))\), \((ans\  = \ 
                  600)\), \[IndentingNewLine]\((If[\((mu\  < \ \(-0.25\))\), \
\ \((ans\  = \ 
                      700)\), \[IndentingNewLine]\((If[\((mu\  < \ \
\(-0.2\))\), \((ans\  = \ 
                          800)\), \[IndentingNewLine]\((If[\((mu\  < \ \
\(-0.15\))\), \((ans\  = \ 
                              900)\), \[IndentingNewLine]\((If[\((mu\  < \ \
\(-0.10\))\), \((ans\  = \ 
                                  1000)\), \[IndentingNewLine]\((If[\((mu\  < \
\ \(-0.05\))\), \ \((ans\  = \ 
                                      1200)\), \[IndentingNewLine]\((If[\((mu\
\  \[Equal] \ 0\ )\), \((ans\  = \ 
                                        5000)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.1)\), \((ans = 
                                        1400)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.2)\), \((ans\  = 
                                        1200)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.25)\), \((ans\  = \ 
                                        1000)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.3)\), \((ans\  = \ 
                                        900)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.35)\), \((ans\  = \ 
                                        800)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.4)\), \((ans\  = \ 
                                        700)\), \
\[IndentingNewLine]\((If[\((mu\  < \ 0.45)\), \((ans\  = \ 
                                        600)\), \[IndentingNewLine]\((ans\  = \
\ 500)\)])\)])\)])\)])\)])\)])\)])\)])\)])\)])\)])\)])\)])\)])\)]]\)], "Input",\

  CellLabel->"In[319]:="],

Cell[BoxData[
    \(initset := 
      Module[{ans, mu}, 
        mu\  = \ First[
            parmval]; \[IndentingNewLine]If[\((\((mu < \(-0.25\))\) || \((mu\ \
 > \ 0.25)\))\), \((ans = {{0.02, 0}, {\(-0.02\), 
                  0}})\), \[IndentingNewLine]\((ans = {{0.1, 0}, {\(-0.1\), 
                  0}})\)]; ans]\)], "Input",
  CellLabel->"In[320]:="],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist, 
        refgraph];\)\)], "Input",
  CellLabel->"In[321]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{651, 686},
WindowMargins->{{40, Automatic}, {Automatic, 13}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000mdD<01T1T00000000000
00000000003oo`UI4d3oo`000GL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 70, 3, 114, "Title"],
Cell[1812, 56, 64, 2, 28, "Input"],
Cell[1879, 60, 79, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[1983, 66, 40, 0, 63, "SectionFirst"],
Cell[2026, 68, 547, 9, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2610, 82, 52, 0, 63, "SectionFirst"],
Cell[2665, 84, 144, 5, 26, "Text"],
Cell[2812, 91, 896, 44, 26, "Text"],
Cell[3711, 137, 82, 3, 24, "Text"],
Cell[3796, 142, 326, 6, 85, "Input"],
Cell[4125, 150, 47, 0, 24, "Text"],
Cell[4175, 152, 69, 2, 28, "Input"],
Cell[4247, 156, 209, 4, 38, "Text"],
Cell[4459, 162, 101, 2, 28, "Input"],
Cell[4563, 166, 1142, 26, 116, "Text"],
Cell[5708, 194, 73, 2, 28, "Input"],
Cell[5784, 198, 1190, 21, 126, "Text"],
Cell[6977, 221, 709, 14, 134, "Input"],
Cell[7689, 237, 661, 13, 134, "Input"],
Cell[8353, 252, 547, 11, 92, "Input"],
Cell[8903, 265, 142, 3, 28, "Input"],
Cell[9048, 270, 556, 9, 80, "Text"],
Cell[9607, 281, 593, 12, 108, "Input"],
Cell[10203, 295, 597, 12, 124, "Input"],
Cell[10803, 309, 477, 10, 108, "Input"],
Cell[11283, 321, 576, 12, 124, "Input"],
Cell[11862, 335, 174, 4, 38, "Text"],
Cell[12039, 341, 129, 3, 28, "Input"],
Cell[12171, 346, 223, 4, 38, "Text"],
Cell[12397, 352, 117, 2, 28, "Input"],
Cell[12517, 356, 82, 2, 28, "Input"],
Cell[12602, 360, 99, 2, 28, "Input"],
Cell[12704, 364, 108, 2, 28, "Input"],
Cell[12815, 368, 1786, 35, 284, "Input"],
Cell[14604, 405, 359, 8, 60, "Input"],
Cell[14966, 415, 129, 3, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

