(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11632,        353]*)
(*NotebookOutlinePosition[     37871,       1213]*)
(*  CellTagsIndexPosition[     37827,       1209]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
ME 406
Bifurcations VI
Supercritical Hopf Bifurcation\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[265]:="],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input",
  CellLabel->"In[266]:="],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell["\<\
\tIn this notebook, the sixth in a series of notebooks on \
bifurcations, we look at a simple example of a supercritical  Hopf \
bifurcation.  At the bifurcation, a stable spiral equilibrium becomes an \
unstable spiral equilibrium and throws off a stable limit cycle.  The \
amplitude of the limit cycle at birth is zero, and increases as the \
bifurcation parameter increases beyond the bifurcation value.  We construct a \
movie showing the changes of a selected set of orbits with the bifurcation \
parameter. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Definition of the System", "SectionFirst"],

Cell[TextData[{
  "\tWe consider the following system, depending on one parameter ",
  StyleBox["a",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  "  =  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " - ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " - \[Mu])  ,   ",
  Cell[BoxData[
      \(TraditionalForm\`y\& . \)]],
  "  =  - ",
  StyleBox["x - y",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^2\)\(\ \)\)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " - \[Mu]) ."
}], "Text",
  TextAlignment->Center],

Cell["\<\
We begin our analysis by defining the system for DynPac.\
\>", \
"Text"],

Cell[BoxData[{
    \(setstate[{x, y}]; setparm[{\[Mu]}];\), "\[IndentingNewLine]", 
    \(slopevec = {y - x*\((x\^2 + y\^2 - \ \[Mu])\), \(-x\) - 
          y*\((x\^2 + y\^2 - \ \[Mu])\)}; 
    sysname = "\<SuperCritical Hopf\>";\)}], "Input",
  CellLabel->"In[265]:="],

Cell["We look for equilibrium states.", "Text"],

Cell[BoxData[
    \(findpolyeq\)], "Input",
  CellLabel->"In[267]:="],

Cell[TextData[{
  "It is easy to show that this is the only equilibrium.  For this problem, \
it is useful to obtain the equation satisfied by the polar radial coordinate \
",
  StyleBox["r",
    FontSlant->"Italic"],
  " = (",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\()\^\(1\/2\)\)\)]],
  ".  We have"
}], "Text"],

Cell[BoxData[
    \(\(r\& . \)\  = \ 
      FullSimplify[\((\((1/r)\)\ \((x*slopevec[\([1]\)] + 
                  y*slopevec[\([2]\)])\))\)] //. \ 
        x\^2\  \[Rule] \((r\^2 - y\^2)\)\)], "Input",
  CellLabel->"In[275]:="],

Cell[TextData[{
  "This equation shows clearly that there is a stable limit cycle for \[Mu] > \
0, namely a circular limit cycle of radius ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Mu]\)]],
  ".  For \[Mu] < 0 , ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  " is negative for all ",
  StyleBox["r ",
    FontSlant->"Italic"],
  " except ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 0, which shows that the origin is a globally stable equilibrium in that \
case.  We look at the equilibrium in more detail."
}], "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input",
  CellLabel->"In[276]:="],

Cell["\<\
Thus the equilibrium is a stable spiral for \[Mu] < 0, an unstable \
spiral for \[Mu] > 0, and a center in linearized theory for \[Mu] = 0.  It is \
not hard to show that the equilibrium is a stable nonlinear spiral for \[Mu] \
= 0.  The bifurcation at \[Mu] = 0 is called a Hopf bifurcation.  We see that \
the equilibrium goes from a stable to an unstable spiral there, and a limit \
cycle of zero amplitude is born there.  As the parameter increases beyond the \
bifurcation value (zero in this case), the limit cycle grows in amplitude. 
We may visualize this in a bifurcation diagram by plotting the position of \
the equilibria and the amplitude of any limit cycles.\
\>", "Text"],

Cell[BoxData[
    \(\(plot1 = 
        Plot[{0}, {\[Mu], \(-1\), 
            0}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Supercritical \
Hopf\>", \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Mu]\>", "\<x\>"}, 
          Axes \[Rule] False, ImageSize \[Rule] imsize, Frame \[Rule] True, 
          DisplayFunction\  \[Rule] Identity];\)\)], "Input",
  CellLabel->"In[278]:="],

Cell[BoxData[
    \(\(plot2 = 
        Plot[{0, \@\[Mu]}, {\[Mu], 0, 
            1}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                1}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Supercritical \
Hopf\>", Frame \[Rule] 
            True, \[IndentingNewLine]FrameLabel \[Rule] {"\<\[Mu]\>", \
"\<x\>"}, 
          Axes \[Rule] False, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity, ImageSize \[Rule] imsize, 
          PlotStyle \[Rule] {Dashing[{0.03, 0.03}], 
              Dashing[{0.03, 0.0}]}];\)\)], "Input",
  CellLabel->"In[279]:="],

Cell[BoxData[
    \(\(Show[{plot1, plot2}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  CellLabel->"In[280]:="],

Cell[TextData[{
  "\tImagine a gradual change of \[Mu]-values from negative through zero to \
small and positive.  For negative \[Mu], the system will settle into the only \
attractor, the stable spiral at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 0.  It will stay there as we increase \[Mu] slowly.  When we just \
exceed \[Mu] = 0, the equilibrium is no longer stable, and the system will \
make the small jump to the limit cycle of amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Mu]\)]],
  ". "
}], "Text"],

Cell["\<\
\tNow we construct a short sequence of phase plots for different \
values of \[Mu], for a given set of initial conditions.  These will \
illustrate the bifurcation at \[Mu] = 0.  We will mark the equilibria by red \
dots for unstable, blue dots for stable.  We do this by constructing a graph \
refgraph which is then included in each picture of the bifurcation \
sequence.\
\>", "Text"],

Cell[BoxData[
    \(refgraph := 
      Module[{ans}, ptsize = 0.025; \[IndentingNewLine]display\  = \ False; 
        setcolor[{Black}]; \[IndentingNewLine]If[\((First[parmval] <= \ 
              0)\), \((setcolor[{Blue}]; \[IndentingNewLine]ans = 
              dots[{{0, 0}}])\), \((setcolor[{Red}]; \[IndentingNewLine]ans = 
              dots[{{0, 0}}])\)]; \[IndentingNewLine]setcolor[{Black}]; 
        display = True; ans]\)], "Input",
  CellLabel->"In[321]:="],

Cell[BoxData[
    \(\(\[CurlyEpsilon] = 0.02;\)\)], "Input",
  CellLabel->"In[322]:="],

Cell[BoxData[
    \(\(initset1 = {{2, 0}, {2, 2}, {0, 2}, {\(-2\), 2}, {\(-2\), 
            0}, {\(-2\), \(-2\)}, {0, \(-2\)}, {2, \(-2\)}};\)\)], "Input",
  CellLabel->"In[323]:="],

Cell[BoxData[
    \(\(initset2 = {{2, 0}, {2, 2}, {0, 2}, {\(-2\), 2}, {\(-2\), 
            0}, {\(-2\), \(-2\)}, {0, \(-2\)}, {2, \(-2\)}, {\[CurlyEpsilon], 
            0}, {\(-\[CurlyEpsilon]\), 0}};\)\)], "Input",
  CellLabel->"In[324]:="],

Cell[BoxData[
    \(initset := 
      Module[{ans}, 
        If[\((First[parmval] <= 0)\), \((ans = initset1)\), \((ans = 
              initset2)\)]; ans]\)], "Input",
  CellLabel->"In[325]:="],

Cell[BoxData[
    \(plrange = {{\(-2\), 2}, {\(-2\), 2}}; asprat = 1; labshift = 18; 
    imsize = 360;\)], "Input",
  CellLabel->"In[326]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/5};\)], "Input",
  CellLabel->"In[333]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 500; bothdirflag = False;\)], "Input",
  CellLabel->"In[332]:="],

Cell[BoxData[
    \(\(rangeflag = False;\)\)], "Input",
  CellLabel->"In[329]:="],

Cell["\<\
\tNow we choose a small number of \[Mu]-values for a bifurcation \
sequence.\
\>", "Text"],

Cell[BoxData[
    \(\(parmlist = \ {{\(-1.0\)}, {\(-0.5\)}, {0.0}, {0.5}, {1.0}};\)\)], \
"Input",
  CellLabel->"In[330]:="],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist, 
        refgraph];\)\)], "Input",
  CellLabel->"In[334]:="],

Cell["\<\
\tAs our final task in this notebook, we will make a movie of the \
subcritical pitchfork bifurcation.  We will center  the frames of the movie \
around \[Mu] = 0.  We make 41 frames at \[Mu]-intervals of 0.05, with \[Mu] \
running from -1 to 1.  We use the colored dots for equilibria as before.  We \
use a parameter-dependent time step so that we can use more time steps to \
capture the nonlinear spiral near \[Mu] = 0.  \
\>", "Text"],

Cell[BoxData[
    \(nsteps := 
      Module[{mew, ans}, mew = First[parmval]; \ 
        If[\((mew\  < \ \(-0.25\))\), \((ans\  = \ 
              500)\), \[IndentingNewLine]\((If[\((mew\  < \ 
                  0)\), \((ans\  = \ 
                  2000)\), \[IndentingNewLine]\((If[\((mew\  == \ 
                      0)\), \((ans\  = \ 
                      5000)\), \[IndentingNewLine]\((If[\((mew\  < \ 
                          0.1)\), \((ans\  = \ {500, 500, 500, 500, 500, 500, 
                            500, 500, 5000, 
                            5000})\), \[IndentingNewLine]\((If[\((mew\  < \ 
                              0.5)\), \[IndentingNewLine]\((ans\  = \ {500, 
                                500, 500, 500, 500, 500, 500, 500, 2000, 
                                2000})\), \((ans\  = \ 
                              500)\)])\)])\)])\)])\)]; ans]\)], "Input",
  CellLabel->"In[382]:="],

Cell[BoxData[
    \(\(parmlist = Table[i*0.05, {i, \(-20\), 20}];\)\)], "Input",
  CellLabel->"In[383]:="],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist, 
        refgraph];\)\)], "Input",
  CellLabel->"In[384]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{651, 686},
WindowMargins->{{40, Automatic}, {Automatic, 13}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000mfD<01T1T00000000000
00000000003oo`S7ag3oo`000QH00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 78, 4, 150, "Title"],
Cell[1820, 57, 64, 2, 28, "Input"],
Cell[1887, 61, 79, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[1991, 67, 40, 0, 63, "SectionFirst"],
Cell[2034, 69, 538, 9, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2609, 83, 52, 0, 63, "SectionFirst"],
Cell[2664, 85, 144, 5, 26, "Text"],
Cell[2811, 92, 606, 29, 26, "Text"],
Cell[3420, 123, 82, 3, 24, "Text"],
Cell[3505, 128, 269, 5, 65, "Input"],
Cell[3777, 135, 47, 0, 24, "Text"],
Cell[3827, 137, 69, 2, 28, "Input"],
Cell[3899, 141, 426, 15, 46, "Text"],
Cell[4328, 158, 228, 5, 48, "Input"],
Cell[4559, 165, 546, 16, 58, "Text"],
Cell[5108, 183, 73, 2, 28, "Input"],
Cell[5184, 187, 696, 10, 94, "Text"],
Cell[5883, 199, 456, 8, 92, "Input"],
Cell[6342, 209, 585, 12, 118, "Input"],
Cell[6930, 223, 135, 3, 28, "Input"],
Cell[7068, 228, 529, 12, 58, "Text"],
Cell[7600, 242, 397, 7, 52, "Text"],
Cell[8000, 251, 469, 8, 108, "Input"],
Cell[8472, 261, 86, 2, 28, "Input"],
Cell[8561, 265, 182, 3, 44, "Input"],
Cell[8746, 270, 244, 4, 44, "Input"],
Cell[8993, 276, 194, 5, 60, "Input"],
Cell[9190, 283, 142, 3, 44, "Input"],
Cell[9335, 288, 94, 2, 28, "Input"],
Cell[9432, 292, 113, 2, 28, "Input"],
Cell[9548, 296, 81, 2, 28, "Input"],
Cell[9632, 300, 100, 3, 24, "Text"],
Cell[9735, 305, 124, 3, 28, "Input"],
Cell[9862, 310, 129, 3, 28, "Input"],
Cell[9994, 315, 449, 7, 66, "Text"],
Cell[10446, 324, 917, 16, 156, "Input"],
Cell[11366, 342, 106, 2, 28, "Input"],
Cell[11475, 346, 129, 3, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

