(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8370,        290]*)
(*NotebookOutlinePosition[     34607,       1150]*)
(*  CellTagsIndexPosition[     34563,       1146]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
ME 406
Bifurcations I
Bifurcations in a Simple LInear System\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[325]:="],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input",
  CellLabel->"In[326]:="],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell[TextData[{
  "\tIn this series of notebooks on bifurcations, we look at simple examples \
of common bifurcations.  We follow in part the discussion given in Chapter 3 \
of ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontWeight->"Bold"],
  ", Steven Strogatz, Addison-Wesley, 1994.  The examples in all of the \
notebooks include the following:  saddle-node bifurcation, transcritical \
bifurcation, supercritical pitchfork bifurcation, subcritical pitchfork \
bifurcation, and Hopf bifurcation.  In this first notebook, we look at a very \
simple linear system with a single parameters.  As the parameter is changed, \
the equilibrium goes through the following sequence:  saddle, stable node, \
stable spiral.  We construct a movie of the change with the parameter of the \
system orbits."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Definition of the System", "SectionFirst"],

Cell[TextData[{
  "\tWe consider the following system, depending on one parameter ",
  StyleBox["a",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  ",
  StyleBox["ay",
    FontSlant->"Italic"],
  "  ,   ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  "  =  -",
  StyleBox["x",
    FontSlant->"Italic"],
  " -2",
  StyleBox["y",
    FontSlant->"Italic"],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "This system in general has a single equilibrium point at (0,0), the \
character of which depends on ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  We begin our analysis by defining the system for DynPac"
}], "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{a}]; slopevec = {a\ y, \(-x\)\  - 2\ y}; 
    sysname = "\<Bifurcation in Linear System\>";\)], "Input",
  CellLabel->"In[327]:="],

Cell["We give a name to the equilibrium point at the origin.", "Text"],

Cell[BoxData[
    \(\(eq = {0, 0};\)\)], "Input",
  CellLabel->"In[328]:="],

Cell[TextData[{
  "We also note that when ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 0, the system is degenerate, and the entire line ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "= -",
  StyleBox["x",
    FontSlant->"Italic"],
  "/2 is an equilibrium line.  This suggests that ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "= 0 is an important value in the bifurcation study.  We get the \
eigenvalues at the equilibrium."
}], "Text"],

Cell[BoxData[
    \(eigsys[eq]\)], "Input",
  CellLabel->"In[329]:="],

Cell[TextData[{
  "From the expressions for the eigenvalues, we conclude the following:  for \
",
  StyleBox["a",
    FontSlant->"Italic"],
  " < 0, the equilibrium is a saddle; for 0 < ",
  StyleBox["a",
    FontSlant->"Italic"],
  " < 1, the equilibrium is a stable node; for 1 < ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", the equilibrium is a stable spiral.  Thus the important bifurcations are \
at ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 0 (transition between saddle and node), and ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 1 (transition between node and spiral).  The most important bifurcation \
is at  ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 0 because it is a stability transition.  We now construct a sequence of \
phase plane plots showing the bifurcations.  Each plot shows a representative \
set of integral curves for a given value of ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  The connection between the plots is that the integral curves are always \
anchored at the same spots on the edges of the plotting window, and a \
specific curve color is associated with each anchor spot.  On the graphs, we \
place a black dot at each of the anchor points.  We set the parameters for \
integrating and plotting."
}], "Text"],

Cell[BoxData[
    \(plrange = {{\(-2\), 2}, {\(-2\), 2}}; asprat = 1; labshift = 18; 
    imsize = 360;\)], "Input",
  CellLabel->"In[330]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/2};\)], "Input",
  CellLabel->"In[331]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 800; bothdirflag = True;\)], "Input",
  CellLabel->"In[332]:="],

Cell[BoxData[
    \(rangeflag = True; 
    ranger = {{\(-2.1\), 2.1}, {\(-2.1\), 2.1}};\)], "Input",
  CellLabel->"In[333]:="],

Cell[BoxData[
    \(\(initset = {{1, 0}, {1, 1}, {0, 1}, {\(-1\), 1}, {\(-1\), 
            0}, {\(-1\), \(-1\)}, {0, \(-1\)}, {1, \(-1\)}};\)\)], "Input",
  CellLabel->"In[334]:="],

Cell[TextData[{
  "Now we specify the list of ",
  StyleBox["a",
    FontSlant->"Italic"],
  "-values for which the portraits are to be constructed."
}], "Text"],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input",
  CellLabel->"In[335]:="],

Cell[BoxData[
    \(\(display\  = \ False;\)\)], "Input",
  CellLabel->"In[336]:="],

Cell[BoxData[
    \(\(ptsize = 0.02;\)\)], "Input",
  CellLabel->"In[337]:="],

Cell[BoxData[
    \(\(refgraph = dots[initset];\)\)], "Input",
  CellLabel->"In[338]:="],

Cell[BoxData[
    \(\(display = True;\)\)], "Input",
  CellLabel->"In[339]:="],

Cell[BoxData[
    \(\(parmlist = Table[{i/10. }, {i, \(-20\), 20}];\)\)], "Input",
  CellLabel->"In[340]:="],

Cell[BoxData[
    \(\(setcolor[{Red, Blue, Green, Cyan, Magenta, SeaGreen, BurntUmber, 
          Orange}];\)\)], "Input",
  CellLabel->"In[341]:="],

Cell["\<\
Now we use the function bifurc to  construct a long sequence \
suitable for a movie.\
\>", "Text"],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist, 
        refgraph];\)\)], "Input",
  CellLabel->"In[342]:="],

Cell[TextData[{
  "The movie sequence is too long to print out, so we construct a second, \
much shorter sequence with the following parameter values:  ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = -1 (saddle), ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 0 (saddle-node transition), ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 0.5 (stable node), ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 1 (spiral-node transition), and ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 2 (spiral)."
}], "Text"],

Cell[BoxData[
    \(\(parmlist = {{\(-1\)}, {0}, {0.5}, {1}, {2}};\)\)], "Input",
  CellLabel->"In[343]:="],

Cell[BoxData[
    \(\(bifurc[initset, t0, h, nsteps, 1, 2, parmlist, 
        refgraph];\)\)], "Input",
  CellLabel->"In[345]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{651, 686},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000mfD<01T1T00000000000
00000000003oo`QFO>3oo`000QH00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 85, 4, 186, "Title"],
Cell[1827, 57, 64, 2, 28, "Input"],
Cell[1894, 61, 79, 2, 28, "Input"],

Cell[CellGroupData[{
Cell[1998, 67, 40, 0, 63, "SectionFirst"],
Cell[2041, 69, 813, 14, 96, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2891, 88, 52, 0, 63, "SectionFirst"],
Cell[2946, 90, 144, 5, 26, "Text"],
Cell[3093, 97, 345, 17, 26, "Text"],
Cell[3441, 116, 238, 6, 40, "Text"],
Cell[3682, 124, 177, 3, 44, "Input"],
Cell[3862, 129, 70, 0, 24, "Text"],
Cell[3935, 131, 75, 2, 28, "Input"],
Cell[4013, 135, 448, 15, 42, "Text"],
Cell[4464, 152, 69, 2, 28, "Input"],
Cell[4536, 156, 1277, 32, 132, "Text"],
Cell[5816, 190, 142, 3, 44, "Input"],
Cell[5961, 195, 94, 2, 28, "Input"],
Cell[6058, 199, 112, 2, 28, "Input"],
Cell[6173, 203, 126, 3, 28, "Input"],
Cell[6302, 208, 181, 3, 44, "Input"],
Cell[6486, 213, 161, 5, 26, "Text"],
Cell[6650, 220, 81, 2, 28, "Input"],
Cell[6734, 224, 83, 2, 28, "Input"],
Cell[6820, 228, 77, 2, 28, "Input"],
Cell[6900, 232, 88, 2, 28, "Input"],
Cell[6991, 236, 78, 2, 28, "Input"],
Cell[7072, 240, 108, 2, 28, "Input"],
Cell[7183, 244, 148, 3, 44, "Input"],
Cell[7334, 249, 108, 3, 24, "Text"],
Cell[7445, 254, 129, 3, 28, "Input"],
Cell[7577, 259, 523, 18, 54, "Text"],
Cell[8103, 279, 107, 2, 28, "Input"],
Cell[8213, 283, 129, 3, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

