(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13203,        511]*)
(*NotebookOutlinePosition[     39440,       1371]*)
(*  CellTagsIndexPosition[     39396,       1367]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Example of a Phase Portrait with Multiple Equilibria", "Title"],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[669]:="],

Cell[BoxData[
    \(plotreset; intreset;\)], "Input",
  CellLabel->"In[670]:="],

Cell["\<\
\tIn this notebook, we construct a phase portrait for the sytem \
given below.  \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  -",
  StyleBox["y",
    FontSlant->"Italic"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`x\^4\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`3\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`y\^4\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`3\/4\)]],
  Cell[BoxData[
      \(TraditionalForm\`y\^5\)]],
  " ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  "  =  4",
  StyleBox["x ",
    FontSlant->"Italic"],
  "- 6",
  Cell[BoxData[
      \(TraditionalForm\`y\^3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4\)]],
  "+3",
  Cell[BoxData[
      \(TraditionalForm\`y\^4\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`x\^5\)]],
  " ."
}], "NumberedEquation",
  TextAlignment->Center],

Cell["We begin by defining the system for DynPac.", "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{}];\)], "Input",
  CellLabel->"In[671]:="],

Cell[BoxData[
    \(\(slopevec = {\(-y\) - \(1\/2\) x\^3\  + \ \(1\/2\) x\^4 + \(3\/2\) 
              y\^4 - \(3\/4\) y\^5, 
          4\ x - 6\ y\^3 + x\^4 + 3\ y\^4 - x\^5};\)\)], "Input",
  CellLabel->"In[672]:="],

Cell[BoxData[
    \(\(sysname = "\<Portrait\>";\)\)], "Input",
  CellLabel->"In[673]:="],

Cell["We use nfindpolyeq to look for equilibrium states.", "Text"],

Cell[BoxData[
    \(eqstates = nfindpolyeq\)], "Input",
  CellLabel->"In[674]:="],

Cell["We have found five real equilibria.  We name them.", "Text"],

Cell[BoxData[
    \(eq1 = eqstates[\([1]\)]\)], "Input",
  CellLabel->"In[675]:="],

Cell[BoxData[
    \(eq2 = \ eqstates[\([4]\)]\)], "Input",
  CellLabel->"In[676]:="],

Cell[BoxData[
    \(eq3\  = \ eqstates[\([5]\)]\)], "Input",
  CellLabel->"In[677]:="],

Cell[BoxData[
    \(eq4 = eqstates[\([14]\)]\)], "Input",
  CellLabel->"In[678]:="],

Cell[BoxData[
    \(eq5 = eqstates[\([25]\)]\)], "Input",
  CellLabel->"In[679]:="],

Cell["Now we classify all of these equilibria.", "Text"],

Cell[BoxData[
    \(classify2D[eq1]\)], "Input",
  CellLabel->"In[680]:="],

Cell[BoxData[
    \(classify2D[eq2]\)], "Input",
  CellLabel->"In[681]:="],

Cell[BoxData[
    \(classify2D[eq3]\)], "Input",
  CellLabel->"In[682]:="],

Cell[BoxData[
    \(classify2D[eq4]\)], "Input",
  CellLabel->"In[683]:="],

Cell[BoxData[
    \(classify2D[eq5]\)], "Input",
  CellLabel->"In[684]:="],

Cell["\<\
We see that four of the equilibria are unstable, and the fifth -- \
the origin -- has a stability which is not determined by linearization.  As \
we showed earlier, the stability of the equilibrium at the origin is \
established by a Liapunov function, namely\
\>", "Text"],

Cell[BoxData[
    \(\(Vlap = 4\ x\^2\  + \ y\^2;\)\)], "Input",
  CellLabel->"In[685]:="],

Cell["The orbital derivative of Vlap is", "Text"],

Cell[BoxData[
    \(Simplify[orbdt[Vlap]]\)], "Input",
  CellLabel->"In[686]:="],

Cell["\<\
and this is clearly negative definite in a neighborhood of the \
origin.  \
\>", "Text"],

Cell["\<\
\tWe begin the phase portrait by constructing the stable and \
unstable manifolds about the saddle points.  We set the plotting \
window:\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{\(-4.1\), 4.1}, {\(-4.1\), 4.1}};\)\)], "Input",
  CellLabel->"In[687]:="],

Cell["\<\
We set range checking and integration in only one time direction.\
\
\>", "Text"],

Cell[BoxData[
    \(rangeflag = True; ranger = plrange; bothdirflag\  = \ False;\)], "Input",\

  CellLabel->"In[688]:="],

Cell[BoxData[
    \(eig1 = eigsys[eq1]\)], "Input",
  CellLabel->"In[689]:="],

Cell[BoxData[
    \(eigvec11 = First[Last[eig1]]\)], "Input",
  CellLabel->"In[690]:="],

Cell[BoxData[
    \(eigvec12 = Last[Last[eig1]]\)], "Input",
  CellLabel->"In[691]:="],

Cell["\<\
Notice how different the eigenvalues are in magnitude.  Motion out \
along the unstable manifold will be much more rapid than motion in along the \
stable manifold.  We construct the unstable manifold first.\
\>", "Text"],

Cell[BoxData[
    \(\(\[CurlyEpsilon] = 0.005;\)\)], "Input",
  CellLabel->"In[692]:="],

Cell[BoxData[
    \(\(initset = {eq1 + \[CurlyEpsilon]*eigvec11, 
          eq1 - \[CurlyEpsilon]*eigvec11};\)\)], "Input",
  CellLabel->"In[693]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.002; nsteps = 5000;\)], "Input",
  CellLabel->"In[694]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/3};\)], "Input",
  CellLabel->"In[695]:="],

Cell[BoxData[
    \(\(labshift = 20;\)\)], "Input",
  CellLabel->"In[696]:="],

Cell[BoxData[
    \(\(graph11 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[697]:="],

Cell["Now the stable manifold.", "Text"],

Cell[BoxData[
    \(\(initset = {eq1 + \[CurlyEpsilon]*eigvec12, 
          eq1 - \[CurlyEpsilon]*eigvec12};\)\)], "Input",
  CellLabel->"In[698]:="],

Cell[BoxData[
    \(t0 = 0.0; h = \(-0.02\); nsteps = 5000;\)], "Input",
  CellLabel->"In[699]:="],

Cell[BoxData[
    \(\(arrowvec = {4/5};\)\)], "Input",
  CellLabel->"In[700]:="],

Cell[BoxData[
    \(\(graph12 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[701]:="],

Cell["Now we look at the second equilibrium, eq2.", "Text"],

Cell[BoxData[
    \(eig2 = eigsys[eq2]\)], "Input",
  CellLabel->"In[702]:="],

Cell[BoxData[
    \(eigvec21 = First[Last[eig2]]\)], "Input",
  CellLabel->"In[703]:="],

Cell[BoxData[
    \(eigvec22 = Last[Last[eig2]]\)], "Input",
  CellLabel->"In[704]:="],

Cell["First the unstable manifold.", "Text"],

Cell[BoxData[
    \(\(initset = {eq2 + \[CurlyEpsilon]*eigvec21, 
          eq2 - \[CurlyEpsilon]*eigvec21};\)\)], "Input",
  CellLabel->"In[705]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.002; nsteps = 5000;\)], "Input",
  CellLabel->"In[706]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/2};\)], "Input",
  CellLabel->"In[707]:="],

Cell[BoxData[
    \(\(graph21 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[708]:="],

Cell["Now the stable manifold.", "Text"],

Cell[BoxData[
    \(\(initset = {eq2 + \[CurlyEpsilon]*eigvec22, 
          eq2 - \[CurlyEpsilon]*eigvec22};\)\)], "Input",
  CellLabel->"In[709]:="],

Cell[BoxData[
    \(t0 = 0.0; h = \(-0.002\); nsteps = 5000;\)], "Input",
  CellLabel->"In[710]:="],

Cell[BoxData[
    \(\(graph22 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[711]:="],

Cell["\tNext we look at the last saddle, eq4.", "Text"],

Cell[BoxData[
    \(eig4 = eigsys[eq4]\)], "Input",
  CellLabel->"In[712]:="],

Cell[BoxData[
    \(eigvec41 = First[Last[eig4]]\)], "Input",
  CellLabel->"In[713]:="],

Cell[BoxData[
    \(eigvec42 = Last[Last[eig4]]\)], "Input",
  CellLabel->"In[714]:="],

Cell["First the unstable manifold.", "Text"],

Cell[BoxData[
    \(\(initset = {eq4 + \[CurlyEpsilon]*eigvec42, 
          eq4 - \[CurlyEpsilon]*eigvec42};\)\)], "Input",
  CellLabel->"In[715]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.002; nsteps = 5000;\)], "Input",
  CellLabel->"In[716]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/2};\)], "Input",
  CellLabel->"In[717]:="],

Cell[BoxData[
    \(\(graph42 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[718]:="],

Cell["Now the stable manifold.", "Text"],

Cell[BoxData[
    \(\(initset = {eq4 + \[CurlyEpsilon]*eigvec41, 
          eq4 - \[CurlyEpsilon]*eigvec41};\)\)], "Input",
  CellLabel->"In[719]:="],

Cell[BoxData[
    \(t0 = 0.0; h = \(-0.002\); nsteps = 5000;\)], "Input",
  CellLabel->"In[720]:="],

Cell[BoxData[
    \(\(graph41 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[721]:="],

Cell["\<\
\tBefore looking at the unstable node eq3 and the stable spiral at \
the origin, we first combine the graphs we have so far.\
\>", "Text"],

Cell[BoxData[
    \(\(firstbigraph = 
        show[graph11, graph12, graph21, graph22, graph41, 
          graph42];\)\)], "Input",
  CellLabel->"In[722]:="],

Cell["\<\
\tNow we look at the unstable node eq3.  Some of the integral \
curves leaving this point have already been constructed.  A little \
experimenting shows that one more curve is useful.\
\>", "Text"],

Cell[BoxData[
    \(eig3 = eigsys[eq3]\)], "Input",
  CellLabel->"In[723]:="],

Cell[BoxData[
    \(eigvec31 = First[Last[eig3]]\)], "Input",
  CellLabel->"In[724]:="],

Cell[BoxData[
    \(eigvec32 = Last[Last[eig3]]\)], "Input",
  CellLabel->"In[725]:="],

Cell[BoxData[
    \(\(initset = {eq3 + \[CurlyEpsilon]*eigvec32};\)\)], "Input",
  CellLabel->"In[726]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.002; nsteps = 5000;\)], "Input",
  CellLabel->"In[727]:="],

Cell[BoxData[
    \(\(graph32 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[728]:="],

Cell[BoxData[
    \(\(bigraph = show[firstbigraph, graph32];\)\)], "Input",
  CellLabel->"In[729]:="],

Cell["\t We add a few more orbits to fill in the picture.  ", "Text"],

Cell[BoxData[
    \(\(initset = {{3, 1.75}, {2, 4}, {2, \(-3\)}, {\(-3\), 0}, {\(-4\), 
            2}, {\(-2\), \(-2\)}};\)\)], "Input",
  CellLabel->"In[730]:="],

Cell[BoxData[
    \(t0 = 0.0; h = 0.00025; nsteps = 5000;\)], "Input",
  CellLabel->"In[731]:="],

Cell[BoxData[
    \(\(bothdirflag\  = \ True;\)\)], "Input",
  CellLabel->"In[732]:="],

Cell[BoxData[
    \(\(arrowvec = {3/5};\)\)], "Input",
  CellLabel->"In[733]:="],

Cell[BoxData[
    \(\(lastpiece = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[734]:="],

Cell["Now we put the pictures together.", "Text"],

Cell[BoxData[
    \(\(newbigraph\  = \ show[bigraph, lastpiece];\)\)], "Input",
  CellLabel->"In[735]:="],

Cell["One more orbit.", "Text"],

Cell[BoxData[
    \(bothdirflag = True; init = {0, 1.25}; h = 0.00025; nsteps = 4000; 
    t0 = 0.0;\)], "Input",
  CellLabel->"In[736]:="],

Cell[BoxData[
    \(\(solast = integrate[init, t0, h, nsteps];\)\)], "Input",
  CellLabel->"In[737]:="],

Cell[BoxData[
    \(\(lastpiece = phaser[solast];\)\)], "Input",
  CellLabel->"In[738]:="],

Cell[BoxData[
    \(\(newbigraph2 = show[newbigraph, lastpiece];\)\)], "Input",
  CellLabel->"In[739]:="],

Cell["\<\
As a final touch, we place a blue dot on the stable equilibrium and \
red dots on the saddles, and a green dot on the unstable node.\
\>", "Text"],

Cell[BoxData[
    \(\(display = False;\)\)], "Input",
  CellLabel->"In[740]:="],

Cell[BoxData[
    \(\(setcolor[{Red, Blue, Green}];\)\)], "Input",
  CellLabel->"In[741]:="],

Cell[BoxData[
    \(\(ptsize = 0.03;\)\)], "Input",
  CellLabel->"In[742]:="],

Cell[BoxData[
    \(\(dotgraph1 = dots[{eq1, eq2, eq4}];\)\)], "Input",
  CellLabel->"In[743]:="],

Cell[BoxData[
    \(\(dotgraph2 = dots[{eq5}];\)\)], "Input",
  CellLabel->"In[744]:="],

Cell[BoxData[
    \(\(dotgraph3 = dots[{eq3}];\)\)], "Input",
  CellLabel->"In[745]:="],

Cell[BoxData[
    \(\(display\  = \ True;\)\)], "Input",
  CellLabel->"In[746]:="],

Cell[BoxData[
    \(\(show[newbigraph2, dotgraph1, dotgraph2, dotgraph3];\)\)], "Input",
  CellLabel->"In[748]:="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{651, 686},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@UM750000000000md0801T1T00000000000
00000000003oo000003oo0004G<00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 69, 0, 114, "Title"],
Cell[1811, 53, 64, 2, 28, "Input"],
Cell[1878, 57, 79, 2, 28, "Input"],
Cell[1960, 61, 104, 3, 24, "Text"],
Cell[2067, 66, 981, 46, 30, "NumberedEquation"],
Cell[3051, 114, 59, 0, 24, "Text"],
Cell[3113, 116, 89, 2, 28, "Input"],
Cell[3205, 120, 217, 4, 43, "Input"],
Cell[3425, 126, 88, 2, 28, "Input"],
Cell[3516, 130, 66, 0, 24, "Text"],
Cell[3585, 132, 81, 2, 28, "Input"],
Cell[3669, 136, 66, 0, 24, "Text"],
Cell[3738, 138, 82, 2, 28, "Input"],
Cell[3823, 142, 84, 2, 28, "Input"],
Cell[3910, 146, 86, 2, 28, "Input"],
Cell[3999, 150, 83, 2, 28, "Input"],
Cell[4085, 154, 83, 2, 28, "Input"],
Cell[4171, 158, 56, 0, 24, "Text"],
Cell[4230, 160, 74, 2, 28, "Input"],
Cell[4307, 164, 74, 2, 28, "Input"],
Cell[4384, 168, 74, 2, 28, "Input"],
Cell[4461, 172, 74, 2, 28, "Input"],
Cell[4538, 176, 74, 2, 28, "Input"],
Cell[4615, 180, 283, 5, 38, "Text"],
Cell[4901, 187, 89, 2, 30, "Input"],
Cell[4993, 191, 49, 0, 24, "Text"],
Cell[5045, 193, 80, 2, 28, "Input"],
Cell[5128, 197, 98, 3, 24, "Text"],
Cell[5229, 202, 161, 4, 38, "Text"],
Cell[5393, 208, 108, 2, 28, "Input"],
Cell[5504, 212, 91, 3, 24, "Text"],
Cell[5598, 217, 121, 3, 28, "Input"],
Cell[5722, 222, 77, 2, 28, "Input"],
Cell[5802, 226, 87, 2, 28, "Input"],
Cell[5892, 230, 86, 2, 28, "Input"],
Cell[5981, 234, 231, 4, 38, "Text"],
Cell[6215, 240, 87, 2, 28, "Input"],
Cell[6305, 244, 149, 3, 28, "Input"],
Cell[6457, 249, 94, 2, 28, "Input"],
Cell[6554, 253, 94, 2, 28, "Input"],
Cell[6651, 257, 77, 2, 28, "Input"],
Cell[6731, 261, 112, 2, 28, "Input"],
Cell[6846, 265, 40, 0, 24, "Text"],
Cell[6889, 267, 149, 3, 28, "Input"],
Cell[7041, 272, 98, 2, 28, "Input"],
Cell[7142, 276, 80, 2, 28, "Input"],
Cell[7225, 280, 112, 2, 28, "Input"],
Cell[7340, 284, 59, 0, 24, "Text"],
Cell[7402, 286, 77, 2, 28, "Input"],
Cell[7482, 290, 87, 2, 28, "Input"],
Cell[7572, 294, 86, 2, 28, "Input"],
Cell[7661, 298, 44, 0, 24, "Text"],
Cell[7708, 300, 149, 3, 28, "Input"],
Cell[7860, 305, 94, 2, 28, "Input"],
Cell[7957, 309, 94, 2, 28, "Input"],
Cell[8054, 313, 112, 2, 28, "Input"],
Cell[8169, 317, 40, 0, 24, "Text"],
Cell[8212, 319, 149, 3, 28, "Input"],
Cell[8364, 324, 99, 2, 28, "Input"],
Cell[8466, 328, 112, 2, 28, "Input"],
Cell[8581, 332, 55, 0, 24, "Text"],
Cell[8639, 334, 77, 2, 28, "Input"],
Cell[8719, 338, 87, 2, 28, "Input"],
Cell[8809, 342, 86, 2, 28, "Input"],
Cell[8898, 346, 44, 0, 24, "Text"],
Cell[8945, 348, 149, 3, 28, "Input"],
Cell[9097, 353, 94, 2, 28, "Input"],
Cell[9194, 357, 94, 2, 28, "Input"],
Cell[9291, 361, 112, 2, 28, "Input"],
Cell[9406, 365, 40, 0, 24, "Text"],
Cell[9449, 367, 149, 3, 28, "Input"],
Cell[9601, 372, 99, 2, 28, "Input"],
Cell[9703, 376, 112, 2, 28, "Input"],
Cell[9818, 380, 148, 3, 38, "Text"],
Cell[9969, 385, 157, 4, 44, "Input"],
Cell[10129, 391, 207, 4, 38, "Text"],
Cell[10339, 397, 77, 2, 28, "Input"],
Cell[10419, 401, 87, 2, 28, "Input"],
Cell[10509, 405, 86, 2, 28, "Input"],
Cell[10598, 409, 106, 2, 28, "Input"],
Cell[10707, 413, 94, 2, 28, "Input"],
Cell[10804, 417, 112, 2, 28, "Input"],
Cell[10919, 421, 101, 2, 28, "Input"],
Cell[11023, 425, 69, 0, 24, "Text"],
Cell[11095, 427, 163, 3, 28, "Input"],
Cell[11261, 432, 96, 2, 28, "Input"],
Cell[11360, 436, 86, 2, 28, "Input"],
Cell[11449, 440, 80, 2, 28, "Input"],
Cell[11532, 444, 114, 2, 28, "Input"],
Cell[11649, 448, 49, 0, 24, "Text"],
Cell[11701, 450, 105, 2, 28, "Input"],
Cell[11809, 454, 31, 0, 24, "Text"],
Cell[11843, 456, 139, 3, 44, "Input"],
Cell[11985, 461, 103, 2, 28, "Input"],
Cell[12091, 465, 90, 2, 28, "Input"],
Cell[12184, 469, 105, 2, 28, "Input"],
Cell[12292, 473, 156, 3, 38, "Text"],
Cell[12451, 478, 79, 2, 28, "Input"],
Cell[12533, 482, 92, 2, 28, "Input"],
Cell[12628, 486, 77, 2, 28, "Input"],
Cell[12708, 490, 97, 2, 28, "Input"],
Cell[12808, 494, 87, 2, 28, "Input"],
Cell[12898, 498, 87, 2, 28, "Input"],
Cell[12988, 502, 82, 2, 28, "Input"],
Cell[13073, 506, 114, 2, 28, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

