(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15551,        540]*)
(*NotebookOutlinePosition[     41788,       1400]*)
(*  CellTagsIndexPosition[     41744,       1396]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Orbital Stability", "Title"],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[267]:="],

Cell[BoxData[
    \(plotreset; intreset;\)], "Input"],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell[TextData[{
  "\tIn this notebook we develop some examples which illustrate the concept \
of orbital stability.  We begin by reviewing the \"standard\" definition of \
stability, which is usually called Liapunov stability.  The system under \
consideration is an autonomous set of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " first order differential equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "."], TraditionalForm]]],
  " = ",
  StyleBox["F",
    FontWeight->"Bold"],
  "(",
  StyleBox["X",
    FontWeight->"Bold"],
  ")  ,"
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is the state vector and ",
  StyleBox["F",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "is the slope function.  "
}], "Text"],

Cell[TextData[{
  "\tHere is the definition of Liapunov stability.  Given a solution ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") with a given initial value ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  "), we say that ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "is stable if, given any \[Epsilon] > 0, we can find a \[Delta] > 0 such \
that for any solution ",
  StyleBox["X",
    FontWeight->"Bold"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") satisfying \[VerticalSeparator]\[VerticalSeparator]",
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ") - ",
  Cell[BoxData[
      FormBox[
        StyleBox["X",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ")\[VerticalSeparator]\[VerticalSeparator] < \[Delta], it is true for all \
",
  StyleBox["t",
    FontSlant->"Italic"],
  " \[GreaterSlantEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  " that \[VerticalSeparator]\[VerticalSeparator]",
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ") - ",
  Cell[BoxData[
      FormBox[
        StyleBox["X",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ")\[VerticalSeparator]\[VerticalSeparator] < \[Epsilon].  We call a stable \
solution ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "  strictly stable if there exists an \[Eta] > 0 such that ",
  "\[VerticalSeparator]\[VerticalSeparator]",
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ") - ",
  Cell[BoxData[
      FormBox[
        StyleBox["X",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ")\[VerticalSeparator]\[VerticalSeparator] < \[Eta] implies that ",
  "\[VerticalSeparator]\[VerticalSeparator]",
  " ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "*"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ") - ",
  Cell[BoxData[
      FormBox[
        StyleBox["X",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "(",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ")\[VerticalSeparator]\[VerticalSeparator] goes to zero as ",
  StyleBox["t\[ShortRightArrow] \[Infinity]",
    FontSlant->"Italic"],
  " .",
  "   "
}], "Text"],

Cell["\<\
\tThis way of defining stability means that neighboring solutions \
evaluated at the same time must remain neighboring.  We shall see below that \
for periodic solutions this is in general too restrictive a definition of \
stability. A more appropriate definition of stability for such systems will \
be given after our first example.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Example 1 - A Nonlinear Center", "SectionFirst"],

Cell["\<\
\tWe consider Duffing's equation with a hard spring, a parameter,  \
and no damping:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " + x + ",
  StyleBox["a",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  "= 0.  "
}], "NumberedEquation",
  TextAlignment->Center],

Cell["  We define the system for DynPac.", "Text"],

Cell[BoxData[
    \(setstate[{x, y}]; \ setparm[{a}]; slopevec = {y, \(-x\)\  - a\ x\^3}; \ 
    sysname = "\<Duffing\>";\)], "Input",
  CellLabel->"In[268]:="],

Cell["We set a parameter value of 0.5.", "Text"],

Cell[BoxData[
    \(\(parmval = {0.5};\)\)], "Input",
  CellLabel->"In[269]:="],

Cell[TextData[{
  "\tAs we already know, all of the solutions of this equation for ",
  StyleBox["a",
    FontSlant->"Italic"],
  " \[GreaterEqual] 0 are periodic.  As an example, let's find and plot the \
solution with intial conditions (1.5, 0)."
}], "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 300; initvec = {1.5, 0};\)], "Input",
  CellLabel->"In[270]:="],

Cell[BoxData[
    \(\(sol1 = integrate[initvec, t0, h, nsteps];\)\)], "Input",
  CellLabel->"In[271]:="],

Cell[BoxData[
    \(asprat = 1.0; \ 
    plrange = {{\(-2.2\), 2.2}, {\(-2.2\), 2.2}};\)], "Input",
  CellLabel->"In[272]:="],

Cell[BoxData[
    \(\(labshift = 10;\)\)], "Input",
  CellLabel->"In[273]:="],

Cell[BoxData[
    \(\(graph1 = phaser[sol1];\)\)], "Input",
  CellLabel->"In[274]:="],

Cell["We find the period of the solution:", "Text"],

Cell[BoxData[
    \(period[sol1]\)], "Input",
  CellLabel->"In[275]:="],

Cell["\<\
Now consider a nearby solution, obtained by altering the initial \
conditions slightly.\
\>", "Text"],

Cell[BoxData[
    \(initvec = {1.6, 0}; 
    sol2 = integrate[initvec, t0, h, nsteps];\)], "Input",
  CellLabel->"In[276]:="],

Cell[BoxData[
    \(\(graph2 = phaser[sol2];\)\)], "Input",
  CellLabel->"In[277]:="],

Cell["We show the two graphs together.", "Text"],

Cell[BoxData[
    \(\(graph3 = show[graph1, graph2];\)\)], "Input",
  CellLabel->"In[278]:="],

Cell[TextData[{
  "The orbits are everywhere close, and we could have made them even closer \
had we chosen the initial values of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " to be even closer.  This is a situation which would be reasonable to call \
stable.  However, by our earlier definition of stability, these solutions are \
unstable.  It is because of the period.  For the second solution we have  "
}], "Text"],

Cell[BoxData[
    \(period[sol2]\)], "Input",
  CellLabel->"In[279]:="],

Cell["\<\
Thus the periods differ slightly.  Points on neighboring orbits \
will not remain close, because they go around the orbits in different times.  \
Let's make a movie to illustrate that more graphically.  We use the function \
phaseseq.\
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Black, Black}];\)\)], "Input",
  CellLabel->"In[280]:="],

Cell[BoxData[
    \(\(phaseseq[{{1.5, 0}, {1.6, 0}}, t0, h, 10, 160, 1, 2, 
        graph3];\)\)], "Input",
  CellLabel->"In[281]:="],

Cell[TextData[{
  "\tThe situation just illustrated clearly calls for an alternative \
definition of stability.  Even though the two solutions at any given time do \
not remain close, the two orbits do remain close in space.  The concept of \
orbital stability is appropriate to describe this situation.  A solution ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["X",
              FontWeight->"Bold"], "*"],
          FontSlant->"Plain"], TraditionalForm]],
    FontSlant->"Italic"],
  "with orbit ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\^*\)\)]],
  " is said to be orbitally stable if given any \[Epsilon] > 0, we can find a \
\[Delta] such that for any solution ",
  StyleBox["X",
    FontWeight->"Bold"],
  " starting at ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  "a distance less than",
  " \[Delta] from \[CapitalGamma]",
  ", it is true that for all ",
  StyleBox["t",
    FontSlant->"Italic"],
  " \[GreaterEqual] ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ", the distance between the solution ",
  StyleBox["X",
    FontWeight->"Bold"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\^*\)\)]],
  "remains less than \[Epsilon].  Although this is intuitively clear, one \
needs to define precisely the concept of the distance between a  solution and \
an orbit.  This is done, for example, in ",
  StyleBox["Nonlinear Ordinary Differential Equations",
    FontWeight->"Bold"],
  ", by D.W. Jordn and P. Smith, second edition, Oxford University Press, \
1987, Chapter 8, or ",
  StyleBox["Dynamics and Bifurcations",
    FontWeight->"Bold"],
  ",  J. Hale and H. Ko\[CCedilla]ak, Springer-Verlag, 1991, Chapter 11.   It \
is clear that by this new definition, solutions of Duffing's equation are \
stable."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  Limit Cycles", "SectionFirst"],

Cell[TextData[{
  "\tWith limit cycles, the concept of Liapunov stability may apply, but not \
strict Liapunov stability.  To see that, consider two initial points both on \
the cycle.  When the points have gone through one cycle, they will be exactly \
the same distance apart as when they started, so the distance between the two \
solutions will not go to zero as ",
  StyleBox["t",
    FontSlant->"Italic"],
  " \[ShortRightArrow] \[Infinity].  With slight variations, the same \
situation is true for one initial point on the cycle and one just off the \
cycle.  The orbit of the intial point just off the cycle will approach the \
cycle for large ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", but in general there will always be a phase difference between the two \
points.  Hale and Ko\[CCedilla]ak (Chapter 11 -- cited above) give an \
excellent discussion of these concepts, along with definitions of three \
levels of orbital stability.  We will content ourselves here with \
constructing two movies which illustrate some of the concepts for stable \
limit cycles.  We use the van der Pol cycle.  We will first construct a movie \
showing the motion of two phase points which start with a small separation on \
the limit cycle.  Then we will construct a movie showing one phase point \
starting on the cycle, and one phase point starting just inside the cycle.  "
}], "Text"],

Cell["\tWe begin by defining the system for DynPac.", "Text"],

Cell[BoxData[{
    \(setstate[{x, y}]; setparm[{\[Mu]}]; 
    slopevec = {y, \(-x\) - \[Mu]*\((x\^2 - 1)\)*
            y};\), "\[IndentingNewLine]", 
    \(sysname = "\<van der Pol\>"; \ parmval\  = \ {1};\)}], "Input",
  CellLabel->"In[282]:="],

Cell["We construct a  graph of the limit cycle.", "Text"],

Cell[BoxData[
    \(initvec = {2, 0}; t0 = 0.0; h = 0.02; nsteps = 337;\)], "Input",
  CellLabel->"In[284]:="],

Cell[BoxData[
    \(\(sol4 = limcyc[initvec, t0, h, nsteps];\)\)], "Input",
  CellLabel->"In[285]:="],

Cell[BoxData[
    \(plrange = {{\(-3\), 3}, {\(-3\), 3}}; asprat = 1.0; 
    labshift = 12;\)], "Input",
  CellLabel->"In[286]:="],

Cell[BoxData[
    \(\(graph4 = phaser[sol4];\)\)], "Input",
  CellLabel->"In[287]:="],

Cell[BoxData[
    \(period[sol4]\)], "Input",
  CellLabel->"In[288]:="],

Cell[BoxData[
    \(points = Take[sol4, \(-10\)]\)], "Input",
  CellLabel->"In[289]:="],

Cell[BoxData[
    \(initvec1 = Drop[points[\([1]\)], 1]\)], "Input",
  CellLabel->"In[290]:="],

Cell[BoxData[
    \(initvec2 = Drop[points[\([10]\)], 1]\)], "Input",
  CellLabel->"In[291]:="],

Cell["\<\
Now we construct a phase sequence showing two periods, using the \
above two initial conditions.\
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Black, Black}];\)\)], "Input",
  CellLabel->"In[292]:="],

Cell[BoxData[
    \(\(phaseseq[{initvec1, initvec2}, t0, h, 5, 133, 1, 2, 
        graph4];\)\)], "Input",
  CellLabel->"In[293]:="],

Cell["\<\
Now we construct the second movie.  This time one initial point is \
displaced to the interior of the cycle by 0.2 in x.\
\>", "Text"],

Cell[BoxData[
    \(initvec2 = initvec1 - {0.2, 0}\)], "Input",
  CellLabel->"In[294]:="],

Cell[BoxData[
    \(\(setcolor[{Red, Black, Black}];\)\)], "Input",
  CellLabel->"In[295]:="],

Cell[BoxData[
    \(\(phaseseq[{initvec1, initvec2}, t0, h, 5, 133, 1, 2, 
        graph4];\)\)], "Input",
  CellLabel->"In[296]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{744, 681},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000mdD<01T1T00000000000
00000000003omPN2FC3omP004G<00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 34, 0, 78, "Title"],
Cell[1776, 53, 64, 2, 28, "Input"],
Cell[1843, 57, 53, 1, 28, "Input"],

Cell[CellGroupData[{
Cell[1921, 62, 40, 0, 63, "SectionFirst"],
Cell[1964, 64, 382, 8, 54, "Text"],
Cell[2349, 74, 340, 15, 26, "NumberedEquation"],
Cell[2692, 91, 247, 11, 26, "Text"],
Cell[2942, 104, 3721, 146, 73, "Text"],
Cell[6666, 252, 358, 6, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7061, 263, 58, 0, 63, "SectionFirst"],
Cell[7122, 265, 108, 3, 24, "Text"],
Cell[7233, 270, 250, 11, 26, "NumberedEquation"],
Cell[7486, 283, 50, 0, 24, "Text"],
Cell[7539, 285, 160, 3, 49, "Input"],
Cell[7702, 290, 48, 0, 24, "Text"],
Cell[7753, 292, 79, 2, 28, "Input"],
Cell[7835, 296, 260, 6, 40, "Text"],
Cell[8098, 304, 112, 2, 28, "Input"],
Cell[8213, 308, 104, 2, 28, "Input"],
Cell[8320, 312, 125, 3, 28, "Input"],
Cell[8448, 317, 77, 2, 28, "Input"],
Cell[8528, 321, 85, 2, 28, "Input"],
Cell[8616, 325, 51, 0, 25, "Text"],
Cell[8670, 327, 71, 2, 28, "Input"],
Cell[8744, 331, 111, 3, 25, "Text"],
Cell[8858, 336, 125, 3, 28, "Input"],
Cell[8986, 341, 85, 2, 28, "Input"],
Cell[9074, 345, 48, 0, 25, "Text"],
Cell[9125, 347, 93, 2, 28, "Input"],
Cell[9221, 351, 422, 8, 56, "Text"],
Cell[9646, 361, 71, 2, 28, "Input"],
Cell[9720, 365, 258, 5, 40, "Text"],
Cell[9981, 372, 93, 2, 28, "Input"],
Cell[10077, 376, 133, 3, 28, "Input"],
Cell[10213, 381, 1847, 49, 119, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12097, 435, 40, 0, 63, "SectionFirst"],
Cell[12140, 437, 1389, 23, 147, "Text"],
Cell[13532, 462, 61, 0, 25, "Text"],
Cell[13596, 464, 246, 5, 65, "Input"],
Cell[13845, 471, 57, 0, 25, "Text"],
Cell[13905, 473, 110, 2, 28, "Input"],
Cell[14018, 477, 101, 2, 28, "Input"],
Cell[14122, 481, 130, 3, 28, "Input"],
Cell[14255, 486, 85, 2, 28, "Input"],
Cell[14343, 490, 71, 2, 28, "Input"],
Cell[14417, 494, 87, 2, 28, "Input"],
Cell[14507, 498, 94, 2, 28, "Input"],
Cell[14604, 502, 95, 2, 28, "Input"],
Cell[14702, 506, 120, 3, 25, "Text"],
Cell[14825, 511, 93, 2, 28, "Input"],
Cell[14921, 515, 132, 3, 28, "Input"],
Cell[15056, 520, 144, 3, 25, "Text"],
Cell[15203, 525, 89, 2, 28, "Input"],
Cell[15295, 529, 93, 2, 28, "Input"],
Cell[15391, 533, 132, 3, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

