(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    298402,       4950]*)
(*NotebookOutlinePosition[    324641,       5810]*)
(*  CellTagsIndexPosition[    324597,       5806]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
The van der Pol Oscillator
\
\>", "Title"],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell[TextData[{
  "\tThe labels mathematician, engineer, and physicist have all been used in \
reference to Balthasar van der Pol.  The van der Pol oscillator, which we \
study in this notebook, is a model developed by him to describe the behavior \
of nonlinear vacuum tube circuits in the relatively early days of the \
development of electronics technology.  A little more detail on his work, \
taken from the Exploratorium web site (",
  ButtonBox["http://www.exploratorium.edu",
    ButtonData:>{
      URL[ "http://www.exploratorium.edu/"], None},
    ButtonStyle->"Hyperlink"],
  "), is given below.  A brief description of a circuit described by the van \
der Pol equation is given in ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontWeight->"Bold"],
  ", Steven Strogatz, Addison-Wesley 1994, p. 228.  Chapter 7 of Strogatz' \
book contains a very readable discussion of the equation.  Our study in this \
notebook will be based entirely on  numerical solutions.  The rigorous \
foundations for the analysis (e.g., the proof that the equation has a limit \
cycle solution which is a global attractor) date back to the work of Lienard \
in 1928, with later more general analyses by Levinson, Cartwright and others. \
 Perturbation techniques are also useful for the case of large parameter, but \
we will not consider them here."
}], "Text"],

Cell["\tFrom Exploratorium web site:", "Text"],

Cell["\<\
\t\"Balthazar van der Pol was a Dutch electrical engineer who \
initiated modern experimental dynamics in the laboratory during the 1920's \
and 1930's. Van der Pol investigated electrical circuits employing vacuum \
tubes and found that they have stable oscillations, now called limit cycles. \
When these circuits are driven with a signal whose frequency is near that of \
the limit cycle, the resulting periodic response shifts its frequency to that \
of the driving signal.That is to say,the circuit becomes \"entrained\" to the \
driving signal. The waveform, or signal shape, however, can be quite \
complicated and contain a rich structure of harmonics and subharmonics.  In \
the September 1927 issue of the British journal Nature, he and his colleague \
van der Mark reported that an \"irregular noise\" was heard at certain \
driving frequencies between the natural entrainment frequencies.  By \
reconstructing his electronic tube circuit, we now know that they had \
discovered deterministic chaos.  Their paper is probably one of the first \
experimental reports of chaos --- something that they failed to pursue in \
more detail.  Van der Pol built a number of electronic circuit models of the \
human heart to study the range of stability of heart dynamics.  His \
investigations with adding an external driving signal were analogous to the \
situation in which a real heart is driven by a pacemaker.  He was interested \
in finding out, using his entrainment work, how to stabilize a heart's \
irregular beating or 'arrhythmias'.\"\
\>", "Text"],

Cell[GraphicsData["PICT", "\<\
6mP000000DX0c00A0_l<0?on0000B00004P000000001BP3<0000002Q0O805SQ2
BDd000000001BP3<Ag:9L6R_HVX00@0:0000005:0<`0VP000?n3<0000001BP3<
000010000000B00004P0000@02000`0800000000000000000000005:0<`00000
0DX0c0100U@=h^GViNSWk>g^k>o`ko;nl`7emoki:OOfn_cinOOknockoOcko?gn
oOklnoclmo[lno_moOcmoOKmo_cmo?_ko_gm;O_moOclno[moO[lno[ko?cmo?gk
o?cmn_cko?cnnogloOcmn_Sio?cnoOgkoOklo@Son_cmo?[noOh1nocnoOklo_d4
o?gmn__no@?jnokloOdJo?_lo?[ioO[koOkinogmo?cjno_jno_ln_Oho_`4n_gl
n_[mnaOloO_jo?cjnO[jh^GViNSWk>g^k>o`ko;nl`7emoki7OOfn_cinOOknock
oOcko?gnoOklnoclmo[lno_mo@_loOgfoOkloOcknokmoBgkoOglo?_joOgjo?_j
nocloOcmnocloO[lnoclo__mo?gloO[hnOclo_gmnogno?d:oo[loOcjo_gnnocn
oOklo_d4o?gmn__no@?jnokloOdHo?_lo?[ioO[koOkinogmo?cjno_jno_lnP7g
n?kl1?[mo?[joO/Go?gkn_cln_Wjn^;Ui^GXinc]k^c_l>obo_<1mOOnnBWgm_[l
nOWgno_lnoglnocmo_gno?_lo?Ojo?_koOgloOgfoOkloOcknokmoB?koOglo?_j
oOgjo?_jnocloOcmnocloO[lnoclo__mo?gloOX9n?Wlo?kmoO_mo_cm2_ojo?gl
n_kmo__lo_gno?km1?cmoO[ko_d3n__no?gm6_cko?cjnOgjnognnO_moOcln__k
n__ko?[gn?kl1?[mo?[joO/9o?gkn_cln_WjnP9J7n;ShnKYj>[/k^g`ko7_lo7d
mOOem_Ogn?Kln?OgnoSioO`3n_glnokl4?[lmoWmo?[no?cko?GjnocjoOcoo@ok
oOWnoOgloOcmn_[knOOjo_/Zn?ckno[lnocjn_Wknockn_cjnocko?cko?[mo?_l
oO[jnoggn_[knocjo@?ko?gmoO_mo1?jnogko?_lnoKinocjn?[lnockn_kk0oci
o?[nna3lnogjoO_jo?[in?Sjn__koOkjoo_onRWkn_Sjo?_hn?Okh^?Si^WXj^c^
kO3_lNoclOCemoGfmoOhm_chmoOkn?Wmo0?joOcko_`8n_cgnOgln_kl1ocko?Gj
nocjoOcoo@okoOWnoOgloOcmn_[knOOjo_/^n?ckno[lnocjn_Wknockn_cjnock
o?cko?[mo?_loO[jnoggn_[knocjoO_loOgmnogl4o[koO_lnockm_Wko?[hn_ck
o?_jo_/3o?Wln_kk2OckoO[mno[ln_Won?ojoo/0oOkjoo_onRWkn_Sjo?_hn?Ok
h^?Si^WXj^c^kO3_lNoclOCemoGfmoOhm_chmoOkn?Wmo0?joOcko_`@n_cgnOgl
n_klo?_lmO[ko?[mo?om3o_mnOkmoOcmo?gjn__imo[nna;ho?_kn_cko?[jnO_k
o?_jo?[k6ocko?cko?[mo?_loO[jnoggn_[knocjoO_loOgmnogl4o[koO_lnock
m_Wko?[hn_cko?_jo_/3o?Wln_kk4?ckoO[mno[ln_Whn?[jno_mo_[onooj2O_j
n?[lnoShmo/2CACOh^CWjNKYjno]k^oal?;cloGgloKmn@GlloOjo?SnnPOioOcl
oOcko?km:?_joOchn_gmo?ceo_[koO_loOcloOcloOglnO_ko?[ho?_nno[jno[l
o_gln_ol2O[ho?kmoOcknogno0Sko?ckoOgnnogmo?omoO`=noglo?gln_cnnogj
noWnnokl0o[lnocnnR?kn_gjnoSin?Wlo?[in_glo?gno?_kn_cinO_mnO_ko?[l
no[mnagin__ino[kn__Oh^CWjNKYjno]k^oal?;cloGgloKmn@GlloOjo?SnnPOi
oOcloOcko?km1__joOchn_dQoOclmOkjnogko?glo?glo?gmo?Wknocjn?cko__j
n__jo?kmo?[oo0Wjn?cnoOglno_mo_`8noclnogmo__moOcooOgl3O_mo?cmo?[l
o__mn__io__no0?jo?_lo_XHno[mn__hnOSio?cjnO[mo?cmo_ckno[ln@[inogi
no_ln_ckn_gk7OWjnoWkn__jnmoRi>OYi^W[kng^ko7`l_?cmOOcm_gi1Occmo[l
n?kj1oWmo?cmo?_lo_dXno[mo?SjoOglo?Gnn__mnocmo?cmo?cmoOcino_ln_Sl
nokkn_[kn_cnoOcjoo`7n_Slo_gmo?/1nogno0Sko?ckoOgnnogmo?omoO`=nogl
o?gln_cnnogjnoWnnokl0o[lnocnnR?kn_gjnoSin?Wlo?[in_glo?gno?_kn_ci
nO_mnO_ko?[lno[mn`Sin__ino[kn_/2FRgOh^GVi^OXjNo]knc_ko;cmO?em_Ch
moOen?[hn_chnoOfno_lno_loOcinoklo__oo0Wio?_kmo[joO[moO`noOckno[j
n?Wln?[knockn__lm_Wkno[ino_jnoOino_imo[jnoWhnO[jnoclno_joOglno[i
o?cmn_Sko?_n0_cmnogloodYo_cho?[jnO_jmoSkn_cmo?cjn?_ko?[inOSkn_gh
n__knO[lo?Sjn?_lo_Wlnckjno[jnO[hno[in?GhnOcinMoRiNKVinSYkng_k>o_
l_?eloGfm?SgmoGhn_Sjo?SkmoKknocknocmo?Wko_cnnool0?T8o?_kmo[joO[m
oOa1oOckno[jn?Wln?[knockn__lm_Wkno[ino_jnoOino_imo[jnoWhnO[jnocl
no_joOglno[io?cmn_Sko?_no?gkoOcooB[no?Sln_[ino[gn?_jo?glo?[hno_l
n_Win?_joOSjno_in_cln?[hnociooWlnckjno[jnO[hno[in?GhnOcinMoRiNKV
inSYkng_k>o_l_?eloGfm?SgmoGhn_Sjo?SkmoKknocknocmo?Wko_cnnool2OWl
no_gn_[mn_gmo2Kmo?_kn_[hnOchn__ko?_jnocfnO_kn_Wkno[kmoWknoWgn_[k
nOPJnO[jnoclno_joOglno[io?cmn_Sko?_no?gkoOcooBWno?Sln_[ino[gn?_j
o?glo?[hno_ln_Win?_joOSjno_in_cln?[hnocnnOck4?[kn_[in_Skn_WhmOSi
o?Wi0Ud?h^?Ti^WXjng^k^o`lo3bl_ge2OKhnOWjn_WjnO_nnPOho?[loOcmo_kk
6Oglo?_mo?_lnogin?_knOcmnOgjo?glo?Ojo?`PnoWjnOSin_Skn__imoSjn__l
nO[jno[kn__ho?SinOSlo_/@o?_lo?gknOOino_ioO_mo?djnocmnoglno_mnogi
nOclnOWln?[lo?_mn_[hno_inOckn_Wknockn?_ln_[ln__jn__knO[io?OjnOgm
nQcino[jn?[jn?[in__lh^?Ti^WXjng^k^o`lo3bl_ge2OKhnOWjn_WjnO_nnPOh
o?[loOcmo_kk1oglo?_mo?_l4O_mnOSknoWloOWmn_cmo?cgn_cl8?_in_WhnO[h
no[knOOhn_[ko?Wjn__jno[kn?chnOWho?kkA?cko?cmnoWgnO_knOgkoOcmnocm
noglno_mnoginOclnOWln?[lo?_mn_[hno_inOckn_Wknockn?_ln_[ln__jn__k
n@KjnOcgn_WmoOXLnO_jn_Sjn_SjnO[ko>;Si>KYj>_]k^k_l??`l_;mm@Wfn?Wi
n_[in_Wko_X7n?cjo?gloOknnaWmo?ckoOcko?_mnOSknoWloOWmn_cmo?cgn_cl
7?_in_WhnO[hno[knOOhn_[ko?Wjn__jno[kn?chooT1n?cnnd_lnocloO_imoWk
noWmnogloO_loO_mo?_koO_mnOWlo?Wio?Sjo?ckoO[jn?_knOWlno[ino_lnoSk
o?[jo?[kn_[knoWjnOcgn_WmoOX<nO_jn_Sjn_SjnO[ko09PAn3Ri>KXin[[l>c/
k^o_l_;dm??em_OfmOSjnOSin?Ohn?GinO_lnoSknocknOOfo?cjnoclmoGko?[i
nOklnocjo?Wim_Wko?kioOL<n__jn_Whn_WhmoSknOkh3OWkm_Ohn?_jn?KfnO[g
o_T?nockn_SjnO_koO_jnOcknooj:_ckoO_ko?cno?Win?Sgn?[jn?Sin_[koOSh
nOWhnOWjnO_jnOWjnOWjnO_mn@_jno[hn_ShnOWko?[nnCojn?Whn_Wkn_SfnO[P
h^CVj>OZjo3/k>k_ko;bm?CcmOKgm_Ghn_WhnOSgn?SenOWko?_hno_lnoWgm_cl
n__l4ocgmO_ln_Wio_cko?[lnOWfnO_lo_Wmm`cjno[jnOSjnOSgn?_io_P=nO_f
moShno[hm_Kin_OnnCcko?_jn?[ino_mno[io?_kn_[lnogknoclo_cinOShmoSj
n_ShnO[jnoghn?Win?Win_Wkn_Win_Win_WkoOT2n__j2?Sjn?SinO_ln_kiDo[h
nOSjnO_jn?Kin^3Ri>KXin[[l>c/k^o_l_;dm??em_OfmOSjnOSin?Ohn?GinO_l
noSknocknOOfo?cjnoclmoGko?[inOklnocjo?Wim_Wko?kioOL<n__jn_Whn_Wh
moSknOkh2?Wkm_Ohn?_jn?of0_Wjmoki??_lno[hn_Wknogkn_Wlno_jn_ckoO_k
o?cno?Win?Sgn?[jn?Sin_[koOShnOWhnOWjnO_jnOWjnOWjnO_mn@_jno[hn_Sh
nOWko?[nn@_jn?Whn_Wkn_SfnOX2IP_Sh^CVi^GXj>g]jnkml@3bo_D4m_WgmoKn
n0_in?[jn?_koOcmn_KnnoojD_Kgmo[jnO[lnOcln_Win_gknO[lo?WloO_jno[k
no[jno[hn_Wino[in?[kn?WgnOWfnO_emoWkn?Ofn?Sfn?[jnO[loOWmn?SjnOOj
no[joOgn6?cjno_mno[kn_[ko?Wkn_Whn_WgnOWknoSnn@7go?kj=_WjmoWkn_[k
nOWjn_OfmO_jo?Wio?Shn__kn?WgnOWjnOScnO[gn?Win?[Sh^CVi^GXj>g]jnkm
l@3bo_D4m_WgmoKnn0_in?[jn?_koOcmn_Knnooj1_Kgmo[jnOYTo?Wlo?[inO[m
noWjo?cio?gkn__jno_jn__jn?[inO_jnOSjnoSimoWim_WkmOOinoSgm_Shm_Sj
n_Wjo?gioOShn_Wgn__jn_gmo_cjno_mno[kn_[ko?Wkn_Whn_WgnOWknoSnn@7g
o?kj4_WjmoWkn_[knOWjn_OfmO_jo?TSnOchn?[knoSimoWin_WhloWjmoSinOSj
hn;Ti^KUj>S]kN_^oO40l_ke1?KimoOfo_P;nOSjn_SknogloO[fo__onS[fmoOj
n_Wjo?Wlo?[inO[mnoWjo?cio?gkn__jno_jn__jn?[inO_jnOSjnoSimoWim_Wk
mOOinoSgm_oh;_Khn_[in_cmnOghn?[imo[kn_[moOkln__koO_jno[jnocino[i
n?[imoWino_ho_T1mocnnR[in_Oino[jnoWin_[gm_Gkn_cinOchn?[knoSimoWi
n_WhloWjmoSinOSj0V=EhN;UinSYj>?Of=oPjnKZinKXjng_kn_[knoalo;alO?e
m?Sgm_Gcm_[gn?SfmOGcn?Ohm_Ohn?[jmoShn_[hmoSinOSim_SgnOOhn?Khn?Wi
moOjmoKnma?en?KgmoGgmoKhnOGfn?Kem?Ghm_kh0oWjn?cmn@?hmoKho_T0nRoh
n_?go?cjmo_jn_OinOSgmoSjnOSjn_cin?OhnOOjnOKgn?[hn_Sino[inOKem_Gn
n0Sgn?[in_Wgn?Omn3ogm_GhnOOinOSgn?OQh^GWj>WXhmoHgn3[i^[Wi^S[kNo_
jn__ko7cl_7aloGdn?OfmO?fn_Ohn?KemO?hmoSf8OOhn?[jmoShn_[hmoSinOSi
m_SgnOOhn?Khn?WimoOjmoKnma?en?KgmoGgmoKhnOGfn?Kem?Ghm_kh0oWjn?cm
n@?hmoKho_T`n_SjloOlo?[gno[jmoWin?Ogn?[in?[jo?WhmoSimo[im_Ohn_Sj
n?Wkn_Wim_GfmOkh0?L7n?[in_Wgn?Omn67gm_GhnOOinOSgn?OQh^GWj>WXhmoH
gn3[i^[Wi^S[kNo_jn__ko7cl_7aloGdn?OfmO?fn_Ohn?KemO?hmoSfmoShn_[g
n?Sjn_Sgn?Win?Wfn?OimoShm_ShnOWgmo[gm_kg3_Ghm_OgmOOgm_SimOKhmPCe
m?Ghm_kh0oWjn?cmn@?hmoKho_T`n_SjloOlo?[gno[jmoWin?Ogn?[in?[jo?Wh
moSimo[im_Ohn_Sjn?Wkn_Wim_GfmOkh2?Ohn_WjnOOhmogh2oOfmOSimoWin?Oh
m`9VOn3RhnGVimVOWHj@SIFJWY>MT9:DXZBNW9fNUJ6PX9nOZ:2N[:FiYYbOX:BR
]:baZjJS[:o3`;^bZj:Y]Knn]l6Z[;;9c/ZhZ:>g_lk>a[Va/KO6e/n`/[O0em[F
dkFa`MWSg][7al[ChnWGeL;?f^GVh]3DfN?]lo3Wh]oQkO;c>>cWjNccl_KclNoa
m?Kdm?;_mOK`loOdmOGcloCem?OfloGen?Ohn?Whm_Ohmo;eloCen?KhnO[in?gg
0?SnmSkdmo[gm?OinOSgnN3RhnGVimVOWHj@SIFJWY>MT9:DXZBNW9fNUJ6PX9nO
Z:2N[:FiYYbOX:BR]:baZjJS[:mo`l2k/Z^RZKFo_[O1ZZbbbLk:^:RS]ko>c/Ji
/K6ga]K?/;:g`=OJe]>e/L7IhmkJalO:dn?YemG2cm[Ui^;@e=WSkO?`in;OhNgb
lncWjNccl_KclNoam?Kdm?;_mOK`loOdmOGcloCem?OfloGen?Ohn?Whm_Ohmo;e
loCen?H4n?WjnOSmm`3ho_Ibm?OjmoCgnOWhmoWPh^?Ui^OIWif>T8fEVYjCWI2B
U::TWYbMWYFQX:2OWjRPWZbU^JJLWj2TX[B//J^VXjb_`l2k/Z^RZKFo_[O1ZZbb
bLk:^:RS]ko>c/Ji/K6ga]K?/;:g`=OJe]>e/L7IhmkJalO:de3SjMOE`/oJiNKR
d=CIhngcl>ORgn7]l_?/inW/lo;flo7_lOCfm?CbkoGfl??gm?Gelo?dmOCgm_?e
mOSgn?Sin?Kgn?ObmO?dmOSfn?WjnOSmm`3ho_H:m?OjmoCgnOWhmoT2JGoRhNKU
inW?XjZPVHZ@RINW[9^ER8VMXjf[YI2>TIjX[ZjPVIfCZZV`YYfETZ:S/k>/TINP
/KBl^;2SX::]^kRdXIjH/K?5_[N/Z:Zh]<6k/jJRYJnh^;V]YJZU^;nn_JnYYJJi
`<Fk/:JQ[;>f_kn_ZJFZ_/C2_:jaZ[6la/g2`BZ/[l76d/S1`K[1dmoWf]O0`LSK
f^KKdlo:eMoZgMSGc][ViN_Pg]gQi>o]o^<8i>_]loCZj>[_o_@<mO?al_Kfm?;e
l_7clOkf=O[ih^7ViNOYcj>ZX9V:T8VGYjbKUHR9WJ>]ZjF@SY6NZ:j^X9VMTjZY
/:JMUI:RXk>c[96GX7Ja];bh/:>PXZfk^;BQWYRa/lFn]jbXZ[Rd`K^cYZ:U[kRh
^JfUZZFh_kjm[jVUY[W0aK^`YZ6//kJo_jnYYJZna<:l[[6Z/Kc6cL;1[:o1a];8
`L6j`M?Oim[G`<78fm[Vfm??b]GOj]gHelkJi^G[h=kMhNC_kOkS1NC[kO?djP;X
j^onm0celo7bm_Kdl_GblO?ao_IYn_WRhNKUinW?XjZPVHZ@RINW[9^ER8VMXjf[
YI2>TIjX[ZjPVIfCZZV`YYfETZ:S/k>/TINP/KBl^;2SX::]^kRdXIjH/K?5_[N/
Z:Zh]<6k/jJRYJnh^;V]YJZU^;nn_JnYYJJi`<Fk/4:VXJbc][no[jVUZ[k4`[b^
/JZa_<K=`/6/[l76d/S1`K[1dmoWf]O0`LSKf^KKdlo:eMoZgMSGc][ViN_Pg]gQ
i>o]o^<8i>_]loCZj>[_o_@<mO?al_Kfm?;el_7clOkf0O[i0VUohN?Ti>SWb9NG
S8b;THV9Thf<VXZCTI>?SIfKX9NEVIj=WJJOVj2LW9JRW9RNX:NPY:6SY:JTWYjW
XZ^LYZZVXinbZJfZ[jN^]kB[[JR[Y:^O[[2`ZHaiIE]aQhRPQY6N[JRTZZjYWZ:^
[:FVYjfXZJRSYK6Z/J^^/Zb[[ZRWXkQo/;6e]kZa][Rk^kk4`/?0`<6oa;Vh_kg2
_;^h_KZj^KNo^k^n]KVlb[Ni_[Bj//2f][g3]KB_`kg<_LBi/[Nl`<Fn`k^h]ko<
bNggmn7Si>CXilRGUhb<Ri69RI>=S9Z:Ti6CShfMVj2GUIVNSIfVWi^PW9bFXYbH
WZ2WX:BQXjAoYZBNWZNRZibVZZJSWk:Y[JZ_Yjjg]:^]Z:^TZin^/;2YS7UUFg67
R:26TIj]Z:BZ[ZVNXZj/YJJW[JRYZ:>U/JZaZjjb[:^^Z:NS^;2a]KNj/KJh^k^n
a<;3`<31_lBi^;nm`[bk^;fj^[Vg_k^k_[Fi_<Zg^Kjd^[;0][Jm`kEo]:o3_Lbm
a;Vb]kc0aKk3^kRg_lc9kOOghN?Ti>SWb9NGS8b;THV9Thf<VXZCTI>?SIfKX9NE
VIj=WJJOVj2LW9JRW9RNX:NPY:6SY:JTWYjWXZ^LYZZVXinbZJfZ[jN^]kB[[JR[
Y:^O[[2`ZHaiIE]aQhRPQY6N[JRTZZjYWZ9S[ZbUYZN]Z:VXXjFaZ[6[[[:/ZjjX
Yj>h/;6e]kZa][Rk^kk4`/?0`<6oa;Vh_kg2_;^h_KZj^KNo^k^n]KVlb[Ni_[Bj
//2f][g3]KB_`kg<_LBi/[Nl`<Fn`k^h]ko<bNggm`9Yon9mj>CYil^^ZiZ<OIFH
ZjBETXR8VJ^/Y9BESifNZZbYV9RCW:>hYj^IUIVQ^;:_WiBA[:nd^;FWX9RJW;:g
/:^TYjfg^;RZ[Z^//kRo^ZBROGYUG6eZL5YMIfieL6UQLZBU^[bj[jNSYZRe`KJ_
X9^NXjo2];FSZK:__;fm]:Z/Oj^b_<W0^;Zb]kg@f=34^kNk^lc3akRd]KS7a<Zi
_KB``<WAbL2m][bi`/Vm_JbY//76b<FhZ;Bc`<C;a<6_Z[2naLO:`;Bge]GemoSR
h^STjNO;[Z^JS7fEV:^TUI:8R9V[[:BDUHnMWZZ/ZIRHTibS^:N[VIFIXKRb[inD
TJb_OkBh]JNPV9ZL/[N`ZjBW[KNh^:Z^Zjbc^;njY:9mNVELKFY`FUeWKWE`JF5b
Y:Fj_;Z_Yj>VZ;G1]ZnPVijS[l:d]J>Y/Znl_KfdZZb[/[c9`;Rj/[Nmd=S@a;^g
^k_<`lNh];FhalC:^Kfd/<39dLW0_KJl^L;9_Kf/ZK;1a/S5OkRX];?0a<_4`JnZ
/;k5al[0];OFeOGgn>;Rj>CYil^^ZiZ<OIFHZjBETXR8VJ^/Y9BESifNZZbYV9RC
W:>hYj^IUIVQ^;:_WiBA[:nd^;FWX9RJW;:g/:^TYjfg^;RZ[Z^//kRo^ZBROGYU
G6eZL5YMIfieL6UQLZBU^[bj[jNSHjJX]L6f[j2KWZ>_`[BeXjVb[kbm_KBZ[:^b
_<W0^;Zb]kg@f=34^kNk^lc3akRd]KS7a<Zi_KB``<WAbL2m][bi`/Vm_JbY//76
b<FhZ;Bc`<C;a<6_Z[2naLO:`;Bge]GemoP2JOoQONCSinK:TXV=V9:DSiF;SY:K
W9>ITI>IVIJKUibKUY>_VY^LXI^HVZJKVjF]YYZUXZfU[j6NYZNRVi6ZYJ:O/:fZ
ZZ:VYK2_YJjXM6ISGeULHf9WJhAhQ75fOIVMOG1lN862NgVMY:^SYJVNYZJXYJ6W
YjFV[KR^[kJaZ:ZX_Wna/;Bk[kBo^kfk`/O0^<Bk_KRl^;Re`;Bc_Kc4_L:`/kNd
^K>h_Kfl];Zj/;>h_KFm_KFe/KRd]kNh]kJi_[^i]kJb/kNo_L2nloGfhN7ThnOV
bY:9SIRBU8nERhjBVibCVI6CVIVFViNLViJC[iZKW:6KV9ZVVi^U[JJJYJ:]YGn_
XIjVYj:KTJZUXYn`[JZZXZJU/:nU[ZQdIV=OFEaSHVM[Q7R4LGImVIemL7ahPH9k
NIfTZj>UZIjVYZRUXJNWYJJ]^:j_][6XZZRn/K2d^jnd_k^m^l;7`;S4^kfh_;Rh
]L2d/kfla;g2/;>g];Vc^;fm_;Bj^[2c^;fe_Kfe]Gna^;Bg]kRg][Vn^kVg][:c
]knm`;kcmOKQhNCSinK:TXV=V9:DSiF;SY:KW9>ITI>IVIJKUibKUY>_VY^LXI^H
VZJKVjF]YYZUXZfU[j6NYZNRVi6ZYJ:O/:fZZZ:VYK2_YJjXM6ISGeULHf9WJhAh
Q75fOIVMOG1lN862NgVMY6>[XjFYWZJVZ:FQYjNUYZfh[Znf/JRZZ;ja/;Bk[kBo
^kfk`/O0^<Bk_KRl^;Re`;Bc_Kc4_L:`/kNd^K>h_Kfl];Zj/;>h_KFm_KFe/KRd
]kNh]kJi_[^i]kJb/kNo_L2nloGf0VWohggVi>OWej:CQhRGXZNVSi2<WZ6RZ9RI
TYBA[Zn_U96@Uin[]JjRVIBV/:nj[:>GXJ:h^[b^YYRJXZ^j]jZHTjF]/[ff/J>/
/iQlHeaVHV5VJ7FWQhRDV;b``jZLMFaXKG9hKhQYK7:>X[:dZZbSZ[6d_K^XXZFd
]<72_:nTZ[5o^L33`K2]/[O9cLk0^:^e^Kg;aKZj[kbn`/W6bk^i/lG5`lW1^;:m
b<?@b;F//;_4a/W4/Jfd`;c>c<Vl_KS2`lS8a;fa][k8b_Cfm^?Si^CWimNRThN8
Uj:WYXn@S9jQXZRHVI:DTJj_[iBAT9NOZkF^XYVDY[2_^ZbSUj6R^;Yo_:jVV9ZR
ZkZgZYRCYJfb_KJaXjbcV7aSG6IRHFIXMJN7R9BH_;33ZYaeK6Q]LWQ_R6U/LXjR
/[BZ[:>Z/KBm^jRRYKBd`L:l[jBZ/KW0`l6`[K:gbLg>`;R[]KVmblFj^Znl_/;9
a/^k^K?5aL?9`KRb_LS3d<Re[;2ka<K9a;5o[KC0_<k<bKbm^<;3b<S4_K6f_/S:
m?Kfhn?Vi>OWej:CQhRGXZNVSi2<WZ6RZ9RITYBA[Zn_U96@Uin[]JjRVIBV/:nj
[:>GXJ:h^[b^YYRJXZ^j]jZHTjF]/[ff/J>//iQlHeaVHV5VJ7FWQhRDV;b``jZL
MFaXKG9hKhQYK79SSZ:b]:Z/XjZa];fkZ::U];C1`[b_Y:Za^L33`K2]/[O9cLk0
^:^e^Kg;aKZj[kbn`/W6bk^i/lG5`lW1^;:mb<?@b;F//;_4a/W4/Jfd`;c>c<Vl
_KS2`lS8a;fa][k8b_CfmP9YOmoRhN?Vj=VEW9bJU9bGVhbRV9ZDUi^IXYfJVinI
ViBHWZ6OWiRKUYNVW:FVXZFWZZ:PWj>`W[JWZ:2QZYbJXj>YX:NTXK:6OV5DBTE:
D5AVKWN9TYVWVZVTU8YYGFieK6]]H6=IGg9RH69RHEiJHjfV[:RVXj^]]Z^i[:ne
^KB_Ok6b[ZRi_[Ji`Kc0^<2i_[:c`Zj`//6g]KVc/KFe_kjm/kV^/KRo][^n^kJg
]kRh^KJ`]kJl^[Jc_;Nh_LVk_L2k_[S4^[Zh_[obm_KOh^7Si^SIUIbLVYBLUi^<
XYRJU9NKVJ:MVY^OVI^DV9jQWinHViJGYYbUYZ:UYjZRX9nSOk2N]ZNXX:6ZW9ZS
XjVPYjBQ/XInHEA:ADY@E6I^MhVBVJNJZJBDRVUMKWE/JfePHeUOLV9PHV9QGUYS
[JJ/Z:JSZjffZkV/[kFi]:na/ZjX^Kjf^L6l`;S0^Kjb/l:^/;;1]kFi/k6e]Knn
_K>i[[6h_kJk_[^f]kNh^;Vf/;NfOkbj][>l]kRmbK^m`;^n^<Bj^[Rn_o;fm]oR
hN?Vj=VEW9bJU9bGVhbRV9ZDUi^IXYfJVinIViBHWZ6OWiRKUYNVW:FVXZFWZZ:P
Wj>`W[JWZ:2QZYbJXj>YX:NTXK:6OV5DBTE:D5AVKWN9TYVWVZVTU8YYGFieK6]]
H6=IGg9RHf1RHV5NFV>]YZbXYZ>[[KJ[^Jb_]KVd[k6b[ZRi_[Ji`Kc0^<2i_[:c
`Zj`//6g]KVc/KFe_kjm/kV^/KRo][^n^kJg]kRh^KJ`]kJl^[Jc_;Nh_LVk_L2k
_[S4^[Zh_[obm_H2JOoQ1>KSiNOLoYMeVZBPYj6AVIFPX:RWUYZMZZfW[ZZITYVO
XkRSYIVEXJ:cZjZWW:>]/k:f[YbOWJnc_/2`XYRZ/;Jk^ij3FF5GKE5:DUEMN9:W
^mBXTWf2OGZ8TG]QKW6MNVa^H4ePNGaZJEIGFUANUk^dYjJP[K^n`k>`Xk6e/e;3
_L2c[Znm`mK?c;^hYkg1blZkZZZm_<G2`K^_/:o3c/g0]Jj__/73bl2k/;2h`LK3
^Kf^]KW5bLc6_;:j_LW:c/Vj`;?5b=3Am?GhhN7VhnGWg?jG:IZTX:NQTIVEX:2X
YiJJWJZ]YjjZVI:IWj>hXjFIUJ6R/j^ZYibS[K>b]Wn^W9nM[k>n`;2RV:Z`][^k
WX=IHEM]DDYBEEehTZNke:RBOH9mNXRANf5^LIejK6iPCF1iO6YYEUMJE5jG^kBW
YZ2]^kk3/k2S/KFc`kg0/jj__L?Fclbk^:Nm`L_:^jZZ_Kc5`/6k[k2_`lk=`;F^
[kk1`l_0^k2`^<76`kVm[Qje^LG9c<Jl/[ZmbL[>bK[0/lG8d=7dmOSQhNKSiNOL
oYMMVZBPYj6AVIFPX:RWUYZMZZfW[ZZITYVOXkRSYIVEXJ:cZjZWW:>]/k:f[YbO
WJnc_/2`XYRZ/;Jk^ij3FF5GKE5:DUEMN9:W^mBXTWf2OGZ8TG]QKW6MNVa^H4eP
NF=lJVUFEeYDGYNk]:NVX:fk_/>c/:>a]K?3_L2c[Znm`mK?c;^hYkg1blZkZZZm
_<G2`K^_/:o3c/g0]Jj__/73bl2k/;2h`LK3^Kf^]KW5bLc6_;:j_LW:c/Vj`;?5
b=3Am?Gh0VTdgn;SiNKUdYfRUIfLV9>MVIbIWHVDVinRXZVPXYVOY9JPWifWVJfV
YijOXi^XYJ^XYZVQX:?nYdNfZZbW[JjQZZB^PVmHHeiHDV1DFEQYOW^=]JNTWX^8
NGIaIV]mNG5jM6ajJFIUFeeiLVEVG5]EBDinUiVMZ:^_/JbZ/Jnh/;=o/ZVf/l2f
]kFl]kJm^KBj/k>f]kJe^k:o/;2c][^_][bh];O8][Vg][Zd^[Jh];VgZk2f^k^f
`;Vl]/?4_L71_/31bKni^[k3]NcdmmoRhnGViM:MXYFMW9RCWIVLVIf9U9^OXZ:Y
X::IWjBFX9nMYiV]YZNNWj>KZ:F[Z:JYXJ00XojWNkJZ[:N][Z6ZY:j2KeQSGUQB
H5AIF6UnNhfeYjBNRhQiMW5VJgeiLGYdK7YYIVEKGGUbIFILFeE9CWjGVIfXZjna
[:Za[kR`/k:Y][?0][Ne_;Nf_KVd^[>c][Nf]K^b_k2`/kJk[kJl^;Bgb;Ji]kJj
];Zf^;Bi]j^`][]<^kK0^Kbf`lBm`L6n`<79_kVj_/>ek?Cggn;SiNKUdYfRUIfL
V9>MVIbIWHVDVinRXZVPXYVOY9JPWifWVJfVYijOXi^XYJ^XYZVQX:?nYbnfZZbW
[JjQZZB^PVmHHeiHDV1DFEQYOW^=]JNTWX^8NGIaIV]mNG5jM6ajJFIUFeeSNG9U
IUaKEDU>OYNIWJR[[k6/Z[6_^;2c/ZVf/l2f]kFl]kJm^KBj/k>f]kJe^k:o/;2c
][^_][bh];O8][Vg][Zd^[Jh];VgZk2f^k^f`;Vl]/?4_L71_/31bKni^[k3]Ncd
m`9YOn3RiNCXi/fFU9VQZZRLUi^QYk:PWiZIVJBbZjfEUYbTZ[Ji/9fRUZbV^K6N
WIVSZ[Jh[ZRLX[6b^[:gXZNQZ;JlZVQTEEEILVm^PVU_U9S3]YnJUWYfSib9Q7Ac
NGQ]OimXN61KHX^3PXa]J6UTEFQADVnASJ:b/[FZXjZ^^;;7OlBk]ZNj_/W8aKFd
]k^ha<72/;N/^;k4aknjZZ^g`lO7_[^a][[<a<>m[k:h`/W6`kFg[[2l`L[2`KRc
_<SAeLW6/Kbl`Lc>b[_YmOGPh^GTj>K=UYBIXJZXW9NKXJNbX9nJVIVT/Z^]UIJL
Y:Zf^K2MXYJ/Y[VaWYfIXjZf^:jXOibR/K:j/[NRYj6X][bZJ6AEEEUbKfj2JFnD
V<>fWiZFNWJ?W8V4M7=iN6eoWfQhH5]RRh>2S6eXJFAEJ55BKi6=X[:b]JZSZZjh
//O4^kJW^[k9b<Fe];Nk^<C1`[2g[;Rna<No^ZZ[]l?7akjk/KJjc<C3_Jnb^<;9
a/>e]jj`Okc1b/;1^;>lb=7EbLJa_;c1c<k:^nWemN3RiNCXi/fFU9VQZZRLUi^Q
Yk:PWiZIVJBbZjfEUYbTZ[Ji/9fRUZbV^K6NWIVSZ[Jh[ZRLX[6b^[:gXZNQZ;Jl
ZVQTEEEILVm^PVU_U9S3]YnJUWYfSib9Q7AcNGQ]OimXN61KHX^3Hh:<KFQYI5EX
DE9_THfR/[:eZZ>Z[[RbalBk]ZNj_/W8aKFd]k^ha<72/;N/^;k4aknjZZ^g`lO7
_[^a][[<a<>m[k:h`/W6`kFg[[2l`L[2`KRc_<SAeLW6/Kbl`Lc>b[_YmOD2JGoP
hN?Ui^;;WiJFV9JHVYFGWJBMRiJUXIbRWiNRXJVRV9^PVIfP[ij]Y:>PXJ^RXJN[
X:BWZJbZYZjVYj6g[JVVLEEDDUUMFF5XMW>JTZJOYhAeHfUjKh>4MgAlUHnJRG>1
QXQ_NfQdMI:?Rgm`Ke]IFE9BLh>6S8n;T9j]Y;>[/P2Yo[=k_KNl];B_^kbg]Kbg
_;Rj[;Je^[>[][Fh/k2m/Jjg^kJf`K>j]KRk][fg]jff_;:`/kF`/[Nna;fobLNh
^[bk/Kfm^L6nkO?eh>7SiNKRbinFUYRFV9ZEUifTWH^FYJ6LXYnGXZ6YXYRKX9VM
X:nN[JBSX:6[XZ6WZj2TYdbY[:ZV[ZJWXKN]ZJIaEEABFEeIHFQfLiZBYYnWQ7ES
JGY_PhAgM7bESiZ9Lh66R6mkJ7AeTXn;Og1_FeUIDU9cPhJ<Sh^@WZfT/j^bZOjc
;kfg_;Bd[k^l]kFl]kbh^Zbf]KZcZkJe^;>`_K6^]k^f]/6c^[Fh^kJm]kN]][bb
/7nc]K2b]kk4_Ko9akRj_;^a_Kfi`Kk]loGPhN?Ui^;;WiJFV9JHVYFGWJBMRiJU
XIbRWiNRXJVRV9^PVIfP[ij]Y:>PXJ^RXJN[X:BWZJbZYZjVYj6g[JVVLEEDDUUM
FF5XMW>JTZJOYhAeHfUjKh>4MgAlUHnJRG>1QXQ_NfQdMARBSh]oL6mKFEUBDW>3
QXb?Ri2N[JBcZk:Yo[=7_KNl];B_^kbg]Kbg_;Rj[;Je^[>[][Fh/k2m/Jjg^kJf
`K>j]KRk][fg]jff_;:`/kF`/[Nna;fobLNh^[bk/Kfm^L6nkO?e0VUoh^?TiN[V
`iRT[[RYVHVHWJB//YJFV9f[[jbWXYFIWkN^YibFU:RY]k2SXibQWjng_:FUXZVY
^KVfZZ2M/ZnRMG1BCe17KGAbQY^@Y:VQRj2?RF5QL7^LZK:KSGJRYkG0`hZ1OiRH
W7b;X8fJSI2BLeULEUIQNX>;PGV3TYV[[k5oYZ>U^kk4a[fiZjjd`lC:_KZb`J^o
aKbe[Jfb`/G;a[nc/KG2a=32ajn/]Kk5a<2_[k:f`LC<bKRf/lG:e=C9`[Zj_l[B
aKjl]nkcmN;Si>GZi/>HY:jhZIV9V9fT[;:FUYRMZjn/Yj:EVIng[ZNLUYBXZKN`
Xj>LXIn_]kbUYJ;oZOniNkJZX9fb[j9eL59?D4M]M7:6Vi2TZJ6;X8n9HF5`NibY
/Y^=MZ:W]L33RX5oV9RLO8^PSIZ=T99cFEaFEV5jPh^1NH>BVJ^_/JJSYK^na<Jm
^J^^]<?4b[fj//6[_lFl]Jf]//;5blJo/k6e`/C@`/N_[;FnaLC0[jnb]/5oa<c9
^;JcaL[De<W2^[Zob];5_[bgk_?eh^?TiN[V`iRT[[RYVHVHWJB//YJFV9f[[jbW
XYFIWkN^YibFU:RY]k2SXibQWjng_:FUXZVY^KVfZZ2M/ZnRMG1BCe17KGAbQY^@
Y:VQRj2?RF5QL7^LZK:KSGJRYkG0`hZ1OiRHW7aSRj2=VXf@TW=IG5IFHGZ3Rh5i
Pi:IZjnaYZ>U^kk4a[fiZjjd`lC:_KZb`J^oaKbe[Jfb`/G;a[nc/KG2a=32ajn/
]Kk5a<2_[k:f`LC<bKRf/lG:e=C9`[Zj_l[BaKjl]nkcm@9YOn3QhnKXilR?Vj6J
UjBLVIRQWiRGSiVKXZ>NYjbTYiZ/WjfNXjJSY:bRWZJ^ZZVVY:6HYZJ^XjRVW:>]
[[:QDU5AEVeMD6MULG:K[K:a[Hf4RH^7Q7IgQHJ4PZ2CTi:TX:F_ZGbDW9Z5M7nd
_i6EKVYQHUYXG5YLHEUQMW5iMFmfOgfS[;Zg^Jbf^[bf/;F^[:ba^KZY][J^Y[Fh
]kZi^K>f`Kfh_;^k/lFi^[Na^;>c[KRa/;Vl^[Rhak_4_LNf^LS6`;Zl^[2o`<Gd
m_SPhN?Vj>O8Si^QVYNTW9VHXInHUhnIVj:SWZN/Y:NJ[9n]WZ>VXjB/XYjV[ZZY
YZBQV:JVOjjSZ:JLXjf^/Z5BDE5FKEe@IfEaLY^]/[6]SHB9RhN4MWN5QXB2X9>C
TZBPYJnYO9BLVXEdOkBoTIE^JV5RFVQLFUaQFF5fLGUeKgImXjbj]kV/][Zl][2e
[Zb//KVjZKJf[ZJe^;Nj^KVc]/6m^;bk^k?5^KZg/KRc/jfh/K2iOkbj^;S7^lBm
akJib<K0^[bj/;o0aOCfn>3QhnKXilR?Vj6JUjBLVIRQWiRGSiVKXZ>NYjbTYiZ/
WjfNXjJSY:bRWZJ^ZZVVY:6HYZJ^XjRVW:>][[:QDU5AEVeMD6MULG:K[K:a[Hf4
RH^7Q7IgQHJ4PZ2CTi:TX:F_ZGbDW9Z5HgAo];nAUFiZHF9JJ5aJG65IHGIaNGE_
MWfS[;Zg^Jbf^[bf/;F^[:ba^KZY][J^Y[Fh]kZi^K>f`Kfh_;^k/lFi^[Na^;>c
[KRa/;Vl^[Rhak_4_LNf^LS6`;Zl^[2o`<Gdm_P2JGoQh>CSj^KBYZZ/X9bJVjNY
[jJPU9BR[k:TX9fGXjni]ZFWUiZQ/kNc[YbKXZNk][^eVIRP][Fi[:RRV9feMUUJ
EUEPFF^6OJR8RYZ^VZVXY8mcNXn1SIj<]I66/<ni^j2TZ[V]^;FnTXR3U=3:bXMY
LfANG6M/FV1ADEMSKWE[J7m/R:Ri`/>d/[FY_l31^KJ`ZKRm`lZm[J^]/<G9b/NZ
];Vka<G>aL72/kboalVh/:Rl_/o:c<://kFgc<k?a/G0^/;9e<Jg^[g6loSghN3T
hn[VdZJZ[:2LVY^WZJnVX9BDXZnbY:2MUj>_^KJUYiNJXK>g/jjLVj:W^kJk]IVH
X7nf]KV/Z::HWKEfFEYFEF1IJhImZ8R:VZjJZJRTSg=jSh6=WXbeTHJ`ckVkX:BZ
^Jfh]KjBR8>Dd<[:QfUcI5iLIfaJH55AEf=^MF]XK8RX^L;3];:eZKo0`KVf/:Vh
_L?:_Jf[[K35bL[7Z[Bi^lC5c/G1`[>l_lO9^;2X_;k?bWo<`Zbc]KO<c/o6aL2j
`/WDa[Nj_LKcn?OQh>CSj^KBYZZ/X9bJVjNY[jJPU9BR[k:TX9fGXjni]ZFWUiZQ
/kNc[YbKXZNk][^eVIRP][Fi[:RRV9feMUUJEUEPFF^6OJR8RYZ^VZVXY8mcNXn1
SIj<]I66/<ni^j2TZ[V]^;FnTV>8PiC@b/Z7JG=TGUaWK5YPDE5GHfieJfQ/R:Ri
`/>d/[FY_l31^KJ`ZKRm`lZm[J^]/<G9b/NZ];Vka<G>aL72/kboalVh/:Rl_/o:
c<://kFgc<k?a/G0^/;9e<Jg^[g6loSg0VUoh^7UiNKTf9nQVYjNXYVMW9nHWZ6K
XJBUUjJVYJ:XZZ6M[Z:WYJZTWIRU/jNX/ZZXVJVSXJRYZj:RZ:FTLUE>BE=MHFAX
RgVDXJV>RXfCRhJAT85hTHfWYjZZW8n`Zl>j`:Ze/k6S^;>RSJ>ocm6UOg:5H5UM
IUAEFUICG5UKE5eoH7NIX[:c/;ZkZkRg]JZb]kNc/[B_[jbl[jjj^kBd^;jk^;[0
_kZm_/35_[Ze/[Nj^KW5_L2e^/2l]kk1_kC9a[fl`/2h`;o3c_?gnN;QiNGVi=RO
XIZNWZ:IWIbOV9jQVj6TYINVYZFRZ:ZQWJjRYjFZY9fHYK>WZ;:ZZ9VYXj5oZ:V[
XZ:XYJAbEDi9DeeQI6R;NIBQZHj:SI>;QY6@PGRASJNWZZZLSk2[`k[0Z[Fc/J>h
/j:=Xko?dJEoLXEPFEeVE5EJEU=LFE]DGF1gVJ:b/k2j^j^h]kFZ/[Ng/k:d[jn/
_:n^^[^d];Rn^kRj`;nj_Kk0aKjj]K:g^[ViaKeo`;Fj`;bg_/6o]<W6_Kc2`;S0
_l?>loOih^7UiNKTf9nQVYjNXYVMW9nHWZ6KXJBUUjJVYJ:XZZ6M[Z:WYJZTWIRU
/jNX/ZZXVJVSXJRYZj:RZ:FTLUE>BE=MHFAXRgVDXJV>RXfCRhJAT85hTHfWYjZZ
W8n`Zl>j`:Ze/k6S^;=SXXfS_loAYGmbQF1IGFIDEEYFDeaIFeAMH7NIX[:c/;Zk
ZkRg]JZb]kNc/[B_[jbl[jjj^kBd^;jk^;[0_kZm_/35_[Ze/[Nj^KW5_L2e^/2l
]kk1_kC9a[fl`/2h`;o3c_?gn@9Y4>7ShnCViMV]ZZBRUibW[Z^VoYI[XkJ_[I>K
WZ6a][2WVifM[[:e[JRRXk6W][ZeYiVKXJ>g]K6JX:BfQVIJDD]<Gf=kRJZBU9ZM
X::SW9:3NX::RHn8OH2I_LO:bkVh^/2oaKS9/:NfaJVba]7Fc[MaWYMkK7mBADMQ
H6QKHeMGG5AXRj6i/:ja]<?4aKn]/:bg_L35^kbZ/KS2a/Rn^KBk_/C<b<>l/[;0
b/bm]K6`]<34bkg0]KZl`LS:a;f`_/;=d/k?/kFhalgam_KQhn?Ti^GI[JZTXYNL
Yjj[Y_jF7j>f[jfCVijQ/KJ`Yi^MWJjb]JfXXZ>aYkJj]JNIVj6SOkNe/IZPY;J6
IUYABdaOHg^9ZY:DVYfPXZ>LTX=jPXZ9ShQmP9Vmal[;^KRj`;o5^<V`YkK5ZK;6
dMK>]g6NUg]/Oe95Af5PJ5]SEeMDJ8^Q^K2^/KC3a<Fo[K2/]kg0aK^lZ[6h`/K8
_[Vd^kk4c<S3_;:b`<[<_KFa/;C0a<^m:<2e^[c1b<[4_K2n`/gBc/nc]KS7cO7f
m^7ShnCViMV]ZZBRUibW[Z^VoYICXkJ_[I>KWZ6a][2WVifM[[:e[JRRXk6W][Ze
YiVKXJ>g]K6JX:BfQVIJDD]<Gf=kRJZBU9ZMX::SW9:3NX::RHn8OH2I_LO:bkVh
^/2oaKS9/:NfHlFY//KAe/jgLIjGNfaoDTE7HF1XFf=GEeAXRj6i/:ja]<?4aKn]
/:bg_L35^kbZ/KS2a/Rn^KBk_/C<b<>l/[;0b/bm]K6`]<34bkg0]KZl`LS:a;f`
_/;=d/k?/kFhalgam_H2JGoPhN3UiNC;VIJCYYfMWj6GUIVLTibQWIZQ/9jPXYnN
Xj:VXZVPYiVSYYfUWjfR[jV^YIfLWI^UYJRXXE5;@EUCEG]TOhZ5VInDV9>NUI64
R9:GTi>>Q9FGPINn[lZld;6]/:NVSHZi/<W3^JNna/o@MGN2OVUbMdm9FEUBEF1N
FgmHEfA]Rj:/]kJf[[:_/[V^^KNf[ZVa/kN`^[>`[k_2^K;2]K_3_kRg`<:j];jl
/KBe^[Rc`L74_/71]knl`/2j`;fl_Kk2_/?6kOGdh>7PiNGTbiVFTjJMWInQUiFI
W9>LXIfJXK2NX::OWZ>RYZ:YX:NIXjJMYIn]XZnY[ZFMW7nMVjFUZ:RQDD]1FE=E
NfAoRXFIWiBHTijETHB8TYNCThj4UIN1Ukj_b[c@/Jf`YjJ=R[V`bL>iYkk6cm1e
Mh9nJG9gCdUIFE9EH5iKF5MTKH^R[;Nf]Zjb[k:i[[Vg]ZjY/K>g/;Zc/:nk`[Vb
`[Fk`knh]l32^[Bn_;6d]KZh/oo1OLBn`L6g_kc2`;[0_Kbm_/:n`lK]mOCPhN3U
iNC;VIJCYYfMWj6GUIVLTibQWIZQ/9jPXYnNXj:VXZVPYiVSYYfUWjfR[jV^YIfL
WI^UYJRXXE5;@EUCEG]TOhZ5VInDV9>NUI64R9:GTi>>Q9FGPINn[lZld;6]/:NV
SHZi/6?9`kVW_/K?d7EgPWiYLWM?BEUIDUEPGU]HEfA]Rj:/]kJf[[:_/[V^^KNf
[ZVa/kN`^[>`[k_2^K;2]K_3_kRg`<:j];jl/KBe^[Rc`L74_/71]knl`/2j`;fl
_Kk2_/?6kOGd0VTQh>;Ti>GTa9^DUIRMYZ>TTHjFXZ:VYYnDT:BX]Jb/VYROXOjZ
0K>MoZ=E/JfeXj>RZZFU[ZfUViZRZWM=F4QJGEb3Ph69YHF7SJ>TTYNJTYVEWInM
U9BZ_K:]^ZbSSHB3WZ2KX9B;UZnFY;jeY;^n^JB@MjIWI6j2CeeZHUEIDUm]HV5O
GgEfU:Na][ne][Jc/[ff_kF[/;6i^lVl^;>c_ko7al?2][bm`/73`K2g]KJia/Jn
]Kbl`[c1`l>l];G4`LS3`;^g_kc8`ngbmN3Ri>CUi<BKU9FHWJJSY96>UZ:RYZJO
U92TZ;F/[9ZHWj7nZP6cWOjS2K6]]J>SXZZUYJio[JFKVZ:ZMdeHB5YMG8>3PHVU
QHN=XjBBUiZBVIFMWifDU:Zm/Zfj[:>=Q8>NX9^PU8^F[iJT_[FT^kjiY91gYVMT
KX9?GFYREEUBGf9QGemeMYBW/KJo]KJf/k:m][neZk2a^K_9_;Rc/knoalO3`[Jl
_L;1`l6`]kFf^LK6_[Go_3O2_<73`kbd]LC1b<?0^kNo_<S3kO;eh>;Ti>GTa9^D
UIRMYZ>TTHjFXZ:VYYnDT:BX]Jb/VYROXOjZ0K>MoZ<m/JfeXj>RZZFU[ZfUViZR
ZWM=F4QJGEb3Ph69YHF7SJ>TTYNJTYVEWInMU9BZ_K:]^ZbSSHB3WZ2KX9B;UZmS
UZBn]JBk_[VTT7NVIfA^PTmMJV9EFE9OHV5OGgEfU:Na][ne][Jc/[ff_kF[/;6i
^lVl^;>c_ko7al?2][bm`/73`K2g]KJia/Jn]Kbl`[c1`l>l];G4`LS3`;^g_kc8
`ngbm@9YOn7ShnGSi;^AVJ2[YJ:CUIn[/jnUW9>HXKFfZZ^TYJR[/Z^TViN[VkZb
/JfOXjF[/;nWZZFSXZ^d/ZANA5E?Lg=dLhNNTjVUZjB`ZXf9T9JeUiBIU8VRZ::e
alZIWiN;VibIXIBIVY2XW9>?U;:h`<N]/WJ]QHAiZVYGG5]II6=YOeaFFEYdN9ZW
[Z^b][nm`KRh/;NX_L6l_KRn][bmc<S6]kN__Kg:b<6a^;bea/G9]k2l^l77a<[1
_KK2a/[=a/Bo]l?5bLo9a;O]m?GQhn?UhnBkTIVPZjFRTiFOZk>_YIbCV:6e]ZZ[
Y:FXZk:[Y9^GZi^j/[6]Wj>UZk2oYjZUOj>RZkBbY5i4EDmcLgAcQijCZJF[Y;2Z
SHV@U[FGU9VDRJ:XX[G7bYVOUh^KW9VQU9VJT:RLThnD/[S0ajfbMZf5Q7VZJUML
FeUTHfULEUUJM7RJYjj[/[Jo_L6h^;2gZ;g1_;fh_[Jl_Lc8a[Ng[kfmb/S1/KRl
]LK5bKN`_;_1OlO4b/6m]/;6b/g6a;ng`lG9clW4]ngdmN7ShnGSi;^AVJ2[YJ:C
UIn[/jnUW9>HXKFfZZ^TYJR[/Z^TViN[VkZb/JfOXjF[/;nWZZFSXZ^d/ZANA5E?
Lg=dLhNNTjVUZjB`ZXf9T9JeUiBIU8VRZ::ealZIWiN;VibIXIBIVY2XHibCSiBb
^<37[K9f[HF4NJYZEeaKFFASJEaFFEYdN9ZW[Z^b][nm`KRh/;NX_L6l_KRn][bm
c<S6]kN__Kg:b<6a^;bea/G9]k2l^l77a<[1_KK2a/[=a/Bo]l?5bLo9a;O]m?D2
JGoPhNCSinC2TI2DVYbYVYNIWibW[JBOTYBRXJVcX::MX:BY[:NQY9NUYjjb/J:K
WJ>XXK6XWjBEXZ^FEdMLDG=nOh:A[Y6:Qj:RZ[R`WY^CXZFRYjNDSZZV/K6iVIFJ
SH23OX]jQgf2OX5dNY9mRiR>Z:A^Uh5kKZ>0IeIHDUiDIB5LGF1HEe=XM:Fb/ZZ]
[kJn_[fh/;6__;o5a;Bg][^n`L>no[EJ_[W8_[j`[;Jca/:o_kFd`;fma/bf]kG3
_lG8aK^l^;k:cLW2loGfh>7ThnOT`Y6@U9ZLZIZGVInLYjfTWi:DXZ6Y/j2RWJ2T
ZJbWXJBGYJN^/[6RVifSZ:6aZ6fOY9FRZiIGAeaALgioPY6^THZ7XZ:Z^;2NVi>R
YJ:WYiB>ZZJa/KVIUIZ=P8=nRgZ7OH9nPGAjTWf;V8jXY6jGPG]^Xh1WEUQBGUAU
G5ePF5MCJ7BU/[:Z[Jnf_[jm^;2a[kboaLBd]kJk_/73__je3[jib;jn/:bf/lK2
_kne]7o0_Kg6c;Jg]L>oaLS5^kbh_/[=bL;cmOKPhNCSinC2TI2DVYbYVYNIWibW
[JBOTYBRXJVcX::MX:BY[:NQY9NUYjjb/J:KWJ>XXK6XWjBEXZ^FEdMLDG=nOh:A
[Y6:Qj:RZ[R`WY^CXZFRYjNDSZZV/K6iVIFJSH23OX]jQgf2OSV1M7ZBOH^HSZRT
KYN1NfjSP6MFF59NE6ELGF1HEe=XM:Fb/ZZ][kJn_[fh/;6__;o5a;Bg][^n`L>n
o[DV_[W8_[j`[;Jca/:o_kFd`;fma/bf]kG3_lG8aK^l^;k:cLW2loGf0VWoh03S
o^Iic9jWZIZLWJ6YY:NXW:>NZ:jcZZ:PVij_[k:UYijKXJVc[jNPYJVZ];Bg/J2O
VJn/]ZjTRUUBKGNDYiJ@U:6T^;FkZ[>f/[jf/K2JViRaY[2ZVk2[/XbNXiVAO71l
LHV4RWYXKej_PhnGT7n2Phbl[7::Q6mNIV=LEe_oEDaQI5mNIFR8U[>k`[Zj]Zjh
a/;7_;6c]k>mdLk:^knb^L30`LNm_;Fk_LK9`;nj_[k;b<g4_[Zl`Lg@d/75^;c0
al_6`/6o`_3cmN3PhokV;LbNYjVJW9fQZJBWZ9bSWZR^/jZRX9^N[jnbYJNNVj6Y
/jnWX:FYZ[Bd]k6PWiUo[jbf[ZB:FE9]MiBWUY2DXJBh]K^Z/kJb_[Ja/9ZKV;6V
/:ZK/:^bS9jSVI5lL7aaRHB:NVQ_GZn3SiN@Oh:3S;b/LXZ4KeiVHeaGFeEEHFAO
GVEXR9Jc^l:j^[J^^<K2akba/kNc_M7>b[^o/[W0`<77_Kbe^kg6bL2o^[jnblPJ
cLBn^[c1cM3B`LFh_<37blK2`Ko2l??eh>3So^IQc9jWZIZLWJ6YY:NXW:>NZ:jc
ZZ:PVij_[k:UYijKXJVc[jNPYJVZ];Bg/J2OVJn/]ZjTRUUBKGNDYiJ@U:6T^;Fk
Z[>f/[jf/K2JViRaY[2ZVk2[/XbNXiVAO71lLHV4RWYSJ6mN[h>?Ui1oPX><_:ab
RXA_GVISG5MKEEEQI5mNIFR8U[>k`[Zj]Zjha/;7_;6c]k>mdLk:^knb^L30`LNm
_;Fk_LK9`;nj_[k;b<g4_[Zl`Lg@d/75^;c0al_6`/6o`_3cm@9Yon00h_kUNM2I
Vi^/ZJBSWY^OXZZTVJ6LWj^^XibOWjBRX;2SXIFMZjn_YjZVX:NW/;NXZiRQWJbY
[h]SGF9gWK>]YIRJXKFOYYnUW[>gZjjmXYZ@U9JRUYVRXjZ8T8^=TgadMFegKgEa
MfYYM8:@SY:?R8inQ[^?UI:0F55HEUUM9eYFEe9KEEELMhVZ/;Fd`Kbd[Zbh_;W3
_[Bd]K6mblG4[K2e^;Jg`/3n]Oo18LC7_;jj_;K6blRn][Fk`<_7c;bj]kc8`/30
]koam?GPh>;niBg@VI^K[:VTXijKWj:ZY9VQW9n[[Z>LWinTXZ2`Xj6EWJ^_[jNZ
YZ2WYk2gZ:^HLj6M[:V_Rf=MHWNM/jfUV9ZQ]InVWjFN/kN[[[fRVY2DUZ:FVJ:S
ZXR@RhfCO7AeKGM_MG5gJVUdPY2>TXn8SWj6^hnETX1HDEQFFEeJEUMBFeEEG7N9
Z[2e]<6l]:j/^;bi`kjd];Fa_L_5a:f`]KRf]l;0o[Go`@K4akbn^[bf6/K;b;jf
]K_0blO<_;Zg_<S2`<2g_o7dmN3Ph_kUHM2IVi^/ZJBSWY^OXZZTVJ6LWj^^XibO
WjBRX;2SXIFMZjn_YjZVX:NW/;NXZiRQWJbY[h]SGF9gWK>]YIRJXKFOYYnUW[>g
ZjjmXYZ@U9JRUYVRXjZ8T8^=TgadMFegKgEa?gMZJGB2T8jBShR>OXJkSiFBP5QA
F5IIGEYFEe9KEEELMhVZ/;Fd`Kbd[Zbh_;W3_[Bd]K6mblG4[K2e^;Jg`/3n]Oo1
7/C7_;jj_;K6blRn][Fk`<_7c;bj]kc8`/30]koam?D2JGoRh>GSi^KAXJFKVJ2V
[:bZXYFJWjFh/:NNWIRNZ:n^Z9nOY:^/]k:YXiR/Zk6dZ:fWWZb/^;6dY9bQWhim
SZBdX;2_[k33Z:nZ^[g7d=;Ca<K>c=K3b;jYWIN`[J69R7miOWJ1NW=fJG:3MGf6
]Gn0OH^DUX?DPg^D]G]KGeMBFGmKEf1RHTm:CfN4[K_1];Bc^Kc;aL6f/kNnalJn
`L6a][W5_lNh^<2m_/W:b;jh]kFl`/[0akbj_[k8alS7_/;1al_8c;S1_/??loKg
h^3UhnKVdJ6UViVPYZb/ZZ:EVYnU^;2WWYfHWZR_[ZROWjB[[;NbZJ>H[:^a]:R]
Yij/[7nh/KBTW:6OSWf>Y;BP/:n_/<>X[jZj_LO@d]?4a/k<e/?8_ZVMUk2]XHV8
OgUnMX5jLgIYLX=eOHJeOh1mRiBFPmB3NiBeNe]OEe9IFeMPHV9?BTmWQ:fk`KBd
/kVlblG1][>g_/O6_/71/KJiaKo7^;S0_Kk9b/Rn^;Ne_<;:`7o7_;Zn_/S7b<Nn
`/77blS<^<6n`locm_ORh>GSi^KAXJFKVJ2V[:bZXYFJWjFh/:NNWIRNZ:n^Z9nO
Y:^/]k:YXiR/Zk6dZ:fWWZb/^;6dY9bQWhimSZBdX;2_[k33Z:nZ^[g7d=;Ca<K>
c=K3b;jYWIN`[J69R7miOWJ1NW=fJF=bPgEmQ[EoP7f;U9J3e8=kU;EkFemGDUUK
Ef1RHTm:CfN4[K_1];Bc^Kc;aL6f/kNnalJn`L6a][W5_lNh^<2m_/W:b;jh]kFl
`/[0akbj_[k8alS7_/;1al_8c;S1_/??loKg0VUogn3RiNKUa9VCXJ:JUYfNYJ6O
Y9NIVZ2[ZJRFUJ2OZ:JXYInSY:f][k2QYZ>TYjf/YJ6RVjZSZjZUVYZ9OIb/^jB[
[KG0alG7`<S?dmKOgMcKe]GMf=WD_k6]/JBLQXYkOG1bJFU/SF]aIFE[O:24Q7J1
O8f;]iabN89fF5aQF5ioFe1KDeYECT]JK8FR]K:l[K6c^[Nh_kJg/kZi^l?2^[Bd
^[g2_/6l^[Vh`Kg4alBf[kW1`/^h`;Bc`L34a;^l]/2o`lS6a[Rj`?3flmoPh^GV
iLBITj6RVYJMWZFQWjBGVIZPZjVXUYFPWjRVZ:FOXjB][Jn`XJJSY:N][:FQXY]o
ZZ>[ZZFJVXUmW:bkY:^]]L37aLO0b<oCe]oMg=_FeMgHfMBo/JfaY9b6RW]mL79Y
JFb=Jg5UIF]lX8B4MX5lSH^gW79hPWIHG65HGU]@Fe=JEDi;FVb5X[Fb_:fa/kZg
^;nf]k>j^K_3`[Zd];Zm`[k1_;Zi^<6ma<O4]Zni`L9obkS0];?1`<C4^kbf`;o3
b<K6^;[0l?Kcgn3RiNKUa9VCXJ:JUYfNYJ6OY9NIVZ2[ZJRFUJ2OZ:JXYInSY:f]
[k2QYZ>TYjf/YJ6RVjZSZjZUVYZ9OIb/^jB[[KG0alG7`<S?dmKOgMcKe]GMf=WD
_k6]/JBLQXYkOG1bJFU/SF]SLFEUJgbPQ8AfPGb=RkNLLWR2MUQLHEQNFe1KDeYE
CT]JK8FR]K:l[K6c^[Nh_kJg/kZi^l?2^[Bd^[g2_/6l^[Vh`Kg4alBf[kW1`/^h
`;Bc`L34a;^l]/2o`lS6a[Rj`?3fl`9Yon7ohooUNL:NUXnKWjJWZZR:RZ:SZjFP
Wija/Jn[X:>DV:NP]K:]X:RNYkZg]ZR/VZ:][K2cX:2IWYbkXJFTVl31bl_>b/c?
dMOPgn7Mf];Ggn7Vi^GOf/:oaKo7_JNcU8B=Wg5VHfMVN7amKFj=QhAmTXf>JXBX
SWMkQ6AOGEeUOf=GHEE@BU1HJfb7WZJW[[30`<6k];>eblK;`;b_/;Vna/W0`K>e
^<?9b<Vh^kW2aLg4_KNk^LK:c/c0_;J``L;6`lO4_L72e=3_mOOQhN?SiNG2WYJ?
VinVYjZXRXZRXj^UX9nN/K6_Zj2SU9RWX;Fb[J2XWZNj]kJX[9ZR[Jf`Ok>PX9VN
W;^QYJBK`<7;blk:c<oAen3OhMgJd]OOhNKViMoJ`[o5_lNmYk>DQ8fOLFISIfIh
O7e]KXf7Q7fBSHiZQ:R>Mg^4I5mMGFESEf5ED4Y@F6]/QijVYjj``<31^kBc]L_6
bl2l[k2i_/K9`<6c]KS3bLS9^;^i`/G=a;fgOk^ia/[>c<2l][31`/K3alBm`L;D
d>oemn7Qhn?UiL:NUXnKWjJWZZR:RZ:SZjFPWija/Jn[X:>DV:NP]K:]X:RNYkZg
]ZR/VZ:][K2cX:2IWYbkXJFTVl31bl_>b/c?dMOPgn7Mf];Ggn7Vi^GOf/:oaKo7
_JNcU8B=Wg5VHfMVHgQlOFe^SHN4OI:=SVZ4Z8igNhATGeeMIF=GHEE@BU1HJfb7
WZJW[[30`<6k];>eblK;`;b_/;Vna/W0`K>e^<?9b<Vh^kW2aLg4_KNk^LK:c/c0
_;J``L;6`lO4_L72e=3_mOL2JOoP0>?ni3jkW:6CUHfLX:FSUhnITI^TYZBFY9fY
YJbXYi^KUiNX/ZVYVYfMX:6/]YFOX9fMXjZWWY^CWHjc]k[4^LFnc<knd@?HeMGJ
o]``fmWNh^STi>;:/;O5`m6j[9VKSHb8QFARH6]_O7^2U9R:NWMoWf]_YXQhIf9Q
I5iEEdiIGF1LFDYFDUQGL9:`[jNY/[:o`kbc[L6o`Ko9^;Fl/;Rh_lJn`;Fl`k_3
`;nT[kBj_Kc0`kNi^/S4`LFh^KBh`Kc5a[_1^lO3lOCdh>3So^@]^ibQTiF=W:2U
XiN?VI6KY:JTUZBMZJF/Z:NKViNGZ;:YZIZMWJ2Q[;JEWj2MWA2SZZNNVi>MS[>g
^/BiaKk<c_kA0mSEeM[ng6CKfMkRj>CTh/Z`]lG3dKZ/VI^=S8R5I69PJfmlNh:D
V8YjMgnOJfnVR7QWHV5TGUEGFEePG5U:EU9HEg2B/:nWZK:b_l>l/jg1_l6obKRe
_;2h^;o6_/2e_<>k`l2oY:nd^[fl`1[3]kVjb<C1aKRi];S1_<G6^l6kal?am?CP
h>?ni3jkW:6CUHfLX:FSUhnITI^TYZBFY9fYYJbXYi^KUiNX/ZVYVYfMX:6/]YFO
X9fMXjZWWY^CWHjc]k[4^LFnc<knd@?HeMGJo]`HfmWNh^STi>;:/;O5`m6j[9VK
SHb8QFARH6=[KgakPYBHRWYgOim[KjJ8N6MRHFANEEMIGF1LFDYFDUQGL9:`[jNY
/[:o`kbc[L6o`Ko9^;Fl/;Rh_lJn`;Fl`k_3`;nT[kBj_Kc0`kNi^/S4`LFh^KBh
`Kc5a[_1^lO3lOCd0VUoh>;UiNOT`Y2@VIjN[9jJTiJO/j^VXYRJXj^b]ZFRWJBS
Yj^W[jZMYJFdZJRTXjJO]:jbWZ:MUZJWZJ6D/:ZaaKk@a/[3`<K@fmgJe=CIcn;Q
in[Yi^CUgmS<bm;5^;FY]:>/QgQmSIJRT8jDSi2>^;J=NY1oNXZ]PVmYHE9FE6?o
IWeJF55?FUYYG6QnWjjh`lJj_;Rg][g<bL:c^[c1`Kk2_;Vo^LO0blS6_K30^l?6
bLBj_;Zlc<O@_;O3^l7?`/K0^[W7`/cBbOCdmn3RiNGWi<:@T9VNWZbNVY>FWk>[
YZ:HVZ>[/[JUXYfTXjN[YjnZWJFU]:VXY:>VWkB^/YioXYfFYZNYXIB`Z[75_]36
b/?0a]3KgM[De=W?h^7Wj^WVi>GOf<c;d/Fh]JVdXjb7N7f=UZ:@SYB?T8jh]Xej
T7mjRZf2KfUQDUIDHfIVFUQACeYJJEaXOYn^^<?6^[bh]kJmc<W2/kZl`L6n`[bi
_kW7`<_8a[f``;_3a/W4^[ao^[c<am2l]l>k`Lo2a/2j^LO2c=;9m?Cgh>;UiNOT
`Y2@VIjN[9jJTiJO/j^VXYRJXj^b]ZFRWJBSYj^W[jZMYJFdZJRTXjJO]:jbWZ:M
UZJWZJ6D/:ZaaKk@a/[3`<K@fmgJe=CIcn;Qin[Yi^CUgmS<bm;5^;FY]:>/QgQm
SIISXY2>U8n@S[RfSGZ@OgZ:[H9_JF5BEUASIVIJF55?FUYYG6QnWjjh`lJj_;Rg
][g<bL:c^[c1`Kk2_;Vo^LO0blS6_K30^l?6bLBj_;Zlc<O@_;O3^l7?`/K0^[W7
`/cBbOCdm`9Yon4nhnCVh/FRUiBAUJ:NXYFFVYFOVjRJU9RJYIfW/ifPUI^SZ:^X
YYfCZJFX[ZVWVJ6QYJfaYI^PUXZ<W:nZ^Zfco[/k`lO<d=CEd]kNgMOJfNCXjN_V
hM?Bb/g7akB`[;FIX9NPU8jEX:V[YZZbX:^^YXRDSg1hXXMcJUmCDDiJOe=QIUi>
CU=BCU9]NHnOYkJe^kfm^[6c_[no`/2f^[[0_Kbo_KZf]kfma/>g]:fg]/G2`[b]
^[^g`l;6`;fo_/70`lNm^;C4`/[dm_OQhN?Ti^;5XYNDTIFRWZ:EUYZEWi^XVYBH
VZFMYk>MX9FKXjR[Z:JMTjVUZ:jYYiVQXJF]3;6UVj2FRXbL[jZj[K?n^fo3alc@
e=GBg]kMem[Ii>SYjnKQdm;:cLO7];2/]IVPUj2DSYFPZJ^VZ[:PZjjVR9B?L7RR
Qg=ZGe=ACUYCHFINCTiCDTiBKGV?WjNf]K^m_KZa/kjo_l;0][Zj`;fl_kfj][Nm
_LK3]kB]]kK5`/:lF:fj^kO3`/K0_Knn`L33akfh]<C2b_Cfmn7QhnCVh/FRUiBA
UJ:NXYFFVYFOVjRJU9RJYIfW/ifPUI^SZ:^XYYfCZJFX[ZVWVJ6QYJfaYI^PUXZ<
W:nZ^Zfco[/S`lO<d=CEd]kNgMOJfNCXjN_VhM?Bb/g7akB`[;FIX9NPU8jEHj2Y
ZjJZ/Z2[[ZJ8U8m`N::7LfYODe5>FU=QIUi>CU=BCU9]NHnOYkJe^kfm^[6c_[no
`/2f^[[0_Kbo_KZf]kfma/>g]:fg]/G2`[b]^[^g`l;6`;fo_/70`lNm^;C4`/[d
m_L2J?kSO>KWi/bFVjB[XY^>U9:SZJNZViREXjR/Z9ZLVi^/ZJnYZIZKY:^^ZjRQ
VZ2[/kJ/[J>UXJJZYiJ<UI^H[l2i]KJc]lgDg]kEe]CQgmoUj>KSi^CSiMgMe<W2
_/>n^/>dY96V]<?7d:Z__l3?_/36XhJ5T9j6V8igGUmMJfmVBeUGGEQIGe]FCU9I
I9FW_[fj]Jnc_[g4a[fc/;Vmb<G6][6d^/?=b<ng_KBl^/G5`;bi^Kk9d/_0`;[0
`<S?bl>k^[[6aL_Cb[gdloOnhc3VinK<UY^TZj:KSYBBXjVWZY^HUJ>X[:RJW9^K
[:V_ZJVJVjB[[Z^XXIZPZk>f[:fSOjFQYZZWUXbEViR_`;Ve][>gcMCNg]GFe>7O
gnGXi^?Vi>?UgMgDbL:n`kjj`kBTTJJd`lO@ZZno`<nn`<JSQXF@WXJHSWMNGee[
KfIIEeeHFEmKETiBFFBEYkjm^[F_/kjma<Jm/k2i_LS5a[Ja];[3cLS?]kfd_;[5
aL2l^KVn5lWBbl30^/30b<o;`k^j^/K5bm?:_OCcmokSI>KWi/bFVjB[XY^>U9:S
ZJNZViREXjR/Z9ZLVi^/ZJnYZIZKY:^^ZjRQVZ2[/kJ/[J>UXJJZYiJ<UI^H[l2i
]KJc]lgDg]kEe]CQgmoUj>KSi^CSiMgMe<W2_/>n^/>dY96V]<?7Hm2Z[ko0ckk0
aZ>6QI2NQYR>MeiOGF]_IUUGGEQIGe]FCU9II9FW_[fj]Jnc_[g4a[fc/;Vmb<G6
][6d^/?=b<ng_KBl^/G5`;bi^Kk9d/_0`;[0`<S?bl>k^[[6aL_Cb[gdloL2JGoO
h^?TiNC<VY>;U9ZSW9B:TiBKWJ6NT9fJWj6/Z9bFWZ2XYjZQTi^HXJVbZjRHUjNW
ZJnWZ9jOWJ6FVjFQVYfZ[k6k`l?:cMOBeMGFelOGh=k[i^3Kf]OAfmWI`lK1`LG0
a<NaVZ>e/[G2a]GBck2f^KFBOhR@MHmmOV9OFEEFEGmCFeiKEE5AEf9GF6=jV[>m
`L:h]:^b^l:l_K:b[kRg`/Jm]K6e^K_0_L:k]k:e]/?5_[je^l34a/:j]:k1`/[=
al2a^[[6b=3El_?dgn;Si>GTc9ZCRiBJXibDRY>DVifQWY2MVYnQ[:RLUYjPZ:NZ
XI>KV:6Y/Z^XV9NWYjV_YgnXWYnMXIJKYJ6JWJZ_/K_3`l[=em;EeMKGamOPg^_V
h=_Jem7KfMW3a/71aL34ak6JXkFb]L;6eM;?/;Ji]I9oR91eSgenHUmIEEIEDe]N
FeEADEMREeQSNYZc_L72^;B[/[_2_;fb/Znh]l;6_KFa]KVk`;g2^kNb]KK3aKjn
]Gnk`<C6`[Zd[/72b/g7`;6j^/K8d=GbloCOh^?TiNC<VY>;U9ZSW9B:TiBKWJ6N
T9fJWj6/Z9bFWZ2XYjZQTi^HXJVbZjRHUjNWZJnWZ9jOWJ6FVjFQVYfZ[k6k`l?:
cMOBeMGFelOGh=k[i^3Kf]OAfmWI`lK1`LG0a<NaVZ>e/V>e`/KEd/n`][VeTWn8
T7F?OGiRGeUEEUECFeiKEE5AEf9GF6=jV[>m`L:h]:^b^l:l_K:b[kRg`/Jm]K6e
^K_0_L:k]k:e]/?5_[je^l34a/:j]:k1`/[=al2a^[[6b=3El_?d0VSohOkTN^G1
Wj:KW:6FVIZKZZRVU9BNX[>/ZiZJVj6Y]Jb`X9bJ[:Za[:>PXJfZ/kN_YYnNY:N]
YZbATiNDXK:cYZB^^L?@emS<bL7Be>3Uin?UgMgNiN?Ael_7c=G8f=?=_/?:c<39
[kG3`LcAbKJiUk2FY[6URJ5dPg1[KVUOF4eAE5UHJ5UBEUI;F66DY;Vn]KRk`Kg8
^[Zc/KRna/:l_K:f^l34`l6l/kFcb<73_;Nb]<C0cLc:_;>f`<O@aLRk^L2odlc9
`/G<lOGhhN7ni2kU`InRVibQUYVJVjZXYYBDWZ:c[:^JVY^QZKF//:2LVZbZ/JbS
X:6]Z[>g[jJOWWnTYjfV[96CUiBQ/[>VY:ji`m3Gf<c9`M;Dh>GWhnGMgMkUhm7G
blO<eLSHdlfn`l[<`<V_]L?1c=79][VG/9JV/JF9XGB3L6]^JEmHDEAIF6QIDUIF
BeQQU:Bi_[Fh^l6mb;Zj/k6h_/K2_;fb][_0a<?1_;>e/lS1`kbg/[C4`1W=c<Zl
/kK0am35b;^i`;oCc<W2aLcamOSQhOkTH^G1Wj:KW:6FVIZKZZRVU9BNX[>/ZiZJ
Vj6Y]Jb`X9bJ[:Za[:>PXJfZ/kN_YYnNY:N]YZbATiNDXK:cYZB^^L?@emS<bL7B
e>3Uin?UgMgNiN?Ael_7c=G8f=?=_/?:c<39[f>e`l7<dLVf^IN`UZJaYHVQM8=`
JfiYGeQAE5UHJ5UBEUI;F66DY;Vn]KRk`Kg8^[Zc/KRna/:l_K:f^l34`l6l/kFc
b<73_;Nb]<C0cLc:_;>f`<O@aLRk^L2odlc9`/G<lOGh0VUoh>7RiNKS]iFGTIZO
Wi6BTYZFZiZLWiRRWJFZX9RIXInSZJb]Wj:MXZFY]Z6/X:RQYJfLWi^GXIVOT9bJ
TiJGZZjg];W1^/C6a/o6eLcEfMgSi]kQg=cWeMK>c/G>aLWAe/Z][kZX]K[8bLg<
`:JHY8b>UYFJTh:OQGYbJEeWEU]oGEA@Ce=DDUaICdmCNHJ_][f`[K:_^KC7][B[
/kZf_/:n^[6e^KJn^KV/Z[Jf^kW0]kJh/Kk0c/2`Z[2m^/;9a;bf]l71cLg?cO;a
mN3Qh^GVhkNEUi6JWinATY:JUZ^JW9nHXYfUZZ2HVJ6OXjV/[InRWJ:UZKJQ[:2X
XJF]W9moViNQVIn@W9ZCUYNZ[[Nd^L6ja<K6clKEc=GIgN?Vg^7Lg>OEe/k>aLk5
bM7FbZf_^ZRe^/S9cLc0YYRTS8jFUIZCPYn5NW9YGFMFFeeDD4mCE59LFDm?DgV6
[kJm/:fb[kVdakJdZk>j][k2_[Za]KVf_[Vi[:Zf][^i`;Nf^;5o_/3>`;2Z/;fj
`/W4_;Jg`L7=cLo=l_7eh>7RiNKS]iFGTIZOWi6BTYZFZiZLWiRRWJFZX9RIXInS
ZJb]Wj:MXZFY]Z6/X:RQYJfLWi^GXIVOT9bJTiJGZZjg];W1^/C6a/o6eLcEfMgS
i]kQg=cWeMK>c/G>aLWAe/Z][kZX]KYSb<W=c<2VV:B<SYJEVY>2WhEjLVUMIeIK
GEA@Ce=DDUaICdmCNHJ_][f`[K:_^KC7][B[/kZf_/:n^[6e^KJn^KV/Z[Jf^kW0
]kJh/Kk0c/2`Z[2m^/;9a;bf]l71cLg?cO;am@9YOn?Qi>GVi[n/XYB?S8^IWJJV
Vj2DVjBYZ:6WV:2QZZb[Y9nPYj2][ZjPXZZT];6cYj:QVYjVZjjWXH2FUZ6UXZVR
[:njbLO@eLFn]M[BfmKNgm[Nj>W/kLo=a/kGfMS<`LG6`/30]JNYZj[Edl^nWYnI
SjbaXjZ0RGQiRW]XIdm@oe9mI6=HDe9>DeeXKG^7ZJnh]kg2_;ba^Jfi_lC7^[Vb
]LG7c<2o]:jf`<C3a;:_][74b/C5_L2g^<K7c<2n_KBnaLo<blBhc<kbloKShNCU
i^Jo[::DShb;VIfVYY^PU9^TZJRQYiRPXJZ/ZjBOX:NP[Jj^X::ZY;Ba/jNRXIZN
OjJ[[ZNQP9JFXJFRZJ:/[k[9am3EaKjef];Ke]kOf]kXjNc]clg6c]OIf<c1aLK2
`<2eYjV[Z]GCbkjNWiV?[;6SZX29N7V:NfQWCe1BDVASF5=BCU=MJ6ekQjV_^;Nm
`[bl/KV]^Ko4akZi/[G5alc0_kB^]/34`lBb[kJaa<[4OlFm`;Nha/O<`;jm];k5
clc;a;S<c_;cm^?Qi>GVi[n/XYB?S8^IWJJVVj2DVjBYZ:6WV:2QZZb[Y9nPYj2]
[ZjPXZZT];6cYj:QVYjVZjjWXH2FUZ6UXZVR[:njbLO@eLFn]M[BfmKNgm[Nj>W/
kLo=a/kGfMS<`LG6`/30]JNYHj^ZeM?;_YjOVHn//J>ZP8UhNHYkJ6M?D59BI6=H
De9>DeeXKG^7ZJnh]kg2_;ba^Jfi_lC7^[Vb]LG7c<2o]:jf`<C3a;:_][74b/C5
_L2g^<K7c<2n_KBnaLo<blBhc<kbloH2JEWQh^?Si^:_VYZNXY6<S9BKXjVTUIJH
TiZOYj6XVZ>LX:FXXI^AWijXZj>QVj>OYjR]YIFHVj>RYZF8THNGVJ2^Z[^]/K;2
alc7^KWAc]OHhMoOh>;ShN?McLSndB;Ccl_?_lC3`[6_][VS]Lnec;FZXjBV[IRX
THI_MXmfGE9CG7m?CEIFE5EMEDi>EeQ]Rjna]jZbZZnf`;^][[Jh^K^n[kNd]kbm
a[fc/jnj`<Nn_:f/^;Jf_l;2/;nm_l?5b;fi/;Ro`Lk@`<C6loCfhN;ShnKR[iZJ
WZ:AS8bDVj>YY9FFV9>JWjNQZ9ZSW:2UZ:6KTInNZ:^SXI^SWjNX[JFEV2FKXj:V
YHRAQiNIX:jZ^jfa//;7c<Ni^M7>emSQgmoPh^?Qhmg=b?kAE]??blnoa<?2/Jnf
^J>eckG<]JZSY:J]V:RAQVmfSgIMDU=LCdeFEUAEGEE>CUMHKH^_/KNZ/ZZ_]/2k
[Jjf^;Vk_Zng];Nl_LJm/k>_^/37_[b][;Rf]W6o`/:`_kfo`lG8_KV`^;o1c]30
a<Kcm?KQh^?Si^:_VYZNXY6<S9BKXjVTUIJHTiZOYj6XVZ>LX:FXXI^AWijXZj>Q
Vj>OYjR]YIFHVj>RYZF8THNGVJ2^Z[^]/K;2alc7^KWAc]OHhMoOh>;ShN?McLSn
d@[Ccl_?_lC3`[6_]V>iXkG?]LbeZZ>TYZfHZ966KgJ?MUeBDea?CEIFE5EMEDi>
EeQ]Rjna]jZbZZnf`;^][[Jh^K^n[kNd]kbma[fc/jnj`<Nn_:f/^;Jf_l;2/;nm
_l?5b;fi/;Ro`Lk@`<C6loCf0VU0g^3RhnSV`ZRPWI>BVibVXj6IUYZVZ:RQVhnJ
^ZbeYJ2GVZ:M/ZfYYiNJYJb`[:fKY:2Y[jRZY:B7OibDYJFOYjKn^c^d`l;0];O0
fMcPgMkGhN7Yi^C[d/kDeMcKe<Zeb<OAe/jk/:>``;kK`[^h[[Rdc;jXXHV5RXN0
OUaHF5UoDf1XHUYECDeGFf1OHWNPZKVk_Kbg/J^g]l?3aKR]/Kk2b<G9`lFb_L3;
c<G4/[ni`<c8a/:h_/3<c<[9`<C0`LO8bLC4aL?>doGem]kPh^?Xi/:XX9fCTY^L
YZ>QVIJJYZRXXI^?V[Z/]JFPUiZRWK:]ZJNGVZF//:b]VjBPZJl<Z:ZTY8MoW9BU
YInWY_jkKkC3`/2d]l3Ig>3Mg]OQhNWVi>_Bc]CEg=_Db[G8am7Fc[^`Xk30_]_2
^kR^^;C<_ZRQRHF:Qh1nG5QHFE=PJ69JEDe=Ee]PGf9gX:Vi^kfl]k6[]kO3`lFh
[K6n`/S5bL?5/[g0blc5a;:o^L3<b<IH`[Rn`<c<b/W0a<31alS9a<C5`lkCmOGf
g^3RhnSV`ZRPWI>BVibVXj6IUYZVZ:RQVhnJ^ZbeYJ2GVZ:M/ZfYYiNJYJb`[:fK
Y:2Y[jRZY:B7OibDYJFOYjKn^b>d`l;0];O0fMcPgMkGhN7Yi^C[d/kDeMcKe<Ze
b<OAe/jk/:=S/<2nfl:k^:jh]<bnZ:69QHZ7P7iLF5QIDf1XHUYECDeGFf1OHWNP
ZKVk_Kbg/J^g]l?3aKR]/Kk2b<G9`lFb_L3;c<G4/[ni`<c8a/:h_/3<c<[9`<C0
`LO8bLC4aL?>doGemP9Yon0Fh^7Ti/:IXijHTi:?ViZSXIJHUYfOZ:KnW6>QZjJ_
XInGVIfSZ;:VXZ2SX:JaYZVHYJBNXZVWTh2ET9FGXZZc[ZFf];Vb^K>_^=WJh=cP
h=oPi^OQg=3=c[o6d=WF^Kji^k;:a/2/X:nma<C:`;:/[KZgV[6:Qfe_K7]QG5UC
I4eEGUQDFU14BeELFFB1XjZb/k^h_[R`/[Fg_l2l`KF^]KVm_<;6/;6c^[k2a;Vi
[KNjbLC3_KRc_;c6a/S0^[Vn`/[?a[fm_l_cmOCPh>;Qi>K2VJ>NV9>BSi^JXj6F
V9JMWjRVoY`GXJ^V[j6OUiVMXjRbYZ:PXj2V/JJYV:FTOijRZJNCP9F@UINRZ[>^
YKJd^K:i/jnhfM[Pg>3Pgn3Vin7Ld<g>_lK@fMJi_[Vk//[6`:bP[kg4a<[0/Zb]
^[NJ/HZ7KFm/Nf5LFE==EEiHE5Y@A4]EG5UTPJ>Z/[>k^;jh/;:e]ko0_<6e[[Fi
_Kc2a[2a/kZn`/Bi^Jfg^/W4<<>m^;>l_<K6b<2j^Kk2b/o6_Kfobo?em>3Ph^7T
i/:IXijHTi:?ViZSXIJHUYfOZ:KnW4^QZjJ_XInGVIfSZ;:VXZ2SX:JaYZVHYJBN
XZVWTh2ET9FGXZZc[ZFf];Vb^K>_^=WJh=cPh=oPi^OQg=3=c[o6d=WF^Kji^k;:
a/2/Hj2__LC4b/2b[:fj]iZaRXM]KfakHEaIDdeEGUQDFU14BeELFFB1XjZb/k^h
_[R`/[Fg_l2l`KF^]KVm_<;6/;6c^[k2a;Vi[KNjbLC3_KRc_;c6a/S0^[Vn`/[?
a[fm_l_cmO@2JGoNh^?TinG:VIFFT92RYJFLT9B=TYbUVIVFZYbRXZRTW9BBWJR^
YInMU9b][ZbQXINFU:>TZinQWHN3VIn/XYFO[;6f`[Zf/;K5b<[Ig]c:emWTi>?P
d/[3d]O>a;S;a<k2a<K3cl;BbL6m];fc]kFl/K_2^I>MOXQROWekEU9>CWmHG65J
Cdm=E5QKH5IJK9:Z^L:o/kJ^[K>i_l6n/;Zd_l?7`[Nb]KK1a/^n_[Jc_KS:_<>h
/;Rg_/W3a;Vo^;k2cl[0`KNh_lgLlo?dg^;Si>OUbYVEUY2@XZFUW92DSI:LYIVI
UZZLXZ:XY9bDTYfX[ZFOWIBL[Jj/XJ6GUYBSY7n[Wj6MQh>IWjbRUIn//KK2^[J`
]/G8b]WNg<[GfNCThn3Bb/?Belk4^<_4c/;4a/??`];9`Kfd_K>g]Kba^l:iTien
R69nOG]FDTi>F5aQFTm?CEAHFf1FFVbBZ[W2_k>f[Zfc^Ko1_[2j];o3al:g/[Ff
`LK;_[jf/kfhb[c3^7n`^;NnbL?4^Knh_/;?b/31]kRocMccloCNh^?TinG:VIFF
T92RYJFLT9B=TYbUVIVFZYbRXZRTW9BBWJR^YInMU9b][ZbQXINFU:>TZinQWHN3
VIn/XYFO[;6f`[Zf/;K5b<[Ig]c:emWTi>?Pd/[3d]O>a;S;a<k2a<K3cl;BbF?1
_KBm/kNe_;6k`[VCWGj8HWimNeIBCTiHG65JCdm=E5QKH5IJK9:Z^L:o/kJ^[K>i
_l6n/;Zd_l?7`[Nb]KK1a/^n_[Jc_KS:_<>h/;Rg_/W3a;Vo^;k2cl[0`KNh_lgL
lo?d0VUohN;Ri>KTaiRNXIBEVijRYJZNWhZAWIn^Z:bIWIj//K6TXi^QXJV_[Z>Q
YZNY[Zj]XijOXJfZ/jR>S9FPZKB_ZKNZ[[>oc<Rm]MC:d=WMgmcDf=[Hf=GEcL[>
eLc9cLk7a/S0cMWAeLk;aZjZ//JkakFh^KNfYYVNMUmUK6IMDe5oEe1OGf5JF5a@
E6MIMHZO[Jngckk0_KFd/[:e_lC5_<2kaLK6aLNj`;c3a/S3_kbh_[_6`Lnn^KC0
_/;3c<G3_/C5cm?8aL7:eO?dm>7Rh^CVi<NHWZ6DUI^NXZFZWYn:TIfO[ZR/VIfN
[;6aY:>KXJ6Y[jjSXJJWZJj^[J>NWj5o[JZcZ8j<UJ2Y]:nY]jZ^/ko<b;fee<[@
fMgOg=CHf]SHeMG=b/kEc<W=c/O6b<3=fM7Ec/_6[ZZba[_7]KRi]kJVVIifGfE/
IUeCDEM@GemQFUQLD5AWFGF:Wjf_]lnn`;fe];:b]Ko4aKc0^lG6a/G7^/2l`lK8
`knl^;jka/5ockji]<2n`/?<aL>na<G?dlS5`L[EloCdhN;Ri>KTaiRNXIBEVijR
YJZNWhZAWIn^Z:bIWIj//K6TXi^QXJV_[Z>QYZNY[Zj]XijOXJfZ/jR>S9FPZKB_
ZKNZ[[>oc<Rm]MC:d=WMgmcDf=[Hf=GEcL[>eLc9cLk7a/S0cMWAeLiSblJ^Z[;6
^lNe^;Vg]ZJIWWIOIFaVGE=AEe1OGf5JF5a@E6MIMHZO[Jngckk0_KFd/[:e_lC5
_<2kaLK6aLNj`;c3a/S3_kbh_[_6`Lnn^KC0_/;3c<G3_/C5cm?8aL7:eO?dm09Y
On?Qh^;ThkfDTHBDWYjSW92DSj:QWifJWi>cY[:SXIfMWZNa/Z:JV8nCWKFWXYjL
YZFY[ZZPUI^;OhjWYjBPXZbb];Ve^:ng^[?>cMOBd=3KhN3Nf]72aLSAe]S9a/75
bl_Ac<O@alG2b<>h[J6OWlC2`[Z/VhBCRi5WFfAADTmJOemFF5AAAe5PGE=OCEmb
X;>o]KB[Z[J_aL6e]Jj`/KK7`/;1_Jj`_lC5a;^j]kRn`<Ri_Jbd]l;:b[fe^;Vj
a<K8a[o6_lK:e]Kam?CShN;Ri>>mU964U9jNXib@U8nRXInMVYnC/jJbXj6MWIjW
/K:RVYR?TifeYj:NW:JUZJjZOj2EVh]oSZNWY:2R[;:d^KFh[kNj/lk=em;@d=_Q
h=kJdL;5b=7Ff<W6`LG;bm7<am37aL;8`kR]XInOa<;2^ZbKQ9>;TFMKI55BCeYO
EUQDDDMAH5eCGdeOLZ2c_kFdZjZf[lG1]KF^/;6fal;2`Kf^/;o4aLBk^[Nh_/38
^Kf/OkBg`/[:_KFh^K[4a/S6_lJoa/[Fe_7dm>?Qh^;ThkfDTHBDWYjSW92DSj:Q
WifJWi>cY[:SXIfMWZNa/Z:JV8nCWKFWXYjLYZFY[ZZPUI^;OhjWYjBPXZbb];Ve
^:ng^[?>cMOBd=3KhN3Nf]72aLSAe]S9a/75bl_Ac<O@alG2HlS3^:fQWio4`/:j
[9^4Th^AIe]TDE9?FUmFF5AAAe5PGE=OCEmbX;>o]KB[Z[J_aL6e]Jj`/KK7`/;1
_Jj`_lC5a;^j]kRn`<Ri_Jbd]l;:b[fe^;Vja<K8a[o6_lK:e]Kam?@2JGoPh^GT
i^BmZZ:GV9>IVIjNWhjBU9^ZZJJN/ib[YJFZYIjHX:J^^Z^SXibUYjnZZJBLXYfU
[:RZTh2GX:>Q]JJW/:je`/W<blVoa]7Og^;Lgm_If=_Jdlo6bL?7a=oCd<c9a<_?
f=K8`l6c^KBg/ZZg/LJg_;6CT8>=KVeXG5eGEWmEFFaDFdY=FEMNGEUfQ[2i^;g5
_K^h[[bi^/>n_[Zg`;c;b/Rh];Bk`/;:a/>l_KW5a/_1_KRm`l?8a/O3_[^nalc@
cl;7aM7?l??eh>;Ui>KT_JZRUiRCVIVNWYn>TYBKZZVVW[>LZjFUZZFNV:2V[[Z[
Xj>LYJN_ZZVTW::MYGn/Z:ZCP9NPXj6eYZN`[[G2bLc;bKo6dMoNh]cOfmWHfm[C
clK9`lO4gm?@c<W4bloHe/S3`K>i];NbZ[Naa[Nl/I>@Phe^KFQLGEMFEEU/E5]:
CEUGGUeIMXJ`^KRmaKfk^:jl^K[3_[jj]l2lbl[8^;Bd^l;2b/K3_;fiaLK;`Gnm
^;g3`lS6al>n^kk7c=3?`/O5dLo`loGPh^GTi^BmZZ:GV9>IVIjNWhjBU9^ZZJJN
/ib[YJFZYIjHX:J^^Z^SXibUYjnZZJBLXYfU[:RZTh2GX:>Q]JJW/:je`/W<blVo
a]7Og^;Lgm_If=_Jdlo6bL?7a=oCd<c9a<_?f=K8`f?1/kVd]k:Z]k76]kbaTi23
SFi]J5aMEeIEFFaDFdY=FEMNGEUfQ[2i^;g5_K^h[[bi^/>n_[Zg`;c;b/Rh];Bk
`/;:a/>l_KW5a/_1_KRm`l?8a/O3_[^nalc@cl;7aM7?l??e0VUohN3Ti>GRZXb<
TIfSUYJ?VI:IXYZ@WIFEW[2ZYIfIUYJWYJJYVj>IWZJZZ9^HUj6SY:fRWI^DVYB:
YJ>HTjB/^/G0_kRe`m;AdmOHemCQfn3TgMK@d];Ge<k7_[W5bLO8e<o7`l;7bL>m
ZJBRXZfe/[:hWiRCSjF:Q6IMEDaDDV9oE5=ECeAEGeaJEEIGJh:a_;jc/K:b^Kk1
^KBb[kW3a<O3_kW0^l75_KZl_[C6`<W3^[Rc[kc3c<6m_[g2b/?7_/:k`l?6dL[;
d?;cmN7Pi>CUhZZ<S96MXiJFSiVBVJ:JT9fEUIj`ZZFMVIJFYjFVZI^SVIjVZZRK
V9NQXjB]XYeoViBJU8ZUXiRCY:bjaL2o^;G3d]7CemSGe>7Kh>CMe]3Bd]ODc/Nn
^LG9alSDclO3`/O9`kfYY::R[KFb/[ROV9>?YHZ4IUeEC5ABHUACEDmDEEmLFUEF
Ef^2/Kbn/k6b/[Vn`KVd/Zni`lC7`kni`;_1aKfj_;jda/39`kZh/jmo_<?<`Kfn
_L;:`lNn`[_3`lKAb/_@l_?ehN3Ti>GRZXb<TIfSUYJ?VI:IXYZ@WIFEW[2ZYIfI
UYJWYJJYVj>IWZJZZ9^HUj6SY:fRWI^DVYB:YJ>HTjB/^/G0_kRe`m;AdmOHemCQ
fn3TgMK@d];Ge<k7_[W5bLO8e<o7`l;7bL=S_JVTXZ:]]K:b^9nHThnURXAVGEE<
E59RE5=ECeAEGeaJEEIGJh:a_;jc/K:b^Kk1^KBb[kW3a<O3_kW0^l75_KZl_[C6
`<W3^[Rc[kc3c<6m_[g2b/?7_/:k`l?6dL[;d?;cm@9Yon5mi>GUhkVLVIbMVI^M
Y:>GVYbMWZZUVij[Y[FXYJFSWI^PY:bZWJVDYjf[ZJ:WXJ>UYJRVX9j<QYRXWJRe
Zk2gb<OA_l_4bM3KgmgOhmGAfMoNfMgGf]3EcLG1`L;0_/oCdm;8`k6c/;:Ue=W>
^kR8UZn/XIB4OX]gIE]HE4eO@UMFHUAMDeMEFUYPIg>:/KRh^Kbl`KJj^[c9^[Rk
_;k2al_5a;o4_lK;b<^o`[g8al74`[[2_/O7cL_:bLK0aLK=alSnbcW?f]KbloKQ
hNCUiN>iW9VLWIVKWJBSUiZLWIjZYI^NZjJeZ:FUXifKX:B/ZYfYU:N]ZjVRYj6S
YJFXOjJPWXb6V:RMZ;F[/;O8am6oblC9d=_OgMoSeM7IgmkIgMOJd=G=aL71`/2n
cm?Cd/S3/K>`/ZGDfLjk^8RF[jbQU8AnRgMUFeQDCEmGEV9DGE=GEEYJH6McR[6h
^;Vl_<6f^[ZlbKZh^kbn`/O;aLBoa;o6blS;_l:mb<O1a<:j3/:nalO=bl[9a/35
a/g7b?k;KLoJe_;cm^7Qi>GUhkVLVIbMVI^MY:>GVYbMWZZUVij[Y[FXYJFSWI^P
Y:bZWJVDYjf[ZJ:WXJ>UYJRVX9j<QYRXWJReZk2gb<OA_l_4bM3KgmgOhmGAfMoN
fMgGf]3EcLG1`L;0_/oCdm;8`k6cF[2bYMCIc[^hR9J_[:6DQ7j;MfEKF5A=GeMF
HUAMDeMEFUYPIg>:/KRh^Kbl`KJj^[c9^[Rk_;k2al_5a;o4_lK;b<^o`[g8al74
`[[2_/O7cL_:bLK0aLK=alSnb`G?f]KbloH2JOoQON?Ui^:jSiVRXI>AR8j=TZ2N
UXnDVYnVZ:6]W9bJYIjSYYbMWIJZZZRKViJFYjnbWIZMTi^LT8bEWHFEW[:h_lK0
`[nocMWHemSLfMoMg]_G`l[@e]oKe;nk/[bk`lo@`<Zg`<O4Yj>X]Y^L[k>iTFeV
WY>YOGAcOeA@Ee]KGbmEE5=BGEIPEEI@D5J3XK^j/Jf^[[C1akjf/jfk^lJo_kVf
][Nmd;bm][Re_l_7b;cn]Tc5al;1_KVi_lG;cL[1_[nlam7Bcl_6l_?chN7SiNKR
^XnIXZ6CTHR>SI:PWYJ?U9ZOYZRQ[IbLVZFNXjJLWIfFZZZXVi^FUZN_/YfJWG^C
Vib@S9FMQIFN/[Roa/32_ko=fMSGf=cIgmgNfmO3b]3Fgm_D_k^b_;_3cm30b[O0
alBWXjRfVib_/kVAKFJNTjUmM7=oE51GFe]OEEACDUeFH5EFD51FPj6k^[6][Zjd
`LNn][>]^k_6_kni][Jg_M2l_KJh]Ko;alRlo[H0aGo7`/6m^KVoaL_=b/6n_kc7
dM;?blKblo?QhN?Ui^:jSiVRXI>AR8j=TZ2NUXnDVYnVZ:6]W9bJYIjSYYbMWIJZ
ZZRKViJFYjnbWIZMTi^LT8bEWHFEW[:h_lK0`[nocMWHemSLfMoMg]_G`l[@e]oK
e;nk/[bk`lo@`<Zg`<O4YdNSZ;JKW:nc^I5]IYjCZGedLgmDD5MKFemEE5=BGEIP
EEI@D5J3XK^j/Jf^[[C1akjf/jfk^lJo_kVf][Nmd;bm][Re_l_7b;cn]QS5al;1
_KVi_lG;cL[1_[nlam7Bcl_6l_?c0VUogn;RiNOUaI6=RIRKXYnRRHbAW:BUXYbO
X::XZZnYWZ2LZZj[/:>IX:2]ZZNNY9nVYjb^YZ>JPF]lUIbIYZJW]LW5^lRi/kCB
gMoPi>?Oe]WJh=KLclkJemOFcL:e/;O3dLk7_lC0`;k;aIbn`/6g]kjdM9NNXW>0
NH5QEEMIFEPkFEMNFEEIG5]UFEePPibc`l;0`;Fj_;g5aL:m_;_4`lO1_l6m_lO6
cL[;_[fn_<c:b/O2cko3alW9aLG1o/M0clg9`LO;c]?Jg_Cfm]oRh^GWiLFASHVH
Vj:OXXV<TIbTYJ:LWj2RZ:Z_ZIjPW:Z^Zk2SVJ2P[JZWWZBOYZN/[ZIoXiZ1JgbE
W9VVYZNebLFkb;Vc]=;Mgn3ThmoFfM[Pe]c?c][GemK=`[F`]l?Ac/Noa<30_/_5
W;k2`KNg_[AdUijRLh1iPF5EEeUIF5UGGUUEFEaKIEUMH8>L/l?2`<2e^[bmaLG2
_Kbka<?7`Ko1_Ko7a/g:bkjm_[c<b/[7`/l7_l?7bLW5aL7nagC?cLW1al_>dm[N
m?Kfgn;RiNOUaI6=RIRKXYnRRHbAW:BUXYbOX::XZZnYWZ2LZZj[/:>IX:2]ZZNN
Y9nVYjb^YZ>JPF]lUIbIYZJW]LW5^lRi/kCBgMoPi>?Oe]WJh=KLclkJemOFcL:e
/;O3dLk7_lC0`;iCblFL_/;1]kNn]7BGWZ9cP7V1HEEGFEUHFEMNFEEIG5]UFEeP
Pibc`l;0`;Fj_;g5aL:m_;_4`lO1_l6m_lO6cL[;_[fn_<c:b/O2cko3alW9aLG1
o/L<clg9`LO;c]?Jg_CfmP9Yon1mh^CUh[NCXIbITHf@T9fRU9R?S:>T[ZFLW9FB
Y:BbWjFIV:6UZZJ[VYNJVjbZ[ZZLVYZTFDe9L7b7PiNU[k>iZj>>NHJP_LgDg>7S
g]kMbmC?e=7LfmKD_[Vg`;Vk]l2e]kjm_<g8^W]h]/G?^KRY/FEUYJYmNUUJDf9N
F5MBOe1=EeeLFemFFE5IJ9VZ/[J^/[[2akjf/kRZ_/[6bK:h^Kg6b/W9_<:e^L?9
bKo1^KVhbL_5`kff^;g6b=;3^l?7a<g?clK9`Lcdm?KPh>;TiN:gTj6LVI6=T92M
XYBHShbSY:jUW9bETZBT/YnUVIRQYJZVZiZGVY^/ZZjZW9ZJOjAICDU`O8N3UjF_
/kV[XhiiQZ2mcMCLhN?Ng]g;e<oDdMcKe]Bn^KO0^K^g`;Fg_[flcLRjNgRfaLni
^:VaIFFUZWejFEYCHUiHEe9@CEMMG5]OEUUAFFRIZ[:f[[:j`/Nn][>hZ[k:a/Vb
^;Vma/[9bKc2]KW3bLVo`KVi^<W;OlG3_KJh_LK8d/>k`lO4cLo?a/W1c?Cdm^3P
h^CUh[NCXIbITHf@T9fRU9R?S:>T[ZFLW9FBY:BbWjFIV:6UZZJ[VYNJVjbZ[ZZL
VYZTFDe9L7b7PiNU[k>iZj>>NHJP_LgDg>7Sg]kMbmC?e=7LfmKD_[Vg`;Vk]l2e
]kjm_<g8HkYkN;K5ckVhZK5UIJFZOGYIFU=RGUQGDU1=EeeLFemFFE5IJ9VZ/[J^
/[[2akjf/kRZ_/[6bK:h^Kg6b/W9_<:e^L?9bKo1^KVhbL_5`kff^;g6b=;3^l?7
a<g?clK9`Lcdm?H2JGoPhN?Ti^BcT9^OY:>NVYNIX:2YWiZRWZ^][ZJMXJ:OXijb
ZJfIW9fNXjb_X:>SY[6c[[BRYDa8DG>9SY26TJNPZ9]kMfIIHIFfgMgHe][Kg=3J
d=OMgMONg[o2^lVd`<C4]j:S/KgJak^HbKFldl?8`/F0GW:=PheOIUMGDUaQGSEJ
FEiLFE]LJ5]FFf:QZl70^[bk^[jl_[bl]<71`/?3b<;4a<31bLW<aLFm`/C0`<C2
]l?0alknbTK0^;g=c=;6a<S4cLkCd/oCl_?fh>7Si>KT/i2KWjBSWYZGVJ2PZInJ
XYj[[JjVWJ6RWj>N/ZV]VIbMWZ>/[j2SXjJa/jjdXWnUC4QALhV>T8JAYj2XVg]g
IUUQUKKMgMSFf]_Ld=[@emgMemkN_l:kbKC0a<BgXZ>a_M[7^iS9]KcC`lS2aH1N
LXf3SEmVEeMBG65NFUUNG5UKG6QKEU]RXJ_1`;Zl^kZn_;jl_;C1`L;3`lS2a<C0
`LW9c<G5_L;4`<34`[O3`077c_k:N/2h_Lg<d/K4b<C=c]?Bcm?bloKPhN?Ti^Bc
T9^OY:>NVYNIX:2YWiZRWZ^][ZJMXJ:OXijbZJfIW9fNXjb_X:>SY[6c[[BRYDa8
DG>9SY26TJNPZ9]kMfIIHIFfgMgHe][Kg=3Jd=OMgMONg[o2^lVd`<C4]j:S/KgJ
adfkV<Ve_=?3b<;5P5ibSH>=GfIGEe9LHEiJFEiLFE]LJ5]FFf:QZl70^[bk^[jl
_[bl]<71`/?3b<;4a<31bLW<aLFm`/C0`<C2]l?0alknbQ;0^;g=c=;6a<S4cLkC
d/oCl_?f0VUohMoRiNKO/IfOTYB8RiBSWiJEW8RDZ:R_XZ:;U::cZZNGWXjLY;2Z
Y9nIYi^^[:ZZXInNX:YVDEUKIFZ1W9=WG4]6ATmECEAMHgJ=c=7Kf];Cbm[Mh=3>
f]?7bl[B[[Be/jNVW/;@c[:YX=_4`]B[[jO;VfYLMW1YID]MGEIKD55oCUIOH5]G
DU1@F6YfXJRdZZ^e`<S3^:nc];g9cL:k_Kbmb/S1_[Vm^[foa/Rm_K>c^l3A`;fm
_[oEb/g;bko5]l7Ac<o2b/35eo7dkn7Oh^GVgk6MWi:DR8^DXinFUIb8U:RX[j:R
RiBR/jZWUij>W:B`ZZBOVJNK[ZbZZZ6OWZ1oZVIAFE]UJX6LTfMLBdI6CeE=E5eS
MXg<dM_Jd]?;f]gPd<kJdlO;b]:^];FcYjJN`]3>/ZVPflC2e:^_Yl^KJUafL6UU
BeeMEU]@DDiFGf1KEe9@D5QZMZ6X]:Z[]L38`kR_/kBmbLg2^kfl_L[8`Kji_KZm
_lK8_Kfc/k_0dL3o_Gfn_mG:cL_;_lFg`M7<cl;:`<GGlOC_hMoRiNKO/IfOTYB8
RiBSWiJEW8RDZ:R_XZ:;U::cZZNGWXjLY;2ZY9nIYi^^[:ZZXInNX:YVDEUKIFZ1
W9=WG4]6ATmECEAMHgJ=c=7Kf];Cbm[Mh=3>f]?7bl[B[[Be/jNVW/;@c[9SZJ3K
a<;DZjnWbi]ZG7I`JFE;GEeFFe1ACUIOH5]GDU1@F6YfXJRdZZ^e`<S3^:nc];g9
cL:k_Kbmb/S1_[Vm^[foa/Rm_K>c^l3A`;fm_[oEb/g;bko5]l7Ac<o2b/35eo7d
k`9YOn?Ri^KUhjfIVY^JW9bCU9ZTX:2GX:2IYinaVj>QX::PXJVTXjB/ZZ^aYj^L
Y:B/[jRXXZJTXJAgHfM]PIYhEdE;DfE[O8bPY7Y^MHnNd=?Gh=KAgmWKfmgIdl_8
cKg5_;2QUY?=elVhb9Zg[KOAa[bi`hQTEX]bLVIFDF1GFf=UOeeIF5=JE5UEFEaR
LZ^h`[jl]k[3bLG1akZf_LG7blO<_l:i`LG8`L76_L;8al[1_[bna<?=bLW8clG5
a=3;c/;5aM3De=;3cM?aloKSh^KViN>]VIZKVYbLTiBJY:2PUj2PVJNO/I^SXJ2R
X:6YY:>T[:Z[/JN[W:BT[:nXZ::VOjBQY7MSIff1VWQGAD]CIF]lS:2TNVieSik@
dmOPe]7OfM_KgMWCblS=_LFl/:6FTlgGbKS8V[N]]m76_;W3R6AFRg9bIUIAH5MK
HfEMFEQCFUAIEEULHW:[^<:n_;Nj`lW5`LNj][g5al_7c;o2^L75b<71a[g2b<O:
`Kjl_/C3Olg9bLS?aLG4d<_>`/G5d=CDd/?=do7cm^?Ri^KUhjfIVY^JW9bCU9ZT
X:2GX:2IYinaVj>QX::PXJVTXjB/ZZ^aYj^LY:B/[jRXXZJTXJAgHfM]PIYhEdE;
DfE[O8bPY7Y^MHnNd=?Gh=KAgmWKfmgIdl_8cKg5_;2QUY?=elVhHlRJ]jfgdLJl
^L>8I5J;LW9VEU5PEe]SIEeIF5=JE5UEFEaRLZ^h`[jl]k[3bLG1akZf_LG7blO<
_l:i`LG8`L76_L;8al[1_[bna<?=bLW8clG5a=3;c/;5aM3De=;3cM?aloH2JGoQ
h^7SiN:mV9NCS8fQX:FSTI6HVjFXY9bIVibbZj:HVYbFWZZWYIfNUifRZK>RX9ZO
WjBa[J2GPf=TI6^ZRV9EIWISNHfAX:^X[[2_[9j<Z[k0dMgId][=aL_?b/Zk`ZbY
TY^ZbKBFWJjAb;f_Z;nWY<j7IUQdJ6AQHEMODde>EgmJFf9BE4iED5=NKWjWYkBd
a<C0_L:m];k1bL:h]kRk][o=_L>i^[Voa/S2^;Zi_lK;c<Vj_K[2`]7Aa[c3_<75
c]3?a/33a]GKm?GdhN;QhnGR_IRGThb=XJ2UXi6AV9^UZ:BLVI^L/Z^RV9ZLUYjZ
YjFMWYNMXZVcXZ2JWinT/Gn]X9N3HfATJjZ:HUEVMV=iSI6PZjR^/:n/WXbZ_/3A
gMWBf/g5blo:b[_2[:VBVj[9]9JM[Y78_JnX_jNTcXMVF7AXI65QEemCCDiGFU]R
DUA>EE1CGVinYjNd]<C4`;g2_KBn`LW2^;Nh^kJocKg3^KZi_lK8`[Rj^Ko6blc9
^Wnm^/;2dM76_<>l`LG>d<o6`<?6eM_dmOCQh^7SiN:mV9NCS8fQX:FSTI6HVjFX
Y9bIVibbZj:HVYbFWZZWYIfNUifRZK>RX9ZOWjBa[J2GPf=TI6^ZRV9EIWISNHfA
X:^X[[2_[9j<Z[k0dMgId][=aL_?b/Zk`ZbYTY^ZbKBFWF>^TLRm[jRoYjC>QfIH
M6QTHF5GGe==CUMJFf9BE4iED5=NKWjWYkBda<C0_L:m];k1bL:h]kRk][o=_L>i
^[Voa/S2^;Zi_lK;c<Vj_K[2`]7Aa[c3_<75c]3?a/33a]GKm?Gd0VUogn?Ti^CQ
[inMV9jATi^PW9^JWI>JYI^VYjVR[:>TZZNTWijJXZRZ[Z:YWIV[Zk2Z[9nU[Jfa
Yi=aFUQYYJRi[X=eFV5hOI:GZ;nj`Jnd[[F_`L[Hg=oQcLfmaLS;`/2a/ifM[l6g
/[6[SKWRdj^mZYflRfYaSViaKfEKG5AME5EoDeEFDEAFFDmFDfF3/K_1][o0aLK4
b<70_/G3al:o`[[1b<O9`lbn`LG4`/g<`/K2a<O>b/W3`[[=aLK=bl[3_m3:cl_=
bLO<doKen=oSi>KThJnOWIRNTI>KX9bKVYfCVZFKYZNYXZbSY:ZWY9nNVZ:XZZjR
ZIfIZj^`ZZbOYJeo[K6WTg5JF6VUZ;V^PgEJHGQmTYNX_k[1[kB^]Jo1b]SLgn7=
cKg5b<_2`;6cWIf_`KNb/J^=^N;CZkfZWKb;JW6>KW5_IE]LE5eDEE=EEU5DEUU?
EU=UPk6k`KJo`<G6a<S1`;k5`lO2_l:j`LS7bL?<_/75a<;=c<;6`/C7c/YobL?2
^/g5a/g;b/>od<[?blg9alcCm_Ghgn?Ti^CQ[inMV9jATi^PW9^JWI>JYI^VYjVR
[:>TZZNTWijJXZRZ[Z:YWIV[Zk2Z[9nU[JfaYi=aFUQYYJRi[X=eFV5hOI:GZ;nj
`Jnd[[F_`L[Hg=oQcLfmaLS;`/2a/ifM[l6g/[5SZhfih]>[_JZM_8]ZLHi^LFmU
FeaDGEAEDeEFDEAFFDmFDfF3/K_1][o0aLK4b<70_/G3al:o`[[1b<O9`lbn`LG4
`/g<`/K2a<O>b/W3`[[=aLK=bl[3_m3:cl_=bLO<doKen09YOmoQh^?VhkVDShnE
X:^JV8f<UYfRV::DUYBSYj^PWYZMU9fY[jFPV:6IZJfTZiRUVZbZ/;>XYi9mKTm2
MiVN`Kf]W5iJBEUXThfHRYbBUhRHSkC7eM?Af<KCaLS2][J``[jm^[6dWkK8^ifd
am[4^;F`bha=DWYbMgAZH5eABdmNOeMHDE5=CDmJGE]KN9NY^;c7a<:j_Kc0a/C:
_KZi`/74bL:l^kc4`Lo;a;jl`L7>c/G3_L2f^lc:bKVo`Kc1blo;a<K2alWBdmgd
loCOhN;Si^>iU8n?UJ2[VYR=S9JMXYRRU9JDXjN[X9jJWIBMZJnUX9RQVJV]Y:^H
YIZ/Z[2cOjRWTWe^Cd9gVIk1_JfLGUY9FFRCSIR:W9:GR9R?]<OEdm7Ha]?5b<:f
][32_[fj/KBO]/RkWKC7f/Bh]K3;S4eBNW9gM6YPGE5;CeiGF55ACDe?FUeKFgRG
ZKRlalC2^[fl`<K4b[fj^L;1a<W2_;^la<7?blBn_<71c/k5`kg0OkJkc<[9^Ko1
_<7;cl_4a/;7bM;CgOCcm=oQh^?VhkVDShnEX:^JV8f<UYfRV::DUYBSYj^PWYZM
U9fY[jFPV:6IZJfTZiRUVZbZ/;>XYi9mKTm2MiVN`Kf]W5iJBEUXThfHRYbBUhRH
SkC7eM?Af<KCaLS2][J``[jm^[6dWkK8Hk^M]<OJa;Re/<^<CE9jLWMdJV1MDD]?
GUMHDE5=CDmJGE]KN9NY^;c7a<:j_Kc0a/C:_KZi`/74bL:l^kc4`Lo;a;jl`L7>
c/G3_L2f^lc:bKVo`Kc1blo;a<K2alWBdmgdlo@2JGoOh^GTi^2iXibKWI6CVJ2E
WIVHUij[Z:6PWYbXZJjU[YRGX9^]Z::YXjFW[jf`ZjN/WjBZ[k6dYJ:4EXJZ]mo0
/[O?ZUEd/;bW/IB3QI:JYiNd`<cDg=[3`L37a;g5`;o0][^ga;;9cmJM_MSJh[Fd
/<:8EUZ3Lg]/LWi[FE=@EGmCFeaKCU9HDEQHKHR/^k^l_<S<alVk^[W0b/;6_/33
`<[9clW:b<;=bLS<b<Bob/O>cM7:`l:m_Lc:d<S3aLO7bLo?d=7;c/kBm?Gfgn;U
i>KP^J>LVifATiVPUIfIV9NNZjRQX9jLZ:V^YJjHUj2K[JRRZJ>UYjn]/:^W[9nT
ZWn_/KBUXXAFQZZggl2b]lnZEGB`_:NaU8>5TYZWUkC0c=CLf/?1`<O4_LG0_l2f
^kO4//W?eYfmf=[R]KB``XQFFX=cNfabOV]IDe1EDe]LFdiBF55HF6f8[;^k_;c8
c<O9^kZi`<[2a[k0`l3:bLo9b/S2cLW8c<S4_l[7c/gAbWo3`[fmc<[@b<?5alO9
clo@dL_>c];dmOKOh^GTi^2iXibKWI6CVJ2EWIVHUij[Z:6PWYbXZJjU[YRGX9^]
Z::YXjFW[jf`ZjN/WjBZ[k6dYJ:4EXJZ]mo0/[O?ZUEd/;bW/IB3QI:JYiNd`<cD
g=[3`L37a;g5`;o0][^ga;;9cf?FWKgHf^:e];32R5IJPg=kK79nJeUCD5ECFeaK
CU9HDEQHKHR/^k^l_<S<alVk^[W0b/;6_/33`<[9clW:b<;=bLS<b<Bob/O>cM7:
`l:m_Lc:d<S3aLO7bLo?d=7;c/kBm?Gf0VUoh>;Ti>GN/i26T9jKUI>?Q9VIXZJI
VHjOXK6[YIVHVI^PZj6JW9:FVj2bZJ:MV9bOYJR[W:6GW9nXXVJ1V:_MbKji_IUK
NlO6a[nUVXN<T:NIYZba_LoDa/Zj_Jfe]LC6`KF/XjFU_mONRYJa/LR[`KBcIE5T
NHRNLgAaIE9EFF1oFU=?C4iFGU]NEF9hYK33aL32_KZm`<S5`L6^]KK?cLZo`[fl
_lk8d/_6^/C9cM78c/30`/O?b<6n_K^icm3>b/;4`<W;d]C6bO?bmN3Ri>CUg[>@
QY2NViFCShBIVJ:VVIV>Wj6aZjFIV9VKX:^QVYbBUY^P/ZVRWIRLWjFXZiaoXINL
WjRRIX6HZmg9_[VmVE]kalK6_jFJQhb@YiVV[;6mcmC6b[Zm[KFea<K1]JbSYJFo
emj:U[6ab:_1];=UDFAiR9icM75UDUEIH5YCCda>EUiKGUERN:F``lG0`[fj_L38
aL71[[Ffclg:_l:m_;o>b=;;a[[4bLgAb<k0`<9oalo8`Kjm^kW?d<k:`/C0bL_B
e<K9lo;eh>;Ti>GN/i26T9jKUI>?Q9VIXZJIVHjOXK6[YIVHVI^PZj6JW9:FVj2b
ZJ:MV9bOYJR[W:6GW9nXXVJ1V:_MbKji_IUKNlO6a[nUVXN<T:NIYZba_LoDa/Zj
_Jfe]LC6`KF/XjFU_mMSgXZF/K78Zl6d/fEAI7V8WW=dLFEBEEUPFU=?C4iFGU]N
EF9hYK33aL32_KZm`<S5`L6^]KK?cLZo`[fl_lk8d/_6^/C9cM78c/30`/O?b<6n
_K^icm3>b/;4`<W;d]C6bO?bm@9Yon4Wh^CUg;FISXnIV9n9XI2FTYbLXZFKXifI
XJRVYZFPX9jSYZNSW:2LX_jcDZFVXj>Z[[:/YJJTYjIoO[;?ckbm/[NmPiS6^jn]
[<JkXjBOVKO2`l_Dd/[9`/:f]k6a_;jm][6`ZlC>fj6fd/g:Y[Zl_5MOR7f;TY2M
UHQBCU9IMEYHGUIDEUIJFeY_NjV`]ko6alK0`;ZnalO3a<Bia<O<clk7`L;7b=7:
d<G5_lK<bM;:b[k4c<C>blS6a<[2d]7=dl[;b]7;c=kfloGQhN;TiMbeVHj?VIRO
RJ6@UY:LW::UVj>MVJ6XYZJUX:2NXjJWXibPW:;n/`JUYZ>SZZjbOjbUYZBWYWmn
//o?_;fb]kf3V<Jk[jf/a[^SY9nI]l;3bmCBb/W2`[Jg/K6l_[ff/K2[a<kKXKKB
cLZV^[blEen8OH^BT9fER59>DUUJF5iFE5IFFU]JKg^Y/;Noa/O6`<2j_/O7`lC4
^LC7c<o>al72alSAb]35aKo6c<WBb/Zn@LC<a<k;b<K4b/;BdLgCb/_:dL_<g_Kc
mN7Qh^CUg;FISXnIV9n9XI2FTYbLXZFKXifIXJRVYZFPX9jSYZNSW:2LX_jc>ZFV
Xj>Z[[:/YJJTYjIoO[;?ckbm/[NmPiS6^jn][<JkXjBOVKO2`l_Dd/[9`/:f]k6a
_;jm][6`ZlC>Hm^Q]];=bZJj_;aGGhQmRi:@WIF8DTiBFEYHGUIDEUIJFeY_NjV`
]ko6alK0`;ZnalO3a<Bia<O<clk7`L;7b=7:d<G5_lK<bM;:b[k4c<C>blS6a<[2
d]7=dl[;b]7;c=kfloD2JGoQh>?Si^2VT9NJXiV?SYNJYJRLTI2DU:RVYYZFUiRQ
ZZVVW9^EWZN_ZJJZW:>W[jj/Y:JGViJ_/K>[QgNfemO8[J^RYWQmRH^BTj>P/kbn
]:Fn^/_?e=75_kFc[l;1_KZl[j>V[jngb=Z?Z=k3^ZfcZ;1DIIJOU91mQgZ?H5=G
EWm@E5=@FeYFE5IEG7Bc`;jl^K6e_<[:_KNm_;Fkal33al37aLS<cLW0^/JnbM3@
al72^<g>d/k3a;o2`<gBbLc8c<W;eM;=`<OKm_GfhN3ShnKPYY2GVZ>IShjGVZFX
W96@U9BXYZJJUYNHXJZYYYbKUIjW[jVVZYbSYjn^[:BVUgnKUZna/j^7MkKGelR]
Zj:VN7f9Ri:CXj2c_;jdYKjjbloDdLFo]K>_`/6m^[b_XjJ_[kO8fXnXg/>j[K>X
/5AUUYnDT7f7NXmPDeMFD5ACD5]JEUAFEEad/l2n_;Va]Kc:b[fg_Kbe^lO0`lO0
alG8c<g9`;[6_/W@d<O1`[S=cWoBc/?4_l;0cM;9c<S<bL_Ed/g0am_fmOKQh>?S
i^2VT9NJXiV?SYNJYJRLTI2DU:RVYYZFUiRQZZVVW9^EWZN_ZJJZW:>W[jj/Y:JG
ViJ_/K>[QgNfemO8[J^RYWQmRH^BTj>P/kbn]:Fn^/_?e=75_kFc[l;1_KZl[j>V
[jngb6?JSjSN`kZ]/jR`E6FFWiB@OHMjSf1CEeI@E5=@FeYFE5IEG7Bc`;jl^K6e
_<[:_KNm_;Fkal33al37aLS<cLW0^/JnbM3@al72^<g>d/k3a;o2`<gBbLc8c<W;
eM;=`<OKm_Gf0VUog]oSiNKRZi>GV9VGVJ6GVJ2DV96JVYbOXInHXJFMWZBOWIZ[
V:6VXifKWZ:_XZZXXJ6VXjNQYinLT8^QdmkCcL:l/Zf0LfY_L7^3VjbKW:f/a<WN
clW7^:fc^l2o];bj^K:f[j^`XjNhT;blc/Voa;JUEgn<TXb8S8^1NF5KCEQoDE=E
CeaFD51IDUejZkZj]lJo^[k1`KVm_l71a<Jna<C9b<C;`/[7bLc:aL?7a/G8cLW8
a<G3alG9blO5c<36`mC>bMC:bL[BfoChmMkOhnGVhZ^CUiRIUiVQUiVPU9RAVYZL
Wj6OV:6UWIjTWifJZiRQYZ>MVijR[j:ZZ:6QYZ=oYj6WWib@Rj7Cg]?=`[bb[H1c
JVm`Nh>K[9^L[Jc4bMk?bLNh[K>k`;nd_;Zi/[J_Zk2SYkR@_;c>bKo4]ZEGOhbB
S8R<Rh5iHE]=F55CEDmLEU1@FE9MNZ^j^[O6_kZn`L6i_Ko1`LC6_/C4bLS4bl;:
alW<b/G3alK5b<g9b<AoaL?7aLW;alG<`<K3e<k9e<[9b];Km?Seg]oSiNKRZi>G
V9VGVJ6GVJ2DV96JVYbOXInHXJFMWZBOWIZ[V:6VXifKWZ:_XZZXXJ6VXjNQYinL
T8^QdmkCcL:l/Zf0LfY_L7^3VjbKW:f/a<WNclW7^:fc^l2o];bj^K:f[j^`XjMS
^92l_<k9_lBfYEMoS9:<R8b;PGUQFdeHDE=ECeaFD51IDUejZkZj]lJo^[k1`KVm
_l71a<Jna<C9b<C;`/[7bLc:aL?7a/G8cLW8a<G3alG9blO5c<36`mC>bMC:bL[B
foChm@9YOn3Rh^GViKJ/[JZNU9FHY:jUXIn>VZF[[j^QUinOYjn[YZ>LWiFW[kBT
WIRJ[;>f]ZjQX:6`[jf[WH62YN_Yin3<c<WA]iUdHV9_OIjG[;>m_L78hMWAbK>b
/kFnaL?5^kbZ[;_7_ZNTX9Bbf]SCakf]QFB[ZJFCRXJ9PX=cH5=K3E=DGEQ]FeI@
DUIYP;6lo[i^^/S<d<Bl^k_3c]C@bl71`<G;e]3>aLK8alW=c/Fl_LK>emC?b/_4
bLg?e]73aLW<cM?Gcm7;bMOhm?KPh^;Ui^Ff[:fZWYBEV:B^YJ6OSYZUZjn[XINO
WjN_ZjJSW9nEYjndY9fHVZbc][J^XJ2QFK2_[J^MPH:UjnWWh<c<bM6gVGARHVmm
WYN//kfm`LSQfM79/k:c]Kk5`lFk_:Z/^lNnYjBPU;;Jf=?7_Jf5I:^YYI>:QXV2
Pg=PDe]CE5eHKE]FD59FJH2a_?jn8[[8c=34_;^k`lkDd<_1`L35bmK@c/G6b<O9
cLk5_;g6c]ODOlo:blC9cLoFdL?5bLc=dmO?dL_9eoSdm^3Rh^GViKJ/[JZNU9FH
Y:jUXIn>VZF[[j^QUinOYjn[YZ>LWiFW[kBTWIRJ[;>f]ZjQX:6`[jf[WH62YN_Y
in3<c<WA]iUdHV9_OIjG[;>m_L78hMWAbK>b/kFnaL?5^kbZ[;_7_ZNT9J2D/][H
dlNm[HETZjVUThZ6RH:3Lf1CFe=DGEQ]FeI@DUIYP;6lo[hj^/S<d<Bl^k_3c]C@
bl71`<G;e]3>aLK8alW=c/Fl_LK>emC?b/_4bLg?e]73aLW<cM?Gcm7;bMOhm?H2
JGoQh>CSiNBiViZDUIVMUY^HTIRLWJ:MWibHWin[XJ:PXifQXifJW::OXJFUVinR
XIJZXZBMX:FGTIZ2V;GOg^?Lg^;MeKjfPfIYL7^=P9ZV`LGDf>GC`L?1];>i_;^f
^KK3/KBd^:NNUZj`bLk@d/_7[V1L^IB;R8VBTgIdJ5ABHgmJEeIHEDa?EUUCF7>H
Z[k5a;o3_/2h^lK2`l;5`/36a<G8a/_9bL[<a<S5alo6d<_7cLc9alC<b/k?b/c<
bLg8b/S?b<o>e=SQmOGfhN3ThnGT^I^JU9FIWIJKV96HW9fRWInLV9nOZj6RX:>M
XJ>MVYbRWj6UYI^OXZ6FZZ:TWGnPYINAVX:H]MoNhmcNh]gE_[J3IVU`Nhf0VZK1
aMCHiM?1`l6d/kVl^kJi]/>a];BhYijF[[39c]3BblN^H5biU8^8RI:CMWAXE59S
FUMFF5E<CeIIDeQcV:ZnaLBo`kk0^;_6`/?2aL;0a/C5b<K;bLW:c<C8aLO?a]3;
alg<bGo7a<c:c/o:c<c9cLS:b<o8clkDf>7emOKQh>CSiNBiViZDUIVMUY^HTIRL
WJ:MWibHWin[XJ:PXifQXifJW::OXJFUVinRXIJZXZBMX:FGTIZ2V;GOg^?Lg^;M
eKjfPfIYL7^=P9ZV`LGDf>GC`L?1];>i_;^f^KK3/KBd^:NNUV>^/<W>d=;;ajiP
G;VDRhR9TY=fM6QDDV=JEeIHEDa?EUUCF7>HZ[k5a;o3_/2h^lK2`l;5`/36a<G8
a/_9bL[<a<S5alo6d<_7cLc9alC<b/k?b/c<bLg8b/S?b<o>e=SQmOGf0VWohGgU
i>KUa:^TUIBCXJJUYinKUiBMZ:bVYIfJYJ^eZJRIU9VSZ;B]ZIbNY:b`^;2TX9Vc
/;F[YZ6LPkO;fmoMdm7Mhmbn_JbAJFahVJbk^<K=f]WOgL70/[>ka<[8_kfe`;k8
b<2_VXbcb][Lc];@aHaFKl2>RH:2T:2=NG5>BUAoEFEUGUaDCT]GFVF0Wjnn`L;4
dL_5`;Rj`/k?dL;3`/?=d]C?`/C0b]3@dL;3a/S4d]KDb/G1b<_FdMG=b<O7b=;H
d/g<`LcKl?Ccm>7QiNCViLB[Y9FDTj6VYJNOViNDWJR/YZFMVZF[]JVXVIBIXjRd
[JVLWZB//;R`Y:2I/k1o]J^VXIb3]l_KgmgCdMgSg;jm[95YK7RI[;^ha/gJfMoM
`L2b/k_4b/Ro_KG0_/S8`:nJS;?:f]c>d]35S5I_`8j9PX:@X8eiLDi:E5EUIEiL
E4i;EeYUP9n__/72a=7;aL2h^/;>cm72`l;3cM;Dcl;4`<[@d=72`lK8a=;Fe<Yo
aL78bmKAeLg8alO8d]SBcLc1c=_`m??dhN7Ui>KUa:^TUIBCXJJUYinKUiBMZ:bV
YIfJYJ^eZJRIU9VSZ;B]ZIbNY:b`^;2TX9Vc/;F[YZ6LPkO;fmoMdm7Mhmbn_JbA
JFahVJbk^<K=f]WOgL70/[>ka<[8_kfe`;k8b<2_VXaS/l[Jg<kBd<F<EVo0SXV2
PY2PSGUaCTYDEFEUGUaDCT]GFVF0Wjnn`L;4dL_5`;Rj`/k?dL;3`/?=d]C?`/C0
b]3@dL;3a/S4d]KDb/G1b<_FdMG=b<O7b=;Hd/g<`LcKl?Ccm09Y8=kPh^7SgkVA
S9:QVIVEUI>EXYjLW:6DW9nMX:6KX9JMX_jNFj2NVibSZ:FYZYnTZ[:Y/:BXTijY
Vhbd_L>jal;9blBnYJNZYhIdOiRY]kg;cm[Cckfi^[>d^KR`/[_0`;^h`:nb[jV>
`L[7clW;bk]DFH26R7UmRH69MFMQGU]I0UaFD?iEIU5>G5=IHX>W_;bi]/6l_/;5
`<?1a/?0blO4bLS7`lc>blk8bl;4alc=_lK3a;o4blO9c/O7`/k@b/_=bLO=d<k>
e_7blOKNh>;QhmniTHbBXIVIUIFCUJ:NW9bQU9bOWJ2QVj2FWJ;nWPnPWY^LXjRU
ZJZOY:ZbZK2TCZRCWZVKS;Bm`k[7`/W;a;jUYjZWQWAoV:Vg_L_?f]??_KVj/kBi
^;2b^l30^kS0[k:_ZHk1b/O?bL_;^eAIP8J8NGf9PHUeIf5NFeULEU3nEBeACUaC
FF:3Ykbl^KK1_;k2aL33`LK3`<_7a<W8al?<c/_>b<_2a<O<cKo6`lBo><C;alW>
alO2c]3:blg9alg@c/kFlO;am]kPh^7SgkVAS9:QVIVEUI>EXYjLW:6DW9nMX:6K
X9JMX_jN@j2NVibSZ:FYZYnTZ[:Y/:BXTijYVhbd_L>jal;9blBnYJNZYhIdOiRY
]kg;cm[Cckfi^[>d^KR`/[_0`;^h`:nb[jV>6/7:alo9bl^kE5V0QXQiOHV1RGEW
HEiKFEaFD?iEAE5>G5=IHX>W_;bi]/6l_/;5`<?1a/?0blO4bLS7`lc>blk8bl;4
alc=_lK3a;o4blO9c/O7`/k@b/_=bLO=d<k>e_7blOH2JOoRONGTi=o0VYjNVijY
ZINARhjGY::/VY>CV:N//:bUaIRUZjf]YIZIW:^c/jj^X9NP[K>^^9bHUH:KbLkD
b[Zoc/c5`[:[ZjjM[:R`]kBjb]7If=^l]K:V^KJo/;Zd/;bn`<Nh/ZFPR;_Dc<ji
]kfEDiZCQWE^NI2AXHekJfAIFWmOFe=KCDYBE5]TH6=lW;g7b<[8`;^h_];BblNj
^L;7cm7@c/_4`/CAdMO8a<;6e]?DbL[2`Lg6cMG=bLC5amCEem?2`lGAf^7_m_Ki
h^;Ui>CO`9ZNWY^NZJVGTH^>UjBR[9ZCTiRW[;2/YLFHYJ^][JFJVIb[/k>^[Z2G
X:fc[WnhW9REPY_9c]C:^[o>c<G2/Z^[[Yf/Z;2g];[:dMWHfkbe/ZJi][n`^[B`
_;k0akRbYJ28^mC<c[Vg_IECVY>6MFiiT96QSG][I5UJGe]CFde:DUAKI61SO9bm
alS:b<2k^;kBd/_7^[W2aloAd<k;a<;4dM7Gb<C2a]KCe<W:`Wo1cLK=eLg9a<G7
e=GGdl;3aM7JhNofm_WRh^GTi=o0VYjNVijYZINARhjGY::/VY>CV:N//:bUaIRU
Zjf]YIZIW:^c/jj^X9NP[K>^^9bHUH:KbLkDb[Zoc/c5`[:[ZjjM[:R`]kBjb]7I
f=^l]K:V^KJo/;Zd/;bn`<Nh/ZFPR6>ke<c>^KNmUE>JThIeKWV@TJ6=Nf]TFEYO
Fe=KCDYBE5]TH6=lW;g7b<[8`;^h_];BblNj^L;7cm7@c/_4`/CAdMO8a<;6e]?D
bL[2`Lg6cMG=bLC5amCEem?2`lGAf^7_m_Ki0VUog^3Si>OIZ9FMWINMUXnGTYNJ
XiNIUY^HWY^PUYFMY:FOXijRW:2VZ:>NYiZLXjFSWj>YYJ2U[HQlV<g2_;[0_/G:
]ZNKXjVXXjJY];2n_<K9b/S:`kjdZ:jUZJbd]kc3_Zb_[[Zg]XZi`kVe/[R0EV=n
NgV1OWZ1PHF1RWYcH5PBF5EADeEBCe5KE59BQ9Jf_kjj]?k6JL74^k[2a<K:aL_2
aL?5b<O:b<G6aLZn`LK9`kc;alC>b<g9b/O;cL_EbM;;c<g4c]7HioCdmMkPhnCW
fJREWIfGWIJ?Ui:GVZ>GVIJKV9jKX9JEWJBUWj>NXYbPYZRSWZNJW:>UXinSZJEN
X:F]R7bHcL:l^/2naLZfYi^SZJRSYZVd/;jla/W:b<[3_[BX[ZFY[;Bg_<>n[:n^
^[NfR[W3^KFb^81FHgikNH5nNX61QH6:NW=PF5QEDE=EDTmAFeABDXBF][nn^[Cn
aQg1a;^j`/C6b/G;`/G3aLS7b/S5a/G:_/76bL>lblMoa<k8cLW:al_=bmG9d/_<
cLC>dMSWm?Ceg^3Si>OIZ9FMWINMUXnGTYNJXiNIUY^HWY^PUYFMY:FOXijRW:2V
Z:>NYiZLXjFSWj>YYJ2U[HQlV<g2_;[0_/G:]ZNKXjVXXjJY];2n_<K9b/S:`kjd
Z:jUZJbd]kc3_Zb_[[Zg]XXZ^L>i]K:hP5ISOW]iPGijPH65PHYjLf1HF5EADeEB
Ce5KE59BQ9Jf_kjj]?k6=L74^k[2a<K:aL_2aL?5b<O:b<G6aLZn`LK9`kc;alC>
b<g9b/O;cL_EbM;;c<g4c]7HioCdm@9Y1^7Ri^CVgjCnSgFXYInJTY:EWkNTYYnG
VinZYj:KU9FKWZZ_[Z>MVJ2[/JjHY:BSZjfb]JRUVZ=hX;kD_kFb^L3;blBjRHnN
/K6d/l?6cl_;eMCAd;Zi_;fkY;N`][FoaM:h[JVa/kFJZk^e]:fTEh>FOgmjN7Yo
SH64PXE[LFaXDV1LEDYHFEYIG5YAD8:E_/?5_;6ial3;d<72^k[4b/oCb/Zl^LO=
cm;>cL;8bm7Bd/_0a<;BcMCEclc9bL_Cg=3?c<7Gd][Ce^Ccm?OQh^KTi]nToXlY
Z:FOVY:BUIngY:JOUi^OZZNRViBEVijZ[jjSWIVPZk6^V:BTXj^]/[FXOjFJXgRP
_]Bo]K:i`<_;a;Z9Sija/KBc`lK?bl_Ee=7@^[Vl_K^T]k2f]Ko5d[R]ZK6c]IZ[
^kFd[JAGPiIoOgYhNWn=PHB2QF]aK6QPG5E:F5UJFEaJDE22UKk3aKba^LO0bm31
`[^ja<[?dl[:_;W7cLoBc/g2b<_Ad];;`<C27];=e=G?c<W9bm?Ld<o<`MOBf]?F
i??dmn7Ri^CVgjCnSefXYInJTY:EWkNTYYnGVinZYj:KU9FKWZZ_[Z>MVJ2[/JjH
Y:BSZjfb]JRUVZ=hX;kD_kFb^L3;blBjRHnN/K6d/l?6cl_;eMCAd;Zi_;fkY;N`
][FoaM:h[JVa/kFJHj^k]KB]Y5N3UWmoNWQjOhf1Q8:5Jg5/J61LEDYHFEYIG5YA
D8:E_/?5_;6ial3;d<72^k[4b/oCb/Zl^LO=cm;>cL;8bm7Bd/_0a<;BcMCEclc9
bL_Cg=3?c<7Gd][Ce^Ccm?L2JGoNh>CTiMjZWj6GWYJCUYRKWIFRTiRNXI^HYYnF
WjVRW:6VXJ:EYj6MYj2RVk2U[JBRX9^PYZBLNYVcfKfb^kR^]:^T^IB4VYfRWj;5
bmC<b/o9b=Bn/J^/XInV/jjb^Jbf[Z^c/Jn]O8Z7Sh]dLf>@RH^9Rfi/MgU_MgV2
JfiFF@EHEUaCD53nDQUDFe]lRkRc^;Zn`Kfm_lBja/:maLK6_l7@aOk9FKbh`lK7
al_8alK5b=78cLG7alWAbl_7c<Zl`lk@clcAaLgLl_?bg^3Ti>GNZYnQUijFTiJH
VifEXY>HWZ6KV:JOUYnYXYbQYZ6RUJNQWJNPXY^`YJfTXZ2KX56VY9ajVK?I_K:k
^:jdZjBiU8BJWJ:OX/G;e<c:clW8e;jaZjbQWjJc[[:i[;J^Zk>a[jelRXN?RgAc
Hi29RhV;KVagNFmgNH9[KUIIF5ILDe1@oU8IE5]KO8^h/kRj_/6m_Ko4^/K2_LG6
a[o1d<Gnb@fl^<?6alO;b<O6aLSAb7o=aLO7bM7;blO<b[c3c]3?c=75cMcblo;N
h>CTiMjZWj6GWYJCUYRKWIFRTiRNXI^HYYnFWjVRW:6VXJ:EYj6MYj2RVk2U[JBR
X9^PYZBLNYVcfKfb^kR^]:^T^IB4VYfRWj;5bmC<b/o9b=Bn/J^/XInV/jjb^Jbf
[Z^c/Jn]O1f:Qhn;M7=ST8V;RH]^K7MiKgMiPV]^EUUHEUaCD53nDQUDFe]lRkRc
^;Zn`Kfm_lBja/:maLK6_l7@aOk99Kbh`lK7al_8alK5b=78cLG7alWAbl_7c<Zl
`lk@clcAaLgLl_?b0VQogMoShnGSZYNJYJfOVYJIVZNd[Yb;SIbOZ;:QX9NJXJBX
/:6MUJRX/[>UWYVNW:j`]ZbMV9ZRXhRg_mjj];cAe<>jWjFXUhjY[ZNP_;[Cf]SK
d/W4alKF_ZbTXJbk_/Vl]jJRYZVi]8N9O826Wk:YXY>BNhN=T9R;KVm^MH69ADI8
E55IEFMWIUAACe5JO9c6^l6g]kg0alK9]L2lalg?b/70_<;Aclk6_KVkb<oIcLG1
^[k7dMG>cL72`lkEe]??b<W7dm7Ff/K?hOke<mgOhn?UhjZGVZF]WiZFVIZW]:jL
RhfLWjRbXJ2GVZ6TZ;2QWIFXZ;:cYIjIWYb^/;J/WIQoVZ:SR;Nog[Zd_=7D`kZO
YJRGSZV^Yj2l^]?Jf=_BbLC7a]Jn[:BQ[;^nbKbgYZ:VZKVdQhUlP8JO/ZVRTi9k
Qhf@V8]^KfiePHU5AUAAFEEWIfIDDDmAFWbLa[_1]kNm`<O6bKG0_<O=cl[1`;c2
dLo>a[fi^lS?fLg5`KZnam4DeLk=`L;3c]GFdlo8bLOCdMKJa/oQo_EWgMoShnGS
ZYNJYJfOVYJIVZNd[Yb;SIbOZ;:QX9NJXJBX/:6MUJRX/[>UWYVNW:j`]ZbMV9ZR
XhRg_mjj];cAe<>jWjFXUhjY[ZNP_;[Cf]SKd/W4alKF_ZbTXJbk_/Vl]jJRYZVi
]8MPRGb0QYnbZJ:CTW^7SI2HRfi_KWF1RDE6E55IEFMWIUAACe5JO9c6^l6g]kg0
alK9]L2lalg?b/70_<;Aclk6_KVkb<oIcLG1^[k7dMG>cL72`lkEe]??b<W7dm7F
f/K?hOke0VUogn3ShNKM[InNViZ>Ui^NW9nUY9NLU9RIVYNIYIfOViJKW9bTZj6O
ZIVNXJBRVJJOZj:XZZ>MWh6R[lbi_/C4_K>[SYb/Xh>1WJV``<C>c/c:clg8bKc5
YZVYYjne_KN//:bcYYjTUG1eQWImViZCShbHPhQoQhAhKWmgOg:?C4Ao@E=HE5]@
GTaJC4iEJHR//kVj^[W0^[Nn`LZi`<6m`KRmaLK:`l2n`l34a/G6`lW6a<Joa<S0
alC;b<_=b<W4a/o9b/g;a<GGgOGbmMoPhn7VgJfOWY^JSYNKWYbOYJBGW9BHVIZG
VJFMWi^FVibLY:^QWjVIWZ6TXYVVWj^RZ:YoXifOPJ:_c;Vna<Bm/j^>W:bSPh6M
ZK30a<k>c<[?cLS9_<FVZJVW[kFm]jb`[;>VWZBEL7F6MWfKVY>?S9R3R7n7Q7Q^
OgMoLXm<A45CF5AKD5i<FTa>EFV8[;>i^[Zi`;Zg_/7:^L31_L6h_LG6b/?0_/?0
a<K5a/?9a/C6_lAob<37a<_8blg8bLC6clW:cL_4aMOMmO;egn3ShNKM[InNViZ>
Ui^NW9nUY9NLU9RIVYNIYIfOViJKW9bTZj6OZIVNXJBRVJJOZj:XZZ>MWh6R[lbi
_/C4_K>[SYb/Xh>1WJV``<C>c/c:clg8bKc5YZVYYjne_KN//:bcYYjTUG1SMHIf
OI^JThn<V8>8OhN4N6ioMgmbSda4@E=HE5]@GTaJC4iEJHR//kVj^[W0^[Nn`LZi
`<6m`KRmaLK:`l2n`l34a/G6`lW6a<Joa<S0alC;b<_=b<W4a/o9b/g;a<GGgOGb
m@9XOn3Nh^GVg[^TZJbMTI:AVjBY/JBGU9^R[[2OUInG[[>cZ:FNUY^Q[;:_Yj>T
XjVf[;:KXJF/[;FDXJBNV:6QYZ6EQgJR//^_SIZXZk30d/o@aL;5bm7>bk6YY;6j
`<G1/:ROZjbh[I1eMgYjPYjTW8^6SY:ET::4Mf5oS8R1c9QAB4U;Hf5LEee<DE1>
FfR;/kZf]<76a/Nl^k_6b]78b[nk_<3<d/o?`;nnalo=cL6n^;k:dm3?a/Fla/_F
e<g;al;@dMKDc/_6c=?nmS?Pg^;Ui]jkY:V/WI6BTI^TZK6TUiBKXZj`WiFOUjjc
/jRUWYJKXJbb[jNSY:>Y]ZbbVj6Uojam]IBQY9jHXJ6VXIF7MZ:bbjn=VZR[/<3B
cm35`/G;dLk;/JVT/K[0aL6`Z9n[[;R]T7EgNWZ2WZBLRhJ>TYF@XXAgHGn<R87<
V559Bf=QG5MMC55@CU]XRk>j][C1a/K7_;^ka/[Ab<Zo^kc0c=;?cl2o_/O?cLg1
_[Rnb]?@5<o6aKc6bmKDcL_7`]3Ae]C>blK<dokfIn3Nh^GVg[^TZJbMTI:AVjBY
/JBGU9^R[[2OUInG[[>cZ:FNUY^Q[;:_Yj>TXjVf[;:KXJF/[;FDXJBNV:6QYZ6E
QgJR//^_SIZXZk30d/o@aL;5bm7>bk6YY;6j`<G1/:ROZjbh[I1eH7MjNX:NY9b;
QXjBUI2RQ7MQOhb8PLbHDDU;Hf5LEee<DE1>FfR;/kZf]<76a/Nl^k_6b]78b[nk
_<3<d/o?`;nnalo=cL6n^;k:dm3?a/Fla/_Fe<g;al;@dMKDc/_6c=?nmP9YOn3O
hNGWejJCVYBDWYnCRIJ=TZ6STYZCTiVEU9jLXJNZUj6NX9VMWYfLZZVSXYfLX:>U
[::QX:>4MGJ5K4aXRYj@PXV[X[VcTWFHY[Bm^[_<alg6a<Zg^K:e[JnY[:FEZkBY
X::UTY:2SX1eMHbEVIVMQW^JLgemSGn7QWmkhm>KOeABCeeFEeECDDY=D5a[V;Vn
^l:n_kRl`/70_l:oa<G;`;G1_Knk`/:i`<O5`Kk:_/k9b/W4a/S5b<;:a<c:bl_<
blc5b<kFc]Odm_GPgn7UimNVTiZDU9jOThVFSI:QXi:JTi>IUIBNW:6WZYNQWZ2I
WIjMW:ZYXj:MW:2SYJbROj6PXhAeMXE/C6R:WY22RJ^R^K>BMIRV];fj^lc7cLK4
b[Ni/[F][jV/YIF[]:VPXZFBTX:>P7EeS9FIVIf6NiYcOGf=OhN6Og_Sdi]DDTmM
EUMEDe5:CE1LJiRi_[_2_[nh_<;1`;o2_lC5bl2e`Kfo^l;2^L37aL6nb[k>bL[9
OlC6b<G8`/[4c<[;blc;c<G8c]K>eoCfmN3OhNGWejJCVYBDWYnCRIJ=TZ6STYZC
TiVEU9jLXJNZUj6NX9VMWYfLZZVSXYfLX:>U[::QX:>4MGJ5K4aXRYj@PXV[X[Vc
TWFHY[Bm^[_<alg6a<Zg^K:e[JnY[:FEZkBYX::UTY:2Hhj0MGF<UIVIWHIkVW=m
OHeoQhIoNn?CVeABCeeFEeECDDY=D5a[V;Vn^l:n_kRl`/70_l:oa<G;`;G1_Knk
`/:i`<O5`Kk:_/k9b/W4a/S5b<;:a<c:bl_<blc5b<kFc]Odm_D2JGoPhNCTimRg
YjRKUYBGV:^SXYNAWYjaXJ:JUI>LW[^[[ZBQX::^/[FWXYb[/;6c[J6NVjVX]Zf`
Xib<TJ2[PhnLYZFl`lC7^[a[KYbicLO8b;O6al?3aKZ`ZJfl_L2^XZ6CUK2Z]J6B
N8b7SZ:OXI:AWijM[HJ1PXanVYR=_n?PZWm@BTQAGU9=D5ABJ5mSJHVU^<c7b<JY
^;>oa/[8alBl`<?4b/No/[C1b];Cb<2i`<??dmS:a<Vo`/kAclc9`lK;emK@c<G7
bMGZmoG`h>7Ti>OH]jNXViJDUiR[Xj:GTIjN/J6RVYFCW9jkZjjTXJ2R[[:eYj:L
Zk2a/jfQWY^YZ7nf[K2SW8bAX:^3SibVYKc3a<Nj_6]^W;W=alS8]lK7`l?5^[2Y
[Kbm`:jRXI>E/:ZeXI9hS8N>XYnQTY6OWYf]QX62S7jJV8fohn2ZD4Y8DEiBCE1D
DVQOHfV9YKS<alS6ZKRc_lK:b<O4_<33a<[7_k:d`L[BdlS0^L33cm?HbWo4bKo2
c]7?c<W3a/_Ge]3<aLO9eN[gmO3PhNCTimRgYjRKUYBGV:^SXYNAWYjaXJ:JUI>L
W[^[[ZBQX::^/[FWXYb[/;6c[J6NVjVX]Zf`Xib<TJ2[PhnLYZFl`lC7^[a[KYbi
cLO8b;O6al?3aKZ`ZJfl_L2^XZ6CUK2Z]J6BN6><QhjRWj6BTInNWJf6PH:<OYZH
SKoSh:Y@BTQAGU9=D5ABJ5mSJHVU^<c7b<JY^;>oa/[8alBl`<?4b/No/[C1b];C
b<2i`<??dmS:a<Vo`/kAclc9`lK;emK@c<G7bMGZmoG`0VWohGgRhnKEYYjCUY^J
V9VQTINKW9bEYYZPW:2NV:BMX9^HYYjLXJNOWJVXZZ6WViVQYZJUYJZJY9VZWIVS
WXIbWJnZ[/>e_;VhUWihV:bZ_<Rm^kk3^;Fg`;j`]jjcXJFQWIbGVYB9RGb:PXR;
WZFJXibLT8ZBTI64Ohn3XMWSiYMoD452A4I7De1DDEQ=BE1lTZjn_KVe][Zi^kZi
]ko7_lC3`kni^[Zi_<77`lG1`lNlalO<`/C5`LK3a/?7d<SBb/c@b/k9bLg@i_?f
l^7Qh^?VeJJNTiJKVYRIXI6GVibLUJJJX9bPWYRTWJ2KV:JNW:6WWifYZ:ZQYi^I
XJJVYJEoZYZTVJZMVJ>NQW:M[jZ^`kFl^KRFOWRH[:Zlb;fk_/>h]KO0_[2g[[>Q
YJ6MW9NJU8V9O8Z2R8^NYIZSW9b@RY:ATHAoSh>QfN?VUe11@TA6Ae=@E55HCDU@
O9:^_[fi]KJj^K^j^KNoako4`l>o^KZj^Kc1al?5`L?7_<O7c<9oa<G1a/?6`lO@
b=;:c=3:c/W9cM3VloKbhN7RhnKEYYjCUY^JV9VQTINKW9bEYYZPW:2NV:BMX9^H
YYjLXJNOWJVXZZ6WViVQYZJUYJZJY9VZWIVSWXIbWJnZ[/>e_;VhUWihV:bZ_<Rm
^kk3^;Fg`;j`]jjcXJFQWIbGVYB9RGaSRX:8RijUVZ>LW92:TY6AQ7n?Pj7IhnJG
D452A4I7De1DDEQ=BE1lTZjn_KVe][Zi^kZi]ko7_lC3`kni^[Zi_<77`lG1`lNl
alO<`/C5`LK3a/?7d<SBb/c@b/k9bLg@i_?flP9Yon1mhN?Sgk>RW9BDWJN`[ifH
V:BSZ[2MXi6NYjj^YZJNUZ2S^[ZgXYfLZ[Ba^:ZTWiVZ[K2_Yj^FXZFf/j^ZK7jK
_ko8bkjm/Z^oU8nS[;6eb/[>bkZg];?2`/Nj^j>PUjRYXj6JPX1oR9NYX:BLRjZN
XZJKSI6BUifXWn;Yi]j2OeE:BTQ7AdYLG5mID4a;H76[^lVl/K>falc5aKbm]KW?
bmG2]kFj_<G8b<Vn`L?>bLk>b[fib=;BdmC9`lW<dmCJel[;`lkBg>Gdm_?Ph>7S
hmncXYbDU9fW/:nMV9RTXjZ`WJ>AWZN^[ZJVWYJPXkZj]j:MW:Zd/KRZY9nIZZf`
OjnWZiJRYKJcZjY/OY^o_lS;_[fbZknDSj>//KG:b/k;^[Nd/l;2akZkXj2GZ:VS
XIZ2P7n8UjVPY9b;ZYjRYY^=TI:GWJROh^WVgX9EBTY8AdM:G5aOFE1<Bf1aZk_9
_;6c]/O<aLFl_KFicl_E`[Ne^[c5b<S9_/73c/W>c/ZmOkW8d];Ce<W3bLcCe=[G
b/_3c];LiOCfln3PhN?Sgk>RW9BDWJN`[ifHV:BSZ[2MXi6NYjj^YZJNUZ2S^[Zg
XYfLZ[Ba^:ZTWiVZ[K2_Yj^FXZFf/j^ZK7jK_ko8bkjm/Z^oU8nS[;6eb/[>bkZg
];?2`/Nj^j>PUjRYXj6JPX1oHhRGZJ2TW8^ZWZ:VVhfATYNMZ9oRjNKNPUE:BTQ7
AdYLG5mID4a;H76[^lVl/K>falc5aKbm]KW?bmG2]kFj_<G8b<Vn`L?>bLk>b[fi
b=;BdmC9`lW<dmCJel[;`lkBg>Gdm_<2JGoQh>;TiN2QU9^FTiVNWiJMYJBNSYjE
UJ:MXY^TW9JJWJ2NU:ZJWJ2WYjBXWj6R[k6Y[JBWWI^ZWZ>KZIVIV7QgRK6j^Zfo
c[jf^:J0KYF/^kno_;f_^[Ba]KNc[:BPXINFU9>:TXj:QH6<THn/YiFTUIVATYVU
XIVOVIoYj>RnKWm@AT=7B4=7De9?DDa<DEUQLhNQ[;Jo^KZo_kRna/:o`[o8^lG5
a;^o^;Jg_LC3a<Bm^l?3bl74`lZj_L?@c/o;`LG<c/G7c=?OmOGdhN3Ri>GPXIBK
UY>IWYnFWJFTWXjNUIFRWJ:KY9bFVYfPWYBZVYfPYjNTZ9nQXZnaZJfTYgnMVjZN
Xi^YVIVHN7N9/KZj[Ko>_[JhYX1^UJbk_knl_Jnj];6e]k>/Y:2QUiJDThZBSXZ5
PHbASjbWUJBEVI6BVJFQVInIWnWXj;i^D4I3AdQ3Ae=BCe5<C55IHG>7XJbf_kVj
_knh_/K2_l:ob;_5aLBk_kRf]kg4`lC4_K_3`go;`LC3b[Zm`m3>cl_1aLc>aLO<
dmoemOCQh>;TiN2QU9^FTiVNWiJMYJBNSYjEUJ:MXY^TW9JJWJ2NU:ZJWJ2WYjBX
Wj6R[k6Y[JBWWI^ZWZ>KZIVIV7QgRK6j^Zfoc[jf^:J0KYF/^kno_;f_^[Ba]KNc
[:BPXINFU9>:TXj:QF>1S96?[:NEY9FITI:IYJ6IWiVOjNSX_Vi@AT=7B4=7De9?
DDa<DEUQLhNQ[;Jo^KZo_kRna/:o`[o8^lG5a;^o^;Jg_LC3a<Bm^l?3bl74`lZj
_L?@c/o;`LG<c/G7c=?OmOGd0VUogn7PiNSPZi>?SY^O[ZBMVYVI]K6]XY6GWZV]
^:NMU8nE/K2mYZNOX:J`]:fWWYbN^KVj/ZJQXj2_/;N^X9IlRH6g_lNg/KRe`[J_
VG2;U[_:`lS4/:R[]/g5^jZSWIJN[YjDRXZ4OhnGYYRAX:2SXjNNTY2D[;6d[JkO
kNO[WFIoDT=6@D=1@T=@FEU8C4aPGGV7Uj:_/l7;aL:h^ko7d/cCd[fm`<O9alO0
_[W4blk=aKnm]l2oc<c9_;>kbm;HdmK3b/O;dM?MgoCel]oQh>GXh:^CShjKWjjT
WIZIVKFa[J:AUijY[KRWWIB?UK6`_JJWWj2V/;B]YijLW[Vi^[9oYZ6SX:n`]jjP
UWb9PKNoakNa^;G2]ZnIL8^F^l[3b<B`Z:^fcLFkZZ>MUYj^WYB:RXAoSiNVV96P
X:>SYijBT9B//KB][]o]in^MIU93AT53@D93D5UIB4a<H5eiQiNR[k?1blG2^;^o
am;<dm:m_L37bLO7`;jia<_>cLFo_KMo`;o<c<Vl/k_;d]SCe/?:al_AdmgOm?Gb
gn7PiNSPZi>?SY^O[ZBMVYVI]K6]XY6GWZV]^:NMU8nE/K2mYZNOX:J`]:fWWYbN
^KVj/ZJQXj2_/;N^X9IlRH6g_lNg/KRe`[J_VG2;U[_:`lS4/:R[]/g5^jZSWIJN
[YjDRXZ4OhmSUjJHTJ2PXj>WWY:@U:ba]:f^gngWjieVDT=6@D=1@T=@FEU8C4aP
GGV7Uj:_/l7;aL:h^ko7d/cCd[fm`<O9alO0_[W4blk=aKnm]l2oc<c9_;>kbm;H
dmK3b/O;dM?MgoCelP9YOn3QhN;Sej>AXIJGVI^CVj:TXJJOTifQWIfSYIbKWibK
WZ>QV9bVYJNSYj>JW9RYXK2WZ:NWYZJOXiRNTj2TQI5l/:k2bLZk[ZFNKE][VYNc
^/:m^;J]]K[1/jNT/J6PVYR<RginNgN4SI6?Wi^KWYRIT8ZRZ:Z`XZO:j^WYj7UL
OdXoAD9=@Cll?d54CEA=DEMDEG:7[[Bg_[BlaL?1_/Bl`[foa;g5_K^n]l2la/G4
`l33`Kjm_<6g_lC9b/K8c<K7blo6am;:aLocm?KPhN7RhmNSTJ6FUiVKTi^RY:6V
Wi>MXIfMXjFLVinLVijSXIRLYZFWXjNSVYbHZJ6`YjRWOjNVYYnSV9jCX:B5TGb`
[/;9b[^^YIi]Ff^JUk>j`[fh]Zfe^/6cYjBaXJ2JV8b;OWikMhB=THnOVi^NV9V@
RZ:XZ[2RYl[ZjNWXNEa:?dE2CD4o?3m1A4eDCE5GE5EbQjjd]kjd_<G3`Kk4_<:m
_lBmaKfk_[O0_<K5a<?0`l6nOkfl`KNoa<W:a/S<a/O;clK7d/[5co?dm^3QhN;S
ej>AXIJGVI^CVj:TXJJOTifQWIfSYIbKWibKWZ>QV9bVYJNSYj>JW9RYXK2WZ:NW
YZJOXiRNTj2TQI5l/:k2bLZk[ZFNKE][VYNc^/:m^;J]]K[1/jNT/J6PVYR<Rgin
NgN4HhfASinKVijHVI2:XZRZ/::Wb^[YjNQiG4XoAD9=@Cll?d54CEA=DEMDEG:7
[[Bg_[BlaL?1_/Bl`[foa;g5_K^n]l2la/G4`l33`Kjm_<6g_lC9b/K8c<K7blo6
am;:aLocm?H2JGoQh>CShm:PSYBGWZ:UXibFUJ:WZJ6HVI^HZ:jYY9nOY9jPXjFO
VIRSW[>e[:6KX:2g[;>WWinUXijP/9bPXGQnQiZDTh^1K6QWIFETHXbQ`L37`;B`
];>d_K^^XJ:LUXfJShQcP8F:X9bVSYfJY:6HWiZ>Y:Nd^<GDkN[Yj>5LG7m:B4E7
Bd=5AD54@Sm8Ce9@BdaPGhbD[k[0`[Vn`<K8b/Jn];^jakk5_jfb^Knnc/C1`KVi
`[o:_L6h_/;:d=;@cL;9a/S;e];Jm?CahN3Thn?BX8jDUijRYJ>LUYFRYjVQV9VK
V:R^ZJBOWjBNX:>UWiVHXijc]JbQVj2P]jbcYonOOJFSWZ2`W:2QN7j7VYBCRh5/
J6MUIFARS:71`<O0];2d/kBm^jjQXYbFSIZ?R7>0QHZPW:J>WIZTXIROVXjTYkBh
aMC]j^WXhEaLBTQ5Ad]3ADE1A48oB4mBD4]<H5n<U:nj`<:i_/36b<[6_[Bk^/Nn
aKn]/[Vo_/k4`L6i^Go2_lZm`KRn`/[@d]3=`/W6b<_Fd][dm?7Qh>CShm:PSYBG
WZ:UXibFUJ:WZJ6HVI^HZ:jYY9nOY9jPXjFOVIRSW[>e[:6KX:2g[;>WWinUXijP
/9bPXGQnQiZDTh^1K6QWIFETHXbQ`L37`;B`];>d_K^^XJ:LUXfJShQcP8F:X6>L
YXjMVZBQV9nJSZBW];S5e>gZjNSQG5a:B4E7Bd=5AD54@Sm8Ce9@BdaPGhbD[k[0
`[Vn`<K8b/Jn];^jakk5_jfb^Knnc/C1`KVi`[o:_L6h_/;:d=;@cL;9a/S;e];J
m?Ca0VSohGgThNK;YIbaYjNGTi>RWjFWXJ2KX:j_YJ>ITiZ]Y[2QWYbGXjjd/:bO
VZ6V[K:Y/I^RX[>d]:ZLVj6M/jf^TV=DC4e@FUYRGW>;^YB@^<>l_[o<a/C7][BV
YjbZYIb9Q7N:SYn?VHj=U8nb[KRITI2I]L?6al;MkNgZkN_9F4m8ATQ6BTm:?DA8
A4/m?TI?C4eAEeV0S9bV^;o4d<_4_kBi`lG6al6iaKS7bl_5_[ngc/S=blNm];O0
`Lg;c]72b]3<d<S5`Lg>lOkeon4ai>7VbjFL/JNWUi>CXYnUYj6PVj2^[jFSVI>J
[JJ`XIjLUj>^];2/WiZQYZfbZK6KXZ9o/kBdZYbKXIfc[JjBHeA<CE1JFV9NLh^j
U92h`kbn_lc6a<Nf]:JW[:ZUW8V4MhZ>WhnISXfDSk:]^9VAT9Ve`lK7`]g]kN[]
jlUHCdI8ATY?BSe4B4A;?Ci6Cda=DEMIP8bLY[Roa=3;a;nd^L?5a/O1^LFhal_;
aKjo]lk8cL/Dakfd]l31cL_>dL;:d<c@b<G1cLkao_GohFGThNK;YIbaYjNGTi>R
WjFWXJ2KX:j_YJ>ITiZ]Y[2QWYbGXjjd/:bOVZ6V[K:Y/I^RX[>d]:ZLVj6M/jf^
TV=DC4e@FUYRGW>;^YB@^<>l_[o<a/C7][BVYjbZYIb9Q7N:SYn?VHiPSIB?/Zfh
VI6@VKG3a/O2gNg]j^g[bEQ?ATQ6BTm:?DA8A4/m?TI?C4eAEeV0S9bV^;o4d<_4
_kBi`lG6al6iaKS7bl_5_[ngc/S=blNm];O0`Lg;c]72b]3<d<S5`Lg>lOke0VUo
gn3ShnC9VYFFUifQWI:IV::RWZVGVYnPZZBTTXjPVZNS[:NJW9fRXZJWWZ2PZZ:V
[Jj/XJVJXZ6MYZ6HX9nQ/FYDAd]=Kgb<RZ:^ZXM[R/C5a[Fi[[Nb^[fRUiRQUiR@
QGV4P8V5V:2TVi:IT9JSZ:6K[;>l`m3_kNoYj=j3FDh6AD92CDU8@_i3MD0l@SXl
?e5CCDaGG8NSZk2g^kk8b;fj];bj^lC4`;Jh]ko4aLNm`[Rna<?7`;^h]l;5c]3?
b<?6b<c;c=38joCblmoPhn?TbIZEUYNMXIfBVIRRXYjYUiZOX:ZTY9:>X9ZWXjbW
VYbMXZ:VYijPX:ZRYZf^[:5BZIZRXIfVXIRPWj6aJUA7Bde_O8b:XZjZQf^:a<G6
]KV^]k:j_J:GV:6GV925NHB0RHFHX:BKTYV@UZ>XXI^//kc3d>o]knWXgX=ICTE2
@Te9B4;n@bU0?48j?3mADde<Eeb7Xj^`]k^nb<Rm^[Bl^[_4a<2f^;Noa<G7_L:h
_/Ao`lO0^kRg`/G>d<o8`lK8c<_<d<S[m?;cgn3ShnC9VYFFUifQWI:IV::RWZVG
VYnPZZBTTXjPVZNS[:NJW9fRXZJWWZ2PZZ:V[Jj/XJVJXZ6MYZ6HX9nQ/FYDAd]=
Kgb<RZ:^ZXM[R/C5a[Fi[[Nb^[fRUiRQUiR@QGV4P8V5V:0NY9^BVI2FXjRQVjbc
_<?@kng_jNSNPeU>AD92CDU8@_i3@D0l@SXl?e5CCDaGG8NSZk2g^kk8b;fj];bj
^lC4`;Jh]ko4aLNm`[Rna<?7`;^h]l;5c]3?b<?6b<c;c=38joCbl`9XOn3QhnCT
eJFZXiFATY>S[J^[UYJRYkJU[9^GVj>Q[:n`XifIZJZb/ZVVWZ:Y]KN/[ZNQWYZa
[ZnSViRDYJV`YZYTEV=aMYBEXJ>i/kjTO8Fk^;bjbl2k/Z^QXK2ZYYRCLVU_QYNK
VIjGXIf_[Z6LTY^L^/?;c=GYlNk[k^bjKD]7:d5<Bde>@Cm5AD8n>CXm?SU4DU9@
DEMWNhng_LO2`[Vj`L[9b;jl^KJgalS4o[dI_<k9blc5_l38alG@c/W4b<OBf=79
`/G7d>WnmC?PhN?Ti=FUZZ>ETI:CXjf[ZiJFXZNfYJbKUi^SXJb_/:>MVJVZ/[:Y
YYjRZKFg[:jWXIjJMk6^[j>KV9BUZK2VZVAFHg5fU9FQXkVc_ZAlQK^h_;[;`;^b
Zj6Q/:ZVV9=bJFn6Ui^IWYNQWJn^XIbBVibj`l_<eNWak^_^k;Y]BdM1C4]=CT4o
ADE2?STj?ChiA59BD55GIg^?]kg7`/:i^/7:bLRn_;Vf]lO8a?jm1;c>bL_<5<Fo
`<S7aM3>bLC8am;HdLW2aLO@jOkeIn3QhnCTeJFZXiFATY>S[J^[UYJRYkJU[9^G
Vj>Q[:n`XifIZJZb/ZVVWZ:Y]KN/[ZNQWYZa[ZnSViRDYJV`YZYTEV=aMYBEXJ>i
/kjTO8Fk^;bjbl2k/Z^QXK2ZYYRCLVU_QYNKVIjG@j6M[jjQW9:KW;[3blcEjO7^
jnk/^Ve;Ad5<Bde>@Cm5AD8n>CXm?SU4DU9@DEMWNhng_LO2`[Vj`L[9b;jl^KJg
alS4o[dI_<k9blc5_l38alG@c/W4b<OBf=79`/G7d>Wnm@9YOn7Rhn3SeijIWJFU
V9^LVIfWZ:NKVjbT[jRVVY^GVIN/ZZ^KViRTXjb/WinQYJJ/];>^X9ZTYJZXZi^B
V9JRXK5/FUaVM9NT/J^VYJnVUX:V^l6h^;Vj^:jMWYjGUY2EKfe[P8bFV:2SZhZU
WJ6[XJRQ][_5c>Wal>k[j^N7HTi5Ocm6AdQ?ATA0?ci1?S]1?ca3B4I<D5AML6]j
Tjfmb;^h^/Fg_kjo^[B[_kK7b<Fk/Knna<76`<6l^;o2aL[9a[o8`l_8bLG1b]_b
lo;Qh^?PhmNNVIfUYIRKW9VMYjRWVi^/Y:nXYYZKUiVG[:Z[Vi^HY:>/[9nOXJFV
[;Bc[Z2JOjBUZZR[Vi:HUZ:Q/FaJG6IdUjBaZjJU[jJFPZJk`KRh^KZh[YfNWYNF
T9E_KF^0S9JHX:>[RZFMXJ^QZ:6f^lG<jO7`k^_ZihMRCTDoATM8CdI4@3ln@Chk
@Cll@dQ6C51DGG1[NY>]_LRk^;[5]knn_kZdZknfalS5^k6o_/C1OlK0`Kbh_l;5
b/W6_lS3blS9aL7:fo;cl^7Rhn3SeijIWJFUV9^LVIfWZ:NKVjbT[jRVVY^GVIN/
ZZ^KViRTXjb/WinQYJJ/];>^X9ZTYJZXZi^BV9JRXK5/FUaVM9NT/J^VYJnVUX:V
^l6h^;Vj^:jMWYjGUY2EKfe[P8bFV:2SHj^:YIfQZj6XXKJkaLcYlO3^jn[WQf9>
ACm6AdQ?ATA0?ci1?S]1?ca3B4I<D5AML6]jTjfmb;^h^/Fg_kjo^[B[_kK7b<Fk
/Knna<76`<6l^;o2aL[9a[o8`l_8bLG1b]_blo82JGoOh>?Ui]^Z[:>HUYNHY:V^
Y9BFW:^a/:jGTifY[[2/W9ZHWKZa/:FZWZR/[kRa[:JRZ:bc_[>YVi:O[;2X]InL
O6IkOHBGW9ZIZjbk[ZYgNJG1alS1]K6TZjbWYZ2@SH5lRYBKVY6ATkZS/ZVT[9nX
]<g?g^S^lO;al>oWIEA<C7m9DUY6BDI3A4I;@Sdh?c/l@d=2@dU:D5E_O96M/;Fi
^l?=a/Fb^[[0`lS4^kS0`L[9b/Ji^k_8bLg:a/6l^/c6dl_<`KK:b][Um_;egn3S
iNKKZZbSV9JGV:BY[ZBDUYb[/K2^Ui>MZJj`[9bJV9fj/K2UZYjX[:nh/JbVXZR/
/gnn/jVKTYn//:ReWialIW]mQ9NLVYV[[;^^ZWMiYL77b<6e/JB[[:NVX92=PGb:
U9^JTI6C^Z>bZJB/WjRdcLoNj>kal_7`knMUE4a<BE9JATU6@dA6Bd8m>3lk?4=3
@T=9BU1EKgbAWK2e^K_3cLK5/[Zj`<?8a;^h`<7:bL[6^OnkOLS9cL[6`Kbjc<KC
blc1]/[:f^Gfl_GOh>?Ui]^Z[:>HUYNHY:V^Y9BFW:^a/:jGTifY[[2/W9ZHWKZa
/:FZWZR/[kRa[:JRZ:bc_[>YVi:O[;2X]InLO6IkOHBGW9ZIZjbk[ZYgNJG1alS1
]K6TZjbWYZ2@SH5lRYBKVY6ATf>jXk:YY:bOZ;C=cmkXk_7blO3_ifEDC4a9DUY6
BDI3A4I;@Sdh?c/l@d=2@dU:D5E_O96M/;Fi^l?=a/Fb^[[0`lS4^kS0`L[9b/Ji
^k_8bLg:a/6l^/c6dl_<`KK:b][Um_;e0VWoge7RhnC<V9VOX:B6TIbQY:bTW9FO
Yj^ZZ9Z>W9jTXjBYVYRRW:FV^ZjUV9ZTZ[FdYJ>MXZFSZ:>HVZ>CWjbZXIV1H5iV
LGV<SiFFZjR]S8RNXJBWo[DXZ:2RUYBEUHYfN7Z5S8jHQi:MUJ2T/kN^[;71a>[]
ko;_k^cYfF5RD4mo@DQ5@Dm8AT93?3lk>Cdk?452>3PoATUBDEeQOIJU[;:ga/C9
`K^c/;_2`LK6_[32^<35a<;1_k_1a<W?al2k/lW8dLo6b;k;eO;clmoOh^?Tc9RI
Wj2TQY6LXJB/Y9bEWjN[ZZRJSYbNY:>TZIZHXYbUY[Z^YIRJY:Ze]:FSWJ8OYJ>X
XiRJXi>O[:ZQVH5PGVIaNHb?UIJ[Z:f<R9jQY:On]EbXX::FU9FERWIhNXF<SYR7
TYfEX:Bc]jj//L74j^g_l^o^k>WIHF9@Cd58AD5?B4I2@c`o>cTm>ca1@SPh?dI9
DU5MHGfFYJbb]lK4bL6k/k2k`/76a[j``[S0aLA[`/6o^l74bLo7`;^cbLSAclK8
_/_El_?cgmoRhnC<V9VOX:B6TIbQY:bTW9FOYj^ZZ9Z>W9jTXjBYVYRRW:FV^ZjU
V9ZTZ[FdYJ>MXZFSZ:>HVZ>CWjbZXIV1H5iVLGV<SiFFZjR]S8RNXJBWo[D@Z:2R
UYBEUHYfN7Z5S8jHQi9SWIFPY;>g[Zba`LCZkNobknk/jMUQHU1?@DQ5@Dm8AT93
?3lk>Cdk?452>3PoATUBDEeQOIJU[;:ga/C9`K^c/;_2`LK6_[32^<35a<;1_k_1
a<W?al2k/lW8dLo6b;k;eO;cl`9Yon1mhnCWeJVTVi>GTjbWZZBJV:>V/K6UW9bO
Zjnb/J2LWIRU/Zn/XJ^OYZnb]:NZXj^c_[RgXiRIXYb/YJ>PVYjR]ZB4GVaWOYBP
[JfRXHfDUK:aZJ^]/:F]]Z:OT7e_MY2:YI67X8ZG]K^h^;J//[k5fngdl?7elO7^
jJaJFDY<Oe1>BTA2@TY5@D<n>c`k@D58@D=1A415GUiSGFIXPYNh`/O4_K30`/W7
aLBi_;k6cl[8`;fl`/g2c/S0a<C2bL[Ec<K5aLgBeNCcloCPh>?TimFYY9^CUi>/
YjZTVYRSY[6aYIbLWj^_/[6PW9fHYK:_[:6[WjJ_/[BWZZ>[/kjhOkNSV9VRW:bU
Xj2JWZ:fY8ANK6MnU:2][J:QSIBE/[6YZjf`YJffXYn@OFmfT8ZUTHNPRYNe^kRh
]Zbb_/GKkOC`lOGalNkY[5YIBTa@CTY4@T9:AD53?S/l>d51B453@DA0AEiNHeeV
J8:G^<;7a;f``<;9alG4^Kbna/o:b<2mOkc2cL;>b<34a<;9b]G<a/G5cM;Ei??c
m>3PhnCWeJVTVi>GTjbWZZBJV:>V/K6UW9bOZjnb/J2LWIRU/Zn/XJ^OYZnb]:NZ
Xj^c_[RgXiRIXYb/YJ>PVYjR]ZB4GVaWOYBP[JfRXHfDUK:aZJ^]/:F]]Z:OT7e_
MY2:YI67X8ZGHkFk^;Rf[;:naM_]m?3amO7ak^V/FUU:C51>BTA2@TY5@D<n>c`k
@D58@D=1A415GUiSGFIXPYNh`/O4_K30`/W7aLBi_;k6cl[8`;fl`/g2c/S0a<C2
bL[Ec<K5aLgBeNCclo@2JGoPgn;TiL6MXJVKTI6IVJNWZY:LWJJX[JjSWIbLVkFa
ZijEUiRSYjJbV::PXK:c^Z>SZ;:]/[6OViF@WI:XYjBGSj>OXeY/JWAiQXVHYK>K
U8:KXI^/Y:B:UY>FTh:4MG24PiRBVY:4U:>^[Kjn/[Jf`NC/lO7^ko7^jlMXG5M0
Agm4B4U9ADI9@dE3?CXk?D<j@Si2@TLj@Ce2DU9QFfE`MGb[^;ng_[Jk^[_4_;Nc
_/32`lg7_KS1_L73cLo9`lO4bLc<alK3aMCWloCdh=oRi>G1WJ6YVi6AVIVWYjZB
W9fVZ:f^XifLW9^e/J^NUINHXjNV/YRRX:6b/kZSXjRb[Gnb/InKUI2MTZRWY9N?
XinSFVaZM7V6RIRU/i^DPY^QVjbTY8ZFTiJCPXAeL8B3V9:JTXBDXjj]_[jb][K1
i>calNk_lNk[afQLEd17A4Q9BDE6BD=5@cdj>ce3>T8n@T97>T4m@U9BHE]UL7El
ZkRo]kjf^kZka;bg/kk0`/?=agnm^<6m`L?=clW3alC9c<c7a/?5e>Ocm?CPgn;T
iL6MXJVKTI6IVJNWZY:LWJJX[JjSWIbLVkFaZijEUiRSYjJbV::PXK:c^Z>SZ;:]
/[6OViF@WI:XYjBGSj>OXeY/JWAiQXVHYK>KU8:KXI^/Y:B:UY>FTh:4MG24PiRB
VY:4U6>S[Zfn_[:f]/7Tk?7ak^oak^_7J5aG@4M4B4U9ADI9@dE3?CXk?D<j@Si2
@TLj@Ce2DU9QFfE`MGb[^;ng_[Jk^[_4_;Nc_/32`lg7_KS1_L73cLo9`lO4bLc<
alK3aMCWloCd0VUog^3TiNC7WiVAVijT[JNOV9bW[Zf_Zj:RXjB_Z:nQWYVNZk6[
YZBJXjFh_KRaY:N//K:m/ZbQV::UZj^RWiZKXZO1[JYONgJ;TYVKWjNWUK6bZJJW
V9RSWJROXhmhLWFBUIjZRXj7VKRj_KFi/;k9eNGck_K`l>obk^^EFDiADTQoB4]2
@TM>BD]C@D4mADI=@TI7@ca2@D59ATi:AdmOLH>8UZ:Y/lC3bL31]k;0`LO<b<:l
]Kk;d<S7_Ko0b/gBd<o6_L_?e]?IlOGelmkPi>GTainITI^NY:fWWiRLYjj][j^R
XZ>T[jR_XIjIWZ^aZjJTVZ>U^;fh/JBW[;6b_K9o[:6HXZF[Zj:OVY^RYl6]ZUmk
MX^BVI^OYjNE/K:YYZNHV:>MZ9nSSgQbMI:EWZZ:SXNI^;Zm]KV`_/WEiO?^m_3`
ko;^jiEICU5BB4Q;@T97CTU;Dd51?DE6CD96Ad<l@T51BDI>BTM?Gg63R9JRZK?4
`lW0`KNb`<77c<S2_;Eo_/_@b<Nm_l3:cM;@clJmbloFdmWamOGcg^3TiNC7WiVA
VijT[JNOV9bW[Zf_Zj:RXjB_Z:nQWYVNZk6[YZBJXjFh_KRaY:N//K:m/ZbQV::U
Zj^RWiZKXZO1[JYONgJ;TYVKWjNWUK6bZJJWV9RSWJROXhmhLWFBUIjZRXj7VKQS
^[fe^K2nbMGUlnkfl?3_l^k[UEU>DE98B4]2@TM>BD]C@D4mADI=@TI7@ca2@D59
ATi:AdmOLH>8UZ:Y/lC3bL31]k;0`LO<b<:l]Kk;d<S7_Ko0b/gBd<o6_L_?e]?I
lOGel`9YOmoPhnCRc:ROUi2BUiVLYZ:OW9^UY[2YYI:GX:NVZJNUU:RWWZ:eYinP
X:FY/;>^WinQZ:bdYYfKVIfLY:fXUiZPWZ:/LX:8TYfQW:N^/YFXUiFEWYbCSH:;
Qi>>O6e/Ph6?TI^WSiV]Zk6ha[Zn_^G^mOCdlNkal>cWJEY;D4E7OdTo@3m3AdE7
BTTn>CTn?C]3@T<l>CPn>ci8@T=1C49BFWF6X[6h];ZnbKNc]KNo^lK7`l2l_[Rj
`lC4_lBo`/W:b/W5`/c=dNodloCOh>?Th/bXWiN@TYNIW:JRWibKYJJ`ZJFBUj2W
YZVWYIBXYijR]JNOX:2UZK2c[YnOXJR/OkBVWI^IWIbT[JRGVZ2NXZabPXRBWJ6L
YjjbUJRGUIFNW9>=PX^7ThilKFb3PHnAVjN?VJf[/KS6^[jniNkem?Cak_7`k>MY
FT]@ADM9?d0o@dM5AdY9?STi?Sdk@d93?3Th?S/nB493@Da2DUYeQZ:a^;Bj_/Vg
/kFg_k_6al?0Okbn^;[3a<Boa;o2bL[:bLG2c<gAkoCcm=oPhnCRc:ROUi2BUiVL
YZ:OW9^UY[2YYI:GX:NVZJNUU:RWWZ:eYinPX:FY/;>^WinQZ:bdYYfKVIfLY:fX
UiZPWZ:/LX:8TYfQW:N^/YFXUiFEWYbCSH:;Qi>>O6e/Ph6?TI^WSiV]Hj^a^<Jj
_[kUk_Gdm?7^lO3/ifUJBe15AdTo@3m3AdE7BTTn>CTn?C]3@T<l>CPn>ci8@T=1
C49BFWF6X[6h];ZnbKNc]KNo^lK7`l2l_[Rj`lC4_lBo`/W:b/W5`/c=dNodlo@2
JOoQon9ki/nPTi>IZ:^ZVYJJYZZ`[ZJVXIjW[jf/ZibFZjNh/ZZMXZ6WZk>hYjJV
XZnj]k6TXifYYZffYJNNVj:Z[JB[[6MjPjbf/:2]XJRd_JbTWHifOXn=QX1mQX21
S9JETHb;XJ?1`lNh]kjmd=gbl_3cmO;el_7^f5QEC4i@CAI6@Sm6BTe>CU99?3U0
ATQ9@Shm@Ce0>?i0IDI0Ad8mDE1IHgnI^;o1^;fb_/K<c<K1^lBnalW5a/2m_/G7
b/c:`lS7cm;Ee=W]m??dhN7Rh^K?X9>CVJR[ZYZFVZJZ/:jVYZ6NYjn][:^LUZ^W
^;:ZWJ:QYj^c^:NVYZ:_^[NaY6:SWJVV[KJUYijKXZZ]Y:^/IgZ3[;J`X:fQZ;Bm
[:BMSWInShf6P7f6P86<UYFAS8^QXl73akRg_[g@gO;bl??el_GblNkHF5E<CU1=
AT8oATY=CTiBBC`i@4I8BD8n?D4m@3Sn@1U6@4M2?E5@FF=oVKRo`KRm/[k6c<c6
`K_4_Wo7bLG6`;fnaLO:c<[3b<O?d]GDfNgdloCQhN;Ri/nPTi>IZ:^ZVYJJYZZ`
[ZJVXIjW[jf/ZibFZjNh/ZZMXZ6WZk>hYjJVXZnj]k6TXifYYZffYJNNVj:Z[JB[
[6MjPjbf/:2]XJRd_JbTWHifOXn=QX1mQX21S9JETHb;XJ?1`bk7^;Nn_M3Ml_;`
loGbmO;ak]QHEDa>D4e6@Sm6BTe>CU99?3U0ATQ9@Shm@Ce0>?i0<DI0Ad8mDE1I
HgnI^;o1^;fb_/K<c<K1^lBnalW5a/2m_/G7b/c:`lS7cm;Ee=W]m??d0VSnh_oT
N]BUXYVGW9bYZZBOVY>SXJRcZijHXZBXZjfPWI>VY[>_Yj>KVZ6[Y[R]YjFPZ:V^
^In[XJ2QWJ^Z[:2PWJJ][gQkNX^<ZJ>bY:>ZYi^;Q8=cJ6UcO8RDQgefRhN;TjBT
/k2b^<K2a/C6jNg^l_Cdl_3^k>kTYUYIBDU5AD]=ASm0Bd96BTe==cHh@D=2@T0n
>c`k@cho@DE2>c/h@4E2CfQ/NXbR[[Jb]:ni]kS4_/>f_Ko2alO2_;^n`]79bl[2
_lK:cMSVlo7do^;oi2kDYJ:IUibLZJZTWiZCXj6X/j^NV::TZ:^]X9fCYZJc[jNS
ViZQZjJh[JNUX:RY[WniWj^QX:6MZjZ/X:2MYZf_N7]jRhbYXk:TXjZWVh^4Pg=X
JG=lR9B7OGJ;Qh^CY:Bc/;:ha/;6a<KYkNkbm?Cbl>k/k^BVFUU9BDE5CDHo@4]2
ATY=CCLf>453@T90?S/l>d<n?d55@S/k>415@TmXK7Z<XZjf/[B_^KNha;k3]QNm
_l;7al:l^kk2dLW;b/:oa/[=f>KclOCnh_oTH]BUXYVGW9bYZZBOVY>SXJRcZijH
XZBXZjfPWI>VY[>_Yj>KVZ6[Y[R]YjFPZ:V^^In[XJ2QWJ^Z[:2PWJJ][gQkNX^<
ZJ>bY:>ZYi^;Q8=cJ6UcO8RDQgefRhN;TjBT/k2b^6?6`/K4a^W]k_;dm?;`k^c^
i:IJFDU9ADE=ASm0Bd96BTe==cHh@D=2@T0n>c`k@cho@DE2>c/h@4E2CfQ/NXbR
[[Jb]:ni]kS4_/>f_Ko2alO2_;^n`]79bl[2_lK:cMSVlo7d0VUoh>7Th^GBWI6H
Y:NWYZFHTK6][jbSX9VaZ[2YZY>EXjff]:nYWJ2T[kF`ZibLY;:f]kBaXJNO]Jna
Yj2MX:>R/:2RXYF6NX>MTJJPXJVY]:RLSG5`JGZ0UHV3SXV@VZ2KXj:IWJfhal_:
]l3NkNkdmOCckno]l>k^b6iFEDU@F5<n@d9:B4e6CTU7A3dhA3m2AChkA3m5Ad11
?d50B3Xi>D4o?CY6JWN;RI6HYk?4b[na/K2k_/_6_;ne]Kk6c/C8o/@mdMKCd/S?
go?bl^3Qi>;UdYfAV:BWYjJUV96a[Jn/Xj2I/JZ`ZJZCUJ>]][B_ZIfPY:ne/:^L
W:Bb][Nd/J5oYine[k6WX9fPXj:`X::RUHIjPifAYZ2QZJVdZ9b=LG1YNX2ERH>>
RI2JX9^SXYVM[KS7blZg`=k]k_Cem??_kng`k^k8KUIEBE1HDd=2BTQ=ATi9Ad@m
>4@o@TDn>d@oADM0@Cm1@4Pj>CU1?cdjAVYgRhVAV:Nca<Zo/K6`^kh:blJl_kFe
_/K>a<Sna77Ae]?Bb<oOlo;bh>7Th^GBWI6HY:NWYZFHTK6][jbSX9VaZ[2YZY>E
Xjff]:nYWJ2T[kF`ZibLY;:f]kBaXJNO]JnaYj2MX:>R/:2RXYF6NX>MTJJPXJVY
]:RLSG5`JGZ0UHV3SXV@VZ2KXj:IWJfhal]Fb[O0g^g^m?Gdlno_kO3^k/Q^EUE9
D5QC@d9:B4e6CTU7A3dhA3m2AChkA3m5Ad11?d50B3Xi>D4o?CY6JWN;RI6HYk?4
b[na/K2k_/_6_;ne]Kk6c/C8o/@9dMKCd/S?go?blP9YKmoPi>CUcjJFV9BFWZJZ
ThjUXZZV[JJLWZ:SZ;BRVIRGX:N/]JNXV9^SXjRZYibPZZb]/j^WViZIYZ6/YYnL
UJBSXjbVVWI_LWjBUIVLWY5oPg=eMG^@PhJ:UYB<ShjSWjZbZZJR/[31b<WJjO3_
l_CnlPcdkng/ih9JFde7AdY8OdI4A419Ade4Bd<m>Se3@413?3dk>Sho@Sa3?D0j
>3Xo?d0h?cm3BeMiRXfBX:^k_/2a]:nd^[o4_[Vb]kk5a/O:al34_/[Be>3al_?O
h>CTiLnVUYRDUYjVZY>>YJ:ZYZfVW9jRXjRdXYVHUj2W[;FWZ9RKXj>XZZNLX:Z/
[K>[>jNKVYVVXJbVWibEY:>S[:JJMVmbOY:EVIbNTGn3LgEeNi23QXZFU8b?SZ>O
Z[:ZYZ:b/<78bM[Yl>obm?kb@?C_kNcWPUYKCDM7BTQ6A4A0BDM=A4]3?CXm@d10
@c`m>cXn?d8l@ce0>SPj?cm0>3lo@d]GNHZ=TZ2[^kk0/KB_OkBj_lBn^K:g_/G6
al[7`<Bnb];Dh?7blmoPi>CUcjJFV9BFWZJZThjUXZZV[JJLWZ:SZ;BRVIRGX:N/
]JNXV9^SXjRZYibPZZb]/j^WViZIYZ6/YYnLUJBSXjbVVWI_LWjBUIVLWY5oPg=e
MG^@PhJ:UYB<ShjSWjZbZZJR/[311lS9f^W`ko;do_9Hm>o]k>N2FU]=AdM:B4I4
A419Ade4Bd<m>Se3@413?3dk>Sho@Sa3?D0j>3Xo?d0h?cm3BeMiRXfBX:^k_/2a
]:nd^[o4_[Vb]kk5a/O:al34_/[Be>3al_<2J?oQo^=jaYfM[:VUViJNZKBe/JnI
VibV[[6^YZRJXjZi/KFYX9f_[;RX[J6PZ:ng]k>YXZ:UZK:_ZIfQXZ^_/ZnTY:2S
YKQmOGmjOhJCWIR<KFUgRY2HYHUnQGf7VY^_Xj:W/kc5a/74fncam?3`lo3blOCc
lNg_gEU=DeA;D4Q=CDE4BDe?Ade5Ad8l>T]7?d8n?S`j@D<m?D0kATLj>ce1@d0n
B3`l?cm6Eff7WinTY:je_kg8`/6i_ko8cL;3`K_3c=3?clVnc>Wcl_;QhOkS;/JM
WJbYYI^FWZVd]K6_VI^LYZja[ZJXVZ>Z^K6eZJ2M[jbhZ:fQX:R_]kNcZJ:ROjFY
/ZnYWJ6RZjnb[jBTX:>U^7emOgYoQY>MV8a]JGN:T9RURGj5OHNJVjnSXZNc_<G6
`LCKk?7dl?3cl?;am??akNoMFDeCE4]@B4e5A4U=CdM=ADM2?3Y;Acm2?Shl>T53
?Ce0>dI7>S/m@D=0?TPl?3loAUM]QinOY:B^]Knm6LS2`KVo_lS=`/?1^l?<d<o?
bKk<jO?bl^7Qo^=RaYfM[:VUViJNZKBe/JnIVibV[[6^YZRJXjZi/KFYX9f_[;RX
[J6PZ:ng]k>YXZ:UZK:_ZIfQXZ^_/ZnTY:2SYKQmOGmjOhJCWIR<KFUgRY2HYHUn
QGf7VY^_Xj:W/kc5a/74Hm_/lOC`l??`l_7dlo7]kmeICE=DBe18CDE4BDe?Ade5
Ad8l>T]7?d8n?S`j@D<m?D0kATLj>ce1@d0nB3`l?cm6Eff7WinTY:je_kg8`/6i
_ko8cL;3`K_3c=3?clVnc>Wcl_82JEKPh^?RhkfGVY>EZjNWUYZMVj:^X9RBWZ6V
XZ6WY:>HW:V`[j>LWinWZ:jXY:6PXZ6aZ[2[WIjVY:^TZ9RNWJNXYZbNVinYYXAm
Mg=XG5QEHfYkO8B9RIknR2F3Q8VFZZB_[[>^Z[S7eNg_ko3`koCbkNo`l>g[/FmJ
DDm<CTQ2B`Q:@TQ8BDY?A4Wn?Phl?Cdl@C`m>3Pm>dE0@T?n?F4l?Cll?40n?T=2
?cTo@daWU9:KZJ^[^kk3]kJf_LK0`/c0_ko4bLc=a=Oal_?bh>;Sh^>mUiZCUJ^W
YiJJWI^R[Z2HTYjQYZ:QYjBSV9bY/:nSW9nOYjR^Z:BQX::Q/JZ`Zb:MWZJTZjBX
V9jMYjRV[9jKWjVVQ7egLfQLF5ESJW]lQ8V9W_j8;X>4RIJZY:n^/jjZ^<OEkNo_
l?3_m?;]ko3`kN^aKeYACda>B49;BT98B4U:CdA9oSh>?3dm?44l?CPh?C]5@493
oSdE?3do?3a0?Si3@Sli?d=<IiBBVjV[Zfjk_/>g][Jma/32c<2o_lC9c<g4eo7b
lo;Ph^?RhkfGVY>EZjNWUYZMVj:^X9RBWZ6VXZ6WY:>HW:V`[j>LWinWZ:jXY:6P
XZ6aZ[2[WIjVY:^TZ9RNWJNXYZbNVinYYXAmMg=XG5QEHfYkO8B9RIknR0f3Q8VF
ZZB_[[>^Z[S7eB3]kno`l>odl^g_l?3]jk5_FU5?C4i8@T]:@TQ8BDY?A4Wn?Phl
?Cdl@C`m>3Pm>dE0@T?n?Bdl?Cll?40n?T=2?cTo@daWU9:KZJ^[^kk3]kJf_LK0
`/c0_ko4bLc=a=Oal_?b0VT0gokRNnJoXj:/YijKViV`[ZfOXiZO[:j^Zj>HVJ:b
]jfYYijNYZjc]:RHUJ>Z/;BZZj:^Z:fb/ZNGUYnT][6VX9bRUZ^]]jNRVibWZgeO
FV=TPgYmUXnQShJ6X:>W/JjS[k2b]L[Oj^_dl?3dl_Gel_3`kno^j75BD5M;C51<
A4A<@di@CDi?BDQ=A451?d50>ShnBcXi@S/l?T10@D4m>T8n@3a3?CPl@ce2A3e3
BEa[UYn][k:c/kC3`LG7][Ro_lO:d<_2^L7AkO?bm=onhRoV_j>R[:NNVi^I/:j]
Wj>JWjb^[Z^SV9VR/[N]ZJNNWZJ^/kBXV9FSZ[2dZZ^R[ZQo[K:bYiNFWjBf/JJP
W::FZjfgYj:KW:N[OEmJHfB3NWfFSj6?QXJPXjNa[Z>_/;:eb]oZjoC`l?CbmOGb
l?3_knkXLE9@Ed]<D4a4A4=>D4e>CdU8CDA1@Cm1@3Xn?T/j>D8k?3i0@451?CY2
?T0l@cdh?4<m@T@m@dULJiJO[JlH/[>c]<?1aLNf^;noal[@bl:i`M7]lo;dgokR
HnJoXj:/YijKViV`[ZfOXiZO[:j^Zj>HVJ:b]jfYYijNYZjc]:RHUJ>Z/;BZZj:^
Z:fb/ZNGUYnT][6VX9bRUZ^]]jNRVibWZgeOFV=TPgYmUXnQShJ6X:>W/JjS[k2b
]L[Oj^]Sm?3`m?;emO;`l>o_k^QaDU1GBda@C4A4@di@CDi?BDQ=A451?d50>Shn
BcXi@S/l?T10@D4m>T8n@3a3?CPl@ce2A3e3BEa[UYn][k:c/kC3`LG7][Ro_lO:
d<_2^L7AkO?bm09YKMoPhn;S_Y^FYJRXXIbFXJ6SZ:BTW9fJXJbUWiZMViR_[jfR
VJ6SWj^YY9FEW:BSY;JQZib[Xk>YY:6JVJ^RYjVWWIRMX:NVZjFPX:RVVWAfJG5]
MGj7QX]nNh6CVj>][ZJJXZSJjO3`l_;al>oco_8>l>k/dXINF4E9AdM<B4Q5Oc`o
A4U:B4U0@C/n>Ci4?clm?C/k?chk?CPm?Ca0@3`n>cLl=c/l?3Li>d16@3`h@5UR
MXZOZZb^[[2m`<_5^[Rj`LK;bKc2ancblo;Oh>?RhkjKUZFXZ:6LUZ6QXjRTY9bM
VZ6/YInJWI^H[jn]XYVQXin[ZJBEUIbTXjBfXJ^L>J^S/jVTXIZIZj:WZJNMV9fP
YjJ[YJ2PZ:JJM7IYLFeeOXN6RgikPI>KXjf^YYZRZ=[Yl?3bl_7`ko?nlT;`k^cB
QUiHADU7Ada8B4Dl?dA9BTQ9@44k?STnA3lo?Cdk>cln>cdh?Cdl@40l?S/g?3Lk
?3`g>C]0AT0l>41IHWJ:OinZ[:j^/;g0blFj^;[1a/_9_<;7k?;cl]oPhn;S_Y^F
YJRXXIbFXJ6SZ:BTW9fJXJbUWiZMViR_[jfRVJ6SWj^YY9FEW:BSY;JQZib[Xk>Y
Y:6JVJ^RYjVWWIRMX:NVZjFPX:RVVWAfJG5]MGj7QX]nNh6CVj>][ZJJXZSJjO3`
oo83lO3_lokbF_3^k=:6GUQ5BDM7C4Q8AC`oA4U:B4U0@C/n>Ci4?clm?C/k?chk
?CPm?Ca0@3`n>cLl=c/l?3Li>d16@3`h@5URMXZOZZb^[[2m`<_5^[Rj`LK;bKc2
ancblo82J?oPo^=jaYZNY::CUIBQ[ZZQVIVFUk:RZ9jGV9VSYjNQVJ6MUjV_Z:BN
V::X[kJ/WinLVib`ZZ^JV9^JYJnUY::IUY^/[k2OWiROYJ^cZZ^^Hd4k@DIDIfQW
GXNAWiVFUZ6ehnkcko?em?7cl>o`l?GalNkWL5]9BDE4Bd]:@c`ood1;B4A4@d8k
@d4l?3ll?d10?d10>cXg>CXl?48l?38o?T8m?Sdk>C`m@cXk?3hh=Se7KFaaLGn>
XjVn]KJc^;_2b<2k/[g2bNGaloCPh?kS;/JJWZBRTiFDXJjZXIVIUYNbXZRNUiRI
XjNWXIVQWINY[jRTWYRRZ:nf[9nOW9^LOk2ZZiZHViZU[jFTXYVFVjb_/9nOV9nU
Zk>ZZjiS@C]1AUAWJ6MNQi6OVIJFXKGSk_?_loGdlO?`ko3`mO7ak^M`FdU9ADA;
BdY3?3m0@4Q4A4=2>d=1?3`o?3m0@3m0@3/j=cTj?3a2?3`b?ci2?Chm>cTl?D<j
>c`n>3HmAfe/og4GOhjSZKje][>h^l;8`;^b_L;9iO7cm>3Po^=RaYZNY::CUIBQ
[ZZQVIVFUk:RZ9jGV9VSYjNQVJ6MUjV_Z:BNV::X[kJ/WinLVib`ZZ^JV9^JYJnU
Y::IUY^/[k2OWiROYJ^cZZ^^Hd4k@DIDIfQWGXNAWiVFUZ6ehnkcko?eHoCalo3_
l?3elO7^ig1KBDU5A4];BT<l?d10B4A4@d8k@d4l?3ll?d10?d10>cXg>CXl?48l
?38o?T8m?Sdk>C`m@cXk?3hh=Se7KFaaLGn>XjVn]KJc^;_2b<2k/[g2bNGalo@2
JGoRgn?Ti/RJU:2OZ:BMVIbNZZNVXibVZ;BZ[:2LWJNT[:J`Y:RT[:b`/YbRXjVZ
[K>Z[JBLXZF[[J^WWJBYYj>VYIfQXjFZY[6QZIjTXjfcS3Tg=S/l>SiEaH1iO9>G
_M?Yj_3`m??blo;bkNk`m??ak_3YZeiCDDi<B4Q9AdE7B0Q3B4@nCD]6@T;n@7<i
@T]7?cdnA4/j>C/kAClnAd<lACe5ATM:?ca0?4=6@Se4>cDe>dECHg1fP8n@XjNh
][>k_L;6`lG3_lSQl?;ch]oSi>K8VYBPWjRTWIVLWZZWYZ>LYZRdZZbPW9fWY:bV
/:BXY:b//;:LXZ>YZZfcZZfTW5BRYJ^]ZjNMY:VWXjJUWJ6SYJZV/J6YWZBS[K><
>CLf>c`j?UG5P7UlTiNmdnWZl?3dlo;cl_;]k_3dlo7^l>V[GU=ACTa8B4U7ADM8
@dQ4?Te;AT92oT0W>D9;Aclm?TA;>STk>dDo?TM3?4DmADI7BSll@3a3AT8mA3/e
=C]5DgmSL7J0Si2SYkRf/k^m`/K3aL>ob>7`l_?Rgn?Ti/RJU:2OZ:BMVIbNZZNV
XibVZ;BZ[:2LWJNT[:J`Y:RT[:b`/YbRXjVZ[K>Z[JBLXZF[[J^WWJBYYj>VYIfQ
XjFZY[6QZIjTXjfcS3Tg=S/l>SiEaH1iO9>G_M?Yj_3`m??bloob7^g^l?CclNk`
jJ]NDe5>C4Q8BDM5AdQ3B4@nCD]6@T;n@3li@T]7?cdnA4/j>C/kAClnAd<lACe5
ATM:?ca0?4=6@Se4>cDe>dECHg1fP8n@XjNh][>k_L;6`lG3_lSQl?;c0VT6hN3S
h^G=[OjIMIFFWjRNV9JEXZ>/[ZFLTIjOZZb[WYfIVZ2cZk6SXI6DZZZgY::QWJ6Y
[K:TYYBJUj^/Y9f@V9JXZjbQUYVOV:JX[jNA?Sde?3lj>3dmAM_LeHjCVnO]kNkb
k^oalo;al?3_k^o]kNkZQVA;A4m=B4Y1AdA0@TOoAE12>Sho@CTj?dM5>S]1?C`m
?d<l=cQ7Ad<n>Sll>DI4@Sa4?d8k>Se>@cHf<cHk>SPj>TE=E6AdMg=aP8FS[LFh
][>ea<SFio;`l^7Phn;UcJgnVBVEUYnXWYRFUJ:S[:jUW96NWjZ/ZijMVIZP/j^a
Xj6AU:ZZ]jBRXIfQZJeo/ZBVU9ZGZjbTWI2HUZR[[:6FVInHYZR_Yi4n?CDl?cXh
?Ce5fmcESY>King]k_;^ko7cl_7`l>o^kng]k^Z6I4]4Cde8BT57A412AdE5@SXn
?d4i>Sm7ACXk@Cdl?Cm3?3LhAdM3?SXo?3U6A48lA3m2>cXmCT<f=S<f>cXh>SXN
ADeDI7AgLg60QJ>]aKRf/kG4b=KWl_3bhN3Sh^G=[OjIGIFFWjRNV9JEXZ>/[ZFL
TIjOZZb[WYfIVZ2cZk6SXI6DZZZgY::QWJ6Y[K:TYYBJUj^/Y9f@V9JXZjbQUYVO
V:JX[jNA?Sde?3lj>3dmAM_LeHjCVnO]kNkbk^oalo9SlO3`knk_kNg^jXITBdA?
CDQ:@DM4@497ADE2>Sho@CTj?dM5>S]1?C`m?d<l=cQ7Ad<n>Sll>DI4@Sa4?d8k
>Se>@cHf<cHk>SPj>TE=E6AdMg=aP8FS[LFh][>ea<SFio;`lP9YOmkQh^GT_IfS
WibKUifOXjJZX:2UY::a/J2/XJFV[::SY9VPYZNe/ZnPWZ>U/[:gZZJWXJVZZJ^P
Z9nRXZR^YjRNX:>MZ:BZYJ2WX[>;CSTj=c@e=3Lf>E3QhlCTknk`kO3bkO;`loGa
l^o_l^k[k^g]gVESDeI9BD=6D598CdI8Od=1@4A;@S/j@T4l=CXg@clo@d0jAD0l
A4I3@D91@Ce9A4U0@dA3=cm0?3dl?CTi?CLg>CLo@Da?FemTIG5dQY>l`<Fo^Kfi
encal_?NhN;Ui;fMXinLViNMWj>VZZ2PYJBR/K6P[:6UYZbRXjBIX:JW]K:_X9jS
YK:b]jZVYj6YOjZYZj2XWj:RZ:jWZ9jPXifXY:ZUX:NR/h]>>CXg=3Dd=cHiD>7S
a>C_k_3]l?;]l_3cmO7bknobk^_^kNgNIF=CETU9@dI@DTQ?ATQ3@D14Bd8k>T91
?3Dj=d<o?d=0>TE0?4A6@d52@D4mBDA9@4=4@cLo@3`m?3di>Cdg=cTgOcm1C4mK
GfAULGB6Tkc0aKni_KWGk?7blmkQh^GT_IfSWibKUifOXjJZX:2UY::a/J2/XJFV
[::SY9VPYZNe/ZnPWZ>U/[:gZZJWXJVZZJ^PZ9nRXZR^YjRNX:>MZ:BZYJ2WX[>;
CSTj=c@e=3Lf>E3QhlCTknk`kO3bkO;`loGaHo;_ko;^jnk]kMiUHe=FBDU3AU1B
B4m6B4=1@4A;@S/j@T4l=CXg@clo@d0jAD0lA4I3@D91@Ce9A4U0@dA3=cm0?3dl
?CTi?CLg>CLo@Da?FemTIG5dQY>l`<Fo^Kfiencal_<2J?oPo^=8`ZBFUY6OWj^S
VY^MXZb^WiFJUYRU[ZjRXIF=V::/[J>[XZNL[:FLYIjVVJR`[[2NVijHXJB_V9RI
UZ:VZYbJTiFLX:jc/YDo>Ohd;SPf=S@i?eOMGe>Xk?7al?C`l?;clo;am?3bk>WX
jNb`NE=:ADI:CDY:@T10AT9@CDU6@SXk?3lh>S`h=cXm?Shi?40i?Sm0Ad4n?44i
?3m0>C`j@CQ>>d4n?3/c?3Dj>S@f<c@b=ceAG4e;CE=FKGFNWZRlaLO5gNobko?P
h?kS;/:TUYJAWin[XiZKWJ:/[YnEVYJHYJj^XZ6ESIRR[:fSZj:WW:bUW:FNYYVX
/:j`6IjKWYRQY:nHV9VFXZJZW9ZCUIbP[[>bUClioSAR>3Hf=3ToEmeODjS/lO7`
m?3`l_?cl_7dl?;/jNSYk;1iDdY5ATY=BTY2@416@U19AT8j>c`o>3Xl>3Lj?Chn
>Ca0>Cho@4M1?Sa1>C`o@3Tl>T4hCS]1?S`k<c`e>SXd=S<d6C8g?E5LCD]=DeI]
MIjNZ;c5alGMko;_ln3Po^=8`ZBFUY6OWj^SVY^MXZb^WiFJUYRU[ZjRXIF=V::/
[J>[XZNL[:FLYIjVVJR`[[2NVijHXJB_V9RIUZ:VZYbJTiFLX:jc/YDo>Ohd5SPf
=S@i?eOMGe>Xk?7al?C`l?;clo;aHoC`l^cYj>W//7UCBTE6BTe:BT90@4I2D4U6
@SXk?3lh>S`h=cXm?Shi?40i?Sm0Ad4n?44i?3m0>C`j@CQ>>d4n?3/c?3Dj>S@f
<c@b=ceAG4e;CE=FKGFNWZRlaLO5gNobko<2IWoNh>?Ti[RRWZ2KWIfYX:>SXZFR
WjN[Y:JPWif/YjjTWIbEXZjb/k6_XZN^[[RR[J6UZ:fc[jZQWjRMXIZaY:BVYZ2S
YZ:YWZJ^[Um1?3Tb=CHd=cdj?ceFZD13M^_/kNc_lO;clO;cl_CblNk]knOXL6aK
Ed]:@TM<DD]8B4I1C2i5C3hjBE53>d<m?3ll@D@n?cY3>D51?dDk@D53?ca1?d91
AD12@SY8?cXl>3lj>?dkC3Lk=c]1I55AD4]AEf69UZba_[Rne_3am?;Nh>?Ti[RR
WZ2KWIfYX:>SXZFRWjN[Y:JPWif/YjjTWIbEXZjb/k6_XZN^[[RR[J6UZ:fcNZnZ
XInXWJ6J/JBTYZJPXjJRZIjV[ZiO@C`i<SDf=3Lm>SlmEZU0@gK[k>g/ko7blo7b
lo;dl_7^kNoWj71/FeM;BT97C55;B4Q6@Da5C3hjBE53>d<m?3ll@D@n?cY3>D51
?dDk@D53?ca1?d91AD12@SY8?cXl>3lj>?dk03Mo>cLk@FAADE1;DEMQRIJ//Kjh
_]K`lOCbg^3Si>JhXYjPVifMZJ2SXj:UXYnWZjBVX9nM[:N^Y9fLUJ:^/[>a[j:W
[ZjhXZfQYJR]/jnZXInXWJ6J/JBTYZJPXjJRZIjV[ZiO@C`i<SDf=3Lm>SlmEZU0
@gK[k>g/ko7blo7blo96m?;ak^g_inQ`K5]GBdY2AdaABdQ8AT5<AD`n>TUA@c]3
?C`o?454?Slj@cU1@Cm5>d51@cll@Cm2@DE0@T8jB3lj?3Po>SSm>aPg>cLk@FAA
DE1;DEMQRIJ//Kjh_]K`lOCb0VQog=kRh^>dXHjBX:ZXX92=S9N/[J6GVYRZYZVR
XY^GVZJ]Wj>RWYNIWZVXZZ>LVj>U]ZJYXJ6JVjN]XIbAUI>Q[9nVUYVAXJBlID<e
=SDh<bld;cDa>SHkFChl?T_LhncYl^gal>c]ko3_lng^jn_MRe]F@dM2AD=3A4Pk
?T51AdY8@3/m@451?c]1@CTl>SU0?3Ln?cM1=SPl>D52@Cm;?c`m>ca1?4<o@CLj
?CTi?Sli>CPi<CTj>3a4A4YACTi<Ce1DLZNj^[c0j_k`<mcNh^;S]:6>TZ2ZZ:2@
SHbG[:fQUiZHZZJYXZ:KUiZV[InSXYjGVIjYZ:ZSW9^SYKJVZJ5oXIZKYjfQW96E
Tj6/WjJFVI6QY;aU@cDf=CPc;c@_=C4j=S]I?S`nBmcSk>WbkO7`k>g_l>ockNk[
jmf;FeI3Ad95@d=4B3/n@D57BT0k?D11@Clk@D4i?3Xi@3`g?Slg@CHh?3U1@T4o
Bcll?C/l@Ca3?d4g>Sdi>Cho>CTh>C4D>CXh?4A4BU5>CTa?D5AbYkZj_<3Zo_1W
g=kRh^>dXHjBX:ZXX92=S9N/[J6GVYRZYZVRXY^GVZJ]Wj>RWYNIWZVXZZ>LVj>U
]ZJYXJ6JVjN]XIbAUI>Q[9nVUYVAXJBlID<e=SDh<bld;cDa>SHkFChl?T_LhncY
l^gal>c]ko1Pko?]k^_[gH]KET=7@TE3@dA8>ci1@DM:@3/m@451?c]1@CTl>SU0
?3Ln?cM1=SPl>D52@Cm;?c`m>ca1?4<o@CLj?CTi?Sli>CPi<CTj>3a4A4YACTi<
Ce1DLZNj^[c0j_k`0VWoh?oUNn?0YI6GV9jUYZ:TUYJOWJ6QYijVXJFTXIjUW:6O
/:R][ZRWXJ>/];JbY9nRYIjd]KBNWj:UZ:ZVX9nXYJjY[ZVM[J1l?3Lg=S@g<S4`
>3@e=C@g>T50?4KFj^c^lO7cl?7^mO;]l>k/inNBKUYDBT=0@dE5D4i3@dA4ASio
@Ci6>4A3?d90?c`n>cLe>Sm0>cY0@4=8?ca2A3m;ACm1?SY5@TLj@3Y0?3Po>SU2
@CXj=3Xh=3LiBEE>EE9DE5=LJ8NL/[O9j_3aln3PiNGS`:FAUiRNYJJRY9JFWifQ
XJNNYZ6UY:6NYIbQWk2X[JjXYj6S[;Bf/ZBOXZFN];Eo]9jOXZFXZZJPWjRU[ZV^
ZIf]X7`l=cLf=3Lb<C0h=3De=3Lj@D0lA]KZk>kalO?`lNkel^g`k^cWii9^FUA:
@d13ADE@CT=3A4A6?T4nASQ4@cm2@3ll?S/g=CXo@3/j@413B3ll@T@oBdDo@Chj
AD97>T0j@3`h?cXi@T4j>SAo>SPd=cU9EDiEDUADDeaXQibb]lWZl?7ch>3UiN?0
YI6GV9jUYZ:TUYJOWJ6QYijVXJFTXIjUW:6O/:R][ZRWXJ>/];JbY9nRYIjd]KBN
Wj:UZ:ZVX9nXYJjY[ZVM[J1l?3Lg=S@g<S4`>3@e=C@g>T50?4KFj^c^lO7cl?7^
mO9SkO3^k>OWTViJE4Y3@4=5AE1>@d=4A4Hn@Ci6>4A3?d90?c`n>cLe>Sm0>cY0
@4=8?ca2A3m;ACm1?SY5@TLj@3Y0?3Po>SU2@CXj=3Xh=3LiBEE>EE9DE5=LJ8NL
/[O9j_3al`9YOmoQi>?T^iNEWjJPW9ZEVI^WZ9^OUi^Q[:VWWYB<UZB/Xj^QW9bR
XK2^YZ>KWjZe]:^QXIZHX[R^YjJFTYnR[J^_X:BTY[=;=c4j<3Pe=Rla<S@h>CXc
=cTi>3a7KL7^k?3^knoalNk]kNc[k>[7IF16ATA2@D@m@T50?S]7Ad53Ocm0@3]1
?chm@S`jAT@g=c<n?SPo@c`fAcXh?T<oAchl?ci4BClk@3/l@C/o?3Xo>CPg?c<i
=c0a=3UGDDi7BTQ?E5UiOI:G]>;^ko3OhNCSi;^GUInVX9bJUIVKYjRKWiNKXJbY
YijDS9JT[:>[XIbLXZ6`[ZJSVinZ]KB[XJ6JOiRR^:jWYYJBWj:]ZjnPY:BV/d/g
<CX`>3Df;c4b=3Pi>S<g>CTh?4M]`Nk/l>k_ko7ak^g]k>_/j/MUH4I6A491A3e2
@D0n>dM7@D<o@40k@Cln?D8l>TI4=cLc?Shh?d<l=TLj>3i3?dLn?3lnA4To>d0k
?44k?c`j?cTh=clcOcTg<34d>EMACTM:B4mDFGUmTYNdh^k_l=oQi>?T^iNEWjJP
W9ZEVI^WZ9^OUi^Q[:VWWYB<UZB/Xj^QW9bRXK2^YZ>KWjZe]:^QXIZHX[R^YjJF
TYnR[J^_X:BTY[=;=c4j<3Pe=Rla<S@h>CXc=cTi>3a7KL7^k?3^knoalNk]Hng/
jncZafEPATI4@T54?D91@3hkAdM1@cm0@3]1?chm@S`jAT@g=c<n?SPo@c`fAcXh
?T<oAchl?ci4BClk@3/l@C/o?3Xo>CPg?c<i=c0a=3UGDDi7BTQ?E5UiOI:G]>;^
ko02HooQNN?Ti/>MU9BPY:NRXibNZZ6[YibPVJNU[ZJOVIRHY:B^Z:RIWJV_/Jb/
X:NN[;:[/;BXXijUYZ^bXJBNX:Ja[:f^ZjMO>cH_=S<d<C8`=3Pe>CPc>Cli>CXk
Ae:GkNk`k_3blN_blO7cjnRoM6aHBTU1@T16ATm6A3Y3oDPQB3]7@TDl@DA8@T=4
?D10?D0n>C]5@Se5>3/m@d8oA410A?i3FTA0@3i4@Cm0AShh=cPd<SDj@c<j>DU;
EDQCCE=9CeaMOXb^i^k_lN7QhnCV`ifDU:2TYj:SW9jZXJ^WW:2IYjF^YYnIV9RT
Y:jXZ9VMZJna[:bPYij//Z^`]:Q7XijUYZ^bXJBNX:Ja[:f^ZjMO>cH_=S<d<C8`
=3Pe>CPc>Cli>CXkAe:GkNk`k_3blN_blO7cjnRoM6aHBTU1@T16ATm6A3Y3o4PP
>dM2ACa1A4Q2@d@m@40m@3hi>dE2?DDh>ce3@Sm4@414oT<>A410?TA1?d16?SPg
>3@bOcDj@c<j>DU;EDQCCE=9CeaMOXb^i^k_lN7QhnCV`ifDU:2TYj:SW9jZXJ^W
W:2IYjF^YYnIV9RTY:jXZ9VMZJna[:bPYij//Z^`]:RSWZFVZk:QY9jPY[6/[Jj[
Yelk=Rlf<c@a<S0d>3Di>3<i?cTi>S]7DYO]k_3^l?;ajo;a4o7cjnRoM6aHBTU1
@T16ATm6A3Y3o4PP>dM2ACa1A4Q2@d@m@40m@3hi>dE2?DDh>ce3@Sm4@414oT<V
A410?TA1?d16?SPg>3@b=CY3<cXiBD]EB5==DdU?G5enS:kVk^oa0VQTh>7RhnFk
XJ:NVYFCVYfSYjJIViNGXjB/WYZ;U:2NY:6MWIZ][;Jb/IbNVYNa[k:XYYnLX[Ba
[9fTV9bR[JjRXj>OYJPn=c8`;S4]<SD_;c@b<SDc<cHh>c]1A4Q4B]g[k>gal?3n
kQOal>WRIF9;?cm=BT=0@ci1@3e8ASm1A446>ce3?T8l>_hoMDQ3@Shn>T4n?D54
>clg@DA4@3/i?411Bd=4@dDo@4=:C3/k>C/l?CDf=STe>Ca1=D57C455AU];D4m;
E5NWi?3_kN3Qh^?U^j6RWYZETiZMXjNVVI^GUj>T[9jJRiBPWZBQWIfJ[Jbf/[6L
WYZG/JnbZ:JOW:8`];6/WJBHW::][Z:SXinUZ3hg<S0^<Bdb=Bl_=38b=C<c=SPk
>d54B4A:gN_/kO7`l?k^7_7`jN9UHT/o?de:@d13?T50?DQ6?d54@C/m@ci2?3[n
?bU8@d8n?SY1?Se1A3/o=d54A40k>Ca0@D]3A4=5?d13BT`k>cTk?3de=SIl>CDi
?44e@DM<@DE6Fd]@Cd]DEjOTl>o]h>7RhnFkXJ:NVYFCVYfSYjJIViNGXjB/WYZ;
U:2NY:6MWIZ][;Jb/IbNVYNa[k:XYYnLX[Ba[9fTV9bR[JjRXj>OYJPn=c8`;S4]
<SD_;c@b<SDc<cHh>c]1A4Q4B]g[k>gal?3nkQkal>WRIF9;?cm=BT=0@ci1@3e8
ASm1A44k?D<n@S`joSm1B4=2?Shj@Chm@D@k?cM1A4A0>cTl@45;@dA3ACm0@dY<
>c/i>c`m=CHf>CDi?44e@DM<@DE6Fd]@Cd]DEjOTl>o]0VUogn7Ui>J^VIRjZJRO
]iVIXJ>Z[:2OW:JX[:NKW9FFXIjN/jZ[X:ZU/k:][Yb/Z[Ja/ZROY:JT[k2aWjJO
YJf_ZJnZZ6a6=3Lg=CL/<SLc<cPf<cPe=CHc=Se6Ad53CmCZm>o`kNg^kNoajN:S
HU94?d=6B490ATQ<@Ci0BCe9BDYo@S`n@DE3@cm2@TA5@D4o@T12?chn@Cm3?dE8
AdM2?Sdk@T56BT<n?cm5AT<m?c`m?3Xk?CPh>cTl>cXiE4A;BE=ACU9CEeBSjO;c
l]oQiNCV[YVH^ZVXWkNIVJ6SZZbPWibVZ:bWVibEUZ6NW[>ZZj2ZYK>b[JjL[:Zf
/K:XWjAoYZB_/;6OYYnU[JnY[jZXK4Hd=cLe=b`b=c<c>3Hc>3De=S<f?DI7@D=?
e>[dko3]kNk]ko7YhZ=RDT@o@dI8@T16B4a1?T19?DU9BT8l?T55@d<o@T94AD51
?d90@Sln?T4o@cm5B4M7@Shm>d91ATY3?SloADI3?Cll?C`j>cgo>7dk>C`k>SUD
A4]9De5>DU=GE:?Yl_?bgn7Ui>J^VIRjZJRO]iVIXJ>Z[:2OW:JX[:NKW9FFXIjN
/jZ[X:ZU/k:][Yb/Z[Ja/ZROY:JT[k2aWjJOYJf_ZJnZZ6a6=3Lg=CL/<SLc<cPf
<cPe=CHc=Se6Ad53CmCZm>o`kNg^kNmSlNWRXf9BA3m3ATQ2@4I8C44n@4TmBDU:
@S`n@DE3@cm2@TA5@D4o@T12?chn@Cm3?dE8AdM2?Sdk@T56BT<n?cm5AT<m?c`m
?3Xk?CPh>cTl>cXiE4A;BE=ACU9CEeBSjO;clP9Y>^;Ph^7T]ZFRVIBCT:>VXY^>
UInLYjVMWinLV:jUXZ6DVi>G[ZRXYZZOWj^][:^]XjV[/KBa[JJTXYb]oZ]1XZJM
[UTo=cHc=2db;CLg=Bd^<3<c>3@`;cY8=CQ3D87Ki>g[knoZjn_/knfBIUE0>CQ6
?Shm@d=0BD10A48mAd930T=1>_hm4C/i?4E6@d10@T8k?cdk@STn@?hoI4@i>Ca0
@D=0ATE5?THl>48k>cXl=SLg>3Pi=c8e=SLd=495BTeDC4Q3BTU>WNO^l>oRh>;Q
i;JUXYVDTi2SYZ:KSYFOW:NYWInOW9R^YJ:QU9^CUjjXZ:JZWin[[Jb[[J>YZk6d
1[6]YZBRW:gnZdBRYYf^FClg=S<d;C8]=cLe;Bh`<c<h=30_>TPe>4=@PM_TkN__
kn[[jnc_kI9VED0i>4Hn?Se3@d19@414@Se7@T=3@C[n?A4k>Ca5AT=0@492>clm
>d8i?T3n?aQ4>CTl@453@4I5ACi6?3Q2>c/j?3Hg=cPhDSTg<SDf=c@d@TE:CEA<
B4=:BDjMink`kn;Ph^7T]ZFRVIBCT:>VXY^>UInLYjVMWinLV:jUXZ6DVi>G[ZRX
YZZOWj^][:^]XjV[/KBa[JJTXYb]oZ/YXZJM[UTo=cHc=2db;CLg=Bd^<3<c>3@`
;cY8=CQ3D87Ki>g[knoZjn_/6^o]TVIE@3ThAShn?D=3@4U0@4A2?DM2@d=1>_hm
4C/i?4E6@d10@T8k?cdk@STn@?ho<4@i>Ca0@D=0ATE5?THl>48k>cXl=SLg>3Pi
=c8e=SLd=495BTeDC4Q3BTU>WNO^l>l2JGoOh>;OiZfWWjVVX9NOUZ^VYjNLVYnT
XJFXZJ6UY:N^[jBQWZB/[jVdYZ2S[ZZb^;Fh[JVb[Zba[ZJMZJ^g^;:_Z9i2>C4b
=c@b=Bdg=S4`<bd^;c0k=3Y5?SU2MmKYjnW^kO;]k>kbk>_SHFU>Ad0m@ChnA4U0
@d=1A4=5@TDo?gm2?d55@3U1?dHnA4E1@Sm4=SM3@STm>Ca2@4]<@D93>cm7@dU3
Cci8=SM2?Cdl@Sdk?3`j=CPk=c@h=SHiBTA6BDiECdiECXCSkO7`gn3RgnJ]YinY
YZ2GWiJ[YZNWW9ZOY:6UZ:VQYJBW[ZnTXIjT[:nY]:JPXjjZ/[Re^:fY/Wn^[;6^
YYfYZkNh/ZnXWT8i<C8g=38e;CLf<C0c;Bh_<3/d>TDn>D9ge^W[jNk]l^g/k_;/
jn=QJDi7@3e1?Si4BD13@d54@dE2AClo@Sm1AD0i@Cm6?TA5@D8oA3Hg@d8i?CTl
@T1;C452@c/oAd=9@dlnB3Hg@Sdm?48m>c`l>Wle>3/g=3Pf=SU:A4I9CUE?CUE>
Q>?]lO3Oh>;OiZfWWjVVX9NOUZ^VYjNLVYnTXJFXZJ6UY:N^[jBQWZB/[jVdYZ2S
[ZZb^;Fh[JVb[Zba[ZJMZJ^g^;:_Z9i2>C4b=c@b=Bdg=S4`<bd^;c0k=3Y5?SU2
MmKYjnW^kO;]k>kbk6?[hf5YCTM0?D4n?TA9@4=3@DA3AD95?cm2?d55@3U1?dHn
A4E1@Sm4=SM3@STm>Ca2@4]<@D93>cm7@dU3Cci8=SM2?Cdl@Sdk?3`j=CPk=c@h
=SHiBTA6BDiECdiECXCSkO7`0VUogn7Sh^Bg[9RAU9FK/9bLUYNLXZRNWIFGW9NP
[:bUUYnBXZF`Zj2GWI^`/K2UXj2L/Jbn[jfTWjJVZKBYZjFU[jE==CPb<C8f<CLe
=c8_:C<b=3D`=C=6?S]0B6V/hNCYk^c`kNcZj>[XWTm>@d0lA40n?d0l?T0o@48l
@Sdn@d9o@D8n?cm1?T18=ca0@dHn>c/n?STj@3i5@c/kAD8oAD8n@D90B4i:@3`l
?CU3@clk>3Dd>CHh>CXc=C@d<SA=Ad94ADI?DeF0i>g`l=oQhn;T]jbHTIBEVk2L
W9JGW::XWYfEUibGX:b/YIJOTZ:U/:^PUifK/;6`YJ>PW;6/_Zmo[JBOYZJY]:V[
YJF_YDde>38a<SHa=cDg<RlY<c8d=C0e<dHn>d18JJcQi>W^k?3]k>[Xj^RNCdi3
@3a4@3ho@3`n@3m0@Sa2?Ci3@T52?Slo@Ci0B3Ll@4=6?S/k?Shi>T0nAD<k>dE2
?dE2?T52@4Q>BT0l?3di@d<o>cPe=3Uo=SPi>S<e=3@b=4e7@TA5ATmCEH3TkO3`
gn7Sh^Bg[9RAU9FK/9bLUYNLXZRNWIFGW9NP[:bUUYnBXZF`Zj2GWI^`/K2UXj2L
/Jbn[jfTWjJVZKBYZjFU[jE==CPb<C8f<CLe=c8_:C<b=3D`=C=6?S]0B6V/hNCY
k^c`kNcZj>YSj9i?CT=0?4A0?Sm0?3i0?d12?48m?T=2@D8n?cm1?T18=ca0@dHn
>c/n?STj@3i5@c/kAD8oAD8n@D90B4i:@3`l?CU3@clk>3Dd>CHh>CXc=C@d<SA=
Ad94ADI?DeF0i>g`l09YOn7Ohn?V_:NSYIREVJFRYjBUUYfRXK:SXinMWjJ/ZJBS
VZ:QZjnXZZ>Y/;Bd/ZnaYjVW^KBn]K>[Z:F^[KF^/JmL?c/c=3Th=SDf<cXa<c8d
<c@c=CTnACLi?8iCT][Yjnk_l_3aj^WThVQMBS]4?d=8ACm5A4Hl?T9<@DE0?T92
OdE1AT93?Sm2?Ci0AdY1ATE3AShm?3i0@4A4?dA5@TU3B4]9ATU9?C]5DT<n@Ce2
?D4j>SHf<chg>3Dh<3DcBe9=DDiCCdm=QNO/kO3Qgn?Si[bWXjFHUIVUXZNTYIJM
XZ6bXj>OWInV[:VTXiZRXJ^_Z:ZSZK2d];:_/JNYYkVdOkje/j^XYJj]]Jja[e`o
>c<d>CPf=CHc>S4c<S@c=3<e>Ci5=cTlSU>Bf^W[k^obl?7ZjNCRJ5e:>d@o@dQ5
?dE4AS`n@Ta1AD0n@T95@DI2@cho@Sdn@4M:@DI5@dHn?C`n@414A3m4AD99@dQ;
BDI9BCdkAE93?T4m@Se1>SXfOcHc?SLh=CP`=C=;DTeACU=?Cdf5inc]l>7Ohn?V
_:NSYIREVJFRYjBUUYfRXK:SXinMWjJ/ZJBSVZ:QZjnXZZ>Y/;Bd/ZnaYjVW^KBn
]K>[Z:F^[KF^/JmL?c/c=3Th=SDf<cXa<c8d<c@c=CTnACLi?8iCT][Yjnk_l_3a
j^WTHn9XGDXkA3m3B4DoADA6?3i2C455@3i2@TE1AT93?Sm2?Ci0AdY1ATE3AShm
?3i0@4A4?dA5@TU3B4]9ATU9?C]5DT<n@Ce2?D4j>SHf<chg>3Dh<3DcBe9=DDiC
Cdm=QNO/kO02JGoOh>;Ti[JKU8bDXJVLVYNAW::[YIjLUYfTYj6OV:2JW:2^Y:>M
UY>M[KN_Yj6WY;:g]KJV[ZNc];6`Y:2SXjfg?CXe<S0e;c@e=C4c<2d`<S@g=C@c
@3hh?3j0@6c?i^_^kNo`k^cWeX1D@3Xk>T8o@T8g?T52@4<lAd<m?T12AWm1?3i1
@CY2=d52>Si:Ad@n?3Li?c/k?4=2@c]4@E17ASm0?Si2ACi2?Sa0@DE1@Sdh=38c
?cDg<c4b=c4d<Cm:@T96CU=BCHKWko3`gn3Ri>JfViB<U:6YW9ZGTIbRZjFNW9JM
Y:NQWiRPVYbP[ZBSWIJCWJfg[jNQYjBb]kFfYWn^Yk>d/K2TX:>S[KLm>SDb<3D_
=3De<C<`;C0b=3Le=3=0?SPl?X10K<oVjnk]ko3^k>OFP5A0>S/j@Sm2@SLn@D90
@ca7@cdn@496@C`n@D4j@SM1@SXnBTM4?S`g>Clk>ca3@T<kA45@AdHo@3hn@TDn
@Shl@455@D8m>3@b<glo=CLc<C8g<C@a?dY2@TI>De9=Q^O_l?3Oh>;Ti[JKU8bD
XJVLVYNAW::[YIjLUYfTYj6OV:2JW:2^Y:>MUY>M[KN_Yj6WY;:g]KJV[ZNc];6`
Y:2SXjfg?CXe<S0e;c@e=C4c<2d`<S@g=C@c@3hh?3j0@6c?i^_^kNo`k^cWeV>0
E40j>cY2?d92=ci1@T13?4M3?Ci0@TI1?3i1@CY2=d52>Si:Ad@n?3Li?c/k?4=2
@c]4@E17ASm0?Si2ACi2?Sa0@DE1@Sdh=38c?cDg<c4b=c4d<Cm:@T96CU=BCHKW
ko3`0VT1g>3nhdV^VI^FSYZNVYfRWYZPWiRFWZFNVYfIUi>FWjNDYYnUW:nMVIfU
Z:Vb[ZB/]JZWX:Z/ZjNaXInUZ:RaLCTf=C4b=C4b<c@e=Rla<Ohe;C@b<cTm>45A
@dNE/nO[kN_^k>[Zi5iCAcln>3`h@CTj?Shm>d0o>dM1A450?d4H>3/k?SY3@Ce1
AC`oBd93@CXi?3dl>D13@Oi4<DHn?da4B4<o>Ci2?Ca6=Sm5?c/i=S@l=C/e=c0h
<S8`<cLj@D]9Adi=CDV?j>k_l]cPo^<^[YVKUXjJWYZMXYjJX9nHUYjUWYZMVINC
UYnWU:JOYIb_WIVMYJRY/ZjT[;FZYj0JZZb[Yk6QWjFXZ;5a>CHe<C8e<C8c=3Df
;c4aoSE6=38c>Cdh@E53AiFcin_]jnk/j^[TGU=7?chh?3Q1>CXn?Sdk@3lkAd54
@D0o@CPk>chj@d4m@DDl?d]2@d4j>C`m?3U0@d7nA1M6?Sm<A4Q3?cTn@SdlASHo
AClk>CHd?3DI>cDg<3Pb<S0c=cY1BdU7CTe=BHoXk^obg>3nhdV^VI^FSYZNVYfR
WYZPWiRFWZFNVYfIUi>FWjNDYYnUW:nMVIfUZ:Vb[ZB/]JZWX:Z/ZjNaXInUZ:Ra
LCTf=C4b=C4b<c@e=Rla<Ohe5C@b<cTm>45A@dNE/nO[kN_^k>[Zi5h`DdLo?SPl
>44i>Shn?C]0?c]7@DA1@3m1>3/k?SY3@Ce1AC`oBd93@CXi?3dl>D13@Oi4;dHn
?da4B4<o>Ci2?Ca6=Sm5?c/i=S@l=C/e=c0h<S8`<cLj@D]9Adi=CDV?j>k_lP9Y
OmoQh^CU/8jBYZJXWY^ETZ2][;:OTiJKZJ^/XIbIV9RZ[ZnWXiFVZKJb/KFSZ;2m
`;Nf[j6QY;:_/k:UWZ6XVTHf=S<h=STa=3Ll<Rl/;3<c>3Th<cUTGCYYA4MUFiWZ
k_3/j^[]ilaCF48n>cdl?c`d=T92@cY4@TLm@4A3@TYAOclj?SeAA3]1?DI:AT]=
CTLl?D11@dU9B3]2AD<oCDI8?Ce6BTmEAchk@cm3Ac/o?cLg@CXm<cHc>SLm=chi
@3e3BeIODEU?VNW^ko;OhN;TiK2>TZJVZ9jKUI:P[JbbWi>FVjV[[:6LVIRHZZj_
Yj>EYZVf/[6eXjR`_L2g]ZnQOj6T/Znc/ZFNXJRJASHf<cPf>C4d=c`b;b`/<c<h
>CPc>FAM>VU4AfEKVN[^l>cZj^gWc5=H@Shk?C`o?3@f@T93>TA2Ace0A4=2BU4o
>ShmDD@k@Ce6BTI;CDi7?3e0@D=9BDPk@TE3?de6B3dmATY?EDLn>d<o@dLk?clg
=d4jOcdc=S<j=cdg?SU0?D=;EUmAFDnIjNk_l]oQh^CU/8jBYZJXWY^ETZ2][;:O
TiJKZJ^/XIbIV9RZ[ZnWXiFVZKJb/KFSZ;2m`;Nf[j6QY;:_/k:UWZ6XVTHf=S<h
=STa=3Ll<Rl/;3<c>3Th<cUTGCYYA4MUFiWZk_3/j^[]ilaCHeQ2?S/m?3ll=3I2
@T<jA497?D14@d9:DClj?SeAA3]1?DI:AT]=CTLl?D11@dU9B3]2AD<oCDI8?Ce6
BTmEAchk@cm3Ac/o?cLg@CXm<cHc>SLm=chi@3e3BeIODEU?VNW^ko82IGoLgn?Q
i:VJUiJCWY>DXIfRUijGV:2FXYjNV:2PWibLX:6DW:ZQY9n[YJZSW[2[/k6YZ:R^
Y::/XJ>S/K:/Zg@l>3Td=C@`=30b;bd`<c8d=30e<CU8A4M<?CUXGTf:j>O]jo3V
iIIB@d@f>SPj=cPi>C/n?cdk?clm?D50?TLn?ohm:Ci6>dQ1?dM2@D92Ad55>ci1
@Sm3A456@D8l?C]4@dTl@TU6@T8m?ci2@_dlCSXk=3Ph=CLg=3L^=S@c=DQ?B4a9
BTjRjNg]k]cOhn7TZIZGUY>NTiBQWJ:GWYNHX9JRWYjHX:2OW9bPXIBLZZ6TWj^U
ZZ>N/:^c/JVXZ:i;Y::/XJ>S/K:/Zg@l>3Td=C@`=30b;bd`<c8d=30e<CU8A4M<
?CUXGTf:j>O]jo3ViIIB@d@f>SPj=cPi>C/n?cdk?clm?D50?TLn?ohm:Ci6>dQ1
?dM2@D92Ad55>ci1@Sm3A456@D8l?C]4@dTl@TU6@T8m?ci2@_dl0SXk=?lhOCDg
=c@g;SHd<cE8CdQ<BDY>X^W]kNkLgn?Qi:VJUiJCWY>DXIfRUijGV:2FXYjNV:2P
WibLX:6DW:ZQY9n[YJZSW[2[/k6YZ:R^Y::/XJ>S/K:/Zg@l>3Td=C@`=30b;bd`
<c8d=30e<CU8A4M<?CUXGTf:j>O]jo3ViIIB@aM4=SXh>SLh>CTk?Slm>clo?Ce1
@3i7?Son?BTnAS]8@Cm7@T52@TM1AC/n@D8o@dA1AT52?3dkA4=9?499AT92?Cln
@T;m?1Xj>c@h>3Dg=c@g;SHd<cE8CdQ<BDY>X^W]kNh2JFgNgmoSi:JHWjNW[9^D
VYRR/JRSVYFHZ:nd/i^OTj:X[k6XX9ZIZJnk]jjSW:NZ^kVjY:R_]kJ`/KF[ZZ:[
_G8n=S8`=CDd<SD^<Bhc<c0e?CDh?3a2LIe1?T^6FFQ`j>[/jNSYjF9=?chd=cXi
>ohj3SdiCD17CT@i>Sa5?DE3ASPl?E5?>ce3?Si1C4Y7@T91@Ce5?TQ6@T95AT=>
B4Y2@Cm3AeE<BT52@dE6B4<k@3Pj?3Xn=c/k=cSn=d<f<cHg>U9EEeMBD9;Zl>ka
g]oOhnBVV9nWYjbKU9ZHX[6XXiZEV:R_];>KWi>RZ:naZ:2JVJV_^kN^XibWZ[^i
^ZBX[cVg][2a]J^ZXZ^mLShf<S0e=C@b=Bha;S<c<3Dm=CPl?49aWD4nBhIIJ73X
j^cYj>WYHTdo?S@g>STkoSY2?CU=@4M>A3Tj?4DmAD=6?3eACc/m@chn@Da:Ad92
@D4mACi8AT92ADI3CTQ:@T4o@dMEC4Y1@T=5ATQ3>d0h>S`j?P@g>c/g>?hgMcHc
=SLjDUEGEe9@T^[`k_7NgmoSi:JHWjNW[9^DVYRR/JRSVYFHZ:nd/i^OTj:X[k6X
X9ZIZJnk]jjSW:NZ^kVjY:R_]kJ`/KF[ZZ:[_G8n=S8`=CDd<SD^<Bhc<c0e?CDh
?3a2LIe1?T^6FFQ`j>[/jNSYjF9=?`Dn=3Lj>C_n>TLm>De0Adi4>CXlACe5@dHl
?E5?>ce3?Si1C4Y7@T91@Ce5?TQ6@T95AT=>B4Y2@Cm3AeE<BT52@dE6B4<k@3Pj
?3Xn=c/k=cSn=`lf<cHg>U9EEeMBD9;Zl>ka0VTRgn7Rh>>/WIRWWINHY9FBXj6M
WI^PVZJRW:2QZ9nVWjJDX:WnYbJYWj>/[jf^[K>i]J>f[ZVYYZBUZkBW[;A6?3La
;cDa<blc;C4d<C3n<Blc<CDlAE=7A5APDDY<E>GWk^[XdHeBA3`o=3Lh=SHh?CLk
>clm@4@n>SPoCDE1>dE^Bd5B>chl@TA3@4E8B4=3>Sli@D4n@ci5@T4oACY0@D8m
?457@D=2AT=2AdM3@48h?3]5=38f>SLd<cLe=3Li=392AdY7Ce2Bj>g^l=oQh^3S
[9fHYifGV:BETZ>QWIfKX9ZVXYbPXJROYYnVU:2YoZL=ZInS[:n][Zfc^KFS]Zko
ZAJVY:F[]:N/]4Hl=c4_=C4c;c<]<C@a<?haHc<a=Ca5DdM4E61ABTaDiNO^j^SA
SE94?3ld=cPf=SPm=c/k?ce0A3hj>3m=AD4kAD]1DS/n?494@d15B4Q3@cXo>D51
?T<nAD91?dDj@452?Ca1Ad53@TI3@TM7@d12>3`kAC@j<SHj=c@c=cDd=cTd<T97
BTM?D9;XkNk`gn7Rh>>/WIRWWINHY9FBXj6MWI^PVZJRW:2QZ9nVWjJDX:WnYbJY
Wj>/[jf^[K>i]J>f[ZVYYZBUZkBW[;A6?3La;cDa<blc;C4d<C3n<ALc<CDlAE=7
A5APDDY<E>GWk^[XdHeBA3aS?c@g>3Hf>3dg>c/o?D14?SXh?de5@C]5Bd5B>chl
@TA3@4E8B4=3>Sli@D4n@ci5@T4oACY0@D8m?457@D=2AT=2AdM3@48h?3]5=38f
>SLd<cLe=3Li=392AdY7Ce2Bj>g^l09XK]oNhnCV[Z>Z]9jDSifJ/;6_YiRGW[6g
/J6AUYFM_[>`VIRQY;>i]:j[YZR]/K[1^j^IZ[>j^k>_Z:>S[[jN?CTi<S8i<c<d
=C<^<2hc=Bl`=3@cSGQ5CVjSAE];AecTinS/jIaLC3lg>CXh>S/f?ohj3D5=A4I5
>SXm=eM4?ce<B45ABca7A3a0?TUHDU1;>d91?d95?D52@TU8?TM3@T8m?4I8CTI1
?4=3Bca0?Ci4@Si2ACLc=3/j@cLg=CPg@SPg>4]@ADU?V^_nl3?Og^?TiZjSZ[BN
U8nMV[2a[jNHUija]k6QTIJEWKjc/9VHXJBc^KB^ZjJX[K6j`K^[VJZc>[Zk/jnX
Xj>^_Yhm>CTb<STc<c@e<bh`;S<e;c0d=3>=N4E>KZ=5Fd]7G>CWj>cYW5a<?cLi
>SPj>cHooSY1@De4ATDj>SdgEd@o?Da1DD/lAd@l@3i9F59@Bc]2@Cm2ACe1@T99
B3i7@d92?Ca6B4i6@Ca3@d/l@3dnA48n@TDg53<d>cY3=cLe>3M2>3LhBe15BDnJ
jok`ImoNhnCV[Z>Z]9jDSifJ/;6_YiRGW[6g/J6AUYFM_[>`VIRQY;>i]:j[YZR]
/K[1^j^IZ[>j^k>_Z:>S[[jN?CTi<S8i<c<d=C<^<2hc=Bl`=3@cSGQ5CVjSAE];
AecTinS/jIaLC3lg1STj>3Xk=Son>UI1CDA6ACXj?CMGA3lmC45ABca7A3a0?TUH
DU1;>d91?d95?D52@TU8?TM3@T8m?4I8CTI1?4=3Bca0?Ci4@Si2ACLc=3/j@cLg
=CPg@SPg>4]@ADU?V^_nl09Yommmh>?TZiVQUi>AUiNHX9>RXJJTXJBPWJ>SYY^M
ZinUY:^_ZZRY[9fWZJN/Zk>[[ZjTZZJZZ9jRZZNX[K56=S@a<S0e<R/a<30b<CL`
=C=1=3ToET91Y4iM@E11?SgTi^SU^TU8?Sa1?C`j>S<e>TDo?Cm0>chn?3U1=TQG
CDE1Od4k?d8n@Ce0A49>@dA3?Cm1?dE2A416A3`m?D52CTXj@3lj>d12@D<mAd8k
?Chn>c/e>C@f>chi>SLe=3/f?SHi>D]:C4e=V>[/k_3Ogn3Si:^IXINCTINGV:2C
XZ6VY:6TX9fSXjJKWJ^OYJB[[jZXZJbMYjVW[:^cZjj^Y:ZVOjZXWZ:ZYjR]/DHf
=34b<3Db:c4`<38a=c0e<d4d>CmF@T6TCUe1D44n?NCVj>FjBDPn?44m?3Xj<cDj
AClm?d0k?Shl>D4fB5M=AD51>cm2?T4m@4A2CT=4@cdo@Cm5@TA0AT@l?Ce1@Ti:
>T0o>S]0@T53?DM2>cdn?S/k=CTdOcHk?STj=cDd>cHn=STiBdY<CDfHj^c^l=oO
h>?TZiVQUi>AUiNHX9>RXJJTXJBPWJ>SYY^MZinUY:^_ZZRY[9fWZJN/Zk>[[ZjT
ZZJZZ9jRZZNX[K56=S@a<S0e<R/a<30b<CL`=C=1=3ToET91Y4iM@E11?SgTi^SU
^TU8?Sa1Hcdl>SXc=CY5?cdo@3/n?S`i@CI8Ede5@D4k?d8n@Ce0A49>@dA3?Cm1
?dE2A416A3`m?D52CTXj@3lj>d12@D<mAd8k?Chn>c/e>C@f>chi>SLe=3/f?SHi
>D]:C4e=V>[/k_02JGoPgn;SiLBdXj>;RIZP[[>HX9BQZ[2g[:NRV9nZ[k2^[ZBO
Yjjc]Jn/ZjRi`/:j]:fVYJnd`kRZXijY/K:i?CHb<cXf=S@b=SDc<C<a<CHmASf7
A4Q5]Wa?HDA<ATI2hNKWc6m>AS]0=Sm0>Shh=C/oADE7@cPl?3m6BDe8EiMbJGm1
@TY5@cln@TA6CdU7@Ci0Ac]4ATI1@Si4CCe>AD8l?De8?Chn@4=8AdU2?Cdn?S]<
>SPb?S`i?3`e<S<g>CPd@45;@DA>GJcTjng`h=oRhnG4]:>SRhVJX:jcV:2DXJZ`
]jbWXYROZZn`[ZjTWjN^/kF_[:^X^L;2^[B]YZF_]7o3^:ZSWZVa/[Tm=S8c>SHf
=38f=C<a<c4a=Se6?HM4B4FfO4mQA4a6AT;Qi^O<Kdi6>d0f?d0j?SPe>cm5ADM3
>3`l?dI9CDQGUg9Y@D9:AD<o?T94ATm9Ad4n@4LkA4I6@D8nA4dmCTE2?3e=B3dn
?T13B4M9@Sdm?ShkC3Xh<Wln?3Tl?3Db<cLi>3A0@D]1A4iM[>C[kO3Pgn;SiLBd
Xj>;RIZP[[>HX9BQZ[2g[:NRV9nZ[k2^[ZBOYjjc]Jn/ZjRi`/:j]:fVYJnd`kRZ
XijY/K:i?CHb<cXf=S@b=SDc<C<a<CHmASf7A4Q5]Wa?HDA<ATI2hNKWc6m>AS]0
=V<o@3Xn>3Dk?dE5Ad<h?3`oATU=B5NGLVU1@TY5@cln@TA6CdU7@Ci0Ac]4ATI1
@Si4CCe>AD8l?De8?Chn@4=8AdU2?Cdn?S]<>SPb?S`i?3`e<S<g>CPd@45;@DA>
GJcTjng`0V?oh2KRhnF]Ui>LUYJKWjJOVJ6SYIfKYY^QYJBTXjfKV9nRZjJWXZ:U
Y[;n[PVd[k:fZjJTXjBIo:d>/Vdn=SLa;c4d;Rl];bh`oRhb@TE3G4liBgIDCd51
?T8n?5;Mh]17@T17?C`h=cXd>SXo@cho@Sho?d4oA3hm@48l?DF[1d@mA3a6AD=0
oT=Y?Tm7?3]0?CdgA3ll?3/i@493@CU1AD4lAD8n>Sm3@Cdo>Sm3?S/h>3La<cPg
>SHb;S`g=38d=dQ?BTa=/NO[k_3Ph>;SiJfGTibFUY^OYYnIXJ>UWI^VVj6UY:BS
[I^HWj:[YZNRXZFV/_j^1kB_/[J[YZBS0JBIo:d>/Vdn=SLa;c4d;Rl];bh`oRhj
@TE3G4liBgIDCd51?T8n?5;Mh]17@T17?C`h=cXd>SXo@cho@Sho?d4oA3hm@48l
?DF[A3e4?4I5@d3n@bPnCdLl>d0m?CM4?c`l>cU0@T=1>D55@Ca5@Shj?d=1?Clj
?d<n>cPh=d0a<cPg>SHb;S`g=38d=dQ?BTa=/NO[k_3Ph>;SiJfGTibFUY^OYYnI
XJ>UWI^VVj6UY:BS[I^HWj:[YZNRXZFV/_j^2KB_/[J[YZBSY9Wl[@jbKChf=c4_
<C@^;bd_;S3n;QY2AD=LCcU;MUA?@D4n@ShlD]gRd4M2@4Lm?3PO=cXd>SXo@cho
@Sho?d4oA3hm@48l?DF[A3e4?4I5@d3n@d0nCdLl>d0m?CM4?c`l>cU0@T=1>D55
@Ca5@Shj?d=1?Clj?d<n>cPh=c4c>3Lj=S8^?3Ld<S@gB4m:C4fain_^l09YOmoQ
i>;T^jbXWHfFVZn[[YnWVJb`];2IVIRNZKJeZ:2LWZR^^k>eWYjW/Kbl^k2YZ:nd
^kJe[ZfU[kFn[E/n=CDc=c4f<Bh_<3@f;cDa@e1e@Cm=^U=3Dd8l>DDn@5[Mhim>
CCll?S/n?3lj?3/e?CM3CD=2>3hn@DQ9A4@l?TUDOdE4@ci1@dE9BDE2@dQ8ATTj
?cdg@DM5BcTi@3m2?T5DBE8n@T5;ADI5C3a5?Cm4?cTf>c8^?3e0?SL/<3Lj?3Xm
>d93BUYC_N[^l??OhNCRi;^/Z9f=UYZ_ZjjOYiV//;B`VIVHWZVf]JRPW9jX[[^c
]IjNYk6l_;^`ZJR_];^fOkF^[JF_]Kj]Fche=C<g<CHa;Rl`=3H_=C53D7E1?dfj
Dd=C@S`iACi0F]gSWdi=?c`n>chl?cXl>cDm=d==@d8h?Si1B4U4A3`nBEA5A4<n
@D=5BDU5@T=8B4I9>Slm=d57AD/i>D0o@Si1E4UB?T91BdE6AD`lACdoA3li=S/b
Obhl?D0n=b``=cXl>Sdk@T=:FU>mj^k`lmoQi>;T^jbXWHfFVZn[[YnWVJb`];2I
VIRNZKJeZ:2LWZR^^k>eWYjW/Kbl^k2YZ:nd^kJe[ZfU[kFn[E/n=CDc=c4f<Bh_
<3@f;cDa@e1e@Cm=^U=3Dd8l>DDn@5[Mhim>CCll?S/nHc`o>S`k=Cdg@de3@SPn
?T58BDA4?3i9E4E4@ci1@dE9BDE2@dQ8ATTj?cdg@DM5BcTi@3m2?T5DBE8n@T5;
ADI5C3a5?Cm4?cTf>c8^?3e0?SL/<3Lj?3Xm>d93BUYC_N[^l?<2JGoNh>7ShZNJ
UY^LVYJQUibS[j>VW:6NWjF[YYbYW::OZZVRX:jNWZZ/ZZb]ZJn[_JVW[JfWYJn`
Yj^Z]5Pi>2hl=cH_=2la<30c<Bl];He4@3aLD4=8>Chj?C<b?CeUg6=5?Cdh?3lm
?3/i>chm=Ce0>d0o?d<o?S/o?d15>d8o?gm6A4U7AT=9A40nADU4A4=0@4=3@4=5
@cTh@dU;?cdm@clj>d]2A3a1?C/m?d8n?3/i=cDc;S8f=CPj=3Pg<clf>c<jADQ@
D:SYjnk_g^3Qhn:WVYJKW9ZFXINLXjnSYYbQWYnUZjJLZIbRWjZYXZ2^WYjZ[:Z/
[JV_ZkfYYjf]YgnU[k2WZjZdF3Th;S`g=Rld;c4`<3<a;bd]SDA0?5a@@dPi?SXm
<c8m?FGLHdDm?CPl?cdl>cTk?Sde?D0k@3lo@cln>clo@4Dk@SloATA9AdI3BDA0
?TE9A4A3@413@d13AD<i>4=9Bclm?D<o>S];@T@l@Cdk?Cm2?S`k>CLe<gl^<SHe
>3Xd>3Lc?cHk<cY5B51@Z>W[k^oNh>7ShZNJUY^LVYJQUibS[j>VW:6NWjF[YYbY
W::OZZVRX:jNWZZ/ZZb]ZJn[_JVW[JfWYJn`Yj^Z]5Pi>2hl=cH_=2la<30c<Bl]
;He4@3aLD4=8>Chj?C<b?CeUg6=5?Cdh?3lm?6<k>C/n?CDm@3]0?cm3?chk?cm0
AC]2?cm6A4U7AT=9A40nADU4A4=0@4=3@4=5@cTh@dU;?cdm@clj>d]2A3a1?C/m
?d8n?3/i=cDc;S8f=CPj=3Pg<clf>c<jADQ@D:SYjnk_0VUfgN3ShN:eXYNDUZ2S
ZZ:PYjV^/:^WViNDVZf]]JbSUJ2Z/;JiZ:FO/jnh_KRhYJZ[][Nl]ZRVY:Nf]/QA
?3Da>3Xi=cL[<3@b<S4`<3U@@91RASA;=Bli?dTf=cDnJk]@F3Y0>c`j@DA0@Chl
?DE3@4`o@ClmBdCnA`E2@CYC>dGoA7e5@d]:CTQ7@dM5AdYCBT50@T@oAdHl?4Q2
?cQ4BTE8>SXk@Di3ASlm?Cm1Adho?SXe=3Dm?3Xg=c`j?3di<Shh?U1LH5JTj>W[
kmgPhn7R]J:GU9JPXjZRX:NY[[2[Yi^GU9Z][KF/XiFPZ[2f^JRUWk>_^;fh^:FZ
ZkJg_;I2Z:JTYkJfb54l=C4h>STg=b/`=38b<C0`>E10T696=4/e;cToBCHg=Ci[
^e1H>T0k?3Y1A411?S`mAD=0C3m1?ce;A?i7>D91>U<kADA4AD=;BTi8Ad=7ADM:
DdY1@494?dM6?3a8@SlhA4Y5B3Xj>d5>@dHo?Cdo@DM>?chj=CAo=Cdl>SLg?3Xl
?CTb?SPnD5aPEZCXjN__gN3ShN:eXYNDUZ2SZZ:PYjV^/:^WViNDVZf]]JbSUJ2Z
/;JiZ:FO/jnh_KRhYJZ[][Nl]ZRVY:Nf]/QA?3Da>3Xi=cL[<3@b<S4`<3U@@91R
ASA;=Bli?dTf=cDnJk]@F3Y0>c`j@D@>@44n?3e5@d1<?d4o?D]4oTMA@T4jDc]5
A4A5@d]:CTQ7@dM5AdYCBT50@T@oAdHl?4Q2?cQ4BTE8>SXk@Di3ASlm?Cm1Adho
?SXe=3Dm?3Xg=c`j?3di<Shh?U1LH5JTj>W[k`9YomimhN;TXiBFX9bIWiZIXJRN
YZZNW9nSWiJXVj2K[Z6SXZ^SWZF^[j^Z/jVT[J^fZ[:[[ZBX/[6^[J^b>SPg<Bd`
<S<d;3@a;B`^;Bhb>4]XCTi1=S0]>Si9?c/mAU56@c/j?D4l?CXm?cXj@3ln@Cdl
?T5=@dPm@3hl?Chj?ce47D=1B4Y>B4A1?4A5@d52Acll@DI<@dDn=3M8?S`k@Ohn
GT0jASm7?cho@D4m?d=0@Clf>30^=30d<c<j=CTm?CPg>SI3D4a;X>GWj^[Ng^7R
i:>DUZ2LVInJVJ6XWZJZWYbOXinFZ9^PVjjQXj:[XijU[Zn[Z[>YY:f[]ZZbZjjT
JJRb/Jj]Zk8j>3La;C0b<c@/=34];2h];S8hBfQ>CT4f<2dj?TTo>ce6DDI3>cXm
@C`m>Sdo>SY0?ci1?C`n@De3B3e0?S`m?SXo?DA3@DQ:CTQ4@Ca4AD=1@TLo?456
C4=5?S@gB3hl>d7n?Q90>THoAcln?d51?Cm3@44o=SP`Obhd<3@c<cXe>Cdm>3Lj
=T=@C4^PiNOZj]kNhN;TXiBFX9bIWiZIXJRNYZZNW9nSWiJXVj2K[Z6SXZ^SWZF^
[j^Z/jVT[J^fZ[:[[ZBX/[6^[J^b>SPg<Bd`<S<d;3@a;B`^;Bhb>4]XCTi1=S0]
>Si9?c/mAU56@c/j?D4l?CXm=Clj>T0o?T4m?3i1CD=8?D0n?3dn>SlmA4=1B4Y>
B4A1?4A5@d52Acll@DI<@dDn=3M8?S`k@Ohn:T0jASm7?cho@D4m?d=0@Clf>30^
=30d<c<j=CTm?CPg>SI3D4a;X>GWj^X2JGoPhN;SiJ^DTj2X]jFTUHjO/[baZ9RE
VJNZ/[>PVZ>U];>b/:^QXJJb/kNbYIjY]kbn][JPXJFd^K^c]Chi>C8c=CDd<bhc
<30^=bhe<W56HTlg?411@dQFDci0@3lmB3hj>C/lAclm@3Xj=Shn@TA2>STkCTU@
A4Dl?SE:CTE4CgloA495C4i<@3Q1@4IACdM3?SXn@DA9A3Hi@T10@dY2?c`l@T5:
DdDm?T53A496?STm=3T`<S8j>CTe=3dg@d4j?3<cAU=@Cj;Xk>S[h>7RhnF[U9>P
Z;NUY9F>Wk:l/JRHUIVWZ[:cX9ZSYKBc/[2[XJ6V/[>g/ZFNZKNl_[JfX7nQYKBi
^k>e?STi<S<e=C@c;S<`<2hg;SDbLDIRCcLl@453B5IC?T10?ce8?SXi>ca7?ce0
>SXf?Si2A48j>C]>BE14AC`n=DY>ADA??dA2ADa>C40h@D16DDm7@chj?T54BD@f
>D90@4=:@Sll?491BU=5?Ci1@dA2AShi?C@i<?lbOCXi>CDd?CM3@CXl<c=6De1?
X^S/j>_PhN;SiJ^DTj2X]jFTUHjO/[baZ9REVJNZ/[>PVZ>U];>b/:^QXJJb/kNb
YIjY]kbn][JPXJFd^K^c]Chi>C8c=CDd<bhc<30^=bhe<W56HTlg?411@dQFDci0
@3lmB3hj>C/lAclm@?ljHCHn?T94@SXi>di9D4A5?3heBTi5A4loA495C4i<@3Q1
@4IACdM3?SXn@DA9A3Hi@T10@dY2?c`l@T5:DdDm?T53A496?STm=3T`<S8j>CTe
=3dg@d4j?3<cAU=@Cj;Xk>S[0VSngfoShZJPTi>IWYFIVjBPZ:ZLV:BTUYZLXInK
Vj^SZJRSWYVVXZ2WZ:N[/J^Y/:NUWjRX]:VWZJ6UYCDf>34d=Bla;Bde<Bd]<Bdb
<Sld@cDk@dI4@4e4ADA7@C@k?CLg?3lm@CTm=3Hg=40k?SXmA40ooTD9@44o>C=9
>dHnABE5@TA1ATE7@d]2BD5:ACdo@4I3?4E1>SHg@Cdk@CloAC]1?3U0?_ho8TM2
@CXj>CU1=3L_;cHf>3Xa=cPk=cHj>cDh>T95Bj_XjnWWo]l`hn:VX9>CVIjEVI^T
X:RZW9RTY9JJW:6OVi^[XjVXXijIYZ:PYjRWZk6[ZK2WYInXZ3jdZJNYXJFU=CHh
<C@e;c4];CDa;Bda;C8b?cA3=C]3ATA0CDA5A4M1=3/m=cLl?ce1>Cdd=SLd@3/n
>Se4@3onABm0@Cli<dTkASi5AD94@DI5Ad=;@TU1BTDm?d16@ca5@CXf=d4m>d4o
?dDk@C`i@3kn?`Y7@T4j>STi@C@g;aL_=SHh>S4g>3/g=SXk=CPj@TE;ZnS[jNOn
gfCShZJPTi>IWYFIVjBPZ:ZLV:BTUYZLXInKVj^SZJRSWYVVXZ2WZ:N[/J^Y/:NU
WjRX]:VWZJ6UYCDf>34d=Bla;Bde<Bd]<Bdb<Sld@cDk@dI4@4e4ADA7@C@k?CLg
?3lm@CTm=0Xf=cA0>chj?DA0?oi5;d11?cTcBC]6?TE5@TA1ATE7@d]2BD5:ACdo
@4I3?4E1>SHg@Cdk@CloAC]1?3U0?_ho8TM2@CXj>CU1=3L_;cHf>3Xa=cPk=cHj
>cDh>T95Bj_XjnWW0VWoh3_Sh>>RRi^U[JjRW9FVYkZ`ZYnJXjN/]ZnTT9JSZkZ`
[InOX:Fh_;R[YZ>^]kjf[jZPUj:]^kVb]Z/c<SCn<Sha;30^<C0b<30/<3/e=3Lj
?3TmBdeAATU7AS]1>c/d>3Lf?D0k>cHe<S@o@4]1@c`k@48oAchn@Sa4@4iCCdMo
ACe9BTY3B4A8AE=:FTDm@4M6B4M9@S/i?cXhAd53?T<m?D5AD4U6?d=3CDHo>CXb
?CDj<S8f<C@b=d8h<cD`<c`d>Ce0ADNfjNcWj^3Phn3SXX^KYJf^XYbEYZNj/:ZO
VZ>W[;J_Y92FXj^j/:fOWj2U^;bhZjJS[[Nn]ZnZX9L9XZfk^K:fZc<b=?hbLS4/
<2ha<38`<2``>cDd=cXl>Ce;CE56BDM6>d4k>c@h=cHm@3/k=SDb=3m0Bd53?3]0
@Sm7?Si2?4A0CU=?AdDmBDY:@dQ4B4ECBUY5?D17ATQ7BD8k>Clj>4M1@ci3?Ce1
DE19ASm3@de6?cTj<Sde>S9E<SHa=38g@SPc=C0c?3@i?D15AkKYk>OZh>3Sh>>R
Ri^U[JjRW9FVYkZ`ZYnJXjN/]ZnTT9JSZkZ`[InOX:Fh_;R[YZ>^]kjf[jZPUj:]
^kVb]Z/c<SCn<RHa;30^<C0b<30/<3/e=3Lj?3TmBdeAATU7AS]1>c/d>3Lf?D0k
>cIS=C8d?d1;@D<l>d12?dLn?T8lA41>Ddm7ACe9BTY3B4A8AE=:FTDm@4M6B4M9
@S/i?cXhAd53?T<m?D5AD4U6?d=3CDHo>CXb?CDj<S8f<C@b=d8h<cD`<c`d>Ce0
ADNfjNcWjP9YomlWh^7R[Z6@T9REWZBLYJF/V9VSWZ:AX9jVXj6ZX9nWY:FRZJJa
[ZbZX_jb6ZZY]:J/[::ZZk:W/X9H=c8f;Rlc;34a=C<Y:?h]=2lc=S8d;cXk@d56
A4eC?cLg>SHk>CTa=3Ph<S4h>C@k>ci2>c`h?Se0?3hmA3U0@3i5@4U:MDm2BDQ6
A4e7@DA<@THj?d=1A44o@4@k>Sho>d@n?3m1@3hj?Chm@DM3?dHo?cHk=cPb>3Lf
=CDc<S0f=3Pg>3@c<CTg=T]:`^_]j^[Ogn;QhZjQT92HUIjTW:FU[9RIXijRTJ2N
YZ>QZZ2OYjBUXZVV/Jj/ZZ;n/PJZZKBV[:bR4jZ[/ZNbPUPg<SH^;c</<C4e<bTX
oReX;c<f<S@_>S]3@DI4CE<o=cLj=S/i>C4d>3Pb<CPi=3/k?T8k?3Pn?D0l?Se4
>D10?TE0BDY?@TU8ATA=Ad54C496>Sm3@DA1?d14>cXn?c]4?S`o@D0n>Sdn?D57
@cm6?clf>cLh<SPg@CHe=C<b<3Hd>3Lh=3<a>CLfBd[2jngZj]oOh^7R[Z6@T9RE
WZBLYJF/V9VSWZ:AX9jVXj6ZX9nWY:FRZJJa[ZbZX_jb6ZZY]:J/[::ZZk:W/X9H
=c8f;Rlc;34a=C<Y:?h]72lc=S8d;cXk@d56A4eC?cLg>SHk>CTa=3Ph<S4hHcTd
>c/n@S/l>3hm@3`n?D@i@40nAD19BTm2BDQ6A4e7@DA<@THj?d=1A44o@4@k>Sho
>d@n?3m1@3hj?Chm@DM3?dHo?cHk=cPb>3Lf=CDc<S0f=3Pg>3@c<CTg=T]:`^_]
j^X2J?kPO>;SV9FY[JJMWZ:X[:jeXYbDY;>b]jVWXYfV[;Bb[::KYk2f]Zj/WYjU
_Kjo^K>X[j:f][noYTLk=38i<cD`;C0d;c0^:c4^;SDf<b//:cm0F4a6BdQ4<Sm0
=CTh>3Xd>c`n=c0j<SA3@d0o>S8g?dE8Acm2>cQ;A4E7B4I7odI9ETU?AdQ2B4e@
CDm0>Cm5@DY7Ad@j?D57A4]7ASe0?DM0?T12?3doC4Y9?CDg=cdi>cHh<c@f=cHd
=SDi=c4j;S4l>dI;^Nc]k>Snh33RhiREZJfVWIjRZ:b^]J:LU:Bc/[NYYj:MYZbd
/ZbRVjN`][J^[9jNYKfn_kVcZ:nRokKo_g^VAc/d<STc=C0]<3@_<2h[<Bh^=CHc
:b`[?d1HC4I;B4@b?d0e>CPh>S@k?3hg<3Xb=4=3@3lj<SLoADQ7?d8k>4]4ADM8
ATM6AUI9CdM8@TQ=D4e?@3ToAD5:AdM4>Se1AdA;AdHm@3e7@3i0@S`m?da:BCde
=cLm>C/f5cPc=3Hg=S@f=CTg<CX^<C`kAT^ik>g/j?kPI>;SV9FY[JJMWZ:X[:je
XYbDY;>b]jVWXYfV[;Bb[::KYk2f]Zj/WYjU_Kjo^K>X[j:f][noYTLk=38i<cD`
;C0d;c0^:c4^;SDf<b//:cm0F4a6BdQ4<Sm0=CTh>3Xd>c`n=c0jHc8d@d=0?cXb
=cm5B4Lo@S/hBdA5AdQ6AdI6ETU?AdQ2B4e@CDm0>Cm5@DY7Ad@j?D57A4]7ASe0
?DM0?T12?3doC4Y9?CDg=cdi>cHh<c@f=cHd=SDi=c4j;S4l>dI;^Nc]k>P2I_oN
I^7ShYfCV:BDVj6VYjZPZJFYVYZOXJ:J[jJPXjVQUXnTZJV[[jVWZjf][[JaZJn`
]:bS/JR^AcPi>C8d;bh`;2/a<2`/;C<b;bda;c4`;S8m@d95?DPg@3Ln<S8a<S8k
<cXj=c@c=CWm?18n>SLf@CXh>TI5?cU4@T55AdE>?D97CT58BEI:CTm@BD97A49<
A4`o@cdk>SXm>cli>d4n>d51@TA:ACm0@T8n>S`h=cTd<cLb=3Ti=c8f>SL`oSDn
<c0d=49;^>_[kNWNg^7ShYfCV:BDVj6VYjZPZJFYVYZOXJ:J[jJPXjVQUXnTZJV[
[jVWZjf][[JaZJn`]:bS=;6X[TLh>CTb=2l^<2`[<C0/;2dc<Rl]<Bla<2hb?D=2
ACe8=d0g?S8b<C8b>c<j>SLd<cDioCa6?SXg=T4j>3Y6ACliA491ADM5CT97CT58
BEI:CTm@BD97A49<A4`o@cdk>SXm>cli>d4n>d51@TA:ACm0@T8n>S`h=cTd<cL9
<S@i>CLb=SXg<?heLS<`=3A2BkS[jngYg]kQhn:MTiRTU9^QYZNZX:VUZIZJWj6R
VZnVX:>YXIJ?Y:VYZjnYYj^][Jjf/JV_/;B/Xk6X[TLh>CTb=2l^<2`[<C0/;2dc
<Rl]<Bla<2hb?D=2ACe8=d0g?S8b<C8b>c<j>SLd<cD0>OdlD3hj=cI1>SPjATDo
>DA2@DE7ADi2Adi1B4UFBTi?D4U2AdA2C4A<?d<m>cXj?C/o>C]1?S]1@D94BTDo
@492?SXl>3Li=3<g<S@i>CLb=SXg<?he2S<`=3A2BkS[jngY0VThgN7Oh^2SVjFW
VYVIXJRXYj>LWi^RXJRYWZ>RYZ:[[J:QWJ>[YKR_[I^QYZbe/[RU[J^c/;2VCcHh
oS?o<0Xb<C<b;c0]:B`_:oh]oc0a;S0d=3Q4Ad14D3Xd=CTi=3@f=cdm?3Xb<cHg
>3]1>Shh?T1=A44kDTM6@4aBAT58BTUoB59CCT]8FUQMDUQ8A4E1@d@nBCi5>cDl
=dE1ACPi?3Lm@4E9?44n?dXmACPk?C`m>cLh<C0a=cHi=Sdj=38d<cHi=SXc=Cjc
j^cWj=gQgn;PXi^UYiZIVJ6XZ:NSW9nKXZ6XZIjSXZJRZjfRXIfSZjFh[jfKXJJ/
]K:hYJf[/k04/:I?=SSn<ol`2S8a<c8_<2dY;2l[oRgo<6D^<3@d>4A7@4A@>S@e
>CTd=3Hg?Cdl>S8c=SLh>d4j?SPn@4e4@C]BAdI0C596@DQ:BDQBDdi;B5YHGE9H
B4A5@D=4?TTnAC/e?3M5@DDh>C`g?D15BCa1?Sm:?DDh>cdl?C/g>35@<34g=STf
?CXd<S@c=STf>S<e?[?Zk>OXgN7Oh^2SVjFWVYVIXJRXYj>LWi^RXJRYWZ>RYZ:[
[J:QWJ>[YKR_[I^QYZbe/[RU[J^c/;2VCcHhoS?o<0Xb<C<b;c0]:B`_:oh]oc0I
;S0d=3Q4Ad14D3Xd=CTi=3@f=cdm?3Xb<cIS=cPk@CXn>3i0CDA1>e97AT1<DTI1
B4Y9B59CCT]8FUQMDUQ8A4E1@d@nBCi5>cDl=dE1ACPi?3Lm@4E9?44n?dXmACPk
?C`m>cLh<C0a=cHi=Sdj=38d<cHi=SXc=Cjcj^cWj09YOmgPhn?Q[J6HU9j^ZjNS
VYbV[KFdY9^LWZ:Z/:fRViVX[k6j[j^WX:6^];^d/ijYY[Jj_;JcFcha=CL`=3<g
>3Le=38c<Rd^;S4]<S4`;c0f>SLh?3LoM4dm>cHi>3Pg@40lASXh?CXi=c/j?3Y0
AdM4@D93AS`fF3U>CE59?d]HOe9<DejFOFiTHDM=B4a@BdM6?ci0AS`j?SU2>d8o
?dE2>SY6ADA<D4dn?d90ATi;?CXj?3Tk>Sdl@3/l?clj?3Hj<STj>3`m]^S]jNSM
h>?ShJfQV9BN[Z^WXiZLYZfe]:BKW9jRZ[2]XY^IZ:na^Zn[Yj2Q[[Bk];>NZJJf
^[bfOk=K?S4e=c0d<cLh=cDd<S<b;Bh^<Bdb<C0_<3Hj=cPl=cmdCCdk=STh>3M0
@3a6>SPm>STg>cXl>T17AdA1@T=6?3IH>Di=DDToBeQBC5=NUWe^I657CDQ<D4]7
ASln@4Hl>Shi@S]2?cm5@SXjATE4C51=?Sm2@4I>Bcdj>S`iOc/j?Ca0>c`o?cXl
=SXb>CXh?3ffj>gYj=gPhn?Q[J6HU9j^ZjNSVYbV[KFdY9^LWZ:Z/:fRViVX[k6j
[j^WX:6^];^d/ijYY[Jj_;JcFcha=CL`=3<g>3Le=38c<Rd^;S4]<S4`;c0f>SLh
?3LoM4dm>cHi>3Pg@40lASXh?CXiHcLk>S`j@4M7A452@dHl=UPiCTeABCm;F59<
DejFOFiTHDM=B4a@BdM6?ci0AS`j?SU2>d8o?dE2>SY6ADA<D4dn?d90ATi;?CXj
?3Tk>Sdl@3/l?clj?3Hj<STj>3`m]^S]jNP2J?oOon5kh[:WVifLWifSYJNBTInR
[J^UY9fRWZZa[:fPWInPYjZcYJ>KUjja^;NWYZN^/[^i/D8e<Rlb>30a<C@c<c0_
;Bl/<2h[<38b;bla<C8e;SXe@E]4>SHd<S8e<cPg=T0i=cTk>CHj>S/j>3i0@D4m
@TPlB4E7C4Po?dABDC=CEGC3giQRH61:C4E0@DU=DDI0?C/f=Sdj@cLj>Si3?C`j
?cdm@D9@?Ci9@ChlAd90?3ThoSM8?C/m>SLh>chh>cDe>CLk?kKXj>OWgmoQhN:b
Yi^MW9nMXjFWTY6OXZf[YJBMXYjZ/Jb]X9fOX:NZ/jFSViN^/KRgYjJW[[:k^Gna
@SDb;c8h<34a=3<c<2l];b``;R/`<S8_;c4a<SD^>SE1Fd@j=S@b<SDc>3Lf@3Tg
>C/i=SXj>cXh?T11@Ce2B3a8ADM<B3loA59ADeEd`mnHHV1PBTa5@459CE56@3dk
=SHm>T<g>SXn@cdl>Slm?D52D3dnBD4n?4M2@3`i>?hgO3dk?CXg>3/n>3/e=CTg
>cnfj>SWimoOhN7R/ZNKWIbOWJ>UYi:AWj:]ZjFTWJ:NZ[6/[J2MWj2WZ[>UXi^G
[[6h]jNVYjjb^kVa@SDb;c8h<34a=3<c<2l];b``;R/`<S8_;c4a<SD^>SE1Fd@j
=S@b<SDc>3Lf@3Tg>C/iBcHj>S/j>3i0@D4m@TPlB4E7C4Po?dABDE=EM<?OV69P
H4Y<AD11BDeAAT0m>cHf?CY3=cXj?T<m?3Xo?Ce1@U0m?TU1?Sa7@T0l>CSn=a@m
>cdj=cPk?SPk=CDi=c/o]^SXinL2HccNhN7RhZjGTjJ_[ZbZWj>OZK6a[j2TZjfZ
[;2ZYj6Q]ZneXiZPWjF^];F/[:VZ]K^d/kZ^Uc`m<SHb>cH/oS?n<3`_;CDg=C8b
<C0`=3H`<3@_=c/nW3hi<S@b<SHg>S/i>3i2>CY1=cPoA3m2@d<o?C]:ADY<CdQ6
BdU=FeA@44nZiNCU[6MHCTaACe9;B4i9oCdb@c55?cdnA4=7ACPj>Sm6BdM4B4I5
AT98A4<i?S`m>CXh=CHi>3e5?T51>cdl>SDd=cbno^TdimkQhN;R[YNCYZn^[:ZO
XinY/K6_X:B[[JZ//:ZWXJ6f[kFSVZ2OYJjd]Jb/ZJZe^kBc^Zh8Uc`m<SHb>cH/
oS?n<4d_;CDg=C8b<C0`=3H`<3@_=c/nW3hi<S@b<SHg>S/i>3i2>CY1=cPoA3m2
@d<o?C]:ADY<CdQ6BdU=FeA@Cj[Ui>F/IeQ>C55?DT]8CTWm?Ai3<DDo?Ci4@dM5
>3Xj?dI;AdA8ATE6@TQ4@cTn?3di4cXh=CHi>3e5?T51>cdl>SDd=cbno^TmimkQ
hN;R[YNCYZn^[:ZOXinY/K6_X:B[[JZ//:ZWXJ6f[kFSVZ2OYJjd]Jb/ZJZe^kBc
^ZjG?3db=S8k=Rcn<oh`92l]=CLe<S8a<30d=S0`=2lg>cjL?STb=38b=SLj>cTh
?T8i>T4X=cPoA3m2@d<o?C]:ADY<CdQ6BdU=FeA@Cj[Ui>F/IeQ>C55?DT]8CTWm
?C93<DDo?Ci4@dM5>3Xj?dI;AdA8ATE6@TQ4@cTn?3di>SPe=STh?DDn@D4k?C`j
=C@g?;knj@3W0VUog]oQhN2eWYJITJ2_/J^TW:BO/:fYYi^PXZNX[j^JTjfR[K:e
XZ6RYZn^^:jX[:^_];Nf]WPk=Rh`<S</:C0^<Rld<2d_<S0b=2``<S0g<BhY<C<o
>5A1>cHf=3Dc=3Lg=S@g=SPf?Sdn>S`k>ChkATA5@dPnBTEHCUI;@TILFeA0EM[R
h^BaHF1ID4Y=CTQ6CdXl>c/g=bm4?CThB4<k=cHl=c]1AdE0?d54?d0l>cHa<C8h
<CHi?CLi>Sdm>3hg=ccn=c/h>SS2j^c]jmkOhN7P]IjFVI6P[k6[Y9bTWk2]ZJNK
X::WZ:n[VY>]XZfb]J:QXZJ_[[R^Z:b[[kBg][IoN3/f;S0b<b`Y<2hb;c@`;Blb
<38d;30b<3La;RTa<clhE44k=SHd=C<d=cLf=3Lf>3Hn?Chj?3/i?S]6A4E3B3i:
AEQ>ET]2AUaKE5GJh^;T/F5PFE1:CDi8ATm:?3/k=cL_A3di>4Q3>cLf?3Lk@DM5
@3m1A3m0?3/f<C4b>34<=STm=cTj?Cdh?SLg??hgKcPj><;Zk>g[g]oQhN2eWYJI
TJ2_/J^TW:BO/:fYYi^PXZNX[j^JTjfR[K:eXZ6RYZn^^:jX[:^_];Nf]WPk=Rh`
<S</:C0^<Rld<2d_<S0b=2``<S0g<BhY<C<o>5A1>cHf=3Dc=3Lg=S@g=SPf?SeH
?SXl>cTn>dI4AD=8?TY5F4iFBd96G5]DEM[Rh^BaHF1ID4Y=CTQ6CdXl>c/g=bm4
?CThB4<k=cHl=c]1AdE0?d54?d0l>cHa<C8h<CHi?CLi>Sdm>3hg=ccn=`Lh>SS2
j^c]j`9YOmkPhn7TWiBH[Z>WY:FW[Zb_/:fLX:Z_]JfbW9ZOYZf_]:fSZZJW]K>d
[ZjY^;Zl`[J_ZYm>=c8d>cDd<cLd;bh[;S0/;c@b<S@a=38g=2ha;SPj=3M0>CLi
=cLe;S/k=c@a>CHm@3hm?clm?d59@4U0B4Nc[WEXGTYEG5mGIEMIOiKSi^KX`VAI
F5MDEEAECDM2>D90?3`g?CPh@3ln>cTi=cm8BTe8?T8hAD0j>SLi?STg?SM1?S`j
>SU4?T4j=c]2>C/h@3Dj`^k]k_3Nh>?Qi9nDV:jSYjBUYjj/[k2]W:2Z[kF]/YbJ
WjJ][kB]XjZVYkFc]:j^ZKRj_<:f[jZOOdhg<S@k=C@c=c@_;R/^<2`_=38b=34d
<SLd;S4^>3Xd=d0i=cTg=cD^>c/g=34i=Se0?Sdo?cdo@DU0BD18Ak>^MFQNBUEL
GeMUEeVFhnKVj<9TFEQGE5EDEDe7@SU2@3`l=cdh>40o?S/i>CLoB4Y=B3i2>4E0
>SXg>Chi=chgOd4n?3Xj>D@n@CXg>d8i>cQ0=C[2k^g^l=kPhn7TWiBH[Z>WY:FW
[Zb_/:fLX:Z_]JfbW9ZOYZf_]:fSZZJW]K>d[ZjY^;Zl`[J_ZYm>=c8d>cDd<cLd
;bh[;S0/;c@b<S@a=38g=2ha;SPj=3M0>CLi=cLe;S/k=c@a>CHm@3hmocmQ?Cm1
BD19@4Q7/jieJ5i:EEaOEfEGFIKSi^KX`VAIF5MDEEAECDM2>D90?3`g?CPh@3ln
>cTi=cm8BTe8?T8hAD0j>SLi?STg?SM1?S`j>SU4?T4j=c]2>C/h@3Dj`^k]k_02
JGoMg^;QhZNJUZFOZJbWY9nUZZ^`Z9bRXK2//jBHWJ>VYJ^c[:ZUXjB[/ZfbZk:/
^;Ja^kRG@SDd<C0/;Rh`<3<d<Bd^=C0`<S8`<C<d<cL^;c4d<cA2>cLe<3@c=CLc
?3Lh>3Th=cE0?T0i=S<k@ci0?TQ@gn;FeLiZF59NEUmHOGoFgn[Xi/m_EeQCC4m@
B592@C`k>CTf>d4f=C@e<c/m>CLkADDo?3@e=SHe=SPk@Sdo?3Xi@3dh>3Db=CQ5
?c/j?CXg?CTh>L?Yk>_^gMkRhN:WVYJUWjV/YjBOYJZ[/:RLXZ6`[;>TV9fSYZF[
/jbZYJ>TZk:]/Z^b[;Rf/K^hUgm2=C@a<2`^;S0`<c@a;Bhe<30b<S0a<c@c=bh_
<C@c=48k=cD`=3<e=c<l=cPh>CPg=D0n@3Tf<c]3?T0nB53Oh]KEcVYHDUiFGeQm
e]oZj>K?KeMHDda?D4QB@T4l>cTi=S]1=SDd=C<k?CTg>dE5?c`d=CHf=CHh>d8m
?c`j>Gm0?CPh=C8e>4Do>cXm>SLm>CPi`nW/jnkMg^;QhZNJUZFOZJbWY9nUZZ^`
Z9bRXK2//jBHWJ>VYJ^c[:ZUXjB[/ZfbZk:/^;Ja^kRG@SDd<C0/;Rh`<3<d<Bd^
=C0`<S8`<C<d<cL^;c4d<cA2>cLe<3@c=CLc?3Lh>3Th=cE0?V=0>CHc>d<n@3i8
D=oRe]G>JUQBGUIOF7gFgn[Xi/m_EeQCC4m@B592@C`k>CTf>d4f=C@e<c/m>CLk
ADDo?3@e=SHe=SPk@Sdo?3Xi@3dh>3Db=CQ5?c/j?CXg?CTh>L?Yk>_^0VUogN3R
hN:PX:NcYJ>MXZ^a][6RXZ>a]J^`ZJNIZj6]/JZ/Xi^`[[ba/Zf[^;Rk`;jh/:^a
WdHg=30b<3Hg>C8^<CPe;cHc<C8a<3Db=3Dg=c@f=C=5?3<e<SLl?c/c<clg?CXi
>cdh?C`j>S`j?Se0@T1R/NWXi>OWjNOG`UaMDm`kiNS[jnS9KeERHeaAAd15?DM6
?3hj>D92<SDc=CPg?452B411=STa=3a5?SXh=T=3AC/i>cLb=ci5>Se1oSa0?Tdl
=cXj>D?<j^c^l=gPh^7RX:2W/jFSWJ:[/KJaXZ:S/KF[/:VWVJ^Q[K6Z[:>K/:jl
/K:]ZkRh^l2n^;2[/ImoASLd<38`=SLi<Rha>3D_=S<a<S4`=C8d=CLg=3He<dDl
<cDb=c`o>c<c?cLm>STk?CPm?3Xj?3Xn?D12@6:ajNSTinOYimO2G5eCg>GXjn_X
bFmEHV=LDDM0ACe7AS`n>SU2@S8e<cDh=ca1@TQ0@CHi<C@lAChj>3I3@dDk>C/7
=c8g?TDj?D7n?7@nCC`g>SXi@lcZk>k`gN3RhN:PX:NcYJ>MXZ^a][6RXZ>a]J^`
ZJNIZj6]/JZ/Xi^`[[ba/Zf[^;Rk`;jh/:^aWdHg=30b<3Hg>C8^<CPe;cHc<C8a
<3Db=3Dg=c@f=C=5?3<e<SLl?c/c<clg?CXi>cdh?Cco>U4l>Shm@490H[7Yj>CW
inWWel9LGE?LiNS[jnS9KeERHeaAAd15?DM6?3hj>D92<SDc=CPg?452B411=STa
=3a5?SXh=T=3AC/i>cLb=ci5>Se1oS`<?Tdl=cXj>D?<j^c^l09Yomkoh43UVYZN
WjVWX:6RXjbV[:ZSX:6VZ:naY:BFX:^_/:bQYJFZ/kRcZjF[[k2f_KF^]6Lk=C8d
<Rde=3@^;cH]<2hi;_h`=c4`;SDb;C0a;blb=cPe<c@d<CTd=SPk=Cdf>ce0=3Hi
=cHh?Ce4?SlnS=GYj^SWj>KRhnEkJWWVOn;Xj^WWaVE>DT]7Ae==?CTl>c/j?3Pe
>cHg=cPj>CLj=CTh>34g=C/j?cho@3/i=STm>C/g<cPn=CTl@3/i=SXd<S<e=D14
a>[]k^oNg^3PiIZJWYnYYj2QXZ>/YZbZXj2QYZR_/JBTUZ2[[k2/XJFUZ[>h/j^U
Zjn`][fe[[AW43/e<S@b;CDd=2h_=Rd`;ST^oS1[<C0^=C8]<34_;c8g>3Dc=3@a
>C@f>3/e?CHk?D0d=STg=SPm?D@n?cj<eNWZj>OXi^;SiG]ZNNKRj>[YilIUCU9;
AdMCCCdi?3/k>S`h=C/f=cLh>STg>SDi>3Pa=cDk>Sln?d0k>CHi?CTkG3Lc>3he
>Ca0>cTf>S@b<cDe@4C4j^g^kmkNh>3UVYZNWjVWX:6RXjbV[:ZSX:6VZ:naY:BF
X:^_/:bQYJFZ/kRcZjF[[k2f_KF^]6Lk=C8d<Rde=3@^;cH]<2hi;_h`7c4`;SDb
;C0a;blb=cPe<c@d<CTd=SPk=Cdf>ce0=3HiHcLf>3dmA3ho?XcEjN[XinSVh^?U
NfYii^;Xj^WWaVE>DT]7Ae==?CTl>c/j?3Pe>cHg=cPj>CLj=CTh>34g=C/j?cho
@3/i=STm>C/g<cPn=CTl@3/i=SXd<S<e=D14a>[]k^l2J7oPhMoSi;>]YZ:OWZ2[
[ZbTWj2ZZK2aZYfMYJRh];^ZX:>Y[K>f^Zj]Y:fa]K2a]:^h^;lm=38g=C8c=c8f
=38e<c0a=c<d<C4_=34g<c8`<c@b=CDa;S@g<3<h>3Dd>SHn?THo?cPi?E16?3m1
@d=2AmSUi^OYi^WYj^[X[H_Gk0[XjngXhmF1E6M=Aoi4>TY3AD8l>cXf<cHd=cTk
>Chl@cdf=Cdd@cm5?4@m=CHl@3dk?SXg=cHj@C`h?D50@D@i<c8e>3e:@lO[o^lc
h>7OhnBc[JJRWijPZjj/Y9nPZZV`/JZMWJFX^;BkZZ2SZJfc][Z^[JB]/KF`/KB[
^;Ro?EHd<SLe<S<g<SHd<SDc<34g<c@a<Bld<CLc<S0c=38e=C4^=3L`<cPh=C@j
=ShnASlo>3TmD4Hl?d53@d97f>GVinWVjNWZj^R]RmO/j>_]j>?EPEAWCDOnA2E:
@dE2?3/j=S<f=3Li>cTn?4<m=SDm=4<oACa4?CDf?40m>chj=a@g=SY1?3Pm@D11
A3Tc<SDh?DY3an_nkfOPhMoSi;>]YZ:OWZ2[[ZbTWj2ZZK2aZYfMYJRh];^ZX:>Y
[K>f^Zj]Y:fa]K2a]:^h^;lm=38g=C8c=c8f=38e<c0a=c<d<C4_=34g<c8`<c@b
=CDa;S@g<3<h>3Dd>SHn?THo?cPi?B9@AS`o@D=3@TOHiNKWjNKYjN[Zj:f;encX
jngXhmF1E6M=Aoi4>TY3AD8l>cXf<cHd=cTk>Chl@cdf=Cdd@cm5?4@m=CHl@3dk
?SXg=cHj@C`h?D50@D@i<c8e>3e:@lO[o^l2JOoP<^7Rhj2JWjn]WIbUX:f/Y9nP
WJBSZ:JSX9nUX[F/]9jMY:F/[Jj`Wj^R[;2c_ZndT5Pb<Oh`Abla=2l^;2lh<Rha
=30c;Rh_=34g;SDb<C4_=3L/;cHb=SHg=SLe?Ca4@dM0@Shm@4A4>ci1@D0m@^CT
jnKUj>WVj>[]e<KXk7oWj>[[jmn4EUYCDDI0@Cln@CXi>3lf<clf>STi=SLh>C`n
>40k?CY0?TLn>SXg>C`j?40b=C@h?3@d>d=0?3Xe=c<g=cPj><KZk^g^h>3Qh^>P
VYn_[IfLYJ2][:BOX9fTXjRVXj2OYJ:e[;BNWJBU[:f^/9n[XZb`/kj_]91H<P0a
oS1k;c4d;bh/;cPb;S4d<3<^;Rld<CL^=C8a<Bld=b`_=S8f=SLf=cDm?4A3Ad12
?Se0A4@k?T51@3e2i>C[i^GXjNKXj^gDa^S/inSZjn_OQ5IJDe56@44o?T4j>CPo
=S<o=SXi>CHg>3Tl?SQ0>cdj@3i7?SXj=cTl>Sa0<T`e=3Pl=3@k@d0l>SDg<cLg
>3Xha^[^kNkPh>7Rhj2JWjn]WIbUX:f/Y9nPWJBSZ:JSX9nUX[F/]9jMY:F/[Jj`
Wj^R[;2c_ZndT5Pb<Oh`;bla=2l^;2lh<Rha=30c;Rh_=34g;SDb<C4_=3L/;cHb
=SHg=SLe?Ca4@dM0@Shm@?m4HC/n@D50?D;Ti>_ViNSYi^SZkMC6j>cWj>[[jmn4
EUYCDDI0@Cln@CXi>3lf<clf>STi=SLh>C`n>40k?CY0?TLn>SXg>C`j?40b=C@h
?3@d>d=0?3Xe=c<g=cPj><KZk^g^0VUohMoRhn>^YibNXJ6a]jf_XZNRY;JaZYbH
YZ^`]kFdWJNM]KNf/jJRXJVe][R^ZJZb_eXl=cLd=C4d<c4^<S0h=C0`<S@c=3@c
<cDd<cDf=C8g@3Dg=C8f>3<j>C@e?5:PTUeCDeaSM550@Si3Ad]5CJ3WjNkYin[]
jNSZjn_`kNmoj^W]j^WNTVELCdU6?d52@d<l?C/k=3/n>SLd=CPm@T51?cDn@Clm
@3m5C3]1@T0l?cLk?3Dl=CXi=S@m?S`j=S`b=CLnA4CAjo3`kn7Oh^?S[ZNLWZ6Q
/KN][j:WXZBf/JZLV:J[/;Ne]9fWWKFg][>VXZ6Y]KJh[ZVZ/[mJ?3Mo=c@e<C@c
<Bhb<3Pe<30b=3<d=3<c=C@c=CHe<SM0=CLe<SHh<cXi=3DlDZ2BGE=CG6=dDD12
?T=7BdE=X>OYk^WWj^gYj>[[jo3]kn[YkN[YgY9UG4m9ASm1@T=3?3dk>c@k?SXg
=3Dh?D91@Cle?T4o?D0oAD`k@D90?3lg>cao=C`e>STf=3dn?3Xf?38e=ci4A=7[
l?3_hMoRhn>^YibNXJ6a]jf_XZNRY;JaZYbHYZ^`]kFdWJNM]KNf/jJRXJVe][R^
ZJZb_eXl=cLd=C4d<c4^<S0h=C0`<S@c=3@c<cDd<cDf=C8g@3Dg=C8f>3<j>C@e
?5:PTUeCDeaSM55S@48n@dM;ADfPinW^jNOZkNWXj^_[l>g_j^W]j^WNTVELCdU6
?d52@d<l?C/k=3/n>SLd=CPm@T51?cDn@Clm@3m5C3]1@T0l?cLk?3Dl=CXi=S@m
?S`j=S`b=CLnA4CAjo3`k`9YOmoPhN3RYZ:UYYRKYIfV/:fXVj>X/;F[XIbPWj>U
/ZFYVZVWZJZ_/:>SYkVa[k>_Zg@i?SHd<c4]=S0f=3<`<C@a;bda<c/d=S8h=S<c
=Bh^<3Lb=C8c<c@g=cHg>C]iciV?UZ:SZKJKJ4=1@Si8@e2gin_ZinWYinKYj^c[
jn[[On[YjncZggiDEeM?A3hl>Ci2?c`n>3Ld=CXi<c`j?C`i>Sll?D10>Sa5@T0f
>3/j>D0j?C@b=CPb=chi=3Di<cTl>3@b>Ce1d>_^k_3Oh>7PhZJRYJJHVjFMY[2]
Z9^SZ;2eZj6LX9nSYK:UZIZYYjVZ[k2SXjNi/Jnc[j]d>ChfOc@c<Bdf<3Hd<c0a
=34_;C4c>c@f<SPf<c<e;Rh`=c8e<S<c=3Lg=SLi>gW?VHnFXZ>Y]Y]X@d52?TQ3
D;OWjn[WjNWWi^WZk>_[j^_ZjN_/j]mnE5MGCd@n?3Tn@Sll?SPg=3Dj>C<l>Sdl
>CXo?3e0@3XlAD90=SPk>SU0>SddOc8e>38g?STd=CTc>C`h=38i?D7@jnk^l=oP
hN3RYZ:UYYRKYIfV/:fXVj>X/;F[XIbPWj>U/ZFYVZVWZJZ_/:>SYkVa[k>_Zg@i
?SHd<c4]=S0f=3<`<C@a;bda<c/d=S8h=S<c=Bh^<3Lb=C8c<c@g=cHg>C]iciV?
UZ:SZKJKHfQ3@D8nB4=@]nO[j^OYjNOVjN[/jn_Zjn[YjncZggiDEeM?A3hl>Ci2
?c`n>3Ld=CXi<c`j?C`i>Sll?D10>Sa5@T0f>3/j>D0j?C@b=CPb=chi=3Di<cTl
>3@b>Ce1d>_^k_02J7_Nh>;ShjRNTZ>P/[>ZZ9fNZ:nb]:fVWj^]^KB_WiRJY:nk
]ZjOXj:T_;Zh[JRa/:AA>3Pd<SHi;S@c>30c<S4b=Bda<SLj<3<`>S8g>3Lf<cLf
=c@g<cDc=cLh>d9BfNCSaX=eXKO:bKU3@CY0B46ThNOXj^S^kN[XjNO`o^h0kooY
ond/jmmnFe=>ATEAAT92?SDi?S8e=S/g=Sm2?Sdl@TLm@418?dA0?SPn?T57?CPg
oSE;?3Pi>c/h?CQ3=clh?3Xi>3`i?m7YkNg`g^3Rhn>XWY:SX;:cZZRMWZR_/[B]
YYn[[KVd[inHVZB_^kJ^Wj>RY;bj^:fX/K2TDCPh=4Lb=ST^=3<h<3<b<C8e;C4b
=cX`<c0j<SLh=cHc=cHg=3Lc=C<g=cPk@U;Ii>?6PgFQ]l[9^D=1>T18@JCQinSZ
j>k]j^SYio3nkS7_jNW]kN_OOU]CCTI5DDI2@She>Chb=CHk=cHo@Shm?497?D10
B3m4@3hh?Si1Acdh=oheOc`h>C/k>3dh@cLo>3`j>CPl>CoAjNg]l=kPh^?SZ9jB
Xj2b/jZXWIjX[k:d[JJOZjfi]:nOV9ZT[k^f[YnSXZBl^[R]Z;6`Y54h>3@b=ST^
=3<h<3<b<C8e;C4b=cX`<c0j<SLh=cHc=cHg=3Lc=C<g=cPk@U;Ii>?6PgFQ]l[9
4kU3@CY0B46ThNOXj^S^kN[XjNO`o^haknWYkNg[ggiKDdi6AE56@T8n=CTn<SDf
>cLf?d8n?Ca2Ace0@4PoA40n>3hn@DLm>3On=ALl>3Tk>cPm>4<g?cPl>STh?3To
dNW]kO02JCKOgN3PhjjZWijHXJ:[]:VFUijVZ;:_Z:JOXjn^[Z2OWJ2XZ:fY[9VK
YJRe^;R^[4Hj=34];C0coS;o<3@d;CHe=3@f=SDd=2l`<2ld=CD`<c0`<bd`;CHb
=C8i?49jfn?Wh]:3V:N]/<E8AD0m@433iok/2n_/jnW[k>g^k>[Zj`g]j^WYin5m
GF1@B492>Oi1oc/6>3<g>Chf>OhfHSY1@dLl>S/m?T56@STk>cXj@CPf<c@d=c/i
>cXh>3Lk?48i=3Lj>3Lo?m;Zk>c`gmgPh>>^ZYnNV:6RZkBYUYNNYZRb[jRVWj>_
[ZjPWifPZ:R]ZJbIVjFX]KRh[Za6>S@a;@8]<3?n<_l`=3@]=SDd=3Hf=C@d;c0`
;c@e=C0c<30c;C0]=S8e<STl@W[KhnORdX>HYjf`aDQ5@3e0@<?Wo^`Ijnc[jN_/
kNk/j^[[kN[YjNOQOEePD4Q2@SWn@Olk1SPc=cTn=SWn=QHj@D=7?3Xk?Ci1AT8i
>c/j>T4h=S<d=4hg>cTk>SPh=c/l@STd=cXh=clod^[/k?3OgN3PhjjZWijHXJ:[
]:VFUijVZ;:_Z:JOXjn^[Z2OWJ2XZ:fY[9VKYJRe^;R^[4Hj=34];C0coS;o<2/d
;CHe=3@f=SDd=2l`<2ld=CD`<c0`<bd`;CHb=C8i?49jfn?Wh]:3V:N]/0S5B4E0
?D10`nOnk1W[k>_Yjnc]k^cZj^_]j^WYin5mGF1@B492>Oi1oc/6>3<g>Chf>Ohf
;SY1@dLl>S/m?T56@STk>cXj@CPf<c@d=c/i>cXh>3Lk?48i=3Lj>3Lo?m;Zk>c`
0VQogMoQh^:PVin]/;NZZjVW[;:Z]JJUYZV^[kVYXJ6R/kFl^k6]YJ^Z/KRd]ZJe
/J<i>SHg=3X[=c4e=38a=CDc=c/f=CLc=bh`<Rl^;SLg>C<e=SDh=C8k<S4d>Cbc
i>OXjNCSh]bo/K[6GD13BDU7hn;_j?3]kO3YiNk_l?3^k>e8jnW^k>cXSU9ADDi9
BTQ4?DDj@3Lf>cdo=S8f?Cho@T]3?Ca9@D8o@S/i?416>S/m<c<l>chj>cDl>DDm
?CXh=CDd>cdl?CgFl?k^<mgOhN;RX9^O[K2gZZ^YYjbbZ[FVYJJY[ZniZJ6QX[>e
_;^a[JF[Z[6h];JV]K6S>CXf=cAo>R/g<CDd<S4e=C<g>cHe=c<g;S0b;bh^=cLi
<cDf=CPe<S/b<C@i?;?TinSYi>?Rg;na^/IM@4=9BDOSh^oXl>g]l>WUk^o`l>k/
kN_Yk^c/j8iBDE5>BDY8A3e5>T0g=S/m?cHb=Sdn?d9;@cdlBD52?d8k>Ca0ASXk
?C<c?3/D?SXk=C`iACdm>SPe=C@k?C`m?MK`o^iWgMoQh^:PVin]/;NZZjVW[;:Z
]JJUYZV^[kVYXJ6R/kFl^k6]YJ^Z/KRd]ZJe/J<i>SHg=3X[=c4e=38a=CDc=c/f
=CLc=bh`<Rl^;SLg>C<e=SDh=C8k<S4d>Cbci>OXjNCSh]bo/KYPaUe0@dU9An?R
knS`kNg`jNG^ko3`k^c]jnW^k>cXSU9ADDi9BTQ4?DDj@3Lf>cdo=S8f?Cho@T]3
?Ca9@D8o@S/i?416>S/m<c<l>chj>cDl>DDm?CXh=CDd>cdl?CgFl?k^0VT0g_kP
Nn>/WijQWJ6N[jBLY:BP[k2/XiJMY:fVZ:FOWZJVY:^hZ:BOYJ^_^KNYH4@h=Rlh
<C<`<clc=C@b<bd^=C<e<SD];bh^;CDb<Bl`=SXf=CHc<S4g<SHf>SfUe>GTjNKU
hNCA^IBANCm0?D5:inOXk>_XkNcXj^c/jN[/jna<kN_Zin_UWEEKBD=4B40n>40h
?S`d=cTj=C@i>c`j?4Q5@4A<?Cho>SXg?3/f?48n=C4i=c/i@CPh=cTh>cHc=CTf
=SP_?CoBj>c^kmknh2oS[9nNXIfQWZnTW:BTX:n`[:>FWJB]YZRUWijVYZB[^:RT
WjF[[kVgZF14>3H_>35o<c0c?c<e=38c;Bhe<cDb=Bd_;Rh]=C8a;c0f>SHe=S<b
<CLb=SHj?JGDiNCYi^GQi=6iU95i?d0m@D[WinS/jnS]k>SZk>cYj^c[k>g[j^O[
iIeEFdU3A4Q0?SQ0>3hl=3Li>SDd>C/l>Sa8AD14C3dn?cXj=c`k=Sa2?SDa>CLH
>cU1>3Pg>CPk=S<e>CHf>2lm?m;Xk>k_g_kPHn>/WijQWJ6N[jBLY:BP[k2/XiJM
Y:fVZ:FOWZJVY:^hZ:BOYJ^_^KNYH4@h=Rlh<C<`<clc=C@b<bd^=C<e<SD];bh^
;CDb<Bl`=SXf=CHc<S4g<SHf>SfUe>GTjNKUhNCA^IASTGTo@3e1B^OWj>c[j>g/
j>[/k>WZk>_/kN_Zin_UWEEKBD=4B40n>40h?S`d=cTj=C@i>c`j?4Q5@4A<?Cho
>SXg?3/f?48n=C4i=c/i@CPh=cTh>cHc=CTf=SP_?CoBj>c^k`9YOmoPhN;RVYRJ
/:jaX:>LX:Zg/:^QXJ:^[JjiX:6S];Jh/JVVZ:2/[k^i]jI^BCXi>SXb=C<j=S@c
<C@i;c@j<c<`;2ha<3Dc<bdb=C/^=CDg=CPf<c<a=CPc=C@mM9_Ri^OUinWZin??
RhECB4Y8D>KVjN[/k^k]k>[Zk>g/kNkY5>S[j^[WhJe:GE5ECU4m@CTm>Sdi=_hi
IcLeA3`l>cll@DU=CDHo>cM0@CDi>48o=d8k@D4o=cPe>d4o>3Xi>c<k@3<g=cTn
en_^knkOh>7RhYZHV[2^/J2SW:2Z]k2[XJ6R[Zf^^J2QXkBf^;6YYZRP[:nk^KNV
KTTj>CXj<SDcH3Xf=3<a=3T_=3Xc<c0/;S4`=C<c;C8e>bhe=CLe>3Hc<c4e>3<e
=3edVn;VinGWjN[Whln;QE=8BTQ@i^KYj^c^k^g/j^[/kNc]k^WXjn[Zin6]BUeA
EDiA?D4i?CXm>CKn>A/g=D@l?3/o?459CDe6?c/g@44e>CQ2?cM2>d51Oclg>3Dk
@Clh>STk<c]0<cLg>CkGjnk_k]oPhN;RVYRJ/:jaX:>LX:Zg/:^QXJ:^[JjiX:6S
];Jh/JVVZ:2/[k^i]jI^BCXi>SXb=C<j=S@c<C@i;c@j<c<`;2ha<3Dc<bdb=C/^
=CDg=CPf<c<a=CPc=C@mM9_Ri^OUinWZin??;8^5DdQ:B53Vi^WZk>k^kNcZj^c]
k>g^jNS[j^[WhJe:GE5ECU4m@CTm>Sdi=_hi<cLeA3`l>cll@DU=CDHo>cM0@CDi
>48o=d8k@D4o=cPe>d4o>3Xi>c<k@3<g=cTnen_^knh2JEOOgN3QhYjETi^PZZR/
TiJOYjn_[JRSX:FZ/;:YX:>PZKBc]jBSXZ6hHdA1=SLd=S@e<S@d=C4c=38b=3Df
<Rld<30b<C0c<S<]<Rh`<C<f<C<c<S<f<SDioSOo=18jJ9CNi>GSi>CWi]^7LUE6
@TWWo^H2j^cZo^/6jN_XjNKXjSGWj^KWin;<Be16AD14?CPl?CDh?cXk>3Hi=cPf
@D@o?C`k>Sho@cTk?cdg=d<o?S/m>3hk>cSn>@4g?OhjocTo=cDg>CPl?mWXk>k]
gmgPhN:NUI>KX:ZX[9>FWjN_[jfXXj2UZ[2bZJ2SX:Vd/kNTXj:Q^6=4@CHg=3Hd
=C8d=2<e<C<d<S8d=CHb;c@`<38a<3<b<bdb;S0a<cHa<c<b<cHb=CWn=old4SYX
U=kTiN?Ti>OVfhMbEDI2BNOniP;Zk>[njc[YjnSYi^SZin[VinORc4]@ATE0A3dh
?3de>3lj>cPf>CLh=T54?cdl>cXn?d<i>clm=cM3?chk?CPn>`4k>?hi0CLmoS[o
>F<g=CLi>3`ofNS/k^gOgN3QhYjETi^PZZR/TiJOYjn_[JRSX:FZ/;:YX:>PZKBc
]jBSXZ6hHdA1=SLd=S@e<S@d=C4c=38b=3Df<Rld<30b<C0c<S<]<Rh`<C<f<C<c
<S<f<SDioSOo=0XjJ9CNi>GSi>CWiPOKQg9EAT99iokV0^[/j_k[?>W[j>WVj>[W
j^KWin;<Be16AD14?CPl?CDh?cXk>3Hi=cPf@D@o?C`k>Sho@cTk?cdg=d<o?S/m
>3hk>cSn>@4g?OhjocT;=cDg>CPl?mWXk>k]0VTAgmkNh^:OUIBV[JVLX9RSZK>`
oZ@DYjZgZJFMXIjc/[JYYZJXZ;9>?CPeoSIB;S<d=C0f<S@_<S0_<SHb<30]<C<e
<c4]<38e;c0`<c0b<bla<Bhc=CDl<cLd>c@i>cdmKh_XinWXj^CSh]65@Cm1[^3V
inKZjNWZi>OVj^SXiNAMiNKOdJ1[H55@Ce58B3dk?d0k?SLc>cTo>3Pe=ci5?D4j
=3m3?Slg@4=6?C`o>CPk>TA2>CXf=cPi>d@l>CHj=T0n=CLf=cOJjNc^kmoNg^;R
WiFDYZfYW:2HXjVc/?jT5:NZ]jVUWJ6N/k:fZJJVZ:RbCSdh=Ohf1Rhc=3D`=S9o
=2lb<2lb=S8`<2da<cDc<Bd`<SD_<30c<38c;c4a;S<e=C`c=c@k=3Tk?Ce_RnSW
jNSZi>?RdHE1?d6^h>KWi^[YjN[TinKZj>SUi>GVgm6PJf1AD4mAB4Pm>cm0>chg
<c/i?cPh=CLnACe1>S@o@cho=d13ASdl?cTh>cY4@STY>SHg>3TkA3`i=SXf@3he
=cHg=m[Yk>k_gmkNh^:OUIBV[JVLX9RSZK>`oZ@DYjZgZJFMXIjc/[JYYZJXZ;9>
?CPeoSHj;S<d=C0f<S@_<S0_<SHb<30]<C<e<c4]<38e;c0`<c0b<bla<Bhc=CDl
<cLd>c@i>cdmKh_XinWXj^AShn;AQD4o@JkPi^OVj^WYj^CWi^[Xj>GTiNKOdJ1[
H55@Ce58B3dk?d0k?SLc>cTo>3Pe=ci5?D4j=3m3?Slg@4=6?C`o>CPk>TA2>CXf
=cPi>d@l>CHj=T0n=CLf=cOJjNc^k`9YLn3OhN;SZJJMWZ:Z/Z^Y[ZZ_/;Vj[j^S
Xjf_/k>YZjR_/[Nj]k:M?3Pg<C0b?3@d<3<e<c<d<3D`>cLj<Bl]=3<f<34^:C4c
<30a<Rle<SHc<STj=SDd>cDf=3<b<c/m>DQQ]^?Vh^OSi=j9Aca4AF[:h^KSo^L8
j>KTh^WWiMSHOj:0KVeWFVALEe1:Aci0@clm=cLd<STm?3`o>SdmA4E4>3Hk@T1A
>d4n?4I2@c`n>S/mASa9?chi?c@k?T@j>STo>CLf>CXmf^O]kncPgn7RhjVVWIjR
Z[:[ZJjZ[k2i^Zn[Xj>][k>cZJ^X[k:g^[NbWC`h=c4`<S`d=30c=C<c?c@`=C0k
=cXa;bdd<cH`<BhY<C<`<34b;cDb=S<b>CXf=C@k=CHd<c8c>cdiB66fhnKRin?T
gXU7?4A5J/[Ri^?niccXi^CRjNOUf=RRP6i]IeYTG5M@BTLn@4<o?CLg=38i?C`l
?cXm?DA5A3Pf>d90DC]1?Sa6@T<l?SXk?DHlOdTo?STo=3/nA3Xj>Cli=cHi>SgJ
ing_k>3OhN;SZJJMWZ:Z/Z^Y[ZZ_/;Vj[j^SXjf_/k>YZjR_/[Nj]k:M?3Pg<C0b
?3@d<3<e<c<d<3D`>cLj<Bl]=3<f<34^:C4c<30a<Rle<SHc<STj=SDd>cDf=3<b
<c/m>DQQ]^?Vh^OS2nCNRDLlA4EZb^;VhokWE>SVi>;YinGHf::0KVeWFVALEe1:
Aci0@clm=cLd<STm?3`o>SdmA4E4>3Hk@T1A>d4n?4I2@c`n>S/mASa9?chi?c@k
?T@j>STo>CLf>CXmf^O]kn`2JCWLh>;OhIbNZ:FVVj6PY;>//:VTYJ>c/[6UY:JS
XKJh]:J[[K2kQSXf>3Hc<SDa<2he<Rd_<c@b;C4coS0<;Rla;c0^<C8b;bla<?h^
<S8`=C@b<S@a=C@g>34e<c@k>C/g>DMV`=OOh>;<CSho?3e3J]?=`KVf^jnMTY6;
K6MNEGmBF5EJG5A=A4Y9C492?d<i>Sa5=S8e>S`oA3]0=cTj@DQ2?CPk>3TkADA3
?CY0?cln?3`e>3Xn>Se0@3Pi?40h>3Xj=3To?McVk>_^g>3Rgn6LWZRUYY^QX:Bc
[;2YY:FS/k:aYJBVXj6f^;BVZjf`^hHj=SPf<c8e<C0^=C8];`Dc=38]<C?n<0`^
;c4_<2ha<S8_;c4`oRiV<S0e=38b=34e=3Lh<CDc=3/i>cLiAfK0emoPh/a>?Sll
?D=Zdlg1^KJk[ifBTH]/IeiEDUQEFUaDCDA:BDa2@Sm3>CXlACHb=CXl?d@k@3Li
>T58@Sdh>cPi>dE4@cdj@3lo?S`l=E4h>Shj?D10>3Tl@3Ph>SXd>Clmg>K/jnkL
h>;OhIbNZ:FVVj6PY;>//:VTYJ>c/[6UY:JSXKJh]:J[[K2kQSXf>3Hc<SDa<2he
<Rd_<c@b;C4coS0<;Rla;c0^<C8b;bla<?h^6S8`=C@b<S@a=C@g>34e<c@k>C/g
>DMV`=OOh6?Rc4hn?c`m@f[CcL6i][^_WI:ARfaWGUEBF5EJG5A=A4Y9C492?d<i
>Sa5=S8e>S`oA3]0=cTj@DQ2?CPk>3TkADA3?CY0?cln?3`e>3Xn>Se0@3Pi?40h
>3Xj=3To?McVk>_^0VU[g=oPh>6WX9^[[jfZZJNWZK2c[K>Y[Z^f^;Rc[:6TZ:nc
]kFoSE<b=SLd=CHd<CDc<C@e=3Lc<Rh_;C<d;c<_>C<c;R`e;bh_=S8a=3<`<S<`
=2h`<cHd>Sdn>CLj>c`o>SLoAGRQiNCVP492oSl@?4=TGE1@DUI=CTmCF5QOFeEo
DDm?DDa:A3];DT8oB3i7>SPk>CTh>cPi>Si2@Ci5AdE4ADA4@c`k@Sm1Ad=1A3hm
?SU2?cPh?STi@DHl?d4m>3Tg?3Lm>cSMin_[kmcOh>3QYj2KZjn]ZZVWYjV`/jfc
ZJj[][Rh/jbQY:R_/kNe_heC<SHg=3Df=34e<c4d=C@g=c<b;Rl]<c@_<bli<c<^
;3D_;Rlf<S4d<c0b<c0d;S0c=S@j?Chi=cXk?3lj=cm5N:7Ui>J0@T;n?d@l@fAM
D51BETe>Ce=HF5mKEE5?Ce5<BT@kBe92?dPnAcXh>cTi>3/h>CXn@T4nADM5A4E4
A4<l>d8o@DM3@D@n?Chi@Soo>7dn>CU1AS`o@Cdh>CLl=cdk>=gWjn__g=oPh>6W
X9^[[jfZZJNWZK2c[K>Y[Z^f^;Rc[:6TZ:nc]kFoSE<b=SLd=CHd<CDc<C@e=3Lc
<Rh_;C<d;c<_>C<c;R`e;bh_=S8a=3<`<S<`=2h`<cHd>Sdn>CLj>c`o>SLoAGRQ
iN@3iX12@_hoG3a3I5e@D59FCDi?DeQHGe]EDDm?DDa:A3];DT8oB3i7>SPk>CTh
>cPi>Si2@Ci5AdE4ADA4@c`k@Sm1Ad=1A3hm?SU2?cPh?STi@DHl?d4m>3Tg?3Lm
>cSMin_[k`9YOmkMh=gRXZ>UY::LWJN]/Jj_YZ^O[;>[YJVUYjJYZk2QWjR[WCXd
=C<b=2lf=bhg=c8^;bdd<3D`<Rl^=b`]<3@`>bl^;C8`<3@`;Rla=34`;c8a;Bm3
=c8m>3Pe@30g=cPe=3Xm@HbL^D<f>S/m?3loCTe>BT]:C4eKEU=<CD93@D=8A3i6
A3hnBDa7>3Xn>cTi>3`h=cLl?ce0>cPb>ci3@DDm>Slo>Cm4?clj?CXm?D4k<c8d
>3Lk>cY0>CLa?CXf=?hi>SXig^WXjngNgN3MhZ:SYJBRW9fW[K6^[jJ[WjbcZjFY
YJNVZJ^`XInXZidj=3Dc<S@_=SL^=cLb;Rl]Oc@`=C0b;bhg;2d`=30k;bh]<S0`
=30^;c4d<C0_<S4];d<g<Sdh>3E0<3Lg>3Dd>Se1S9bi@cHj>cdl?cm>CDi:BdY<
CE]FDda=@T=3B4@nAT@n?TU<AcPj?S/i>CPl>3Lg?3lm@3/h<S/n@d55?CXo?cTo
A3lo>Sdj?Ce1>c<b3C@h=c/k>T0i=c4m>SHdoSU^>SWNjNS[kMkMh=gRXZ>UY::L
WJN]/Jj_YZ^O[;>[YJVUYjJYZk2QWjR[WCXd=C<b=2lf=bhg=c8^;bdd<3D`<Rl^
=b`]<3@`>bl^;C8`<3@`;Rla=34`;c8a;Bm3=c8m>3Pe@30g=cPe=3Xm@HbLFKU3
=SXk?C`o?di=CTY;BTa=FeICC4e2@d=8A3i6A3hnBDa7>3Xn>cTi>3`h=cLl?ce0
>cPb>ci3@DDm>Slo>Cm4?clj?CXm?D4k<c8d>3Lk>cY0>CLa?CXf=?hi1SXig^WX
jnd2JGWNgMoPgYnLXjf/[JF`YjN[^;FfZJn/[;6[/;2[[;6f^k_1Y5Xh=S@j<SDd
=3/k=c8^;SLe<S8e:S8_=SDg<S0c;S@b<C0_;Bl^<38b;S@a=C<b<C0f>SHd=SLh
=T4j?S/m=SXh>CY?Kf4k@Ci0@Cm1@DI6DDUCB557A?i6od@0Bgm8AD97CTQ5@4M7
AD91?40i>CLj>Cdl>SHh@Ca1@C`o?SU2@4M1?S52@T54?4A2BT94@Clo>C/g=cTn
@40e=CTiACHi=S@m?>7VinS[g]gOh=jOW:>][:fU/:NWZkRe]ZV_[:baZk2`Zjba
][^k`JAJ>3Hd>S8e=3@k>cLb;Rhg=Olb@cDZ<Rlf=CLb<3<^=38a<2l];bh`<S8^
=34e<c8a<3Hj=S@f=cPf@CXn>cdf>SPi>Tm_HC]1?T11?d51ATIABE=8DDM4oTKo
A3A;B4E2Adi8AD17AdE2@Ca0>CTg>STm?3Xf>44l@D4l?chi@T17@Cha@T91A3a4
@TY2A44o?gli>cLg>Ci0@3De>CU5=STf=3dlhNKWj>_NgMoPgYnLXjf/[JF`YjN[
^;FfZJn/[;6[/;2[[;6f^k_1Y5Xh=S@j<SDd=3/k=c8^;SLe<S8e:S8_=SDg<S0c
;S@b<C0_;Bl^<38b;S@a=C<b<C0f>SHd=SLh=T4j?S/m=SXh>CY?Ka5Q>d4n@44o
@D56AU59DdQAAdCnA_m4C4]8AD97CTQ5@4M7AD91?40i>CLj>Cdl>SHh@Ca1@C`o
?SU2@4M1?S52@T54?4A2BT94@Clo>C/g=cTn@40e=CTiACHi=S@m?>7VinS[0VU7
gmkQhMfTXjFUVJ6N/kb_/JFUYZ:k]Zf/ZjJ^^[ZhYjZY[4Dk<cD_;c4_=S4a=S8^
<Rl`<34e=2hc;Rlc>c8a<2d^;Bl/=2L/oRdd<S0/:c0c<c0]<C`f<cHf=cLf=STf
>SHm>C/j?C/i>3ll>cdf@4do@44j?Ce2B497Bde=@4LOAD0o?TE4B415@cdn=cHl
=C<g?3Xf=C/j?3dk>CPg>d7n??lhFS`kAcdl=3LoBDY0@CHi<SXh>cXh>C/j>chl
>cXc=SLf>c[Ri>KXjmoNhN7MY:>UYIVQW[>l[k6UYJJR^kJ][:^V[[Zj^:NZZJa5
>c<e;bla;cHa<CHb;S8_<30C<CDd;S<^;c<k<S4`;Bh];b`d9bcn;E@b<2`[<3<c
<2da?3Hc=SHg=cHf>CHj=Sdi>cXm>cTh?c`k?CI0CCm0@CXm?D98@TM;CDe0AdE0
?ci5A4Q0AD<m?SLf?3Dc=c`j=SDk>S`m>cTh=c]1oSco>0hl>dLm?3@g?dU:@44f
>C9O>SPk>SPi>cXk?S`k>S<f=cHk>^;Ti^S[gmkQhMfTXjFUVJ6N/kb_/JFUYZ:k
]Zf/ZjJ^^[ZhYjZY[4Dk<cD_;c4_=S4a=S8^<Rl`<34e=2hc;Rlc>c8a<2d^;Bl/
=2L/oRdL<S0/:c0c<c0]<C`f<cHf=cLf=STf>SHm>C/j?C/g>CPo?3/m=T1=?d11
>Sdm@TQ2Ad]=CD17AD0o?TE4B415@cdn=cHl=C<g?3Xf=C/j?3dk>CPg>d7n??lh
9S`kAcdl=3LoBDY0@CHi<SXh>cXh>C/j>chl>cXc=SLf>c[Ri>KXj`9YBmoPhmoI
Y9^QYjb[YZbX[kJg/jRV/K2c];Ba[JNc^[Zh^j@o=S0c;S0h;2`b=C<e;cTc<bla
=Bh_<S<]<Che>C<e=S0d=2h[:b`b=CGn<C0c<CDf<SA4>CPf>3Pg<cLj=CDg?SU0
?d13>d0oA40o=ci5?ci<@d93@T=4ADe:C4E1OdA7CTQ7@TLl@3li>chj>CXf>CPn
>3dh>DA4?D4h=CPj>44h?48o?TQ2@S/l?457@44o>3Xh=Sa0?454>D11?Sdi=SDf
>Cm6hn?VjnkOh>?OfJBKXJN/ZjJ/Z:nf]k>XY[6`/kBd/JfW/kZj^;^T?cH`<bh`
>2`/<SDc=Bli<c<_5c4e;Rlb<bda?SDi<cDf<3@d;R/[;38e=OhaI3<a=CHb=4@i
>3Hh>3Lc=cXe=CLn>D0o@4<k@3m4@3lg?TDo?Ta3@T=2@dA5CDY<AD54Adi8Ad97
?40o>C/n>STj=STh?SPm>3U4A3e1>3Dh>SQ1>3a2?ci8@T8k?3a1Ad11?cPjHcPf
?40l@D@i@44n?CTf=CHi?dKShnK[k]oPhmoIY9^QYjb[YZbX[kJg/jRV/K2c];Ba
[JNc^[Zh^j@o=S0c;S0h;2`b=C<e;cTc<bla=Bh_<S<]<Che>C<e=S0d=2h[:b`b
=CGn<APc<CDf<SA4>CPf>3Pg<cLj=CDg?SU0?d13Hc]0?dA0?cLnAClnC4=2@d93
A4E=BTa5@DA7CTQ7@TLl@3li>chj>CXf>CPn>3dh>DA4?D4h=CPj>44h?48o?TQ2
@S/l?457@44o>3Xh=Sa0?454>D11?Sdi=SDf>Cm6hn?Vjnh2Ic?Ngn;NfJ^OVj6I
X:^`Z:VYYJ6^/;2/Z:6[ZKJf[[:ZZZAL>3La=2h_;c@_;c0b;bd/<3<^oS18;c4_
;2/i<C8a=34/;S0a;2XZ<Rh]<30/;c4e=3Dd<S4b=cU1>SH]<CHg>c/b?3M0=S@k
>3Xf>CA1?Sdi?SY0@DE3BClo@TA0@ae5@d=1@dHo@D10>SPl=d0h=c8f=c8k>Si0
>cDj?47n>`lj>CTk@D14?Sdo=3`i>cTkoS=;=chj>CPk?ce0@S`j>C8g=3Ho?^7X
iNC]g]oRg]V[Wi^QVJ2[/:RYZJFQ[[2`[:RQZjVf]ZjbZZZTG3Pg<C@^;bld;bl`
<Rl];30c;_h`IRla;b`[>C4b<C@a;2h`<B`Z:S8^;C0`;2la=C@e=38a<SLi@CXf
;C4f=c/k<S`g@3Hd>cPj=STd@Chm>Chj@455@dTo?d94@4=5@d=1@dHo@D10>SPl
=d0h=c8f=c8k>Si0>cDj?47n>`lj>CTk@D14?Sdo=3`i>cTkoS=;=chj>CPk?ce0
@S`j>C8g=3Ho?^7XiNC]g]oRg]V[Wi^QVJ2[/:RYZJFQ[[2`[:RQZjVf]ZjbZZZT
G3Pg<C@^;bld;bl`<Rl];30c;_h`<2la;b`[>C4b<C@a;2h`<B`Z:S8^;C0`;2la
=C@e=38a<SLi@CXf;C4f=c/k<S`g@3He=3/h>SHi=44n?CTn>T11AD=9?cm2A413
AD=3@D=6?d50@3Xh?3M0>3Lb=SLb>cXn@3/e>Sa1oS/?>STi>d50A3hm?c@l>C/i
>ohc5cLn>STh>clm@48l>STb=c@f?ckQj>GTk@9YOmgNhN;MY:JZZjVW[k2]/K:`
Y:bY/[Fb/Jn^[;6`_K32QDHd>3Hb=30e<Rd`=38c;B/_=CDb;c4[;c4h<cXc<C@d
<S@`<38_=2hc<2hc=bhf<SD`<c4j=C8l<c4c>CLb=clh>Ce6>4Ld;SHk>c@k<S]9
@Cln=cPnBT15@T9;ASe0OdI8CTa7?Se1?3m5?chi?T4l?CHb=3Y3>chn>Sa0>c/l
@Cm0>CHg>493?3Xd=3Hd=CTc?C@l=choCD10>Shg>c]2=SXh>3Lnh^OYjNgMg^7R
gJBVZZ^YYjn`[K6b/:B/ZK:e/[6_[Zba/;f``XE6=3Pf<S@`=C8]<3@b<bd[;cDe
Oc8_<B/_<CPc>S<a=3@b=30`<Rld;S<`;S<g;SHb=C0c<CXe<S`c<C<i=c8g?cPi
?DHhAc@^=S/k=3/b>dU1?chg>3i:@4E2@T]6?D16B4i<Achm@C`oACln>Ci1?3df
<S@j@c/n?SXl@3/k?44o@3Tf=cQ2@c`j=3@f=3Di<cddOc`g?Sm=@40j?SLk>d8f
>SPh=ckRinWYkMgNhN;MY:JZZjVW[k2]/K:`Y:bY/[Fb/Jn^[;6`_K32QDHd>3Hb
=30e<Rd`=38c;B/_=CDb;c4[;c4h<cXc<C@d<S@`<38_=2hc<2hc=bhf<SD`<c4j
=C8l<c4c>CLb=clh>Ce6>4LdHbhf>c/d>c8kBD4o?SLh?TY0AD92BdHm@4I8CTa7
?Se1?3m5?chi?T4l?CHb=3Y3>chn>Sa0>c/l@Cm0>CHg>493?3Xd=3Hd=CTc?C@l
=choCD10>Shg>c]2=SXh>3Lnh^OYjNd2JGoLg^?QhJNETiVBZ[6_X:>PZ:nh]ZbV
X:V`^K6/ZjimDS/f<c0`<c8a=34];bdY<C8`<38];Bh^<C4]<c0d;2le=bh`<C4`
:3@`<Rh^;C0^<Rdf;S0]=SH`>38b=Rlc=SXo>C@e>T@j<c0i>3/k=CI1>3Hh=CXj
@d@o@Cm2AdM8?aPm@DI2@dDm?CTg?Shh?3Pl=cDc=3=1?c`hoS`<@3Xl>CPl>Shf
>SPl>ohiDc/g=38c<S/j?C<g<cPk>C/o>C/e>3@l>SLg?^?ViNO[g=kShN6WUI>I
TZZa[j2SX:R_^;J/YZ2Y/;Va[:^^OE8k=S<`<3<b<C@a;Bl]:C4b<30b;F@];Rha
<Bdc<3@/;cDg;S0a<C0X=30b;Rh]<2hb;CH^<2df=S0h<S8f;c<f>Sli=3DjA3Xc
<3Th>c/e=T4h=SPe>SY3A3m1?d97AdPo?D56@T=5?Cdi=chn>3`h?3Le<c@c@Cll
>?hl340j?3Th?3Xn=SXh?3_n>@Lk=c@b<c8k>Wlm<cLc>3/i>cli>cDh=3`j=cLn
hnKUin_Lg^?QhJNETiVBZ[6_X:>PZ:nh]ZbVX:V`^K6/ZjimDS/f<c0`<c8a=34]
;bdY<C8`<38];Bh^<C4]<c0d;2le=bh`<C4`:3@`<Rh^;C0^<Rdf;S0]=SH`>38b
=Rlc=SXo>C@e>T@j<c0`>CPk>cDf@CPf>3Dj>T=4?d4o@TM7B3lm@DI2@dDm?CTg
?Shh?3Pl=cDc=3=1?c`hoS`<@3Xl>CPl>Shf>SPl>ohi7c/g=38c<S/j?C<g<cPk
>C/o>C/e>3@l>SLg?^?ViNO[0VWogc;PhN6^[:FUXZZa/[Jf/:bT/KJe]ZjdZjn_
/[NT@SPc<c8h=C8b<Bde>30d:b/e=c0g<C;n<DLc<C8d=38f>3@d<bh];2/a<C@`
;c0a:c8^=Bhb;c8c>3/b?S@d=c@f@cHc<TY4?cTf>d0m?3Tg=Rlf>chl@D5<?dA7
?D=4AD=oADA1?D55@dQ4=cXj@3]3?cDd>3@i?D=6?3dg?Chk@3Tn?SXm=STj@C@l
>SLe?c`c=C0f>3dk?CPl>cln>cHh>3Dl>cPf?d;ViNOWk=oOh>7Q[ZbUYJ:Z/K:f
][2/Y;6f]KJ^]:^_[k:gY48h<c<b>3Db<S4]=CP`=2/[=CL`=c40<_haNc<a<S@d
<SHh=3@c;Rd/:c4a=30_<34[<Rhe;S8_<S<h>c8n=3@g=3I3=S<bBT@o>CHk@3dl
>CLf;cHk?Sa1@D`oA4Lm@dA5@dE4@Ce1AD=8A3Lj>T0k@cle=3Pd>Ce3AS`m=cdn
>d0i?Shj?CHi>T4d?3Xg=Cll<cD`=SQ<?C/m>3`k?chk=SPh=C`k>3Ho@^KUinO/
gmoPhN6^[:FUXZZa/[Jf/:bT/KJe]ZjdZjn_/[NT@SPc<c8h=C8b<Bde>30d:b/e
=c0g<C;n<Blc<C8d=38f>3@d<bh];2/a<C@`;c0a:c8^=Bhb;c8c>3/b?S@d=c@f
@cHc<TY4?cUS=S]0?C`i=cH_=S/n?451C3m4Ace3A4E3ADA1?D55@dQ4=cXj@3]3
?cDd>3@i?D=6?3dg?Chk@3Tn?SXm=STj@C@l>SLe?c`c=C0f>3dk?CPl>cln>cHh
>3Dl>cPf?d;ViNOWk09VD=oNgmkRX9NEWj:`[J6QWIb][KB`YYjT[[JoYjmH?C8g
<c4b;c0b;c4`<C4e;b/_=30Y<2d_<c@^<S<d<S8e<C`d;Rd_;bh]<Rhd<S4b=34f
<_d_:S<`<SDd=S<i<STf>38i>40i?cXh=C0d=T0fA3Hj>CXg?TA;@clj@4Q3?ch^
?3i1A4Y4@SXn>SHgA3do>cTj>STj>T90>3Tj?CXo>S`e=3/l=CPf<S8h>3Lb=CCn
<`/m=CLg?3hg=dDn?cSn=chf>3Xf=SoRhnGVjmoNgmkRX9NEWj:`[J6QWIb][KB`
YYjT[[JoYjmH?C8g<c4b;c0b;c4`<C4e;b/_=30Y<2dL;c<d;S8c=38b=C4l=2h]
;bl^;C8^=38a<S@a=S;m;eTc<38e=3Hc>C8i=SPb>CQ0>Clj>3D`=3I0=T@f>STj
=ci4Bd<o>T18@cln?3i1A4Y4@SXn>SHgA3do>cTj>STj>T90>3Tj?CXo>S`e=3/l
=CPf<S8h>3Lb=CCn<`4m=Olg1c`n=cM5?SlhoSMK=SPj=SHoh^?Ui^_Og]oNhZ2G
UInR/:fQXIfL[Jfd/:JNY:jf_jN_F3db=c<a<Rl`<Rla<34a=Bl[;c@`:C0];c<d
;S8c=38b=C4l=2h];bl^;C8^=38a<S@a=S;m;a8c<38e=3Hc>C8i=SPb>CQ0>Clj
ASPe<3@f@3I4=SXi>SLnA4]3?cY0B4<o?S`n@DA:A48j?SXf=d@m?c/i>SXi>SY2
@3Pi>Sdj?cXl=C@k?3Dh=S8b>3Pg<SDdoS<;?CDg=c`n=cM5?SlhoSL:=SPj=SHo
h^?Ui^/2JD_Lgn;QgjNQXJjNYZ:W/;2Z/JBZZkR`[:f]^KBh>2lg=C4a;34d;bld
<Bl`;SL_<c8];C4^<C0h;c@`>c4b<3Hg>30a<B`i<34c;2d`oS8`=30];SDa<Blc
>CPh=S@g=CLl=3/j=Rhm=T4n?3`i?3E3?cTj>3Hi@cm1@C/i?4I:?gm3@TDm@D57
>C/m=3Dm?chi=cLi=SDh?d4m?SLg>d93@c`h?CTk?3he>3@i=Slm@3Tg=S`j>Ce0
AT0k@3he=T0m>CTg=CHmAnWVi^O/g=oRhMnWXJ6^WZJRYk2`Z[6TZZ^h/:b][KVd
^3P_=cDa<B`a=2l_=34_<2hg;c<b;Bda;QLa<3P_=30k<C8`=SLh<34a;3T`<C</
;C3n<V@d<2d^=C4a;c<i>3Pf=3Le=c`d>cXf;Sdf@Chl?3Tl=D<o>CXh=SU3?d51
>cTlATXo@d95?D51AcTk?C@e?Cln>CLg>CHe>3m1?Chg=c]2@d<l>3di>c`n=CPd
>CHo?D0i=cHl>V<i?D16@3]0?SDf@3di>CLe=Se7jNKVincLgn;QgjNQXJjNYZ:W
/;2Z/JBZZkR`[:f]^KBh>2lg=C4a;34d;bld<Bl`;SL_<c8];C4^<C0h;c@`>c4b
<3Hg>30a<B`i<34c;2d`oS8H=30];SDa<Blc>CPh=S@g=CLl=3/j=Rhm=V=1?S`l
>C`e@cli>SPf>D<o@D4k>Ca6BSm3@TDm@D57>C/m=3Dm?chi=cLi=SDh?d4m?SLg
>d93@c`h?CTk?3he>3@i=Slm@3Tg=S`j>Ce0AT0k@3he=T0m>CTg=CHmAnWVi^O/
0VUogMkQhMJFUj2S[jbLW9ZSZ[bZYj2NWJfd/kB]XRla=CHb;R``;c<b<Rl]:bla
;2`a<R`[;38`=Rd^;c<b<S/a;Rl];cD/<2h^<2/Z<38^;SHb;blc<3<`;c4c=cTm
=SHc;bhk=cdf?3Le=3Tn@3Ta@3Tj>c/m@D12?CdiACm7@T57=STn@DTg>CTg?cdk
>cPh=SDg=S4h=CHm=SPm=cPj=CPj?d56>CXd=3dn>3Xl=C@c>3<e=2he<CDg>3`i
<S<k=c`j=Rlc>D3Wo^Hdj]gNhN7FUYNPXjn/W9bJXjZlZZNPWYf]];>d[J8_<CDf
<Rh/<2lc<S8_;B/_<B`/<C8/:bao<S0f;Bh_<c8b>c4^;bd_=B``;Rh`:bX`<Rh^
=S8_;c<`<c0_<C<g>Cdf=S<_;S/g?CHl=cDd>Ci0>C50>CXk>ce1@48m?CU5?dM2
@CHi?T59=cTi=clm>c/h>3He=cHa>3Df?CHh?CLh>SDh>Sm1ASTj=3@m?SPj?3Dd
<cPc=C@C;SDa=CLh?3Tb<c/g?3Xf;c<i@>OniVSZgMkQhMJFUj2S[jbLW9ZSZ[bZ
Yj2NWJfd/kB]XRla=CHb;R``;c<b<Rl]:bla;2`a<R`[;38`=Rd^;c<b<S/a;Rl]
;cD/<2h^<2/Z<38^;SHb;blc<3<`;c4c=cTm=SHc;bhk=cdf?3MO=C@i?T0i<D0i
>S/k?D50@Sdm>DDoAd91=STn@DTg>CTg?cdk>cPh=SDg=S4h=CHm=SPm=cPj=CPj
?d56>CXd=3dn>3Xl=C@c>3<e=2he<CDg>3`i<S<k=c`j=Rlc>D3Wo^H0jP9YOmoP
h^7EW:FMX:R^ZjbVXjN]/;>b]Jf_[:Ni_JDj<bla=3<c=c8a<3Xd;Blc>Bh];S@]
<bdc;SHe;c0d<cPb<S4^?S<];C4`<S4a<3Hd<2hg;bla=Bld<cHg=S/d=SLg;c8b
?S0k>cdf>3Xi>3Lh=44f?Ca1?Cm3B3Tn?d56ADE1Od16>Ce0?48j?3lk=d4o@C`h
=c4d>CTm@S/l>T0k>C8h>S`i>Se1=clb>cPj@S/`=cDg>3@g>C0i>cLh@T0n?cLl
?3Ti<c]6i^KXjNOOh>;QeIbUWJ2X[Z^/YZ>W[K2c/[F][jbW^KfU>S<_<C@c<cLb
<C0j=2d_<cT^;Bhd;C<]Oc<^=SD_<3@c>38b<Bhn<bd]<C0b<C4`=S@`;SL_;c4e
;c@c=SLf>c@f=cL_<S8n<3/k?CHh>STh=cPd@CHm?44m?d=8>Cho@DI5AD50ASTm
@3a2>S`o>cM1?d4l>3La=3Ti?D8k?3Y0>cTb>3Xl>CXm@CLo<S/h>T8k<3Le=cPd
OcLi<3Tk=cQ2@3ho=c`l>CTc>dKVi^SYimoPh^7EW:FMX:R^ZjbVXjN]/;>b]Jf_
[:Ni_JDj<bla=3<c=c8a<3Xd;Blc>Bh];S@]<bdc;SHe;c0d<cPb<S4^?S<];C4`
<S4a<3Hd<2hg;bla=Bld<cHg=S/d=SLg;c8b?S0k>cdfHcPj>CPg>3A1=Sdl@Cdo
@dPi?Sm1ATE5@D16>Ce0?48j?3lk=d4o@C`h=c4d>CTm@S/l>T0k>C8h>S`i>Se1
=clb>cPj@S/`=cDg>3@g>C0i>cLh@T0n?cLl?3Ti<c]6i^KXjNL2JOoP;moQf9VK
WZnXY9fLVjfe/:BRX:Nb^[JbZjEA>cPg=C0b<CD_;c4b=C4_=CD];BHb;Oh^9Bda
<c8^<S4d;R``<Bhe;2/d<c<^<Blb;c4_;Rh[<3<d<cDf<SHfoSDQ>2dc>CDf?CLf
=30f>CLh?CXi=chlBSdm>CTd?dI1?CHj?d4j?Sm1@cTe=D0l?3Hi>CLg=SHg;SLd
>C`j@C/l>D4m?3ll>CLh>CLe>DHm=Shh?3dm<S8^<S<e=cPg=C<d>cXo?S_n=cXm
@NGXinGZh>3OhMRIVij_Z:BMW9^]]K2TXZ2W/[Zf/Z^UDC/h=cD`<S4e;bla<SDa
;cDe;BdV<Rd^;RH^;C4c<Rhb<C@^;30a;SD/:c@c<bha;c8_<Bl^;R/`<c@c=CHb
=SKn=EDh;C<i=CHm=cHd<3Hi=cPm>STg?Sa:?Cdi>C@oAT4m=SXo>Sho@D<i=CE0
?3`f>CTg=cHf=bhg=3Tl>T4k?3U1?C`o?3Tg>3Tg=CU6?CHn>3`m?C8b;Pdb<cDg
>3Le<c@k>Sln>ohg>3e1iNSWiN[Ph=oQf9VKWZnXY9fLVjfe/:BRX:Nb^[JbZjEA
>cPg=C0b<CD_;c4b=C4_=CD];BHb;Oh^9Bda<c8^<S4d;R``<Bhe;2/d<c<^<Blb
;c4_;Rh[<3<d<cDf<SHfoSD9>2dc>CDf?CLf=5T`=STg>3dj>CLn?4Xm?CTi=3m6
@Cdf>Slj?Sm1@cTe=D0l?3Hi>CLg=SHg;SLd>C`j@C/l>D4m?3ll>CLh>CLe>DHm
=Shh?3dm<S8^<S<e=cPg=C<d>cXo?S_n=`Hm@NGXinGZ0VWogggQh]fSX9VTZ[VZ
ZJJUXkJf/;BVZJfc][f;@3Tb>3Pi=3<e<S4]=Bl^=3Dc=2/a<b`^<Rl/<34d=3Hd
=S0/<S<b<34_=S8d=c<g<C@f=C4b=34_<3Ho<CLd>3Ln@cL`?c8e>T8j@SLc=CXj
?T4l@3`i?CdkAC`n>TM3@414?cYoAC`l?dA1=SU2?3`o>cXi>SLg=C4j>3Pm?3dn
@d8o>40l@c]8>C`h=c/n>D14@C]7>cdi=3Pf=c8g?450@Si1?3`k>C`j?4GWj>KY
jmoOhN;MXj2IY:ZiZZVVYJ>f][2dYZV]/kJmRd0i<SPh>C@c=C8a;CD_;S@e<c@[
<C</;S9o;b``<C@d=S@f<2`b<c8`<Blf<S@g<cLa=3He<C8d<Bl`=Sla=c@h=ci3
=c0o<SDj@SY2=c<e>SXn@Ca0?3Tm?C]5?3hjAd=0@4@o>TDl?3m4@CHi@S`l?c/j
>CXg=cDa>SPh?C`m?T=2?cQ0?4<kB3Tl>3Lk?SU0A44kAc/m>CAo>3Hg<SLl@D12
?T4l?3/i?3XlANOXi^W[gmoQh]fSX9VTZ[VZZJJUXkJf/;BVZJfc][f;@3Tb>3Pi
=3<e<S4]=Bl^=3Dc=2/a<b`^<Rl/<34d=3Hd=S0/<S<b<34_=S8d=c<g<C@f=C4b
=34_<3Ho<CLd>3Ln@cL`?c8e>T8j@SMS<cDj>Si1?40l>Cdm>dDl?SY7@d10A3lj
AC`l?dA1=SU2?3`o>cXi>SLg=C4j>3Pm?3dn@d8o>40l@c]8>C`h=c/n>D14@C]7
>cdi=3Pf=c8g?450@Si1?3`k>C`j?4GWj>KYj`9Yomdjhn7LX:NYYibOXJFX/:Z/
W9nV[;V^Z:JZ@Chc;S0k?3hb<c0g<Bh/<B`b<S4a;R`X:bh^;B`b<SPe<SCn<3lb
;bd`<34b<S0_<2lc<2h`;c0a<c0`=S4f>C/e?c<c<3H`<CLi=C4g=Ca1?CHh>c8i
?d0n<cPf>CM1@S`j?C/jOc`h@STh>CTh@Slg=cPi@C`m=c<b=CPh>Sa0=3Ld<cTi
?T8j>SPi>D0k?C@k?3Xi@3di>SDa=C8a>C/n?3/l?3Tg=cPh=ca;iNCUinWMgN?Q
g:2WZJNLWj6UZ;2Z[9bOYZbi[ZRVZT4n<bh`>c`n<S<`=c4^;34/<S8a<Bh/:2/^
22h];38b>3Db=?h`Lc8_;C0`<C8b<2l`;c<`;S0_<34c<30f<CHi>cDo<c<`=S0a
=cTe<CLe?44m=SPk<STo@3hc>3Hi=d52?3Xm>cXl>48i>3Ti>48o=cLh>D4l?CLc
<SDh>3Xl@3@g=3<i>Ci2>SXh>CU0>cdd>c`j>D0m>CXeE34e<S4i>chl>c`l>CLg
>3Pg?4_Ui>GWjMgMhn7LX:NYYibOXJFX/:Z/W9nV[;V^Z:JZ@Chc;S0k?3hb<c0g
<Bh/<B`b<S4a;R`X:bh^;B`b<SPe<SCn<2Lb;bd`<34b<S0_<2lc<2h`;c0a<c0`
=S4f>C/e?c<c<3H`<CLi=C4gHcDl@Cdf>3/b>Cm0?S<h=STg@D8l>Sdk>S`h@STh
>CTh@Slg=cPi@C`m=c<b=CPh>Sa0=3Ld<cTi?T8j>SPi>D0k?C@k?3Xi@3di>SDa
=C8a>C/n?3/l?3Tg=cPh=ca;iNCUinT2J@COh>;Rh?jL6iRCYJVUY:ROWYfd[jFe
Zjf_T3/h=3Hc<S0`=3cn;R@/<C0h<C@a;38a;Bh/:R`c<C4c<S<a;bhc<c4]=b`c
;c0^;S0eoRh`=34b<C0^<Rdf=C@g<CHe>S@e>3Pk>CTg=c@f=cHm?Sdg=CLg@3Pl
=cPh@D0k=d0oAAE5>Sdg>CTl=3Xg=cDl<C/g>c<k=cdjoSHH>Se1>cLf>S]0?Sdj
>SPi?3/h>Sa0>C`j>Ohk6cPg>CLh>c`o>T0l?Chk>CLi@^KVinO[gn3Rh^3nW1^H
TjFYYJBXWijM]:nU]J^][i0k>3@f<c8`<3@loRh<;34`>34d<B`b<Bd^;1LZ;3<a
<C<b<c4_;S<c<Bdg;3<_<2h^<3Gn;THd<C8a<2hb;CHe=3La=SDj=3Dh>3/i>CLg
=3Hg=Sdn?CLe=cM0>3`g>3Q1@3/g@3m5ACXm=cTi?3@j=cLe?34k=c/c>cLm>_hf
6SXm@C/g=SXk@3hm>SXh>C`k>3Xl@3Tl>STk>a`k>3Li=cPk?3lj@3`m?S/i=cU2
i^KWin_Oh>;Rh?jL6iRCYJVUY:ROWYfd[jFeZjf_T3/h=3Hc<S0`=3cn;R@/<C0h
<C@a;38a;Bh/:R`c<C4c<S<a;bhc<c4]=b`c;c0^;S0eoRhH=34b<C0^<Rdf=C@g
<CHe>S@e>3Pk>CTg=bdd=SLf?Chm=cDg=d0h?3Lh>450>cM0?dE5>Sdg>CTl=3Xg
=cDl<C/g>c<k=cdjoSHH>Se1>cLf>S]0?Sdj>SPi?3/h>Sa0>C`j>Ohk5SPg>CLh
>c`o>T0l?Chk>CLi@^KVinO[0VUog]oQhm^ZZZjWVYJLZ[2mZjNFX:>_`;Ng/GHj
>3Tg=3L];c4c;b`a=2ha=S@`;CD`;R``;B/X<Rlc=d4a;2`^<2hf>S@];SDc=34`
<CLj>CTc=2X];bh_>3Da>CXh=CHc=She=S`g>D56>cTk>CXh>cTn=Clh=CA0?TI3
@3e3A4YoBclm<cPo>3Ll?3Pj=cHg=Shk?3@i=S@h@d8f?CLf=SPn?D8l>cPoADQ2
@C<f?4Hn?Se1=CLg>3hj<cTf@d5L>Ce2?3dfA4WViNOZkMkOhN?KZZZ^YiZFW:Z`
_J^WUZ2S[l2g]k5f>SPi=c@g;Bla<bl/<C@^<CHd<2de<2h/<2eo:bPb;c<g@C4/
;2h`;SHj=2d^=C<d<C0a=cXi>C<d:Rd_;Rlh=C4i>SPe=S<f?SDf?3Li@DHk>C/i
>SPk>Che?cPe=40nAT=0?D=4BT/o?C<h?cPg?3`h>SLf=cHn>c`d>CHd>4=2=Sdg
=SHh?Se2?3/h?dE8@T4c=Sa6?Shm@CGo=gdh?SXc>CI3@E`i?D8l?CI4BNKUin[]
g]oQhm^ZZZjWVYJLZ[2mZjNFX:>_`;Ng/GHj>3Tg=3L];c4c;b`a=2ha=S@`;CD`
;R``;B/X<Rlc=d4a;2`^<2hf>S@];SDc=34`<CLj>CTc=2X];bh_>3Da>CXh=CHc
=She=S`g>D5SAS/i>cTj>3/i?SDo>3Dd@3i6@d0m@dA:Bclm<cPo>3Ll?3Pj=cHg
=Shk?3@i=S@h@d8f?CLf=SPn?D8l>cPoADQ2@C<f?4Hn?Se1=CLg>3hj<cTf@d5L
>Ce2?3dfA4WViNOZk@9YFMgOhN?FW9fMUY^QW:B/YJ2JZ:FRYZJX[X]3=c``<cDg
<STc<S4b;c4`<CHb<c8_;2d]<c8^:c8^;S4f;R/Z;c0b<2l`;Rle;c@f;bl^<3<e
<2/_;c0a;c<i<_hd8Ri0<3@f=C<h=cPk?3Tg=SLk@T4l?STo=CLl?3lj?T52AT54
Oc`j>3Te>CTe<c`i?3Xi=SHl<cPd>C@`<c/o=chf>S<c=cdl?3/l=cdo>cXk>Slm
?3]0AcLj>3`a<CHk=chi?SXk@3/h=3]:iNGWi^WMgn7SeYbMWIJKXIbT[:FPVZRU
XZJVZ:j;@cLl<3<e=c8i<c8a<Rla<34f<S<b;b`];C<b9Bh[<Rh^<CH^:bX_<38`
;c0^;cD_=3H_;bh`<cD`:bl_<34_<cTboSAF;T0`=3He<cPg>3/l>CLf=c]2@C`n
>Cle=c`l?cXn@D96@D@l>SPi=CTi=C<l>C`j>CHf?3<h=3Td<3<k?cLn=SXc<cLm
?3`k?3Lm?c/j>cXo?C`k@4LgLCXh?34a=S/g?STn>S]0>cPd>d[UiNOVjMgOhN?F
W9fMUY^QW:B/YJ2JZ:FRYZJX[X]3=c``<cDg<STc<S4b;c4`<CHb<c8_;2d]<c8^
:c8^;S4f;R/Z;c0b<2l`;Rle;c@f;bl^<3<e<2/_;c0a;c<i<_hd2Ri0<3@f=C<h
=cPkHc`i=cHg>d91?3hi?cDg?3`o>Si1@TI1A3`j>3Te>CTe<c`i?3Xi=SHl<cPd
>C@`<c/o=chf>S<c=cdl?3/l=cdo>cXk>Slm?3]0AcLj>3`a<CHk=chi?SXk@3/h
=3]:iNGWi^T2JGoMgn7Rd[:/YJ2EVj2/^:jUWib//K>/ZK1N>CTe<C8`<S<d=c4d
=38a<3Le=30_;R/a;38b<bd^;3@d?C0c<2lc<S8]<R/^<S4`=Rh];2da<c4c<Bda
<C@d=SDi=S@j=C@m?3/g>S8a>CPk?3Ld>3Q:@3/g>3hf?4M3=cU1?Ci4CGm2?cTh
>S]9=SLo?3Xo?Cdj@3Xn>STo=3Pf?CA1@T4i>c`o=3Lj?T4o@3Pd>dM>AT8k?T<i
@cXi=c@h>cdi?T<g@c/l>3/lANCXj^SYgMoQh]:b[:FPUI^P[;R^YInL[;6c[:V`
GSTi=C4b<38c=3La=3@b<C0g=C@`;bh[<B`b<Wlc;Bh/=3@m<3<`;c<b<Rdb:bhb
<C0f;Rd/;C4c<C<a;C4a=3@f=CTf=3Xe=3dl>cLj<S4i>3/l=c@h>4Y0>cLh?SHl
Ad<g>D4m?TA=@Sli>3XkBCHg?c`j?cdm>T0j?SXi?c@h=Sdd@D91>C/l?c@g>Si1
?d0h=3]7CTI2>ci3>Gm3>STg=3Pk?CTn@cM3>c`h>ca5i>SZj>WMgn7Rd[:/YJ2E
Vj2/^:jUWib//K>/ZK1N>CTe<C8`<S<d=c4d=38a<3Le=30_;R/a;38b<bd^;3@d
?C0c<2lc<S8]<R/^<S4`=Rh];2da<c4c<Bda<C@d=SDi=S@j=C@m?3/g>S8a>F<h
>c`g=3PhBT0k=cPn=Sa7@cLi@CdnA4e2?cTh>S]9=SLo?3Xo?Cdj@3Xn>STo=3Pf
?CA1@T4i>c`o=3Lj?T4o@3Pd>dM>AT8k?T<i@cXi=c@h>cdi?T<g@c/l>3/lANCX
j^SY0VU=gMcPhLjOUI2IVZ2OWJ2HY:ZTYjFUWZ6c?CLa:C0e;C8b=C4d<S8];Rhf
<2/];2l_<2d]:bh`=bhd;SD`;2h^<Rl[:bd/<C4^;S@^;S0boS0^<c8b;C0c<S8f
<C@m>C8f>CXh=3Hb=cDc=cDf>cLh@3Pk?CTj?3Tk>Sdn@3ln>d=o>cQ0>3lm?SPh
>T0n?cLo=STg>S/g=S4i=cH`?cPk?C@i>3Li>d4e>Sdn>Sho@T8kA3e3>C`e=S4j
>CDk?D8f>CXl@CLh>4SQhnSVimgLh>7>WiF@VIZPWifPV:BZY:NUYIjQ/cdg<BT`
=Bdb<SDa=38b;Bh^=S0[;B`_;c0];B/I;S0g;S@^=C0/;Rhb;b/[;B`a<Bh^=2h^
<3;n<68c<S8]<3<b<SHa=3di<SHi>SPd=S8g=C<g=CHk=cQ0>3/m>CXl>C/j?Ci0
?chk@c/h@3Po?Chh>3Y0?Slg?cHi=cXk=cHa>CLf<3lh>cdd>CPg>C]1=CXm?SXn
?d92>d@m@cUU?3Df<CXi=C/m@SHi>Sa1=cPhB>7Sj>KWgMcPhLjOUI2IVZ2OWJ2H
Y:ZTYjFUWZ6c?CLa:C0e;C8b=C4d<S8];Rhf<2/];2l_<2d]:bh`=bhd;SD`;2h^
<Rl[:bd/<C4^;S@^;S0boS0F<c8b;C0c<S8f<C@m>C8f>CXh=3Hb=cES<cLe=S/g
>40h>cdi>S`i>cXm?T0o?S]3>cQ0>3lm?SPh>T0n?cLo=STg>S/g=S4i=cH`?cPk
?C@i>3Li>d4e>Sdn>Sho@T8kA3e3>C`e=S4j>CDk?D8f>CXl@CLh>4SQhnSVi`9Y
omooh3OCZj>ETI>P[[B_W9jEW;BfZJJ_QCHi=3@a;c8`=3Dd=cHc:blc=3@`;bha
<cPb;Rd`=CT^>SQ2<?ha;3Lf=S8a=C4d=3<d<SL`<S8_<2l`=c8g?3H_=3Lc<34f
<c`g>C8b>C<i@CHd<?hm43lj>CLj=D4l>cLh>c/mAD=3OcXd=3Lo?4<j?cHl=cHi
@Cll=3@e@cLg?3/j=3I>@DQ0Acla>dI:?Cdl>STnAci2>d50?412>CLf>3Tb=T12
>SXn>4I1>CiBi>KZin[Ogn3Pdj^SUI6CX:jd[ibNUIbd]ZVV[hDf>C@d<Blb<3@e
=3Lf<b/_<c@d<2l^<C<h<Rh]1c0e>Bhj>48`oS4/=cHf<S4e<C@d<c@b=c0b<Rl`
;c0g<SLl=Rld=c<`<CHc?3Li<S8i<cU1=S@`oSe4?cXi=cXe@C`k=cPk>ce5@d<j
=3@g?ca3>Slf?3Lf>D4o?3@d=D<g=c`k>S@fCT58@4Lo<C]6BSdm?3Xi?TLn@S]1
@3a0Dd8i=cHh>C8f@48j>ShhAT4i?U;Ti^[Wj]oOh>3CZj>ETI>P[[B_W9jEW;Bf
ZJJ_QCHi=3@a;c8`=3Dd=cHc:blc=3@`;bha<cPb;Rd`=CT^>SQ2<?ha:3Lf=S8a
=C4d=3<d<SL`<S8_<2l`=c8g?3H_=3Lc<34f<c`g>C8b>C<i0d4f=33n?E`o>STg
>SE1?3/g>3/k?DE3@cXd=3Lo?4<j?cHl=cHi@Cll=3@e@cLg?3/j=3I>@DQ0Acla
>dI:?Cdl>STnAci2>d50?412>CLf>3Tb=T12>SXn>4I1>CiBi>KZinX2JGoLg^;P
eYBGVYnPW:2SV::ZWI^QX9RU[V`g=c0`<C@d<c8^<2la<c4_<C0_;Rh_;S0`;bl]
;c8a<3Pe>SDc<S0a;bda<c4]:C8c;Rda<C8`;C0a;C<d=CLh=SHb<c0`=2ld>CPb
>3Pd=C@e=C<f?SLl>3Ti<c<g?Cll?3Q1?D0i>7lf@Shj>cTg<chk@S`h=3Xc=S/d
=2la=cDg<S8f=S/h>C`n>SHi>cHm@4Dl>SXg?c/i?c`g>CTg>CDe>CXo>SLlB3Xm
>cTkE>GRjNWZg=kRh=JDUiZOX9bPXiRRZYfKXJ2HYJi/=cL`<34d=3<b;S0_<C<a
;c4`;bh^;bh`<2l_;Gl_<S4`>3Dj=C<b<34_;C4c<BdY<S<^;C4a<S0]<34]<c@e
=cPf=S8c<30d;c@i>38h>3@e=3De<cHn=c`h>CTc<cLm?c`l>44m@3Th=T8n>S/i
=c<n>d8l>3@j<cHk=3@_<CLe=c8b=SHk>3Tl?SXf>C/f?D15?3Xj=clk>Cll=oli
OCLi=CDi>Slj=ca8>Sdk>C]DiN;YjN[Lg^;PeYBGVYnPW:2SV::ZWI^QX9RU[V`g
=c0`<C@d<c8^<2la<c4_<C0_;Rh_;S0`;bl];c8a<3Pe>SDc<S0a;bda<c4]:C8c
;Rda<C8`;C0a;C<d=CLh=SHb<c0`=2ld>CPb>3Pd=F<d=CDc=Shg?3Pi>C<c=cdo
?3`h@Ce0>CPf@Shj>cTg<chk@S`h=3Xc=S/d=2la=cDg<S8f=S/h>C`n>SHi>cHm
@4Dl>SXg?c/i?c`g>CTg>CDe>CXo>SLlB3Xm>cTkE>GRjNWZ0VT0gokPNmfIVHnC
WJnaZIFJXJjd[K>OWJ5R=d<e=30g;SXc=CPj=cXh=CHd=S4a<S@Z;Rdc=CDd>S4b
=cdf<S8a<C0a<Bh`=Bd`<S<^;2db<C8a<Rda<cHd>T4b=2l]=SPi>3Xa<S`m@3Hd
=3Pe>d<m?cHc>CPi>c]4>34hB417>cOo=bLl>C`l=3<g=d=2@3dk?SPf>CTf<C@c
<cTi>cLj=T@i>TLo=C`i@S`noT@O>3dg>S]8>dHh=SLi>Ci5@CXg>DU:AClj?5?X
i>K[kmonh2oMVIV?Tif_/JVEVZ6^]:fcWifQHSM3=C@`=bhj<cDh>SLj>3Df=3Ha
<C8d:Rh]<cE:=C@j<C8g?CHb<S4a<34a;S0e;C0b<bh/;C8a<S4b;C4c=S@j@C8d
;bdf>3Th>S4b?3e0=S@d>3Dk@cdo=S<i>3Tk>d@h<CQ8@4LkoSLW?3Tl?3@c=cM3
@T0m>chh=STi=S4d<c<i>C/g>SI4>CY7?cDl>D8l?_i41SPm=cXkB3/HASPf=cTi
?TE1>SLiBDY5?cXlDnSTi^__gokPHmfIVHnCWJnaZIFJXJjd[K>OWJ5R=d<e=30g
;SXc=CPj=cXh=CHd=S4a<S@Z;Rdc=CDd>S4b=cdf<S8a<C0a<Bh`=Bd`<S<^;2db
<C8a<Rda<cHd>T4b=2l]=SPi>3Xa<S`m@3Ko=1@h=C]3?Clf<cTh>C/kA3Pa>4Q0
Ac_n=bLl>C`l=3<g=d=2@3dk?SPf>CTf<C@c<cTi>cLj=T@i>TLo=C`i@S`noT@N
>3dg>S]8>dHh=SLi>Ci5@CXg>DU:AClj?5?Xi>K[k`9YKmgNg^3IWZBKUiZJU9:F
Y9jUXZ6KVJJdM3Xi<STd=Bd]<CHeGGR<Sh>6ED0h;S8`;S<]<2h_;c<g=3<`<SLa
;30[<38f:bdZ<38c<2`_:bdi<30a<cPh?3Td<Shf=c@`<CHk?STh=C`^;C@e<SXk
>3gn>olj2Sdk@3Q0?dA2@cPjOc/j=c`k?3La?3Y1=cdl=cHk=C@j>CLe>S8g>SLf
<SDg>D0n>c/g=SLm>C/j?Clk<c`k?S`l>CPd>3<m=STm=cE9@Cm0>3IAi>CXj^_M
g]kPfIjTViNJVYBBUZBNYJ:QViVV]7@j>C8i=3D];C4f=EehS8n3QUE0>2hb<2hc
;C0^obli<cLd<c0b=c4/<2/`<SH[;BX`<S<`;2l[;CT`<34c>3Pl>C@b?SHg=30a
=S/n>CPe?2h]=3Db>S/h?OhkocXn?C]0>40oA493>3Xk>SLl>c`g<C`j@CLm?3Lf
>cDd>STg=CXb=cXg=S8e=cU0?S/k=cHg?CTk>Sdo>c<l>chlOc`i>3@h<cdf>Cdg
=DU1?d0h=U7Ti>SZjmgNg^3IWZBKUiZJU9:FY9jUXZ6KVJJdM3Xi<STd=Bd]<CHe
GGR<Sh>6ED0h;S8`;S<]<2h_;c<g=3<`<SLa;30[<38f:bdZ<38c<2`_:bdi<30a
<cPh?3Td<Shf=c@`<CHk?STh=C`^1bdd=C8j>cPmoS_o>UHm>d0h@3m4@T<h>S/j
=c`k?3La?3Y1=cdl=cHk=C@j>CLe>S8g>SLf<SDg>D0n>c/g=SLm>C/j?Clk<c`k
?S`l>CPd>3<m=STm=cE9@Cm0>3IAi>CXj^/2JC;Mg^;Re9>KUj2OZZ6DTYbT/kJT
W9RY[H@b<34^=C@`<2meLG5VMJC3b^?GH3db?S4_;COn;dTf>CDb;S@i<cHd<C4b
=cD`;38c=Bh];c4_<S0/<38e=cLf<3Hd<C@e<c91>3/f?Slo<cHe>Sa4ACTl>3dj
?Ce0>cXj@cm3@DXj?WlnA4HlB3Xf<3dmAc]0=C@e>3`i>3Xh=cHj=STg>cTn=S97
@D18?3@e>Se2?CLk?3U1AD<i=CHo>cla?3hj=3@jATQ?>CXmF>CVj>SYgMkRh]BC
ViNPWjZQU9:LY;>fY9bHZJf4<S0a;SDd<30_MG5aIWFT`l[Sef0m<Sha;bdg;ol_
OCHi=C8^=3Tc=S@a<C8g=C0/<S<e;Rd_<Blb<2``<SDg=cH`=S@a=3Dc<T4h>cHn
?clc=SDj?4A5>C`h?CXm?D0k>SY3?d=1BSXn?TA6?4Pj=S0m?DLk@3Dd=CPl>CPj
>3Lf>SHi=c/i?SHbAd50B3`d=CXm@Sdg>c`i@DE3>DXe=Slk?c4l?SXd=3Y6B4li
>SeHi>KXj>WMg^;Re9>KUj2OZZ6DTYbT/kJTW9RY[H@b<34^=C@`<2meLG5VMJC3
b^?GH3db?S4_;COn;c4f>CDb;S@i<cHd<C4b=cD`;38c=Bh];c4_<S0/<38e=cLf
<3Hd<C@e<c91>3/f?Slo<f<f=CXlA4Di?3Pm>Sdm@3/j>T<o@d5:>ShnA4HlB3Xf
<3dmAc]0=C@e>3`i>3Xh=cHj=STg>cTn=S97@D18?3@e>Se2?CLk?3U1AD<i=CHo
>cla?3hj=3@jATQ?>CXmF>CVj>SY0VUogMkOgm6QWI>HUIJFWj>DUZFCUYbYZg@j
<C8a<c<a<3e?JfQ`IFQWG5=bgKUfB3lb<B``;2d`<Rl`<c@f<2la<38l=bh]<SD[
<2h`;2``<2l]<38j>S8i;c8j<38f;c<c=c/i=cXb=CPj<CTk=CHh?3Dj?3Xg?3ll
?D0l@Cm1A41o>Si3=cll?cPi>SDi>C<f<cHh>SLg<cHa=SPc=CHh?Sld?Chn@3hm
=C4h<CLk?3Xg?C/m>3Xj>c]0=CPj=cDd=d4l?chh@5SUinSXjMgNgmoAXIfCV9FF
UYnSU9JUTiJLZJ]d>S4b<C<c<C0mCf]XL6EXIeaCL]fiMTPo<S4/<2ao;C0b;c0c
=3H`;c4`<S`g;Rdb=B/`;S0/;30`;bd`<SXj<ST_<SX`<SH_<c<g>cTg>S8e>3Xa
>C/e=SPl=CXl>SLl?c`m@3a1?d54@3Xn@cLo?3lh>CXe>CTc=S<f>3Xg=c<f<CHh
<cDf>3ho=3dn?T0n?CDa>34g>c`j=cdk?CSo>_lkNd0e>3Xg=C@g@C`o?SQ0F>GW
j>SYgMkOgm6QWI>HUIJFWj>DUZFCUYbYZg@j<C8a<c<a<3e?JfQ`IFQWG5=bgKUf
B3lb<B``;2d`<Rl`<c@f<2la<38l=bh]<SD[<2h`;2``<2l]<38j>S8i;c8j<38f
;c<c=c/i=cXb=CQS>S4i>cDf>3`e>S`j=c`o?3e0?44o@DA0>Si3=cll?cPi>SDi
>C<f<cHh>SLg<cHa=SPc=CHh?Sld?Chn@3hm=C4h<CLk?3Xg?C/m>3Xj>c]0=CPj
=cDd=d4l?chh@5SUinSXj@9Y0=knh3c8SiVTZJ6JTYZLXjF^UI6?VK5P>3<k<SHd
@3aSGEYCGV5aLVmGE8Fgelb@=CHb<C8`;C<c=C@g<S/e<S8aoSDk;S@b;S8e<cLa
<C<e<34c>CdjAS8g=CLi>3/g<STg@dA3>cHf>CXk>c<f>3PfAClk>SXo>3Xn?TE5
A3/k>C`mACa0>SHb?cPo?3d`>Slf?CPd@c<g=CPj>CTl>c/n@48m>44l@Si3>c4e
<3<g>SY2>CLi>D8m?DGn>@lcA4==?T0h=4ENjNWZjN_No^0_b8nIY:VQVY:JW:>U
[YFASiVaH3Pc>c8f=40lHeeJDeiQLG9_EeB5]mO<T3Df<S4b330]<c<e=3Lb>cDb
<S7n=Fl^=38^<SDc=c4a<cD`<C<i?CY6<SLe=cTh>cLb>CM3A4<k=SHi>S/k<cHh
>3I5?c/j>Slh>ShnADE4>c/l?DDl@3Xf<Slh?c`m<3Xo=Sdh=4<c=cDh>STi?3/k
?T12?CQ1?48n@c/a=C0c=cXj@STgocT3@SdmAOhi3c=4@ddn@3PdAEkYjN[Yjmkn
h3c8SiVTZJ6JTYZLXjF^UI6?VK5P>3<k<SHd@3aSGEYCGV5aLVmGE8Fgelb@=CHb
<C8`;C<c=C@g<S/e<S8aoSDS;S@b;S8e<cLa<C<e<34c>CdjAS8g=CLi>3/g<STg
@dA3>cHfDCTj>c/c=SPh=TDo>cXj?cPj?Si5AD@k>c`mACa0>SHb?cPo?3d`>Slf
?CPd@c<g=CPj>CTl>c/n@48m>44l@Si3>c4e<3<g>SY2>CLi>D8m?DGn>@hcA4==
?T0h=4ENjNWZjN/2JGoLgn3NbiVJVIf>UJ2SV9BOX9^FVIZ`<c<g<SHd<DAFGF5S
KVUQGTaBDF1LKY34Zcdj<2l^;30f<38c<38e=30b<C4/=Blb;Bl/<Bhc<C<^<C4`
=3@a=cLf?3Di=CTg=cPk=S`g?S`e=cXf>3Dg>C`j>D4l@CTk?c`h=cY0?C/k?@Ph
?Sli?Shi>C[n=bY1=T<m>3`k>Cdg<S8e>cPn>CTn>Ce1?456@4=0>cdm<cHc=3@h
>C/j?3PooSe5>3Td=CLi>C/j?S]4G>SXjnWZg=oPg/^IVYVMSYFPXiRDWj2KUYVJ
/3<c=c8f=354EUeQHfiYHEi<DU5PG6j@a:/m>S0_;U@/<3H`<S<`<SDd<38a<B`e
;c8];b`a;S<a<bha<C0d=34g=cHl=CTe>CLg>3/f?3Ln?3Dg>SHh=CLi?3Xi@Ca1
>C/o?3Pg>T0m>c/m>3ho>Chn>CTjoSLW@CI3?CPl>cTm=c8b=C/h?STi?STm@Ca1
AT13@3/m?C<f<c@d>3Tk>P8l>3on?GTh>C@e=cTi>cXn>dALj>S[jN[Lgn3NbiVJ
VIf>UJ2SV9BOX9^FVIZ`<c<g<SHd<DAFGF5SKVUQGTaBDF1LKY34Zcdj<2l^;30f
<38c<38e=30b<C4/=Blb;Bl/<Bhc<C<^<C4`=3@a=cLf?3Di=CTg=cPk=S`g?S`e
=b0j=SPe=cTl>SU1?44i>cll>3Lj@3dk>cdh?Sli?Shi>C[n=bY1=T<m>3`k>Cdg
<S8e>cPn>CTn>Ce1?456@4=0>cdm<cHc=3@h>C/j?3PooSdA>3Td=CLi>C/j?S]4
G>SXjnWZ0VU>gm[Ph;m^M81lIfUWMGR1Sh5]K7:1S3Le=38e=EUnN5iOHFQlS8AB
BTaDLGahSmYC=30g;S8^=30j=3`c>S@]<C@a<c<_=30`;S0b=3Dc<Oh`oc`[=SDg
>cPc?3hm?3Lg@c`o?C`j?SPm?C/e=CLgA3I4?c`h=cdm@D91@cLi?DXA@DI7>Sdj
?Cdg>S/f@C`m?STioSSo<fPk?SPn?STm@U9;?ci2AD51BTA3A3Pg<S0k?cTj>3Pg
?d0n?c/f?40f?3dk>450AFCXjng[k=oJh>2oKWB0O6MYIgEhPHn1KFabPH`g=C@b
=CEIOWQNGf5XO8b4DTY<E75lN8oJDc@`=bhJ<Rhd<3Xd?3<j=2da=34c<bld<30^
<38d=C<aoS3o?3df=CLk>3<l?Sdl=cM3?3lm?3Xn>3dm>cDe=cM4=T@o?3Pg?Ce1
@T53=cTmBT56AcXm>Sdm=cXk=T4l?Chi>Ohhoc<L>chh?Shi?D9BBcln@TE1@DY4
@d@h=c8`>cli>SQV>3Lo@3ho>cHl@3Hl?C/h@D15I>S[kN_/gm[Ph;m^M81lIfUW
MGR1Sh5]K7:1S3Le=38e=EUnN5iOHFQlS8ABBTaDLGahSmYC=30g;S8^=30j=3`c
>S@]<C@a<c<_=30`;S0b=3Dc<Oh`oc`C=SDg>cPc?3hm?3Lg@c`o?C`j?SSo?BLk
=CDg=d@fA3ll>3Lm?D52@D<g>Ce:@DI7>Sdj?Cdg>S/f@C`m?STioSSo<c@k?SPn
?STm@U9;?ci2AD51BTA3A3Pg<S0k?cTj>3Pg?d0n?c/f?40f?3dk>450AFCXjng[
k09YOmoIgmjkATA9@T57B4]2@D=2@TE7@dLe=S8c=TEOHV1VIeeQJfe/Eda9D729
OgFQSTLb<C8d:b`X>C@f;Bh_;c4/;b``;bh_<Rl`;B``;R/b<c@d>S8`<C/g<cLg
>3Df>CTl?3Lf?3/g=cDi>34o?cdj=cHj=cdh>CXh>CTk?CdoOc/i?dA4?T4l?CXi
>cXf>3Xg>CPg>cLg>3@_=cXg@CHf<S<`>Cdl?4<oA44m>CP_<SLg>S`i=CLg@3Tf
=SU1>cLk=STl=T1Nj>[Zi^_OfMoN^dI4BD91AdQ;@T53@T95Ad=7=CHb<cI5Gf9P
IVMMHF]]K5M<BE1`RGmeXHi7<S4bOc@[;2Pi=3H];Rl_<B`_;30_;Rlb;c0];30^
:c8c=3@j<S0a>cLc=cLh=CHi>C`l=cHl>cLg=CTh<Clo?CXg=SXg?CPi>SPi>C/m
?Clk>Cm4A3i1?3dj>C/j=SPj=cTh=c/g=cPd;cLj=d4f=S8c<3Tm?3a3?dA1?CTh
;c8g=cXlOcTe=cM0>CHf>D4k=c/f>C`f@5kXj^[VjmoIgmjkATA9@T57B4]2@D=2
@TE7@dLe=S8c=TEOHV1VIeeQJfe/Eda9D729OgFQSTLb<C8d:b`X>C@f;Bh_;c4/
;b``;bh_<Rl`;B``;R/b<c@d>S8`<C/g<cLg>3Df>CTl?3Lf?3/gHcLe>CPa?clm
>SLf>SLm>3Tj>3Ti>cdm?c/i?dA4?T4l?CXi>cXf>3Xg>CPg>cLg>3@_=cXg@CHf
<S<`>Cdl?4<oA44m>CP_<SLg>S`i=CLg@3Tf=SU1>cLk=STl=T1Nj>[Zi^/2JD_K
f^7M^4Y7BD8l@4Q=BDA0?Sdo@4==<C<e>45kLG]UG5m]ET]fNEA?A4n>Uhn2MJW8
C3Ha<2h[;SLc<34c>c<_<38]<R`_:C8a;BddoSD`?3Pd>SLb<d0e>CLl=CPd<cPo
@3/j<cHi?3Dl=cHg>CI8>cTh>S/m=cY1?cXi>T1:Ac/o=Ci2@Ce??3/k<SLe=c]2
@S`h=3Lc?3Tg?3Hh>3/d=c8c>3Xh@T53@TPi@d];>SHc=cPc?Sdm>chf>C_n@_ln
?S4j@CU3G^S[hn;Xfm[QgKQ:AdU2?418CDU4@3hm?d13CC4c=CQ1Ng5kIEaOKEI;
MWUDCdA?SYN?PWFYb4`f<AL`;R/^=c<`<C<k<bl`<Rdb;2lY<S4];CCn=F@l>3@j
=c8c@3Di=c`e>3@c>3m0>cXc=STl=C`g=SLi=TPk>CPj>cdg>T4o>STj@4Y7?cDn
@T4mCc`k>c8g=CLk@T8l>3@g<c`i=c`f>3Pk=3Lb<cPj>491@d98>D=;BcXf<cLh
<`Ln?Cdk?SHi>oi2ociF<CY1>D=Nj>_Sh^SKf^7M^4Y7BD8l@4Q=BDA0?Sdo@4==
<C<e>45kLG]UG5m]ET]fNEA?A4n>Uhn2MJW8C3Ha<2h[;SLc<34c>c<_<38]<R`_
:C8a;BddoSDH?3Pd>SLb<d0e>CLl=CPd<cPo@3/j<cHi?5<e?3Lf=cTfB3/i>3Xk
?CLj@Clj>CY0BTLo=Ci2@Ce??3/k<SLe=c]2@S`h=3Lc?3Tg?3Hh>3/d=c8c>3Xh
@T53@TPi@d];>SHc=cPc?Sdm>chf>C_n@_ln2S4j@CU3G^S[hn;X0VTdg]gMg;A4
@C]9@TDoAD8o?T53AT8l?C@b=CQ?JfIHFG9YIe=9>V=GFDa8Oh2?R8j?cgTm<bon
;@La;Rh`=3Hf<oh^?3D`<Bh/:Bl]=3Hc;SHb;S8g<c<b<CXi=c<j>C@f<cPj@3Pg
<STk=3Xh>3Xf?3Tg<cPm?C`j?40h>Sln>3Yo>CXl?T4m@CXj>3Hg=CXj>D8h>SLd
<SLe<cdh=S8l=3/h>T0k>SHg>CLo?40o>cdd;c</=SXe>450>Clm?cHf>3Tb;SPf
>f7UjN?UiMkMgMbdA44kBD95?dE2?ci1@dI2?3dd<SDhCf]VF5UbJFMCBCYSEeU<
B7n0ShR>Slmi?C<0;oh]1c4^;S0d=SHcoRi`=C0a;R`Y;bdd=S<^=S8^<SLc<c8a
>STg<cXi=3Hc>3Y0>3Lb>C/d>SPh>SHl>CLc>3dm?3Xl@3Pj?chh>STj?3i1?D4j
>SPf=cDj>SU2>3Xg=38g=C<m>3Hb?3@k>3Y0>cXf=cTg?ca0?c/m=2lc;3I<>SDh
@D0i?cdo=SHh>C8^>3HkHNGYhnGUg]gMg;A4@C]9@TDoAD8o?T53AT8l?C@b=CQ?
JfIHFG9YIe=9>V=GFDa8Oh2?R8j?cgTm<bon;@La;Rh`=3Hf<oh^93D`<Bh/:Bl]
=3Hc;SHb;S8g<c<b<CXi=c<j>C@f<cPj@3Pg<SUS>c@j>3Pj=S`i=c<h?Cdl>Sa0
>3Xo?SPj>CXl?T4m@CXj>3Hg=CXj>D8h>SLd<SLe<cdh=S8l=3/h>T0k>SHg>CLo
?40o>cdd;c</=SXe>450>Clm?cHf>3Tb;SPf>f7UjN?Ui@9UGMkMgmngBTY0@3]=
B4E8A3`m?TU5A4@i<SY_Og5fE55RMh^;OdIQBDiEEfQnXGMkR[6QBcDf<CTj>S@k
=cXb>SXa<SDe=3@`;bT`<c@b;2/n@3`c>3Le=3Hh?3Hb=Ckn>P0moSXJ=Ce1?CDh
>3M7?D8g=c]1>cdj?Si0>Chl?3i12dTh>Ca1@D0m@3/e=_ho>3Tj>C/b?cTn=cTg
>C@i@SPg=38e?TA2>cDe>cLmCChn>cLg=C<d>cm0>cQ7?TE2>c8c<3lj>3mdiog/
<mkMgmngBTY0@3]=B4E8A3`m?TU5A4@i<SY_Og5fE55RMh^;OdIQBDiEEfQnXGMk
R[6QBcDY=S4i>SXd>cLj<SXj<C8e=C@d<2lY<3<d<R`[?T0l<cPg=C@f>3`f<SDn
oSX0?Ohj9SDm@Cde>3PgAce2=cLk@C/m>Shn@3Tn?3`n@DTh>Ca1@D0m@3/e=_ho
93Tj>C/b?cTn=cTg>C@i@SPg=38e?TA2>cDe>cLmCChn>cLg=C<C=3/o@3/hAci5
@S/b<c0o>SPoM>Omk5gNgMoO]dY:@40kCDQ5B4@l?Ci9ADA4>C8jKgmaMUAAHWN;
Rgm6HDU>EEMXOZ5gNhZaXD/e=S4i>SXd>cLj<SXj<C8e=C@d<2lY<3<d<R`[?T0l
<cPg=C@f>3`f<SDnoSX0?Ohj0SDm@B<m=CPh=dLm@SLg>d4k?CXn?T0i?S`l?T59
>3Tl@D50?D0k=CKn?cPi>STk<Sli?SLi=cTd>D8h=c@b=Ci4@S/e=C/g?Ddn?S/g
=cDc=3/o@3/hAci5@S/b<c0o>SPoM>Omk09YCmgLg]jWAT4n@Sm4@450>D95?T90
?T8e=dJ1K61@DVF3W9^>TTTgB5=CEFEADVV5SibSAC8c<S<b<Rhg<B`]=CPe=S4`
<3Hd=c4];cTa<C8ooSD/<C@g=3Lj>cTe>cLe=Rlb>SLf<STg=3Dh>cll>3Lg?3/n
=CDf=3Ld<STl?3Y1OcllA48m@Sdj?cdg=CLi>CLj>C<h=cLh=cHa=C0i=CLk>CDh
@Cm1>chf>CLg=S/i=chi<c@c<cHg@3`n?Slo@3i1=Sdb=d1Yj>W/kn[Mg=kNYdI1
?T8oA411@3U2ACi2@3i2=CM6PFaPD59UPibKSY99=dQCDeEUDE9YQHnLXdDb6c<b
<c8b;SLa;2de>3Df<C0`=S@g<Bd_>C4a<Son=F0a=3Ld=cXk>CDk=cDf;c8j=cHb
>CLd=CPk?c`h=cLl>che=CHd=c@b>C`l>T4o?4A2?D8m>Slm=cDg>CTg>STc>3Lg
>3Lf<CD`>CDg>cTe>44o@C/n=STg=cHk>CLn>C<doc=U=SM0?3hn?cm0?T4f?C8g
@6WXjNc_j]gLg]jWAT4n@Sm4@450>D95?T90?T8e=dJ1K61@DVF3W9^>TTTgB5=C
EFEADVV5SibSAC8c<S<b<Rhg<B`]=CPe=S4`<3Hd=c4];cTa<C8ooSDD<C@g=3Lj
>cTe>cLe=Rlb>SLf<STgHc@e>3/o?3Pg=c`k?SDe=S@g=38i?3`j@CllA48m@Sdj
?cdg=CLi>CLj>C<h=cLh=cHa=C0i=CLk>CDh@Cm1>chf>CLg=S/i=chi<c@c<cHg
@3`n?Slo@3i1=Sdb=d1Yj>W/knX2JF_Kg=gKYdY8?Ce0?D95?SPi?Ci7Achl?Vb:
SgU_CE=nShegNWYI?SE>@U1iF4Q?K7N9`5/e=3<`<S<`=30b<SHm=cLa;Rhb<3@d
<Bhf<c8]@S`e<c4g;cHc=SLe<STg=c<e<c8_;Blg>S/f=cGn=a0l>cHd=C/g>STd
=34n>dHm?gll>4=0@CTg=cHd>CPh=C/h=cQ0?cln?CXj<c@e=cdl@3Xe?cLb=cPj
?44d>cd^<C8k=cm3?C8a<cLk?Sdn?3dj?CPi>3XkJnKXk>c_fmcMfjM:B3dm@3e2
AChh>CdnAdLn?3i/RXmiKdeCOXn=MgYjFCheCT9@NEQ8CfagRL1K=CLd<c0b<c0d
<38b=Sdg=c4^;S8`=3@a;SHc<Re2?3Dc<CL_=S<f=cDb>CLg<cDc<Rl];cLj>cHg
=OhgA3`k=S@e>cLj>C@d<ChkASdo?3Q3@44i=cLf=3Th>3Dk>3Lh@3lo?Sdj>S<d
=CLm?40j=Clg<SLh>Sa1=3/m;S4b>cLo@glm<S4c=c/n?Chl?CXm>3Th>S][i^S/
k>oKg=gKYdY8?Ce0?D95?SPi?Ci7Achl?Vb:SgU_CE=nShegNWYI?SE>@U1iF4Q?
K7N9`5/e=3<`<S<`=30b<SHm=cLa;Rhb<3@d<Bhf<c8]@S`e<c4g;cHc=SLe<STg
=c<e<c8_;Blg>P<k=SLeoSML?3/f=3Dk=cXi=3@a?S]6?Cll>4=0@CTg=cHd>CPh
=C/h=cQ0?cln?CXj<c@e=cdl@3Xe?cLb=cPj?44d>cd^<C8k=cm3?C8a<cLk?Sdn
?3dj?CPi>3XkJnKXk>c_0VUog]gQg:Hn@Si5A4Tl@Cln?455@S/mAV2IXIU`IU=Z
S:=kNfUUFClcA4=JRWUbGfAdO;AL>c4f=C@h;blb=SXi>SDc<CH_>3D`=cPc>3Hh
>3Tg>34o=S<j=SLi<cDl=S@_=3Dm=c@e=cLl<SQ0=cPh>CTe?3df>3Xj>Che?cXo
?3l1@S[n?olhN3Dc=3Hm>3Tl?D@kA3U1?SPm?dPh<cDc>dXh?D0g=SDh>T97CCdn
>3hi>3e4?cXf?3@bAD@l>Ce5?dTl>CPl?G?Vjn_/l=kMhMbV?T8nADA9?44o?Sa1
AD8k?DIPVJ6IL6ICJXbSNg]YIETo<dA3FXYiLUmTM7bdG3]=<CHe=3P_;c8f>STj
=C<a=Rlh=C0g>3<h=SPh>CLh<Clf<cXf=cTc=C`f=2ld=Cdg=3Dg=c`b>40g>3Pi
>CDl?CHh>SXi?SDo>Sll?d8joSoo>2`e<c@f?CPi?3e4>d@i@Chh?Cm8>3<e<c]:
>3e0=cHe>3Y2Addm?SPn>CPmA3mo>SHl=395A3`i?DDoBC`i>3`mLnK[jnc`g]gQ
g:Hn@Si5A4Tl@Cln?455@S/mAV2IXIU`IU=ZS:=kNfUUFClcA4=JRWUbGfAdO;AL
>c4f=C@h;blb=SXi>SDc<CH_>3D`=cPc>3Hh>3Tg>34o=S<j=SLi<cDl=S@_=3Dm
=c@e=cLI?38h@3Lh>3Ti=C`m=SPj>STn=Clj?c`o@S[n?olhA3Dc=3Hm>3Tl?D@k
A3U1?SPm?dPh<cDc>dXh?D0g=SDh>T97CCdn>3hi>3e4?cXf?3@bAD@l>Ce5?dTl
>CPl?G?Vjn_/l09V@MkLh=j/@4@j?3Xl>D4l@D0n=d0m>TieUk2PSVeCFeiWLY^8
MU8j;bdcXI62L5U>B86eJS8_<S0_;Rdb;cDh>CPd<oh`1Bhb<c@b;_dc<3Pc=S@i
<SY0=CPc=C8i>CL^<S8a;C8b@CPb=3Pj=SPk>C8b>CHi?cHd>C`e?3/n?D5o>cTn
?T8m?3Ph=SHn?3Y1?cTg<CTl?cPl@clj@CLh=SXl<cLm?C`l<C8l?4<m<CLh?3Lh
=C`g>3Xh=c`i=CPg<cli=CDn>FkWj>WZkMkLh=j/@4@j?3Xl>D4l@D0n=d0m>Tie
Uk2PSVeCFeiWLY^8MU8j;bdcXI62L5U>B86eJS8=;c8`;bh]<Rle>3Th=3?n<0D^
<S<d<Rkm<f@h<cHd>C8j@3Dh<cDb>CTg;S8b<Bdb<T4h<S@h>SHh>cTb<STf>Clf
=3Tl=C`k?Se1>cTn?T8m?3Ph=SHn?3Y1?cTg<CTl?cPl@clj@CLh=SXl<cLm?C`l
<C8l?4<m<CLh?3Lh=ETl=cPj>3Ll>CDh=c<o>CDe?SU^inSYj^gNg>3N[414>S`j
?3U1?450?SM0?CY>MIN`X8i]De]NIg:KR7IB>Rl]<j6APW1ICTR1]FXb;c8`;bh]
<Rle>3Th=3?n<0D^<S<d<Rkm<aPh<cHd>C8j@3Dh<cDb>CTg;S8b<Bdb<T4hHc8d
>3Xf>3/i<S8i=STo=S@i?3Dl>chm@C/i?Si2?C`h>3Hf?S`j@Cli=c4i?3lh?4<o
>T4g>3Hj?3<g?Cdl?34b?3a3?C4g>3`g>3Dl=cPj>3Ll>CDh=c<o>CDe?SU^inSY
j^d2JGoNg=kO]5IAA4Y;CE9KFeU=BTiCCVFLZ;FUShB2NW1VL7>6QFiN>C8b=XjG
VHj7KcaS[W/c=S4/<CLh=SPo>3de>CPi=38c>3Hd<C4h<cde=SHg<Sld>3le>CPi
=CPk>C@g<c<i<c@g>SXe?3`h>CLi<cXk=3Xk?3@g?D=2>cPbAglj?490?T18?E50
@cLh?40j@D@i=SHj>dE9ACm2>chh>cU4?ca0?clj=Clm@DM2@SY>=STf=Sa>Addf
=c@j@4Y:A3dg>3dmMNSYj^g^g]cNgkAFDDA:BdeBFe]ICDY>DdiUW:ReYHn4PWY`
IW1cQXE^GSTb<SJ>UiV>QfllHjik<glf<B`a=cPf>3lh?CDi>3Td<S<h=S@a<CPc
?CDf=SLb?c@h?cDi>3Te>3/i=3Lc<cTc=3Lj>SDl?3Pi=cTc>S/d>S/l=3Lm@d8k
>397>Sa2@3i0B3eA@4<g>3a0>T54>CHf>S]5BDDo@S/n>3/iA3ll@3lo>SDo?D57
@T8jCSHi=Wlf?4i7CCHg=3Y0BTY4?CLh?Ceej>WZkNkNg=kO]5IAA4Y;CE9KFeU=
BTiCCVFLZ;FUShB2NW1VL7>6QFiN>C8b=XjGVHj7KcaS[W/c=S4/<CLh=SPo>3de
>CPi=38c>3Hd<C4h<cde=SHg<Sld>3le>CPi=CPk>C@g<c<i<c@g>V<j=C`l>3Tg
>C<j>c@j>c`d=ce3@S/h<TLj?490?T18?E50@cLh?40j@D@i=SHj>dE9ACm2>chh
>cU4?ca0?clj=Clm@DM2@SY>=STf=Sa>Addf=c@j@4Y:A3dg>3dmMNSYj^g^0VUo
gMcOfkEVFU1JFF5XH5aJGUeRKFQgW:Vk[J:0N8AhEUUUK69H?3H^<CZ@VXj9MWDj
FjAE<Bla<c0b=che=CHm?c/h=C<a<3Ld<S0b=2d^;S8j<CDc=SA1=c@h>cDi>C/c
;bhe=c/d=S8`=S0c=3<f=SDg=S@e=SLe=44i@C/g=3]o>Ci0ADE1@cm6A40j>c<g
>c/l>CU2>CPn@T13@3Pe=SH^>SXh<cdj?SHl=d8m?Cm1>STo>3Pf?T11?C/d<CU1
?3`h>S<k>7_Xin_[k=gLgm^eIUY@FUUQJ61LFUiMHVeXMibY^jfRP7R4N5IIIFaR
F3`f;S4jT9Z>RGIe>U^TEC5o;c4c<38g?SDe=Sdo>cPe<c4`=c@b<38d;Bh^<SXa
=C<f=44g=3Pk=CTi>c<_;SDg>c@f<S0f<3<d<cHf=CLf=3Df=cDd@CU1>cLd>cTn
@4E5@D<oATA0>S/c=c/k?3Ti@STh?T90@d0h=CHf;SXj>3<m>Shf?3M2?Cdo@CXi
?cQo>3Hn@44m>c@a>D4l?3Pj<c/hNnSWjn_/gMcOfkEVFU1JFF5XH5aJGUeRKFQg
W:Vk[J:0N8AhEUUUK69H?3H^<CZ@VXj9MWDjFjAE<Bla<c0b=che=CHm?c/h=C<a
<3Ld<S0b=2d^;S8j<CDc=SA1=c@h>cDi>C/c;bhe=c/d=S9S<3H`<c@c=SHe=cHd
=CHg=CA1>D4k=c@k>Ci0ADE1@cm6A40j>c<g>c/l>CU2>CPn@T13@3Pe=SH^>SXh
<cdj?SHl=d8m?Cm1>STo>3Pf?T11?C/d<CU1?3`h>S<k>7_Xin_[k09Xo]mlg:eS
K65VDDi@G5aOFUYAGgZI`jnXW:Nh_;NgHTM8@chn>34`<U2DWJ2JUHM5DJE4=3<h
>38hBEi6?S<k?C]2?Sdg=3@g>SHe=bd`<c<g@c4Y=CLn>cDg>3Lh=3Hk?3Dn?C`c
>3Da<cDg=3He?cXi=c<a<cLf=cdm?S/j?CliAD=2@4=2@Si7ASlnAcLm>SPi>3Xi
=d92BT8j@D0g@D`k@3/h<Ca5@44l=Se4ADi9Aci1?CLd=d0m??hh3SY2@44i>d@k
@h;Xj>g[k?kO<=b]HfaQIU5>D5aLGeYJDEmjVL>_Z9bW^;bg]f97B4<n?SPa<39@
U9fPVYF7AE6UA3Ao<cPh<SQ9GTHn<c/m>d8n?CLd=3Lj=SDg;C0c<cM3<BTe=chk
=CLh=cPd=S/l=Chm?3<h=C4c=CLd=SDo>STg<c4c=cHg?Cdn>cXm?dE3@T13@T8n
AdHo?TLg?CXh>CPj>CM2@TY2>T50=d5<>d0k>34lAD11?3HmA4E>BDLn@Cd5=c@g
@3dloSP>>T90@CTkA3]3P^SXkN_/o]mTg:eSK65VDDi@G5aOFUYAGgZI`jnXW:Nh
_;NgHTM8@chn>34`<U2DWJ2JUHM5DJE4=3<h>38hBEi6?S<k?C]2?Sdg=3@g>SHe
=bd`<c<g@c4Y=CLn>cDg>3Lh=3Hk?3Dn?C`c>3EA<C<e=c@f=Clj>CLc<C<g=SLm
?Chk>SdoAD=2@4=2@Si7ASlnAcLm>SPi>3Xi=d92BT8j@D0g@D`k@3/h<Ca5@44l
=Se4ADi9Aci1?CLd=d0m??hh3SY2@44i>d@k@h;Xj>g[k09YA=cMg]f]DeM>EeQF
CDiBEeIUF6R:U:f[^L2[ThiTBCLb<SLd=CDc;cmgSIF;U8b7AcmM=c<b<c`g?D]A
?clk?T52@Chl?_hfoc@0<?hb23Hj=cXa<C<i?_hg2c@f=34c=C<b>C/j>?hf5S8c
>CTe=c`c=STn=SLd=CLh>4U3?SHooclQACdl=d<l?T1>AT4g?c8f>S/j=c<h>dDo
AChl;c=0?Sdh>?heF3Xm@SDj?D<g>dE0?cHc>CXl>D4l?CDf>3Tm?3/m=cQainWZ
jncLgMkM[E=GCUMHETe>DUMFIEQXRYB]ZkW0Zi>>I4Tg<S8g=3De<bloMhfERiB<
QdLoGCLc438c?3LmBe4o?c/n@D91?S`noSKo=00`oS88=SXg>S4a<cTnoSL;=3Hd
<C<e<c8i>cXhoSHE<S<i>CDg?3<f>Chf=c@e=cPhBD<n=_ho8DDm?3M3?3i0CTI1
=clb=SXk>SLc>3]5?dDn?2lc@3hm>3Sn=@`j?D8e>Se3=c]5@3lfG3<i>S`i@C`m
=CHh>Cdl>cdg>77WjN[[k=cMg]f]DeM>EeQFCDiBEeIUF6R:U:f[^L2[ThiTBCLb
<SLd=CDc;cmgSIF;U8b7AcmM=c<b<c`g?D]A?clk?T52@Chl?_hfoc@0<?hb23Hj
=cXa<C<i?_hg3C@f=34c=C<b>C/j>3Hf5SHb<cTi=CLl<cHi?SHg=3Dg>3Q9@chf
oSlQACdl=d<l?T1>AT4g?c8f>S/j=c<h>dDoAChl;c=0?Sdh>?he93Xm@SDj?D<g
>dE0?cHc>CXl>D4l?CDf>3Tm?3/m=cQainWZjn`2JGoMgmgMZVe_EEY@D5AKGV9D
D4f5W;6j[jNBVJN/AC/a<c8_=2lb>CDa@IJLV9b@PcTa>CHc>42LUZ:HR75YMiFU
Wj^[WGUXCchh=CTl=CLd=ST`=CTf=Cdk>Sdo=S8]=C@i<cTi>SDh<cL^<cDd>Cdk
>40k<S<h=3Pm>cI2>cDk?glo@D0o?dA4?dLoA3E3@Slo@cXm>3Pk?E92?d4g>Sm1
@cdk>c`h>2m1?D0k?Cm1>C]4>CXc>c@e>3<g?d0m?T4h?C`nCSPoNNSWk>g^gMoM
gJY]KeEJD51DFeiRE51=QIba^ZnWTYVW[4Dk<C<b;c@_<STe<D6FW9RLT8<i<CTf
<glh@9bFXYR8LFUgUJFOZj^MNFQ??SPe>C`e=c@f>C0e>CHe?C/j?Clf<Rde=3Tc
>CTj=CPc=bhc=C@i?C/h@3/b<cPd>3dk=T8k=C/o?d50?cm4A3m7?d@e@d8o?d<j
?CPh>ceB@Sm1=cXo@D<m>c/l>3P_@Ce0>cdo@CTkA3Tj<glk=3Dh<cLo@3dn@CPm
?3i>>3mij>O/kNkMgmgMZVe_EEY@D5AKGV9DD4f5W;6j[jNBVJN/AC/a<c8_=2lb
>CDa@IJLV9b@PcTa>CHc>42LUZ:HR75YMiFUWj^[WGUXCchh=CTl=CLd=ST`=CTf
=Cdk>Sdo=S8]=C@i<cTi>SDh<f<g;S<e=3Tm>cQ0>c8c>3@h?C/f@S/e>clo@D0o
?dA4?dLoA3E3@Slo@cXm>3Pk?E92?d4g>Sm1@cdk>c`h>2m1?D0k?Cm1>C]4>CXc
>c@e>3<g?d0m?T4h?C`nCSPoNNSWk>g^0VWogOoNNjUIE5=UFdm?E59EHUiPNXfM
ZJ2YT[:8CCDa;bhe<Bd]<3D`:3QKUIRJSXTm<34d;cA7Zjb^VIFCVZfWYY:PZJRZ
YiEQET<i>c<b<CLf;SDj=3<d=cHi>C<e<34^=3Dg?3`d<cDd=S<h=C@f>c<a=CHd
>STg>cXl@C/g=CP;>S/n?3Pe>ci5?D8`oSM`>SPf?3`m>C]1A48o<c<l?Ca6CCdi
>3La<ce1?SHm?3Tb?C`i<cTd=cDl>CPc>S`g=S/l=cTl>WWXj>W/kMgMg]jYFEAC
IE]?CeABEF9NH7Z=WJVPZI:bR4de<Bl^=C4];C0e<2PhFiFHVXj9?C0a=2mG=4N[
[:jIUI>J[JNVTZ2YZ:ZWUF5F@cTk<c8a=cH^=CXd<c@g=STi<cD`<Bhd=CLl?3@c
=C@f<cPe=3Hk<c4e=S@j>CLk>Sa1>cLe>3Xk?S`h=C/nACe2<?hg93Xh=S`l?CTk
@DA2?c<c?3dlATdm>CPg<C<m@Chf?C`i<Sdl>C=o>C@g=C`i>3<j?3Lf>c`g>C`j
NNSXjNc]gMgNgZUIE5=UFdm?E59EHUiPNXfMZJ2YT[:8CCDa;bhe<Bd]<3D`:3QK
UIRJSXTm<34d;cA7Zjb^VIFCVZfWYY:PZJRZYiEQET<i>c<b<CLf;SDj=3<d=cHi
>C<e<34^=3Dg?3`d<cDS=3Hc>3Dd=S/c<CDf=3Xi=c/j?44k=cDh>S/n?3Pe>ci5
?D8`oSLl>SPf?3`m>C]1A48o<c<l?Ca6CCdi>3La<ce1?SHm?3Tb?C`i<cTd=cDl
>CPc>S`g=S/l=cTl>WWXj>W/k@9YomimfmjcJVYDD4iNGFAKEdeLLiZR/[NdL5:P
EcPa=Bda=C4a=c4f<2`c>[2OUWid>3Dd<Bhh>hfMYJNU[Z2SZl?0a;>cYJ:X[[Na
]:AjGCLj=3Le=SLh>SXi?S<c<C`i>cdm>S4`=3Lh>SPb>cLb>3/c=3Hh?dI4?Cdn
?3LiASlhOcXn>cU6A4e1?Cm4A494@Cde>3TnACTg@d=6@DA2>cXo?c/o>d99=3<i
=SdlB4<l<cHe?Slm>SHg=C/j<Ci:>S@i>Shl?D5lj>SZkNcNg]_N/fYZE51>GUeT
FeM=G7>JX[:g]71BX5Lh<CD]<CDa<CLa=S0/<cZ`WiInM3Pe=34^OcPkSIfUYjF^
X:>[`l34/k>UXZR^]k6dY7YM=cXd=cDf=cPj>STn<c<a?3Tk?Cdj<C0d=cPj>38k
=c8h>c<d=SPoAT@m?Chl=cU6?cPj?S/iATA=@CdoA4A2A44m=CPi?TDi=d=3AT54
@S/j?clk?c]2BC@c>CHm?4Q3?3<f=ChoOcdj=SLe>cXa?TXj=3Tj?S`m@GcXj>[]
k=kNfmjcJVYDD4iNGFAKEdeLLiZR/[NdL5:PEcPa=Bda=C4a=c4f<2`c>[2OUWid
>3Dd<Bhh>hfMYJNU[Z2SZl?0a;>cYJ:X[[Na]:AjGCLj=3Le=SLh>SXi?S<c<C`i
>cdm>S4`=3LhHcXh<S/g<SPk<c@f>3m6A3dm?S`g>DHo>3Xn>cU6A4e1?Cm4A494
@Cde>3TnACTg@d=6@DA2>cXo?c/o>d99=3<i=SdlB4<l<cHe?Slm>SHg=C/j<Ci:
>S@i>Shl?D5lj>SZkN`2JGoMg=cJ[EEMG5U@Ee9FE6IKKg^9UK70EdaDFcHb=3h^
<C8a;c<`<B`^<SANXiR5LS8a;Rha<C1MSinS[;:k];2l^<6l`kB/ZZV/[ZjjYiUR
HCXh@SHh=SHg?D0j=C8d<SXl>40i<CDe>3@e;cHg=S@_=3<l>cHl>ce1?cHi<C@l
@Glj@3`g?CXm>S`l>cPj?Cm1?3<e=Cdg=3i0?ca1=cdg@3Xi>C/m?cdg<3Dl>SLk
?3<c=CDc>CI2=CD`=c@g=SXi=S8f=ce3OnGTj>KZgMcLfZeEGEaID5MBEUAVFfmk
RIFa`5M<E5/f<S@n;S4b<Blc<34/;S8dGZ>HQG8b<Bh^<Gla<5f?Wj>//[^d/;bh
`Kc3]:bZZJb^[[ZWVF9Q>SQ2=SPf=SLm@3Xe<S@b>S`h@3Ta=CDh=3D_=SLf=2ld
<c`k=S`k?D4o=STa=3a1>T0l=cdj?CXl?3/h>Sdo@C`c=CDm=c@n@3ll@CLm=d0j
>CTk?Clm=c0e?3Xg>c`c<cDe<gli=T8e=C0g=3Lf>STf<SHg?D=oiNCXi^[Mg=cJ
[EEMG5U@Ee9FE6IKKg^9UK70EdaDFcHb=3h^<C8a;c<`<B`^<SANXiR5LS8a;Rha
<C1MSinS[;:k];2l^<6l`kB/ZZV/[ZjjYiURHCXh@SHh=SHg?D0j=C8d<SXl>40i
<CDe>6<d=Blf=cHd;c@c?3/f?3/m@Clf>C4d?44j@3`g?CXm>S`l>cPj?Cm1?3<e
=Cdg=3i0?ca1=cdg@3Xi>C/m?cdg<3Dl>SLk?3<c=CDc>CI2=CD`=c@g=SXi=S8f
=ce3OnGTj>KZ0VWofggQfkMUGTaAEVAQIdmGDX:BUjVgP5ijP4L_<TLe<c<^;c0c
<Rd`;RhjDHV1OE<i=c0_<c@c>cf][jZ[]KK0b<C8_L2i][Fi_[B`ZJV^XKJ^VfI;
>3e4?d8h>cXk=S/l>S@f<CXk@3@m?CDm?C`m?CDd?3/k?cdl?3Lg?3/f@d=o?CY1
AD4n=cTn>44kA498@CXg?cm;@3hm>413B3m5>CXh?Sm1?dLo?c<d=SU1?SXi<SLo
>SHe>cPb<3M:AC@e>CLb@Chi@XCRgn[Zk=_KhM^gIEi<DEITHFM?Ee:2TYNY]h1N
NX17;c97=C<c;Rl`<c8]<2h^>U69PGeC>CL`;c=o=3<k?Jf_ZZ^e]/38a<Rm`;Vf
]KVn];2YZJjQ]ZjKIT/h?D@o@SPk>S/f>c`j=3Ha>S]0=3dm=Cdm?3dm=C@l>c/o
?C`l=cLl>cI3@cdj@DE1?SLi?SQ1>dA2B44j=cloBd0n?CQ0@dPoACTj>3ho@Cm7
?clc=3Hi@Chj>C8g?cYo=SDk>38`=dY5=3Di=c91?SU2Q>;Oj^[/fm_QfkMUGTaA
EVAQIdmGDX:BUjVgP5ijP4L_<TLe<c<^;c0c<Rd`;RhjDHV1OE<i=c0_<c@c>cf]
[jZ[]KK0b<C8_L2i][Fi_[B`ZJV^XKJ^VfI;>3e4?d8h>cXk=S/l>S@f<CXk@3Co
?F4e?Cdl?Cde=3`k>clm?3`g=c`k=T=3?CY1AD4n=cTn>44kA498@CXg?cm;@3hm
>413B3m5>CXh?Sm1?dLo?c<d=SU1?SXi<SLo>SHe>cPb<3M:AC@e>CLb@Chi@XCR
gn[Zk09Yom/Jg]^]GUUHE4eAC5aLHUU/JhVEOfb1Le0i<d13oS0?<C</;c4a;S4_
<T1bSge5<_h_ocM:=S@fAU>U[j>AUijS/[;0]k:X/K_1a[N`ZIbUZ;>UR4/g?3]1
?C`g<C4d>3/i=c<m>d8g?T0j>S/n>3`l>c]2>Sdl?T54>CTf?Ca1J4@m?d52=d50
?C/h>ce1@Sm1?Sdf?Sa0A3Pd=c`h?d0l=cTf?c`o@D8l>CLiC44k=S8e<SHh=STk
=38_=CXc=3Xb=3Dj=CZ6hNC[j>KKfmkK[EiIF5A=DDaLG69IK6^9UGm/PG=@>C=0
@oh`3c4c;2la<Bha;c90LXmmAC;n;`0gOcLf=3I6DjF_Xi6GWZ>b//2g/ZRa^l76
]k2YW:FX/jF8BcLl>d4m?3La<C@h>cTg<cdk@SLn@3Xj>chh?3`k>d8j?C`n@D@i
>CHm?454?Cm1@SM1@3dk>3/m@D8o@Chm=Shl@4@h=3Ll>3m0?3Li=Sll?d52?3Tg
>Da1>cHb=C8f=3Pf>C/d<Rle>S<d>S8d=CXe>XKQi>_Xi]_Kg]^]GUUHE4eAC5aL
HUU/JhVEOfb1Le0i<d13oS0?<C</;c4a;S4_<T1bSge5<_h_ocLb=S@fAU>U[j>A
UijS/[;0]k:X/K_1a[N`ZIbUZ;>UR4/g?3]1?C`g<C4d>3/i=c<m>d8gHci0>SXk
?SPl?3/k@SXm?3i1A3Ti=Sdl@D@m?d52=d50?C/h>ce1@Sm1?Sdf?Sa0A3Pd=c`h
?d0l=cTf?c`o@D8l>CLiC44k=S8e<SHh=STk=38_=CXc=3Xb=3Dj=CZ6hNC[j>H2
JOoLG>3OZUmDD5YOJ5IEEU]bS9jPTFRHUIM5>cIA>CL`;2le;2Xb<Blc<C<oDgYb
A3<_<C8f>CTj=3/jLY>7RYBKU9^N/:nka<Zn^;Vd]kbf`;6cXZNT/9i>?CHi>Shm
?_hl7C/n=Sa2?S/m=c`lAC/l=CXlAd53>cLk?CHm=c/o?glj>C/n?DXo?Si1AT=:
@dDl?T52>D93?3`o?3m6>c`h>CLk?S/l@3hj>TDh?44k?CL^=d8o?cHg>C@f=cLh
>3Ld=cHl=cHnQnWXj^W[g=cPgjYOE51JGfQFEEIKLXbNX95XV9FGAC/fDCTg<2`_
=B`Z<S4_<c4c?e=jLT@c;c4b=_li:3Xd>cYbThN:U9^DVij`[k_4b[jh^KBg_;K0
/K>RYjB`WThm=STj?SdnoSaA>chf?48n>cdg?3a5>c`e>Sa7@D<k=c/m=Sdg>clo
>STk?Se:?chn@DI3BT=5?3i1@SU2@c`l?c`oAS/l>3Tg>chk?40n>SY5>3a1>cdg
;SM2?gHo=SLi=3Hg=cPh=c@g=S`g=Sj7jNSZjN_Lg>3OZUmDD5YOJ5IEEU]bS9jP
TFRHUIM5>cIA>CL`;2le;2Xb<Blc<C<oDgYbA3<_<C8f>CTj=3/jLY>7RYBKU9^N
/:nka<Zn^;Vd]kbf`;6cXZNT/9i>?CHi>Shm?_hl1C/n=Sa2?V<k?CLl?4Dk?3Dj
?4M1@c/g>cdf?CLk?clj>C/n?DXo?Si1AT=:@dDl?T52>D93?3`o?3m6>c`h>CLk
?S/l@3hj>TDh?44k?CL^=d8o?cHg>C@f=cLh>3Ld=cHl=cHnQnWXj^W[0VQYg=[P
fJ5UGU5;CU5AGF1PIhN?ThmUXI1o?3DfKS`e;b/`<Rd_<C8]:c0a?cm3BD0b<cXe
;c8d<cY5@E90@ClkBTmnS8N=WZ^a^L:h^:b/[[Vm`ZbbYJN/W5hk?3/j=D0o>S/g
>3`i?3m3?ohe4U=4A3Tm=Sdh@3Tk>3Tf>CDb>ca8?c`n?Cm0?48n?3hh?T1:@Ce1
@Ci6?Chk>Sln=cI3@CXf>SDl>cXj>CPn>SPn>Clc=S8j=40h?CDh?SXg>CLh<3@d
<CHi?XCVj_kY<mcJh=VQIEiABdiADEePH6N7Si>?IJ6@Oc`e=Vhl=Bl[<38];c4b
;B/`<Clo@dU0<S<j=Ble<S@c>TE1DT11?c]:Cgj<QhfNZk6i`[Rh[:b^^Kg2[;:U
YjbLGS/l>cXe@3lj>cLh?3Tl?d<ooSE6DdA4>Cdf?CQ0>C/h>CHi=C8k?3ll?Sdo
@3a2?S`n>3i0BT4m@D4nASdn>cXo?SLf@d4j=SXe?3/j>STh?SXh?STo<cHb>S@D
@3Pm=CPn>SLi=cP`=3@a=STnQ>KZo^UWg=[PfJ5UGU5;CU5AGF1PIhN?ThmUXI1o
?3DfKS`e;b/`<Rd_<C8]:c0a?cm3BD0b<cXe;c8d<cY5@E90@ClkBTmnS8N=WZ^a
^L:h^:b/[[Vm`ZbbYJN/W5hk?3/j=D0o>S/g>3`i?3l1@con=E]CA4@i?CHm>40i
>cPi=STe<S/l?c`n?Cm0?48n?3hh?T1:@Ce1@Ci6?Chk>Sln=cI3@CXf>SDl>cXj
>CPn>SPn>Clc=S8j=40h?CDh?SXg>CLh<3@d<CHi?XCVj_kY0VUog=gNej1BCTiO
GEiJE5=dN9^NWhE@WI5_=3<i[c0c<Rd_<Bdb<3@Z<34b?S@c>3Pd=T53@CA3Q9:H
YXm5?SDh?3Y4D7MmXjVdZJnZ^Kk7^KFj]KS1`;fl]7U1?T0j>cm2?c/n@D0o@cDf
<CPk?EI3?c4l?dDn@Shf>Sdm?3/m>c_o?Ge<?DDn>d4n?4Lo@cU7@Se7@CY5=chh
>C/m?3Tn>c`i>T17?d8g>cm8@Ci0>CTl>CDg=SLd>CHh>cLj<cHj=CXm=cLm?h?W
jnc/j]cMg]NPDTi>GeeNFUACM7RKWYn5D9fAKc@c>Jl`<c8];c4]<S0d:S0a<Shd
<cPh=3I1@d5o=4>4TYRVSdDn=CPl>TA@MgfSZKBY[jZi_/Ni]KZe^<70_KbdND4n
@3Xk?d8o>ci1@3m3=CHa>3/mET<o<C`oACi2?SHj?Cdl>cdk>cdmC3e5?S]1?Sa7
?d<iAd8mAd4jACLn>3Tk?C`i?S/l>CY0Acm2=c/oB44n@3Ti?3Te=cIo=c@i=SPk
=cXc=SXe>Sdg=cdoPnO[k>cZg=gNej1BCTiOGEiJE5=dN9^NWhE@WI5_=3<i[c0c
<Rd_<Bdb<3@Z<34b?S@c>3Pd=T53@CA3Q9:HYXm5?SDh?3Y4D7MmXjVdZJnZ^Kk7
^KFj]KS1`;fl]7U1?T0j>cm2?c/n@D0o@cES=S4h>ceF@cla?3m5?T8n=SXm?C`k
?C/k?Ce<?DDn>d4n?4Lo@cU7@Se7@CY5=chh>C/m?3Tn>c`i>T17?d8g>cm8@Ci0
>CTl>CDg=SLd>CHh>cLj<cHj=CXm=cLm?h?Wjnc/jP9XFMkMg]jZEe57Ee=HDUAF
NX64S9Z1BfQjHcDe<e/a;Bh`:b/eAc4b<2h^<Sdd=C<_;DI8D45:Ii1n[[Z6@chh
=c/f?3Tk>FjKUInhXJ2W[[:m_k2a^[c1`lEk??hi8SDoA3Xg@CPk=3hl=c<o=cho
?S/b?SDi=48n=S/k?4<m@3]14S/n@3U7@Cm1>CTm?D91@chl>ckn?b<i?C`h<3ln
?3Hf>3Xc>3Q4<cLi?SXo@S`i>3Dc=c@g<c@g?3?n=@/a=38d=C@c=Sj4i>Gnic?N
gMkNZUMAAeMCF59DEWZ1Q8bJPD]XNV<e=C=K<Bd^<2/[=DLa<S0^;S8m=3Dc;be6
B5119DYWT7j^^XI3?SPg>cHl>C/iKY^EWkRQX:N^/[fo/;6j_<73aG/loSTe=Cm4
>SM1>3/d?S`g<clg?Sln>c8n=CTd@Shf>c/l@ce0>d4k?T0iAd4o@CTi?Ce2@D<n
?3/noSlM>Cdl>30o?S`f=SPj<cPhA3<g>Chj?d8l>CPe<cLd1CLc=3Ll<ohe2c4d
<S@e=3<f?XCTiOkWFMkMg]jZEe57Ee=HDUAFNX64S9Z1BfQjHcDe<e/a;Bh`:b/e
Ac4b<2h^<Sdd=C<_;DI8D45:Ii1n[[Z6@chh=c/f?3Tk>FjKUInhXJ2W[[:m_k2a
^[c1`lEk??hi2SDoA3Xg@CPk=3hl:SLc?cLn?chk<She>CA2?SHk>ca3?D0k@C/n
@3U7@Cm1>CTm?D91@chl>ckn?b<i?C`h<3ln?3Hf>3Xc>3Q4<cLi?SXo@S`i>3Dc
=c@g<c@g?3?n=@/a=38d=C@c=Sj4i>Gni`9YOmkMgMjY@TMMHE]JEVIeU:Z/YIY/
GUbBJc4g<SL_;2ha;2lb=3<a;C4c=C8];c<a<e1WFFNa^:VM_I9@GUhl?3Xf>C]2
?F2;OGn;SK:e^K:b]jbdcM33_kV5AD4m?cTl>dE2@T53=Shh>3U>AD0j>cdh@44k
>T4n?CM9A4Xn>cPlOce2BDE5>cdk?493?T91@414B4/f>CTj?Slb<3`i=cM0@4Dk
>Shm?Ca0@CPj>cPh?c`f=c<`=TDn@S/h<C4`>Sho<S@h>dB>iNSUj>[NgMgNZD97
GF5KFUIVMIBZ[:FJK5iLTV/a=c8g;b`^<B`_<S@c<Bda<cDb;Blc<C=@IeUWOk6h
ZIfmTU1NGS`l>SHi>d8mH8]mOh^=/[Fi/[:g[;C=d<>o^HE5@Cdo>C`kAD92@D<f
?SPh>Di5@3Xk?CQ0@C/j@Chm=dU4BShk>3`m@TU5AC/m>ca2@ci2@D10A4Q;=STi
>Sho<S0l>CLg@415>cXn?Cdl@44h>S/h>3ll=SLcOc0fACi2>cPa<C0j?Slb=3Pk
A8kUj>GXj]kMgMjY@TMMHE]JEVIeU:Z/YIY/GUbBJc4g<SL_;2ha;2lb=3<a;C4c
=C8];c<a<e1WFFNa^:VM_I9@GUhl?3Xf>C]2?F2;OGn;SK:e^K:b]jbdcM33_kV5
AD4m?cTl>dE2@T53=ShhHcPiCTE0>S/m>411>cY1?SdgBDA:?S/h?3e2BDE5>cdk
?493?T91@414B4/f>CTj?Slb<3`i=cM0@4Dk>Shm?Ca0@CPj>cPh?c`f=c<`=TDn
@S/h<C4`>Sho<S@h>dB>iNSUj>X2JOoMAMkMZDQ1DVQbTWMUHEUTRi2<IUm1JVle
=S8e;B`/;C0c<c4a;bd`;S4c=C8^;3YbNVNYYJc3dmYNADI5>3lo>cTo@dnISIOn
VCBXZZ^W^jnY/[[3bLg9UChj?ca0>SLo>CXlAS/j=C<b@Clm?C`k=T4i>3U2?d4i
>Ca0@3Dd>Gli=chg@Chn>S/n@D92Ac/k>D12?T@g=chk?3To>chf>SXg?CTi?S/n
?DDj>STg>cTn>CPb=C@k>C`j=cDb=34a>C<a=cTmS^OUj^W[gMgNgJU8@E9XLY9g
IF5II8^@S6IO@FY_=CHb=Bd/;2d`<c<a<Bl]<2ha<cDb;R`jLWYWZA>U[<?CfUi5
ATDh?clk>Cm3CiV=UojIJ:RZZjNk[jVb^/?9cLVE?SXo?40j=cli>Sa6>cXe<c91
?cdm?3/f@CTh>D8o@CTi?410=C@i>CLn=d4n?SXk?T52@TLk>cU0@Si4=cLn>c`i
?c/n=SXj=cdi>Chk?Se5>SXi=c/i?STh<Ule=3/i?3Xg=C8d<C4i<c4g>Cf>inGZ
jN_MgMkMZDQ1DVQbTWMUHEUTRi2<IUm1JVle=S8e;B`/;C0c<c4a;bd`;S4c=C8^
;3YbNVNYYJc3dmYNADI5>3lo>cTo@dnISIOnVAbXZZ^W^jnY/[[3bLg9UChj?ca0
>SLo>CXlAS/j=F<c<T4o?Cdl>cI1>CPi@Sm1>CTl@40e=3Ti=chg@Chn>S/n@D92
Ac/k>D12?T@g=chk?3To>chf>SXg?CTi?S/n?DDj>STg>cTn>CPb=C@k>C`j=cDb
=34a>C<a=cTmS^OUj^W[0VT0f_kLNiQ7@4eCB4e;H6bCO7QTFU]GHTAS=CHc=34c
;c8]<Rha;C8];bh]>CP`<3DoQ:CPhN2Y_N2jBEY?>CHjADalVKJb[i^LY:Jb]JnS
X[2/]KS9aKk<_9]4@3ll>CLi?3Y0?4Dm>cL]>Ci1>c`j>cA1@Chm?S/m?3i3?c`n
>cT4>Sdi>T;n>T@o@d4f>Chm?T93?cTj>C`k=CHj?CTi=cHn>C`j>3dlAdE6>S/j
>CPm?SXj=c@d>3m3<S@b=3Li=CTa;c@h=i7Zj^gZkm[ng2nHAd1=DdQ=Bf1/Tgah
I5YKEf94HcDf<c@a<blb;C8^<Bdb;Bl^;CTh<30e?hBTh>5@h:Vmh;Y9FTli=SY5
C7bI][:_VibTY[:e[j>R/:be^<W5_/blVdA0?c`i=cTl>T0lACdk=bdi?T4k?3Xk
=451?Sdn>cdl?T<o?3hk>CXm>CY2oSX[?d=1=STn?Ci2@cli>STl>cDf>Sdi>CLf
?STl>SPm?4M5ASXk>STh?Chj>SOo=1Hh?d<b=38d=cTe>C4_=3PgTN[ZkN[_f_kL
HiQ7@4eCB4e;H6bCO7QTFU]GHTAS=CHc=34c;c8]<Rha;C8];bh]>CP`<3DoQ:CP
hN2Y_N2jBEY?>CHjADalVKJb[i^LY:Jb]JnSX[2/]KS9aKk<_9]4@3ll>CLi?3Y0
?4Dm>cLL;CTn@C/l>S/d@D4n?Chk?C`n@cll?S/i>Sdi>T;n>T<o@d4f>Chm?T93
?cTj>C`k=CHj?CTi=cHn>C`j>3dlAdE6>S/j>CPm?SXj=c@d>3m3<S@b=3Li=CTa
;c@h=i7Zj^gZk`9YomemgmbP@3I4BCM5@fE[OHJFRGMYCGUjXZ1>?c8]<34e<3<a
<BTe;c8c=SPd<CLf<Tb1b/gM/NWRQ411@3TmQjNd/[KA`kfj^;J_/jjf^/G5^kRe
c<S:d]6o@D52B4@l?D0i>Ca9@Clc=3@l@c`o>CPn@T4oA3Xj=cPl@494@d4nOcTk
?TI0@T4l>T97A3/m?c/n?d@i>cXo>CLk?3dl>C/k=DM7@414?U91AT=4@3Pj?3Dm
@cDg=C`j@455=cTi=c/m?3@l>CN>j>c]k>oMgMoLX40fA4TgAD=UJgf6UXUgJDei
NZ:PCSlb;C0a=C0c<C4Y=Blb<cHh=34g=S9<PL[=OmfajN:4@450>Cf7YkBb]]73
_KZh]Znc[[JjaLFk^;G<b<[BdKm1@D98A3`m@3Ti?4U1?c<d=3a3?3li>3i2@Cm4
>SXg>3a0@TA3@Chi>ci6@491?3Y2Ad@k?Clk?Sm4>C/j?cTg>c`m?3Tk>cE7Ad10
A3iB@DI3A40h>S`e?D<eOcLe?3Y0@DDg>CTg>cdl=3`i=hkXk>g/kmgMgmbP@3I4
BCM5@fE[OHJFRGMYCGUjXZ1>?c8]<34e<3<a<BTe;c8c=SPd<CLf<Tb1b/gM/NWR
Q411@3TmQjNd/[KA`kfj^;J_/jjf^/G5^kRec<S:d]6o@D52B4@l?D0i>Ca9@Clc
ocAQ?4<l?cTh?T91?d@j>SLh?412A4=1?STk?TI0@T4l>T97A3/m?c/n?d@i>cXo
>CLk?3dl>C/k=DM7@414?U91AT=4@3Pj?3Dm@cDg=C`j@455=cTi=c/m?3@l>CN>
j>c]k>l2JOoMGMkLVTm?>34a=39>IXAkG5=MFDYm[MfdLcHZ:B/`<c8e<bhb<38k
Af5==S0b>SYGLIc1[jSRSD]1Fd9:GifHY[c3b;fe/;Je`LFj_;6a^[K7b<c4`<G;
cDi<ATPm>Cgn>a`o>che>3hl?SXi>SDi=4`n>SXg>CHj?d0m>492?gli=SPl>cho
@cdo?T10?Chl>410>C`n?Slg=c<h<SLo@ca:>cPe?Cm>@3lg>3a1@SPf<c@c=cXn
>cPe<3E3?Cli@3Lf<STeTNW[k>gNgMgNg9Y?CcPa<C@bCVJ4NeaCGEU:OJgM]7<f
:RT[<3<b=C<^<S0b>dMQCCH`<SXjEg6L`B^_Z>:=Bd5K@TYOWIRV_<?8_KF`][G1
aKZl/K6j]/O8c<C0aL_=CTa6B3di?OhkD3lk?SDh?S`n>STj=CTdC3hj>SLi=SXo
@3dh@T8o>CHh?3/n?d<m?ci0@3dn?3Q0@3Tl?Sho=cLc>38g?d<lBS/h=CdoCT0o
=cPl@D8h=S<d<gLg>Shk>3D`=D<m?cU0=cHb>CFAjN_/kMkMgMkLVTm?>34a=39>
IXAkG5=MFDYm[MfdLcHZ:B/`<c8e<bhb<38kAf5==S0b>SYGLIc1[jSRSD]1Fd9:
GifHY[c3b;fe/;Je`LFj_;6a^[K7b<c4`<G;cDi<ATPm>Cgn>`@o>che>6<n?3hj
>CXe>CA<?SXj=cTf>Sm0?CQ2@Sli=SPl>cho@cdo?T10?Chl>410>C`n?Slg=c<h
<SLo@ca:>cPe?Cm>@3lg>3a1@SPf<c@c=cXn>cPe<3E3?Cli@3Lf<STeTNW[k>gN
0VUVgN3QgIE5>cLk<S/d@E=]MW][IEM;Q=KQ^fdh;C4c=S@^=S<g<34^I8Z3NSH`
=3@fH65iZH[@iEHoCW^NY[Fk_/6f^L7;b/S5`l:o`l70`l_5`;o=c]CGcmY9CTI8
?SU1?cXh?SPkA?hm5Ca3ASLg>CI0C5=2?STo?3Xn@413?Sao@4Ln=ce2@cdn@d=1
Acdo?D50@T12@STo?T4n?cTl?SHnB4=4=3Xo@ca8B3/m>TLf?Ci0?D0e?Ca3A40g
>CY0>3Xf=T4o@I?Zjno^j]gPhMfEAC/g>c8k=45CKGIkJfEGBhCFhK]]>2da<cHd
;SHc=c0a;VB:PgXf<3@d=V1QNJTbR]3UESm>NijV]K^n`KJi`L_:b<G3`[o3`L33
blG0_lg>e=O?fTU>ATPn>D4o>SPn>3]4oSe9?4=6=cLi=T1<Dd8n>Cll>Si0@4<n
?417?SLm@T<m?T=3@DLm?ce1@490@T8i?ci1?Sli?3hf?TQ3A3@j?d<lB4Pk?CY7
=Sdn@3eo@3Dm?4=4@3Li>T0h>SHf@Cm1Tn[[knkZgN3QgIE5>cLk<S/d@E=]MW][
IEM;Q=KQ^fdh;C4c=S@^=S<g<34^I8Z3NSH`=3@fH65iZH[@iEHoCW^NY[Fk_/6f
^L7;b/S5`l:o`l70`l_5`;o=c]CGcmY9CTI8?SU1?cXh?SPkA3go?F4l@dHg=cTf
@4aC@Shi?c`j?T10@chl@4Ln=ce2@cdn@d=1Acdo?D50@T12@STo?T4n?cTl?SHn
B4=4=3Xo@ca8B3/m>TLf?Ci0?D0e?Ca3A40g>CY0>3Xf=T4o@I?Zjno^jP9YOm_N
gmfC=SH`<SDj<3Tg<c4k?Shm?Cm<GDE9>S0d=SDc<S8a<c<_<E9IIH0d<C<g=eEN
NGB[h=MoWjBW[j>Z][c4a/G?`[^nbl[=b/Bh_[W6dLg:b/?>dM?IC4/n?C`j@Sdo
?CLb>CXjAC/h<cDf=3dh?4U6>Ca2>chj>Shk@3m0OcXn=c<j?454@3dh@4Pe@c`m
>Sdg>Sm0@CXl>3To@44g>3hi@Ce8@3ho?cU3ACdo>CXj>cM3?Slk>SLb=SXf@CHf
>C/m?d>JjN[^jnkKg]oMTcHf<38e>S0i=c<a>chn?CdoC5e5BCX`=3He<c8b<C<c
;c5BFFF0=34c=cMEGWUdOj_PegnOY:N_XjZf_<C6aLo2^kk;b/g:a;Rn^LKAcL[:
`lkAdmU<Bchm?3Y2?Clm=c8i>SY5>cPc=CHd?CPlBDHi?48k?SXj?S]0?d0j?SLc
>Sa1A40m>418=D<l?CXm=cXo@44j?3Pi?d11=cPn>D4mB40n?cli@dDm?cTj>S/g
Od<n?c/j=c8f>SI1=SHi>cdo@i[Yj^k[k]_NgmfC=SH`<SDj<3Tg<c4k?Shm?Cm<
GDE9>S0d=SDc<S8a<c<_<E9IIH0d<C<g=eENNGB[h=MoWjBW[j>Z][c4a/G?`[^n
bl[=b/Bh_[W6dLg:b/?>dM?IC4/n?C`j@Sdo?CLb>CXjHdDk>3<e=S@m>3a9ASTl
@S/n>SXn>d0o@3Xn=c<j?454@3dh@4Pe@c`m>Sdg>Sm0@CXl>3To@44g>3hi@Ce8
@3ho?cU3ACdo>CXj>cM3?Slk>SLb=SXf@CHf>C/m?d>JjN[^jnh2JOoMOMoKTC@g
=c<c=Bhb<38h>3Xl=Se3@D@l?Si6@cXoA4<o@C/i?3M6FUZ?<CPg?SMCD8j;h;:Q
QIfQ][W1`[[1_lK4bl[;a<?;clkDc]77bL[<dm?Bc<oBh5ACBD/j=ca3>T@m>cXh
>cXh<CLc=cHm>D=CCD0n@Cli?4=1?T8lAA8n@d0i>Se1?Si1?dM2>3PiBD@noSYY
@dE3AcXm@3lk@3e1?3Th@dI4AS`g?T<m>Cdn>SPbASi0>3Do=cHd>Sdj>C`i?3hl
VNW/ko7`gMgOfi4d=cLc<cD^<S0b>3Pj?3Hm@d54?3hnAT<j?dA3?d4k>C`gAUYJ
Sc4h=chgDe2>RekP/Z65WJ6f^L72^/6oa/C;b/_4`l_?c]C>dLO9b/cCdm;<cm;P
E5=9BcXg?4<jA3dk>SPk>SPa=c<g=Sdi@e==@3i1?cTl@d4n@Sa5?T=0>CXm@Chn
@Cm7@SPh>DU4?_hj7D=5@dLj?D0o>d0m@C`i>4=6A4Hl=ci3?CTm?SXh<Wm6?T0h
=Clg=S@j?CXi?3Tl?SbIjNc_lO3MgMoKTC@g=c<c=Bhb<38h>3Xl=Se3@D@l?Si6
@cXoA4<o@C/i?3M6FUZ?<CPg?SMCD8j;h;:QQIfQ][W1`[[1_lK4bl[;a<?;clkD
c]77bL[<dm?Bc<oBh5ACBD/j=ca3>T@m>cXh>bXj>34g<cLf?CU3Dde0?T4o>Ca3
@Ci2?4Dn@d0i>Se1?Si1?dM2>3PiBD@noSXe@dE3AcXm@3lk@3e1?3Th@dI4AS`g
?T<m>Cdn>SPbASi0>3Do=cHd>Sdj>C`i?3hlVNW/ko7`0VOofggOgX`d<CD`<c<d
=30c<CDe=3Te=3<g<CTl?SLc=STi?Cdf>3Tf>CM0bcLb<CA=GeNod/YFRInl`;fe
_:nQb/O;`[jl_Kk6cm?>clC8bmG?cL[;d<kJenE5ACa2Ad=4@3Pi=cLh=CLi>S@g
?C`h>SHj?TI5@D8n?3dm>c`m>CWo>Gdj?Shi@3Pk?Sdm@3`h=d0f@3hf@3i1>3Pm
@Clk=SXj=SPl@4Do?3di=ce2>cTc?3Dh=c/k<S<h>C`l>cXh=STf=cLi?Y[[k>[/
k]_Kgmj<=34e<3<c=3@`<c4e=C@i=C@c=c4i?3hg<cHi>Cdm=SPi=STg@</g<S4d
CEmG_m99bUJ9Wkc0_KFl[j7:al_2_[bm_/K?dlk?a<S;eLo=b/_@c][GiDE5?497
@dA0>3Tg=cPe=cTj=3Lm?3Pj=SXnATE1@Shl?Cdk?3gm>C4j?Shi@3Pk?Sdm@3`h
=d0f@3hf@3i1>3Pm@Clk=SXj=SPl@4Do?3di=ce2>cTc?3Dh=olkOC8c>3Tl?3/j
>3Hi=SLg>CjJjncZk>kKfmoNS3@a=C0c<c@d<3<a=CDd>CDd<cLa>C`n=c<f>CTm
?CHh>CHi=d3;=c8a=4eOEkoBbUJ9Wkc0_KFl[j7:al_2_[bm_/K?dlk?a<S;eLo=
b/_@c][GiDE5?497@dA0>3Tg=cPe=aDi>S@g?C`h>SHj?TI5@D8n?3dm>c`moCU9
>Shn>D0h>chm?D0l>3M0=T0n=T0n@CPh?D4o>cHj>SHh?415?c`m>CLm@S/i<c`e
>3Lk>c8c>3Tl?3/j>3Hi=SLg>CjJjncZk>h2JAOMg>3NVdTg<S0d=C<e?T11=c<f
>ce1>C_n>VA1?3Tm?d=1AD90@C`o@dj_>3LiBDeXS[K>]eEf]LC0blG8_jRh_/>j
b<G2_kk5eM?Idm?3b/_>cm?=d=OIiE]9A410@Cm7AShb<cPf=STk?3Ll?d12@clo
@dXo@D11>T@o?d<m@F=4?clm>c/o?d4k>cXoA4Dj>Ce0>chh?dHj@d<l@Cho?d8n
=c/nAca2@C`i=CU0B452>3hn>S=8>3De>CPk>c`o<c@i>SLmX^_[kNk_gMcPgY]9
=c8`=3Dc=Ci0@CLc=S/m@CTkoSXH@C`i?Cm3@DE2@44l?d=>[cPg>DU=J8jfcWng
EGJea<3;aLRoZ;Rn`k[8aL:o_/GEdmWCdl?:blk?dlg@emWUFdU4@411?dM6?S8c
>3Hf>C/l=c`o@493?cm3BSm1@44jA3lo@ce1A3lo?C/k?cm1>c/j?dA5>STm@3/n
>3m6>T=3?44n?cm2?SLk?TLl@T4l>CDi@4Q1@SPn?Rlj<dPh=CDi>3/k?3lc=3Tj
=cfRjn_]k^oMg>3NVdTg<S0d=C<e?T11=c<f>ce1>C_n>Ta1?3Tm?d=1AD90@C`o
@dj_>3LiBDeXS[K>]eEf]LC0blG8_jRh_/>jb<G2_kk5eM?Idm?3b/_>cm?=d=OI
iE]9A410@Cm7AShb<cPf=V<i>c`g?3m0@T<o?d=:?d50@CY4?cm3?D54?clm>c/o
?d4k>cXoA4Dj>Ce0>chh?dHj@d<l@Cho?d8n=c/nAca2@C`i=CU0B452>3hn>S=8
>3De>CPk>c`o<c@i>SLmX^_[kNk_0VWog1KNg:AC@d0j<C0c<c4d<Blf>S`l>cPb
<ohnHcXf=C0f?dE0>3e0GFM;ACi6E8R?X8fNNJA6J;bi/:NHX:JVWZJQVK:ea<S=
a[k0b/[?clk4b<SEem_Me]eZBTE5BCdi?Shg<cdo?3Hd;3Hn@48j?c/l@TU?@cPk
>cm3>SU0>3ET<cXf>D0l?CTj@40m>T8o=STg?D91>3`o=d4o?4Dk?3Le@3`o@D4m
>d14>cdl>Chg=cXm=cXe>C<_;chi=c8d<cLc=cTj?j7[jno/kmcLg]bTDd=0>S4`
<c<a=34_=SXl?3/h<S?n?QLj=SD`=Sm5@3Pm@5eWBdDnAUB8Sj2=WWUoY4IX_;V`
YiRPYZJNYZ6I/[G4b<g6_/3:b/o?c/C8b=GGfmgFgFY:ADE9?CTn?SLc?Cll=S@/
=Si0@SXo>ca2BDm3>3/k?d<j>D0h=C<j=SU0?3di>T10?CY2?cHi=ce2@CPl?cM1
?ca5>c`g=D0l?d51?C]0A3/m?3Tn=cLj?CL`>SDi<bl_?STg<S@c=c<g>CXoXN_[
knc_g=cNg:AC@d0j<C0c<c4d<Blf>S`l>cPb<ohnBcXf=C0f?dE0>3e0GFM;ACi6
E8R?X8fNNJA6J;bi/:NHX:JVWZJQVK:ea<S=a[k0b/[?clk4b<SEem_Me]eZBTE5
BCdi?Shg<cdo?3IS=2`f?T12>Slk?499Cd<h>c/o@cXi@3Pe<cXf>D0l?CTj@40m
>T8o=STg?D91>3`o=d4o?4Dk?3Le@3`o@D4m>d14>cdl>Chg=cXm=cXe>C<_;chi
=c8d<cLc=cTj?j7[jno/k`9YGmgOhMbRHV1FF3<_=Rh]<3@^=Si3D4Hf@d12?cLe
=CHd>T8hA4i4?D=7BEE=IHnFUXZ8OEniAVRa[;N]YZj/Vj:_Z;6f^[S4c/g7c<C2
b/kBdmCCdlK6fmgPM4]2@D4m?Oi273U0@44g?Sdl>chm?dE5>d16D4Y7ADA5>SHm
?ca0OcDi>Cln?3dg@D19>T@kA416@3dm>clk@3Y0>D90?d8i>3hn?3U1>414?Sa4
@Sdn>3HbACho>3dg=c8o@CXa=c@m=SDl>D6NkNc^kngMgn7LXV9PEUPc;cH^;C0d
;SHn@e16=T=0@Slg=CDf=3Y2>4A>A3e3AdUECFF?UYJ:R7eO:kU6J;6/]jfV[ZbK
XZnX/KJj^<C>cLO<a<;:c];Ce=?Ca/KKgN1dBd91@CdmoT9@>D10@CLn?C`k?Sdo
ADDk@4I@BTM5A4Dj=Sdo?40e>CTo?S`m=d50BCY4>dA0AT0m?C/o>d0j@3U2@3m2
>CPn?S`i@CQ0A3hlA48m?SPf<TDnMclh?CLg<Sm1>S4g=3df=C`i@Ik]k>k_kMgO
hMbRHV1FF3<_=Rh]<3@^=Si3D4Hf@d12?cLe=CHd>T8hA4i4?D=7BEE=IHnFUXZ8
OEniAVRa[;N]YZj/Vj:_Z;6f^[S4c/g7c<C2b/kBdmCCdlK6fmgPM4]2@D4m?Oi2
13U0@44gHchm?3/n?Cm5AC]0AU1:AdE4ACXf?Cll@3Di>Cln?3dg@D19>T@kA416
@3dm>clk@3Y0>D90?d8i>3hn?3U1>414?Sa4@Sdn>3HbACho>3dg=c8o@CXa=c@m
=SDl>D6NkNc^knd2JOoLomikWUIIEf<e<C0b=3Db;Bm>I<>^FV]IDEYB>C<e@4IG
De]MF49:D5AWLh>BPgYVJGAmBT9eYZNRVjVNV8ZPX:Z_^kk=a/Fe^kW<c=;9b;_3
a=?9c]?9bWi5Addn>SXm?Sa3@CHe=3Lh?Cdn>cHh?CQ0De99@clkA3ln>cPj>7lh
?D0g?Ca0>d=5ASXm>3Td>Ca7>cLj>44n@Cho?40n<c/m>CTf>3Q1A4<n?CTf>Cdm
>44i=cPj=S/h>cHg<cHh>2lc>CY1W^[[k>g^g=cNgYiFFEMS=C4`<S@e<Rd_CVC3
[UY[FE5JDSTc=D16Ee=KGEQ2BU1DIg>3TX=jIVUdOGm:@WFVYj:KZIjHRZ2PZZnk
_/g6aKFk^Lc<d/W8^l?4dlW>dlW:OTE7CChj>Sdn?4=1=SDd=cPm?Chk=SPm>41C
DTU3?c]4?chk>3Xh>3e0=cdl@3]3ADHj?CPi=3TlAc/g>SQ1?T4n?ca0?S<k?CTi
=SPh@DA3?Sdi=STm?CQ1>Glg>3Xf>cPk=SLc=SPh;c<i>T6Nj^_/kNkLg=kNWUII
Ef<e<C0b=3Db;Bm>I<>^FV]IDEYB>C<e@4IGDe]MF49:D5AWLh>BPgYVJGAmBT9e
YZNRVjVNV8ZPX:Z_^kk=a/Fe^kW<c=;9b;_3a=?9c]?9bWi5Addn>SXm?Sa3@CHe
=6<g>3dm?S/f>3dh@5=BBD<o>d@o?S/h>SPh?D0g?Ca0>d=5ASXm>3Td>Ca7>cLj
>44n@Cho?40n<c/m>CTf>3Q1A4<n?CTf>Cdm>44i=cPj=S/h>cHg<cHh>2lc>CY1
W^[[k>g^0VWog7gOgZ5HDU5H>C8c=STe=C@bHJO9Ne5JFG=B@SHg?5ILK6E/DdXl
Jfa@J6ijIfe?GHN=KEI//jBXZ:BBPGb<XZZj_Lg5`l[3`LS;b/K>cl_=clC>b<gC
blZRD4M=A4Hn?ci0>4@oBdLm=3U1AE14>CXk@EAID453?DM8BT4o>T9o?3lj?Se5
?Se1@4U7@T8l>3a0@498ASLm?TA3@Clj?CTh@Clh>3@h>ca0?SPf>CDh?3M1>3dg
?CLh=3/c>3Tg>CPc<cPg?J;^k>k]kmcLgmjQF59AF3Tb<cHi=CDd<V6WbG]AFUUc
DT8f=caFG6aUK5=:?6]/D6Q^NVM]Cef7SFeoEVbcY:RXY9:1O8bRZ[ZmcLG3b/?1
b<_:a/k?blg?a<k8cM?;bZ9@Ade4ASho?T0hA3m;Acdd>D55D4@i>S]1E5U@@D<m
AdQ:@Clj@S`o>ShmAChm@D19Ad92?3Pl@412B4Hg?Ci4@d4o>Sdi>44o>3Pd>3/l
@3hh=STe>3`g@CQo?CLm=cPd>c<h>CLi>3<c>3LmX^k/k^g_g=cOgZ5HDU5H>C8c
=STe=C@bHJO9Ne5JFG=B@SHg?5ILK6E/DdXlJfa@J6ijIfe?GHN=KEI//jBXZ:BB
PGb<XZZj_Lg5`l[3`LS;b/K>cl_=clC>b<gCblZRD4M=A4Hn?ci0>4@oBdMS?C@i
@DE@A3Tj>d5DFE11@ce7B4Y1?cY2?3lj?Se5?Se1@4U7@T8l>3a0@498ASLm?TA3
@Clj?CTh@Clh>3@h>ca0?SPf>CDh?3M1>3dg?CLh=3/c>3Tg>CPc<cPg?J;^k>k]
k`9YOmWMgmj/O75OGcL`;Rhl=cHd=6F3ETQ=Be5;=S@e=CPg>S/e>SHi>3U:ADa8
FEm<DeYAHFnDUIj<NFIaPWQiUJFV_/G=aL6m/jc8b=;=ajjd/k_9cLK7al>n[E19
AClo>3/oACHl>S/h>C/g@clc=S/i@4==BD4k?SU3@d4h>Se4<ShmASPj>3dg?D93
@clg?D4i>D0m>cY1@3`o>Cdi@cLh>CPj=SU1>SHl=cdf<CHe>3@i>_h`BC/d=Bh`
=3Ti=3Lb;S<g=SfNjnk_k^oIgMoN[7aaGelg<2h^?3Lf=3AUPeI8CD]ABcHd=CDh
=cXk=CXf>CPiBTE<B5UOC5=JDF5_OiBEWXaiIW62N7VEYJJnaLg5`Kfc[<S8d/g7
[[Bc^lW=a/O7`kj]D4U5?clh>cm5=S`j>cPi>cM3?c<f>cU0@de9@C/n>D=3@CPj
?D@n?DHh>SPm=ce2@d<o=ce1>CU0?C/j@D0l?cTm>D<g>3Th>SHi@CXf?3Lm=S4f
=CPd>CX`oc1m>c@e;S0d>CTd=c8^<cLf?Ik[k^o^kmWMgmj/O75OGcL`;Rhl=cHd
=6F3ETQ=Be5;=S@e=CPg>S/e>SHi>3U:ADa8FEm<DeYAHFnDUIj<NFIaPWQiUJFV
_/G=aL6m/jc8b=;=ajjd/k_9cLK7al>n[E19AClo>3/oACHl>S/hBSTk=d<o<cHk
>D13CDU1>chi@d=1>3XmA3hmASPj>3dg?D93@clg?D4i>D0m>cY1@3`o>Cdi@cLh
>CPj=SU1>SHl=cdf<CHe>3@i>_h`5C/d=Bh`=3Ti=3Lb;S<g=SfNjnk_k^l2JGoN
g>3M_8QZG68n<Bdb@5E0>SYb]4Xo=U5[KdU;=S90?cPg<C0hCClhCfI1=3XhH75/
EEYWMW5SGVE_Sijh_Jjl/lFj_<G8`;fj`<7:a<?0aKV`]L7>bL_6a[aIATQ6?Slo
?3a2@Slg>3/k@4M0?c/m>cU1A5A@?c`l?d13>CTk@Glk=T@k@c/m=Si6>cQ6?3`o
>dA5>D0i?C/k@T53?Chh>Ce1@Sa:?cTj>T0m=cPl?3/h=SHc<C0l>3T`=cPk=C/e
<c8_=SM6ZNg^kO3^g]cPgKb8JUaR?S4]<T1E@3XjL[A:?cIAJfm9BcHb@3lh=c4`
>4do>4mV@C@j>61aK5EJIgmfLF=NIFn?W[Rm[[bcaKZlaLS0_K[0`L[4`l35^K2e
`Lk9blK6_5U6B4Hn?cll?492?cLh>c]0Ad0o>cdk>D54E50o?3`o@4<i>C]1>cI4
>d<k?CHnAS/hAS`l?c]4ACU0>Cdk>d91@cdn>3Tm@D8lBSli>SY0?CLh?3`k>3Hf
<gla<3`h>C0g>3/e>cDc<Rlf=dJYkNk]l>kNg>3M_8QZG68n<Bdb@5E0>SYb]4Xo
=U5[KdU;=S90?cPg<C0hCClhCfI1=3XhH75/EEYWMW5SGVE_Sijh_Jjl/lFj_<G8
`;fj`<7:a<?0aKV`]L7>bL_6a[aIATQ6?Slo?3a2@Slg>?lkHD17@3lk?C/i@DAD
D3ll?3m0@cTi>d4k=T@k@c/m=Si6>cQ6?3`o>dA5>D0i?C/k@T53?Chh>Ce1@Sa:
?cTj>T0m=cPl?3/h=SHc<C0l>3T`=cPk=C/e<c8_=SM6ZNg^kO3^0VTTfM_Mg:QL
Ge]I?bh_<59QCc`f?3/a<c@d<D<m>D@h=Sdf=3Lm=?hi>d0d=C<`<S<nCUQWHEYB
I7:MZ;6[[ZRR/KOBc/Rj^jZX]knk]Z>XYJ^_`LFh][[3`;KBKD90?c/i@4E1=ohi
63hi>3/j?3Tl@d<k?SU1A3]0@Slm=SA2?TM`?3Xn?4E6?SY0?CLh>SHl?SPf?3Hf
=ca1=cXk>3e3>3/n?c/f>CPn@cTm?CDo>cdf=Rl_<C@b>CDl;c@e>S@c;c@d=SDf
B:gWj^k^kmWKgMbXG5mKFCl^;c1BHDll=S`k<C<d=353?CU4>3Hm=S@g?CCn>@]0
=3Dc<38c?TiHIf4_FU9TLYfX/J^^Z::a]m;>b;ZkZZRg_k^fXjRUZjo1aKRf^/?0
]]9]@T0o>cU0AD4goSU<?STh>cXl>Ca3@c/n>D54>d12?cdf=48nAc`j?Sa5AShj
@3dg>3Xf?3hh=S`f=SLl@CLj>cPm@cPk?Slk=STh?T<i?Cde?c/m=SH_;c4l=38i
=C`_=3Dj=3<_=3@f=CI8[NOZk^k_fM_Mg:QLGe]I?bh_<59QCc`f?3/a<c@d<D<m
>D@h=Sdf=3Lm=?hi>d0d=C<`<S<nCUQWHEYBI7:MZ;6[[ZRR/KOBc/Rj^jZX]knk
]Z>XYJ^_`LFh][[3`;KBKD90?c/i@4E1=ohi03iS>CPk>S`i?4=3>chi@D@k@48o
?CHd@Si7?3Xn?4E6?SY0?CLh>SHl?SPf?3Hf=ca1=cXk>3e3>3/n?c/f>CPn@cTm
?CDo>cdf=Rl_<C@b>CDl;c@e>S@c;c@d=SDfB:gWj^k^k`9Yomd@gmfWEf1TGU0j
<Rm8GUaW?SWn=fTc>3m1?CHbCCi4@chg?T=:=c8d?3Y0>S@f@eYKLX:2S8bDVjRX
/KN_YjFXa<kBcLfcY;6Z/;6h]kNfXZni_<C6c;^mbXm5BdE9>D12?Si7@Sln>d8l
=dE0?T0n=c/o@Dhh?dE6AT@m>cQ3?DA0>Sa9ATQ3Bd4o>c/f>3M0@clm?CXm@D=2
ACXhA3U1@Clo?3/g=44g>CDj>CLc<CXa<CPf>Cle?3@g=3XioSDM>C/k?4>]k>g`
l>oMgMoMYeMPI5i@>S8_B5iLIchioSLM<cPo@Cdf<TdnA4<n=ci3BSLb=3`j@3Xd
=T=JFg:2Oh:<S9BKZ:Ra]jnWYJS4c];=cK>T/JZ`/KRg]kJR[kVla<K<^kg:SdE;
ADTi@48n?TM2?chk@S`gAD0n@3hg>cm1CSPoADI6A3dk>4=4@3XlBDI8@d]1?c/k
=SPg@4<o?Cdj?D53@TDj>4@i@D4o?c`k=cA1=cTe>STg<c4j<C4h2CHi?cDl=3Ld
>SWn=Adi>c/l@jg/kO3`kmgMgmfWEf1TGU0j<Rm8GUaW?SWn=e4c>3m1?CHbCCi4
@chg?T=:=c8d?3Y0>S@f@eYKLX:2S8bDVjRX/KN_YjFXa<kBcLfcY;6Z/;6h]kNf
XZni_<C6c;^mbXm5BdE9>D12?Si7@SlnEC]2?3M5@3i0?SLk?d5>>3m5ATI4?C/h
@dA0>Sa9ATQ3Bd4o>c/f>3M0@clm?CXm@D=2ACXhA3U1@Clo?3/g=44g>CDj>CLc
<CXa<CPf>Cle?3@g=3XioSD:>C/k?4>]k>g`l>l2JGoKgMoNY69MEE==A3DeBeEC
E5AE>CDd=CLb=T0e<STe>C@h?3/m?CDc=3@k=c<a<2hjD75dO7J2SibVXIfOUIVC
S9f^YZ6PW[:i];2WZj6XZkFc]K>f]lG;bLJE?c`o?3m3@3/d>Cm6@3Tk>3<g@Se0
?Shi?TI:?3`o?C/i?3hm?glf=cDj@D=5?dLj>cLi<cXd?CXi=CPi?D4f=Chi?d@g
?SPi<SPd>S4g=SXm?Slc=SLf<c`d<C@h=3Ld=c8c=3Tf>cDf=CXnYN_]k^g`fmgO
gZARGEECCD@e=D]EDeADECTe=3Dg<SI0=C8i=CTd>3`k?Cde<c@d>cLc<C0^>U1a
M7mlMX:?W:JQWInEVI><WJjVXJ2N/[Vd/:N[XJR[]K>e/kJgaL_9aYDo?3ll?d=0
>c@i?dI0>C/h<cM2?D0n?STnATXl?3lm>cTl?Sdo=SLe>T53ACm7>S/g>C<j=3dj
>CDh>Ce1=SDn>Cm4=chh>C8h=3Xa=cHj?Cho<cHg=S<l=7la=3Pd=c@g<S<d>CHk
=CHe>SjUjng^kO3KgMoNY69MEE==A3DeBeECE5AE>CDd=CLb=T0e<STe>C@h?3/m
?CDc=3@k=c<a<2hjD75dO7J2SibVXIfOUIVCS9f^YZ6PW[:i];2WZj6XZkFc]K>f
]lG;bLJE?c`o?3m3@3/d>Cm6@6<i>cPc=d8m@3hn>Ci6BS`l?cdk>C`n?Clf=cDj
@D=5?dLj>cLi<cXd?CXi=CPi?D4f=Chi?d@g?SPi<SPd>S4g=SXm?Slc=SLf<c`d
<C@h=3Ld=c8c=3Tf>cDf=CXnYN_]k^g`0VUogMcNfimLGeeLEU4d=c]EFf5BE5M=
>C<g=C@j>B`a;Shm>Sdo=c`g=2la=30a=C0cA4U5@fibMh2@RXf<UiVSVXMfNh>2
WZ2][kNRVj>ZZJZW^[^k/;O1`KbX]T52@Ce3?S]0AT<k@Slj?CTn>3ho@c/o<SQ2
@Clm?CTm>Ce1?ceo>3`i>Clm>cdj>Shc<3<j=3Dh=STe>3Xo=38m=SHk>3Lc<CDi
=30e=CPi@Sdi=3Hb<B/c<c4d=38b=3Lk<c8b>Sdf=S`g@:W[knk`lMgLg]^OG5mM
G5IA=3LkEE]QDUAGCCTc=cDd>ST/<Bhn?CXm?cLl=c@_<C@`<CD`<dA9AD=oKW9g
P92:SHbGVJ>JQgIkPh:NX:f_]j:KXjZYZZNj^k^`]l71_:Rf@D91?D<n>d16@c]2
?cXm>Chh?Sm3>clb>491?cdm>Cdi?D4o?CPl>CTo?C/m>SXn<c0c>S@e>3Hi=CPj
?c@b?CHf>cPg<c4e>C@`=CDh>D8m>C@f<S4[<c=o<C@d<S8d=c/c<S8j?CHf?3M0
ZN__k_3agMcNfimLGeeLEU4d=c]EFf5BE5M=>C<g=C@j>B`a;Shm>Sdo=c`g=2la
=30a=C0cA4U5@fibMh2@RXf<UiVSVXMfNh>2WZ2][kNRVj>ZZJZW^[^k/;O1`KbX
]T52@Ce3?S]0AT<k@SmS>Sdi?SPn?d<k?c8h@T4o?Cdi?CTm@Clm>3`i>Clm>cdj
>Shc<3<j=3Dh=STe>3Xo=38m=SHk>3Lc<CDi=30e=CPi@Sdi=3Hb<B/c<c4d=38b
=3Lk<c8b>Sdf=S`g@:W[knk`l@9YOmgOgm^IHEiDF5aQC3dlD4iIHV5MKClb?3Hf
?3Lc<CTn?D=1@cdi<cLa<SDd=CLjAEMDDSe>HY6:VIBCR7I_MH65ThUlPK>ga<6k
V9FT[kk1/ijBVYV`aL[0X:Y1@Sm=?SXk=c]1ATlh?C`l>3Y9@Ca2?C`j?TU6@3`g
=SXi@d90OcHa>CY5?C]3>3Hj>3`i>3M1?3Dd=c`e>c@g=cTe?3Pf=c4c>SDa<C@j
>48g=2la<cLl>C@k=3L^=cXm>Sha=c`k>cLo>T:YkO3`k^oMgmoKVF5NE5QLHD`m
?51>FF9QGFdo<S`f=S`g<c4i?Se3@D<m>C<g<C8e=3Dg>TEGE58mOdiRTHZIU9>8
MVmePHFCRGb1/kO4`K^HUJB__/6cWY:JVK35b/2PZT52?ddn>S/g>d56CcPm?3`h
>TU1?48m?3XnBDI0?3Lf>SU3@T0f<CTjACdk@cPf>SPl>CPg@C`e=3Ll=C/d=cLi
=C`h=SLa<cXe<C4d>SQ2=c@_<C<g?3TdOc/d=bhg>Sdj?S4g?3/k=clj@ZW]l?3^
kmgOgm^IHEiDF5aQC3dlD4iIHV5MKClb?3Hf?3Lc<CTn?D=1@cdi<cLa<SDd=CLj
AEMDDSe>HY6:VIBCR7I_MH65ThUlPK>ga<6kV9FT[kk1/ijBVYV`aL[0X:Y1@Sm=
?SXk=c]1ATlhHcdl?3PjBD4l@Sdl>Si9AT0l=cHj>D=2@3Ha>CY5?C]3>3Hj>3`i
>3M1?3Dd=c`e>c@g=cTe?3Pf=c4c>SDa<C@j>48g=2la<cLl>C@k=3L^=cXm>Sha
=c`k>cLo>T:YkO3`k^l2IWoMg=kKSTIZGEmGFDXo=dEBFU9GEUeE=STb>C@f>CHe
=S<j?D0n=C0b<c<h<C8b=4]<=CDd=3U9AV1HIe]^PYB[QXJCXj6QY:NGXJ2`ZjNR
YIjKXjFOYjBZYjjiB450?38j=cPo?STo?3`n?CPg>CTl>CLg>c`n>3Xi>3Dl=S4g
?`/i>SPj@3dn>CTf=SOn>ohg=C@f>3@e>3Hh=SXb=CDd<blc<Rlc<3@e>3Da<c<d
>3hd<S4b=cDf>CLo?CLc=3Xc>38i>dFYkOk^=>oMg=kKSTIZGEmGFDXo=dEBFU9G
EUeE=STb>C@f>CHe=S<j?D0n=C0b<c<h<C8b=4]<=CDdEc@iBDIPF6MKKX:DZhJ6
Tj>QXJBWUj6P/:^WXZFNVj>UWjNTZZN^^DQ1@3`b>SLh?chi?c`l?Sdh=cTi?3Tg
=c/l?SPj>CPe?3Ha=cli>SPj@3dn>CTf=SOn>ohg8C@f>3@e>3Hh=SXb=CDd<blc
<Rlc<3@e>3Da<c<d>3hd<S4C<SLe=STg?cdg<c@j<cPb>C]5ZNgnkVS_gMcNfhi6
JUeOEeU:?cM5DUYBEeIMECHi<STd=STf=CHc>Se0?SD`<S<c>34b<SA;C3De=3@i
BDIPF6MKKX:DZhJ6Tj>QXJBWUj6P/:^WXZFNVj>UWjNTZZN^^DQ1@3`b>SLh?chi
?c`S?3hm>3Li>C`i=cLk?3hh>STh=C`f<CLo>CXh>T0m?STi=SHgoS_n=cDd=SPd
=CPf>3Hj<SDe=3<_<c8_<c0d=CPe<C<c=3Pn=38a<SLe=STg?cdg<c@j<cPb>C]5
ZNgnkP3_0VUOgMoPgY91D5=ZKFaGBSDe@6IUJ5]BECXi=3`c=c@c?di2?Tg1JcHo
>Rha<cHd=E<n>cTi<c0d>d5kOWi/EYK5_j6MSIZZ]lFo[:2AXInb[:jQWYbSZK6_
/:BX[5]2ACXkoSLL>ce3@3dj>S/nA4@k>CHl=SPn>clk>SXm?T4o=3]o<d0g@D0l
@3Hi>chi>CPf=cll>S4m>3Hd>C`j?3Hj=CHf<c0k>S4c<30h>CXj<cLf?CLe=CLd
=Sa8?4=4Bc/i>cHj>Chl@j_ajo3blmgOh=jB@E1CJVe/EdXe=D1VIFQKDUDj>C@l
<cLd<cm>@Si=`F/f?cX^<C<f=3EC?S/i>C<[<3@k@G]nOVaFU/FoXIf=VZZgaKn/
X96QWk:/[Z6NW:>Y/Jn`Y:R/Fd95>S_n=e0k?D=0?CXj>ci4A3/i=S`f>3hk?c/j
>Sdn@Cld>c=0=d50?40f>C/n>CTh=SLo?3Xa?CPf=3Tl>S`f>SDf=S<`>cXa<c0`
>3Tj>S<g=Sdg=CEg=c@f?4Pl@dA;>cTk=SXi?Sa3Zo7[l?;cgMoPgY91D5=ZKFaG
BSDe@6IUJ5]BECXi=3`c=c@c?di2?Tg1JcHo>Rha<cHd=E<n>cTi<c0d>d5kOWi/
EYK5_j6MSIZZ]lFo[:2AXInb[:jQWYbSZK6_/:BX[5]2ACXkoSL4>ce3@3go>V4k
?TA4>cTf?3Hh?S/o>cXj?Ci1?c@k<d0g@D0l@3Hi>chi>CPf=cll>S4m>3Hd>C`j
?3Hj=CHf<c0k>S4c<30h>CXj<cLf?CLe=CLd=Sa8?4=4Bc/i>cHj>Chl@j_ajo3b
l`9XOmkKg]nG>c<g?4E@C58i=31EGEYOFE]4=c90>cLk>d93<c8fHDdf=SLb<S0g
=SDj;Rlb=C@b=D13CUU^OeEh^[^`^YjVVZ6Y[i^NZInDXXNASHfHTI:V/iZQXJ=F
?3Xi>S/e>C`m=SPj>chk@3Tg=STj?C@h=3Le=Sm1=cDd=34oB3Xh>C`h=chm>CTn
>3Tj=cDo>CTa=SHg>SLj=SPe>3Dd>3<`<C8j=3Pf=CLj>SPn>3/i>cLj?SDf>Chn
>3Pk>3@g=SHi@4^ek>onl3?NfmkOUc/c=ca5D4aB>C@`EEeJGeUKA3Lb@3/g>c]2
@c<b=V5==SHg<S8`=cHe>Rh_<SDdOc8e@4=>FFioEGRj^k2jWZJJXJV_VijYWiBR
Qi6=SIRATZJcVZ6QXeHl>STj>cDi?3df>3Xk?S]0>CLf>CXm=3Pd=cDf?d4g=C@d
<Clj>3Tl>3Ln?CTi?SPi>SLe?cTi<CHf=cXg>SHh=CPe=3Pc<34b>S@h=SDg>SXh
?SPk>C/g53Xn=CHi?Shh>3/h=3Lf=SU0BkG/kok`ImkKg]nG>c<g?4E@C58i=31E
GEYOFE]4=c90>cLk>d93<c8fHDdf=SLb<S0g=SDj;Rlb=C@b=D13CUU^OeEh^[^`
^YjVVZ6Y[i^NZInDXXNASHfHTI:V/iZQXJ=F?3Xi>S/e>C`m=SPjH3/n>d0i=cHi
>Sdd>3@g=CHo@CLe=3@a?cXh>C`h=chm>CTn>3Tj=cDo>CTa=SHg>SLj=SPe>3Dd
>3<`<C8j=3Pf=CLj>SPn>3/i>cLj?SDf>Chn>3Pk>3@g=SHi@4^ek>onl09YomeM
hN2aDE1=?CDf>3hi=cLoBUQ;?STn?Sm4?d4g>cHg;C4c@3Dh=3Lc=Bhb<cDc<S4b
<Bhb<DE=D59HJI5n`<>o`KjgS9fKUh^FU9JHX92GOhZFWjBe/IVIV:EVBTY2>_hg
74E:@C`f@Cm1ASTi<C<f?3i0>3Tj?3Hg=cXk<c<nOcdi?3ho?44i?3Lk=Slj=351
>cXf@CLh=cdk>CLd>cDg<SDa>S@i?495@cTf=cHo>Chm@D4l?3Xe@C]3BT4k>c90
@CPi?Tf^k>k/l?3MgN7P/E5@CCde=SPn>CLg?dYHBchi?ShoA3m1=c/f=bda<d0e
>3@g<cD^<S<e<c8a<S4^:c8aADe@DUQYTGk0`ko1_[N<WI^GRiJDUYRPT9MoRYJO
Y;FaVIVHYFI:BT8joSM@ADY1?3I1?d56>CTa<cHl?T0h>CXl=SLg>S/c<chm>C`n
?ca1>C`g>cHo>S@a@C/j=T4g>3Lm>cTg=3/e=c8e<CXd>Ca2AD<i=SLf?cTn?D51
ocae>SE1>d=:@C/k<T11>3TnCJk/k^c`l=gMhN2aDE1=?CDf>3hi=cLoBUQ;?STn
?Sm4?d4g>cHg;C4c@3Dh=3Lc=Bhb<cDc<S4b<Bhb<DE=D59HJI5n`<>o`KjgS9fK
Uh^FU9JHX92GOhZFWjBe/IVIV:EVBTY2>_hg14E:@C`fHd4o@DHi>C4c=S`n@3Pi
>S`f=cLj>c<c?Sdi?3ho?44i?3Lk=Slj=351>cXf@CLh=cdk>CLd>cDg<SDa>S@i
?495@cTf=cHo>Chm@D4l?3Xe@C]3BT4k>c90@CPi?Tf^k>k/l?02JFWMg]kOYFMR
HE/h<S<c;c@c<3@e<SDgCUQ9@3De=38c=cDa<SPd>2d_;c0e<S@_=3@e=S/b;ce?
BUiIEFA^OJ:PVYn9Q8fLNgV3Qi>DLgIgPgjLS9V:UhYkQ6=C=SDn?CHg>C`j>CLf
?ShjoSTB?CTi>3He=CTb=CDf=cDa<CDf>18e>cXg>CTg=cPc=S<g>CHd?cHfoSEY
=cTi=C<c=3<c=CHj<S<`=S/n?T8k?C/h@CXi<SPg>cdd=cXd@S`o>cPe>cTi>d54
Yng_lNk_gMkNgjEWHV5K>38c<bld<c0d=C8e=diHBD0e=C@b<cLe<C8h=3P];bl`
=C8d;c@d=CHk<SD_?Dm:GUUEI6imXZ2JWhV4SIakNH>7TiAcMWN3OYb<VHZGRW^4
He<f=Chm=SLi?3Xi=cHn?S[n>BDm>CTh=SDe>C8e=CHg=C4a=CHh=C/j=cTi=cLh
<cHc=cTf=3lf=_he7CLi>CDc<c@c<cDf>S8c<3Hk?Si2>cdk>44j>C8h=glk?C@g
>SA2?3lk>3Dk>CTk@DBWkNoak^oMg]kOYFMRHE/h<S<c;c@c<3@e<SDgCUQ9@3De
=38c=cDa<SPd>2d_;c0e<S@_=3@e=S/b;ce?BUiIEFA^OJ:PVYn9Q8fLNgV3Qi>D
LgIgPgjLS9V:UhYkQ6=C=SDn?CHg>C`j>CLf?P4n>_hi9Cdi>CPf=CDi<SDe=SLe
<C4e=SPe>cXg>CTg=cPc=S<g>CHd?cHfoSDe=cTi=C<c=3<c=CHj<S<`=S/n?T8k
?C/h@CXi<SPg>cdd=cXd@S`o>cPe>cTi>d54Yng_lNk_0VUZgMcQgYUKIVEdIeeI
FeiL?C8e>3U=I61JF5I1>C@m>3/c=c@i=c<h>S0g=d8e<CDf=Ca@?SQ8FE1CDU9O
MHbAR6mFEJJDT7moQgeZNYJGS860VJ6^YY5iDU0l@c/j?S/k?chj@Cdm<cTn?3cn
@A4k=cHj=3Ti=SU2>3Db=3Xl=STB>c`l=cLf>cY1=SDg=S@d=CPh??hgJCPd>3Tc
<c@f?4Tl?3Pi=3Y0BSi8>cXg<3Lo>STn=cHh>3`m>Chn>cXm?C/c=C/jA:_`l>k^
lmgLhMjIFfIUM6MMFE]NG3db=CPiCFAPFUQF@CTd?CPk<cLd>CLc>3X`=cM2=C4e
=SDlD3hf>4QID5=BDUmeS968KeIEYYB@Ogn7OFYjUYN<PH2IXJjVTGUBD3a3>cXn
>c/o?SY1?Cdc>Chl??i193/g=SXd>CTf>D8h=C8d>S`f>C/l?3Lg=S/j@CHe=cHd
=3Dh>3cn=adh=3Pi<c<d=Sa9?3`h>C@j@4XnB3/j=c0g?cXi?SMo=SPh?3di?Shk
>Sdm>c<e>cY4Zo3`k^kcgMcQgYUKIVEdIeeIFeiL?C8e>3U=I61JF5I1>C@m>3/c
=c@i=c<h>S0g=d8e<CDf=Ca@?SQ8FE1CDU9OMHbAR6mFEJJDT7moQgeZNYJGS860
VJ6^YY5iDU0l@c/j?S/k?chj@Cdm<cT2?S`loT4T>cLf>S@i>CHi@SPe<S@j?3Hi
>c`l=cLf>cY1=SDg=S@d=CPh??hg=CPd>3Tc<c@f?4Tl?3Pi=3Y0BSi8>cXg<3Lo
>STn=cHh>3`m>Chn>cXm?C/c=C/jA:_`l>k^l`9YomaBgMjKHUeEEe9KGfMOHe5:
@SXk>CY1@TA<C40d=S<k<C8a;c0a<3L^;3Pl=cDf@4M:DS/`?E1GEUM7CUQSFUUF
Cd]?B4E3FfQTKHV6RY:2O6mNBdCn>RLi>S/b<c/h>S]0?3`g>34g@3/c<S@o<blc
=Bdc=S@d=C8i=C4c<3XiOcLc=S@l=3Xf=cHi=CDd=SDj?3He>3Lg=C<l=CTb=cTo
=STd?STo>SXi=SLn?SDi>S8h=c/j>3Xh=STk=c`g>clj<cHi>DNZk>k_k_7Lg=gN
Vf9MEEMBFemWGf=ABT8j>cTj@D94C4a0=3Hc>c4b<Bl`<C0g;R`h?3Le=T17BU8k
830mD5MFEdM>F6=JFEI?Bdm8AD=KJ6A]RHJ:TX9lKei;A?hjFcTj>c8c>cPj>d0l
?3Lh<CM0>c<b=3lc;c<e;C<f=3@e<STe<C<`>STg<cHd?3@j=SLf>CDe=3He>S`f
=CPg=cDc?3Di<SLi?cHi=3hi?cXj>CHg?She>CXb>3LkK3Xh>SPf>C/g?3Lk?cXc
=STiAj[/k^o^lMcLgMjKHUeEEe9KGfMOHe5:@SXk>CY1@TA<C40d=S<k<C8a;c0a
<3L^;3Pl=cDf@4M:DS/`?E1GEUM7CUQSFUUFCd]?B4E3FfQTKHV6RY:2O6mNBdCn
>Pli>S/b<c/h>S]0?3`g>34gHd0k<c8d?c<_<cD]<cHd=3Db>CDa<c0j>CLc=S@l
=3Xf=cHi=CDd=SDj?3He>3Lg=C<l=CTb=cTo=STd?STo>SXi=SLn?SDi>S8h=c/j
>3Xh=STk=c`g>clj<cHi>DNZk>k_k_42JC_PgN3PVf1[J6AGDU5LIfIKEdUABDLk
>She>cU0@D<o>34g=c@c=c8h<S@l@TI2D4i?CV/k=DIICEASBDCnEbm0?eY?@Shj
>3m3CDe?DeE7@Ti4@3Tj=cXh?3lh=SDj=ce2@D8i>S/b>3Xk>cDg>CKn>`dl=C@d
=cHd?S@b<C<g>7li=cDd=c8d=cLc=SDf=CHh?3lg>Slk=C8l=c<a=3Pl?412=SLk
AD4j=cDe=3Lj?44j=CHg@Cm3?3]2>cDg?TU5?c8f?D5O^>o`l?7bh=gPh9]PJfQT
Ee9AG6MVFeM9DDU7>cXn=C/i@453?cPa=cLd<cLb>38d?496@U1>Cdi[>`LeAUU=
E6=9A?iG;d0oFTm2?SXh?d==CDmCEDM2CTA0>CXg>SPl?cPf=CXg?D91@STj>c8h
>S/k=CLi=_hk@C`e=3@g=S@n=38a<cLh>CLe=3Lb=3Lg<cHe=SDf>3`o=cXo>cDb
?3Lc<C@h?3a0@SHg>dE1>SLe=C@g>Sa1>SDf=e=1?d<l>d8k=CLnBDDo<SHm@Enh
ko3`lO;PgN3PVf1[J6AGDU5LIfIKEdUABDLk>She>cU0@D<o>34g=c@c=c8h<S@l
@TI2D4i?CV/k=DIICEASBDCnEbQ0?eY?@Shj>3m3CDe?DeE7@Ti4@3Tj=cXh?3lh
=SDj=ce2@D8i>S/b>0Hj>c/e=cTfoS]I?3Dd=3Lf=3hd<S4c=cPi=cDd=c8d=cLc
=SDf=CHh?3lg>Slk=C8l=c<a=3Pl?412=SLkAD4j=cDe=3Lj?44j=CHg@Cm3?3]2
>cDg?TU5?c8f?D5O^>o`l?7b0VIHg=gNgYmKGUQEF5M@F6ALF5]IEe9FEDY6>cTi
>S<j>SPm>Ca4A4M8@cU0A41JCe9EDEEK<cE0He9GCD8c=S`g<cDo<C@h<SHg?C/h
?cPh>DMRJGa1=c/k>3Gm>B8e?Ce1=CDb=CLa>3He=CPf>c@e=3Lf<SHg<C8_>2hb
=3Le>2<f<c0c<S4b<c@c<34f=C@_<c@e>CLh>CXh@c<h>cXe>SPk>cgn>ePi>S/k
=3`h>SPd>cTb=cLi=C@e?3/d>chl>SPj=3U9Yng^l^o`g=gNgYmKGUQEF5M@F6AL
F5]IEe9FEDY6>cTi>S<j>SPm>Ca4A4M8@cU0A41JCe9EDEEK<b@e@6=BEde2<cHl
=c<e?c4d>38f=cdk>3lh>3U7HVUl@CLk>cPeoCU6=Cdm@CDe<SDg<CPf=CDh=S/d
=C@g=S8f=c4b;cP^<S@g=CPf<c0c<S4b<c@c<34f=C@_<c@e>CLh>CXh@c<h>cXe
>SPk>cgn>``i>S/k=3`h>SPd>cTbocM^>CDd=C`k=3/n?3Xh>S@iBJO]k_;_l=cM
g]jOFeiHEEQGD5QTG5QKFEMBEUE:AS/i>CXc>SXh?CTlA4A7B4<i@4A0FTmBEE5E
Fc<e@6=BEde2<cHl=c<e?c4d>38f=cdk>3lh>3U7HVUl@CLk>cPeoCT:=Cdm@CDe
<SDg<CPk=SDe>3Hk=3Dd=cHb=SLa<Rlh;S8d=cDh=S<`<c8a<S<d<c0a=SDd;c<d
=CTg>3Tj>4<c>3/j=CXh>c/moS/T>CXk>c@l>3Xh=3/i<SLg>CDd=C`k=3/n?3Xh
>S@iBJO]k_;_l09Y?MoLgmjVI6UME59@FFQ]HUQCE5UNKF]HE51MFF=AB3`oAdIG
H5eQCTU=F4dlJDmAEW1nLC0nEe=8FeHf=CHooSDn?SDi=d4j=cXj>CTk?ce5DU/j
>CTn?3Ld?C/d=c<o?dPd=3Pd=Cdj>Cde>CXh>d<i>SXm<C<c=3Db;C@e=3`hoc5m
<SHg<CHo=c@b<3@c=3Hf<d@j=SU2?cXi=C/e>3Tc=STi@TA2>ca0>C`d>CLj>cli
=c8k@chj>CLh>48o@cdg>d4j>dBTko3bk_7Og=oNYVAYGEABD5UXKF9HDeAIGVe[
F5A@GEUSDDPl?dM6Ef1MHDi9CEQ=?6U?DEI`OW4`2CiGDdQKESHe=Son=G8n=CTg
@CXg>SXi>C/o?DEBFcXi>Chl=c@m>c@g<cloB3@d>3@e?CXi?CDi>SPk@cTj>Sda
<c<d=C8]=3Dd?3Pa<C8f=c4f?cLd<S0d<c@f=S=4>SHi@Slj>CDk=CPi<cHi>D94
@S/l@3Tl=3Tg>S/o>CLbEC]3?SXi=cPh@Sm3?CLk@CXkA:C_l?;^lMoLgmjVI6UM
E59@FFQ]HUQCE5UNKF]HE51MFF=AB3`oAdIGH5eQCTU=F4dlJDmAEW1nLC0nEe=8
FeHf=CHooSDV?SDi=d4j=cXj>CTk?ce5DU/j>CTn?3Ld?C/d=c<o?dPd=3Pd=Cdj
HcTm=CTj>3]3>CXj?C4c<c@e<Rdd=C@l>34a<SHg<CHo=c@b<3@c=3Hf<d@j=SU2
?cXi=C/e>3Tc=STi@TA2>ca0>C`d>CLj>cli=c8k@chj>CLh>48o@cdg>d4j>dBT
ko3bk_42JGoLg]gHXEiHE5MQDEAEEU=JEeMFFEQCFUMMI5ITDU1FE5a;CU]KF5IH
EUI5>U5AG5Y_K5ha?5=BBDeI=ca0;c<`=3Lh>C@f=3Ld=3Dc=SXg>S`h>CXh>cdf
<c4g=c/c@3Xe=CHh>cTg>CXg?SXj=S8j=451>bh]<2da=Bla=SDf<`Da;S8`=c3n
<`0foSLj<3Dj>3Ll>CTg>cdg=3Pm=SLg=STl@T11>STn?Cm2<c/e>CPj>SPa>SLj
>3di=cLf>Sli?Shj>SM8[^cnkcCbg=kMf:5NF5AGHE5DEEICFUMGEUUHDeYGGFAF
I59@EUALBdiKFeQFF5IFACYADEaJKfaN<E4lDe99CETg?40_<c0d=cPi=3Hd=c@d
=C<f>SLj?3Pi>SPk?CHc<CLg>c=0>SDe=SPk>CLi>SLn>SXf<SXd@D4k;Rd`;C4e
;c4f=CHc<Bhb<3L`oS<0=_hg9S0e>SPg?3Ti=c/m=c@h?CHg=cHi?490@CXi?Sdo
@S<k=CTh>SXh<A<j=cXh?CTg=cHj?cTn?SXj=dR^k?k_J?;Lg]gHXEiHE5MQDEAE
EU=JEeMFFEQCFUMMI5ITDU1FE5a;CU]KF5IHEUI5>U5AG5Y_K5ha?5=BBDeI=ca0
;c<`=3Lh>C@f=3Ld=3Dc=SXg>S`h>CXh>cdf<c4g=c/c@3Xe=CHh>cTg>Adj=chj
>SHb>SA1@C/^;C0]<CD_<CHe=S<a;S8`=c3n<`0foSLj<3Dj>3Ll>CTg>cdg=3Pm
=SLg=STl@T11>STn?Cm2<c/e>CPj>SPa>SLj>3di=cLf>Sli?Shj>SM8[^cnk`3b
0VIAg]oPfjUTGUQFFemQJ69JD59TJFeOFeA>F6=WJeiDAdE=B55JH5MAHUmKAd1I
D55FGfEX>SU3AE9<DCU9>c4b<c<j=c`e>CTe?S`h?CHm=Sdj?odi:CPj>SLg<SLg
?CY2>S``=SA9>CXd?S/l>SDk=cdm>C<f<C8a=c<l=3Te>OlaOCHb>cm7=cDh=cm6
@T0n=c4g?T@l?D4m@3hm@c`e?3Le>ShkCT16?cTh?SXm>3@b;cPm@CXe=3PlAclm
=3@g=cXm>3m</Ng^knk_g]oPfjUTGUQFFemQJ69JD59TJFeOFeA>F6=WJeiDAdE=
B55JH5MAHUmKAd1ID55FGfEX>Qdi@dEBC54iBC/a<S<c>SLl=CTi=Chl>3df?CHm
>Som>Edh>SXg=c8g=cdj@SXl<3HdBCTj=3hk?3Xe>cLm?CTc=S4b<CLc?3@i=CTa
<CHb>cm7=cDh=cm6@T0n=c4g?T@l?D4m@3hm@c`e?3Le>ShkCT16?cTh?SXm>3@b
;cPmJD4j=C@h?4Lo?C@d=cLj?CPoC;7]k^o^kmkOh=^YI5iHEU]OHFQRFU1BI6U]
Ge]DCUQSIf]NE4M5CDQAFV1GDF9OFdM0FE1AEUmUJ3Xi@dEBC54iBC/a<S<c>SLl
=CTi=Chl>3df?CHm>Som>A4h>SXg=c8g=cdj@SXl<3HdBCUS>S@n>c`j=C/g?Cdi
<cHa<S4g<c`d>CDi<C4f<S/oAcLe>3LoAT90?SLa=ci4?3e1?D0n?D<l=C`g=CXn
>di0ASli>3hj?CPd<Rlh?D4j=C@h?4Lo?C@d=cLj?CPoC;7]k^o^k`9YOmcMgmfK
GeaNGeMLFEaBD5e@Ef=ICeUGDUYRH5U8DDm>A3i5B4@m?V9HDdLfFf=KGU]GB3M2
DDe:@D0m=C4b<c8a<C<l=C@c=3Hf=C<i=cDl=cPd=3Lh>3<d>3Xh>SHh=3Xi?3Tk
=cXf<c<f=cHd=3<e?SHh<c@b<c0b=3He=STg4SDj=cDf=3T_=cHj=SHh@CHl=ccn
>VTe>ce2?CTl?CQ3>C`m=c@m=Slm?CDn?3@d>SL_<STi>3Ti=3Hn?CXj>CLh>STc
?4FZk^__kngLgMoMVemLGUmGG5ULDU1MD5MSFDmIEe9JHV1IB55?CT@nADQ4?CiR
F5=7=U]SFeiKEdPgGT9ACDY1@3de<C8c<S4a<c`e=3<d=SHe<cTg=C`g>3@d=cPh
<c@h>SPj=SPd>STl>C/g>SHc<cHg=S@d<cDn=SPc=38c<38d=SDf>CLe>SLe=S@i
;cLf>SHf>44f?3LloSXM=C/m@Sdi?3dh@cTl?CLd?CHo?Cde?S`d=3Xg;c8iOcTh
>CTd=Shm>SXi=cPj>C<lAJ[^jno_kMcMgmfKGeaNGeMLFEaBD5e@Ef=ICeUGDUYR
H5U8DDm>A3i5B4@m?V9HDdLfFf=KGU]GB3M2DDe:@D0m=C4b<c8a<C<l=C@c=3Hf
=C<i=cDl=cPd=3Lh>3<d>3Xh>SHh=3Xi?3Tk=cXfoc<X=SLf=3@c=Chf>3<d<S<`
<S@f=CHi=cDj=cDf=3T_=cHj=SHh@CHl=ccn>SDe>ce2?CTl?CQ3>C`m=c@m=Slm
?CDn?3@d>SL_<STi>3Ti=3Hn?CXj>CLh>STc?4FZk^__knd2IOkMA=bPGf1BGUUW
KFICC59QJ6QOGUIIFF5]KEU7E5MPGeA2BD=0?EY`G4]7EU]KHfMNBS=5FUIDG5=7
>SPf<S4e>cDm>C`g>_de<cXo=C/h@3Pg@412?cLi>STj=C`o>S/o=cHk=3Xl=Rhd
=S8c>3M0>CL`<C8e<SU3?Cdk?Ce;?3Xk>S/n?S@e>3Xf@CPk>DHh?3a1@cTj=C`j
?caF?STi?TA>@T0m?Sm1@cLk>3He=STe>CXg>CLi?CPl=S@f>D9>?3@hBJc[j^g_
kOkM<=bPGf1BGUUWKFICC59QJ6QOGUIIFF5]KEU7E5MPGeA2BD=0?EY`G4]7EU]K
HfMNBS<CAEYFE5aCAcXh=S8a=C/e?CTl=c[m=FLj?cDk>40h=d10@Slg>CXi>SDl
?cXk?cLf>c@j?3H^=3Hb<cPg@3Tg<34b=C8i@cdm>cdm?3Xk>S/n?S@e>3Xf@CPk
>DHh?3a1@cTj=C`j?caF?STi?TA>@T0m?Sm1@cLk>3He=STe>ALj=cTg>Cdh?3Hd
=SU2CS`d>4V/jn[]kngngDCLX5mPDUiIIfeVDdaBHFQXGeiFFEUQKFeIAeAGH5mD
@TU3@3eJL5a;AeIKFf=WGTXcAEYFE5aCAcXh=S8a=C/e?CTl=c[m=A/j?cDk>40h
=d10@Slg>CXi>SDl?cXk?cLf>c@jHc`f;S@f<S<h=d0i=c0a<SDb>D<m?C/m?C`j
>cXk?Shd=CPj=T4h>cU6>3`l@D<i>SDl>SllEShi>Ci4CT90?Cho@D<g>cPf=CHi
=CTj=cTg>Cdh?3Hd=SU2CS`d>4V/jn[]knd2JOoML^3MVFAREU9DGfEJEeU@GEaV
HUiSEe=CET]HPh28/l2e/Ha2?c]0@d50GVMREe]XES/cEeEHGEI0>3Hc=3@j=SHc
=SLj>CXk>CLj?S``<cHg=S<m>STd=CPk=SHc=SHm=c`k>bd[=CTi<C8g<S4d;CDi
>SGn?0Lj?S/i>3hi>2M0?S`k>cXi>chmA3Hl>d/g>3Dg>CTj>3Xh@C`f?D4h>SI0
?dI1?Ca1oSeD>3Xh<cTb>3Tj=cPk>SL^>SHo@44n>2hc=cI4Z>_[ko3agMgPgIUT
HUIBE5mUFUMID5eLIV9NHeMCDeI;F8>0R;?0]K6<@Slk@4=1@5iWHUMKJ5Hk<d1G
EEQMET0h=S<d=3Xf=S<f=cXi>S/i=cXn?30c=SLf<cdj>C@e>3/f=S<f=Sdg?3/k
;B/e>CTa<SLb<C@]=CTj=Ohl;cXn>cTh?STh@3hl>c/j>C/n?D@f?3];=cPe=cTi
>SPj>44l=Se1>3Xf@3m6@Cdl@Ohm23Pj>3<i<SPi>Wlg>3/j=bhj=Sm0@Chh;S<g
=TBXjn__l?7MgN3MVFAREU9DGfEJEeU@GEaVHUiSEe=CET]HPh28/l2e/Ha2?c]0
@d50GVMREe]XES/cEeEHGEI0>3Hc=3@j=SHc=SLj>CXk>CLj?S``<cHg=S<m>STd
=CPk=SHc=SHm=c`k>bd[=Oli2S4b=c8a=2de>CXeoS`_>Shk>CPn>CQ0?S`k>cXi
>chmA3Hl>d/g>3Dg>CTj>3Xh@C`f?D4h>SI0?dI1?Ca1oSdP>3Xh<cTb>3Tj=cPk
>SL^>SHo@44n>2hc=cI4Z>_[ko3a0VIQg]gPgZI^I69`L8YdL69VJ8J<XFiAEEUZ
GeAF/;OWh^OTi>;Z[gQ3DD1:@EYKHVIeIe/m>51NLFA7>cLg;c8b>3Lj=c@e>S/l
?3ll=S`m<3@l=C<h=Sm5?3/c>SPf>C/e>CCn>?l`63Y1=cY2@SXa<cTnADM3@C@a
=SDg@TM5@S_n>bXmA3Ln>CLoBDE8?DLm>Clm@DI5@cLm@3m7@3le?Ce@@U0oC3hm
@DHo?cXfoSP5?D/l>3TioSY5CTe7A3``=3e3@3PoZNWZko3`g]gPgZI^I69`L8Yd
L69VJ8J<XFiAEEUZGeAF/;OWh^OTi>;Z[gQ3DD1:@EYKHVIeIe/m>2e@GW5TAc/g
=blb<SPg>SLd=CXk?3`o?3Hl?C0d?3Dc>3HoAC`k<cXh=STk=CTdoSSo<1Lj@CLj
@T8j<C<i?TE7@d4d<CHe=d97AD;m>bXmA3Ln>CLoBDE8?DLm>Clm@DI5@cLm@3m7
@3le?Ce@@U0oC3hm@DHo?cXfoSP2?D/l0SPi>OhjLdi=Ad@l<3@m@d0h?jWYj^o`
l=kMh=jVKVARL72:M71RIVR6S:5^DEEIJUmDE[2gin;Wi>CRjZmh@e50BT5JFf9V
MFMK?CQ@GW5TAc/g=blb<SPg>SLd=CXk?3`o?3Hl?C0d?3Dc>3HoAC`k<cXh=STk
=CTdoSSo<00j5T4g>T92>S4c>Ci5Ad=1=34f=CM2AdE2oC/Z?D@g?STg?dU5B3e7
?CTo?D56AD<g?D0oAd0o=CdmD49@?d`n?D56?clj=_hh1Ce;?3Pi>Ohj4Di=Ad@l
<3@m@d0h?jWYj^o`l09Y5=gKgmnCA4I7CUEXEUE3CDeT?diCF?iLFTAENmCMi]gS
hn3Fhn?=Ace2A4aGHeaNF5Y7>c=CDfI8>d@e=S0b=38b?cPe>cTj?3Dj<3/j=Blg
>S/g>cPl?Sdj<c`f=SLj=cLh=SPe;C8a<CHc>SDf;C<d@cOn?PTd=CHg=Cdl>cTm
H3Tj=3Ph>chl>SHm?3/g>d<k=cXf?dI2>3`m?3`i>3/j>TE2@Cm1@clm@D4o?c/k
=C<i>CDg?40m@T8n=C<b?CLg>CDk>dF/j^S]knoMfmoOTdA6AdiEJ5IE@de=I3m>
DeSnG1]4EG_DgNKMhn?Pe^?ScDLm@TA<Ef=LGUQJAc/coe<lITPkA3Df<38d<S8o
>3Dk>CXl=CX`>cXe;cLj>cLk>3`n?CXc?3Hf=cXg=cPf>3D]<S4a=S<j=CH]<cA3
=ohn?C@e=SLe?C`k>Cdi>S@h>3/n?3Xf?C`k=c]3>cLj=Sm6@SPl?C`l>CPk>SY5
@T4o@D<o?D51?clk>cDc>CTe;3Ll@3e2@She<c8m=cLi=C/kAJcZj>g_kmgKgmnC
A4I7CUEXEUE3CDeT?diCF?iLCdAENmCMi]gShn3Fhn?=Ace2A4aGHeaNF5Y7>c=C
DfI8>d@e=S0b=38b?cPe>cTj?3Dj<3/j=Blg>S/g>cPl?Sdj<c`f=SLj=cLh=SPe
;C8a2S4f<cXe=Rdc=4<goSiE=3Df=cDm?3/i?CTj=3Ph>chl>SHm?3/g>d<k=cXf
?dI2>3`m?3`i>3/j>TE2@Cm1@clm@D4o?c/k=C<i>CDg?40m@T8n=C<b?CLg>CDk
>dF/j^S]knl2JOoLOMoJS4Y@@T54BDQ:@EeMECQ2C4mAF4]5IHSQfmSKhn?Nfn7O
gJE4Cd1BF5MNIf1P@3LdECe>BEe6=CLd=CD`<3@_<3<d=cHf>c0g=D8e>3`k>CLd
>3lk=c@o>Shj=C@`<cLe;2X/<3<b>3Tk>cPg=SHn@3`n=SLg>cHm@3/l>cHl>CPl
?3hn>T90?d0n?Cdk?c`k=C/m?chm@CXn?3/h>C]1?Sa1?cTj?4Do>S`e?CLm@D@o
@ChmoSU5=S@g>3Di?S`n>cY6/>c[l>k^g=cOfXa:D491A4U8BT5MGEDh@Ta?DEQ;
AFF8hM_Hfn?Sg]_QgmfUA4m0DUQGGVMPH40g=7mE?Di9GDHe=c@e=C0`=2l`<c@g
=SHk<3Le@SDh?3/i=c@h?c/g=3lj?SXe=30c=cD/:R``<c8h>C/k>3Lf=Si0?3hf
=cLk=Se0>c`k?3Th?3`n?SY2@3m0?Sdm>cll>cDk?Cln?D4j?S`k>3Tk@Chl@Cli
>Sa5?cXl=Cdg?D54?`91?Sgn>GTf=3Lh=CTn?3hk>TJ`k>_`k^kLg=oJS4Y@@T54
BDQ:@EeMECQ2C4mAF4]5IHSQfmSKhn?Nfn7OgJE4Cd1BF5MNIf1P@3LdECe>BEe6
=CLd=CD`<3@_<3<d=cHf>c0g=D8e>3`k>CLd>3lk=c@o>Shj=C@`<cLe;2X/<4hc
<SPi>c/h=cHf?T0l?SHg=c/f?D0k?3/l>CPl?3hn>T90?d0n?Cdk?c`k=C/m?chm
@CXn?3/h>C]1?Sa1?cTj?4Do>S`e?CLm@D@o@ChmoSTA=S@g>3Di?S`n>cY6/>c[
l>k^0VTRgMoPgkF7YYJ=PeQaY9:@SXf>SFeXI5A1?F:`i>?Xh^CRiNKnjEWMUDA:
IG1ZGV=CJ44oDTU0DUeND3Tl=S@c>CPe=cDh=CPd<cTf?CLi<cPj@cdn?c8e?T4k
>S`h<S@e>S@j<BTY<3@g>CU1>T0i>Chm>T10>c]2?Chi?c]1?cm^>3a0?Cdh?Ca2
AC/k?Ce4?U<l=S<n>Sa2?3hh?CHk?3i1@Cdg?cli?cY0>S`oAd99Bc/i>C/h?3Q0
>3df>S/g=cli>Cm0D;SYkNc_kmgOh=neQjJFSH=HLJBBT8j=SXe]J6AD@CeR/>CS
j>;Th^GVo^T=gIE4BVE`JUiSDfQ1?e9oBD1BGEi@>C`f=3<i>3Dg=CPe>3@c>CHm
=cTc>3Y3?Cho<SDn@C/j?3Pb=3Dj=3Xa:BT`=3Li>D4j@3Ti?Sdj@40k>d8m?STo
>d4o?cPl@3dm>3dl@TDk>cdmA3iC?3Hc?SXl@S`n>3df>c`n@D4m=clo>Clj@3Xl
?dM2BD/k>CTj>cPl>40h?CHj>cLg?cTi?d1@^>W]k>o_gMoPgkF7YYJ=PeQaY9:@
SXf>SFeXI5A1?F:`i>?Xh^CRiNKnjD7MUDA:IG1ZGV=CJ44oDTU0DUeND3Tl=S@c
>CPe=cDh=CPd<cTf?CLi<cPj@cdn?c8e?T4k>S`h<S@e>S@j<BTY<3AS=cTi@CY0
>CTn?CY0@3/k@Sdn>Clk@Clo>3a0?Cdh?Ca2AC/k?Ce4?U<l=S<n>Sa2?3hh?CHk
?3i1@Cdg?cli?cY0>S`oAd99Bc/i>C/h?3Q0>3df>S/g=cli>Cm0D;SYkNc_k`9Y
2McMgmjFHFMCE4Sn@a16IVM]L61CDeiBATMmg]3LiokYG^?TjNOTim@oBeYLGf=T
G5I1A4YEJf]GED4f<cDa<cTb<Bdi=C/g=c10?3`h>cPl?3lm>c/f?cPk@3Xk@CXl
<SLb>3<[;cLb=cXn@cTg=3M2?C]5?3dh>STo?D8o?CU17Sdk@CXo>3lm@3To<c`o
>T0m?S/f?STl?T90?T8j=c[n@C=3>cPe>Dm5ACdn?Slj>cPf>3Hg>Cdi?c@n=SDg
>d4k=SHj>D^aj^__ko3LgMoNUV5WDeA8oT<@AVIWKG1PDe=NDTI7OMk@g>OnjA;S
i>WWi>OD?d]JG5mSI5aF@DA:JUE[JeME@CHc=C4c>C8a;CTe>cLg<40l?3Pk>3`l
?cdk>cHo>3]0>S]1>S`b=c8h<b/_=c8g>Si3>CLd=d8m>dDl?CPj>Clm@Slm>D4m
>d4j?cPo?D0i?c<l?cY0?Chk=Shi?3i2@3i2>SLjoT4A@c/h=CU?ADDm?Sho>S/h
=SPf8CLi?CTo=3hf=CLk@C/f=SXiBk7Zjno_l=cMgmjFHFMCE4Sn@a16IVM]L61C
DeiBATMmg]3LiokYA^?TjNOTim@oBeYLGf=TG5I1A4YEJf]GED4f<cDa<cTb<Bdi
=C/g=c10?3`h>cPl?3lm>c/f?cPk@3Xk@CXl<SLb>3<[;cLb=SLj?T<i=c@g@Sdk
AC`m>3Xi?ce2?cdi@Cdk@CXo>3lm@3To<c`o>T0m?S/f?STl?T90?T8j=c[n@BU3
>cPe>Dm5ACdn?Slj>cPf>3Hg>Cdi?c@n=SDg>d4k=SHj>D^aj^__ko02JB3Mgn3O
Z7Z2E5eBDDYUDGEbIGJ7JEIQAd4n[>?Vi^[/kn[nk2?]hn?BBTaYJ61NEDXo>dQS
K5]QG5hk=CLh=cTh>CPf=cHh>Skn>c@l=c0f@dI5?C/j=3m1?4A1ADHl=S/n?T4e
<S@o>S/m>cTh>c/j@D<j?D54>3Y3@d4o?TM:Afa3?d<k>3Q7@d4i@3Lm@TU5>CY3
>ca4ADPj@4a;>c`j>3Pn?D5;Ad5HBC`g=cdn@C/e=CTk>cXi>CXl?chn?3`n?SLj
@DA9]>o`lo7cgMoPgjQjPUAMDU5:IE5eLVEfQfUFHDM1?ZcSi^KZk>oZo^`?kN?S
dTY<JFQPGUE:?c]8Ha=/Ff5LGS/e=cPg>CPi>3Hg=SPj?_hkJ3`g<3I3ATDm>cXd
?d4lA455AS`f>chn@CDb=3lj>cdk>CPk>cY1@cXm@D@h>T=3@ClnAdY7@cm3>cPh
Ad=1>D0g?D99ACTj@c/lA4E8>T1<Bc/l>SPh?Se1BdM1F4Tl=cLm?T4k=CDi>cPk
>STi>S`o?Shl?3hn=cY1A4Vdko3clO?Mgn3OZ7Z2E5eBDDYUDGEbIGJ7JEIQAd4n
[>?Vi^[/kn[nk2?]hn?BBTaYJ61NEDXo>dQSK5]QG5hk=CLh=cTh>CPf=cHh>Skn
>a`l=c0f@dI5?C/j=3m1?4A1ADHl=S/n?T4e<S@o>V<k?C/i>3/k>T53>Se1A3Pj
@d=1?ci7BTM3?d<k>3Q7@d4i@3Lm@TU5>CY3>ca4ADPj@4a;>c`j>3Pn?D5;Ad5H
BC`g=cdn@C/e=CTk>cXi>CXl?chn?3`n?SLj@DA9]>o`lo7c0VWogGgRgI=[NU=I
CU13AdYoLFQcMUILJT`n?:3MhnGSinWYk>c[jnST[TQ1IfIbH4a2BS=6CfEUHeaJ
>c4b=CLa=3Tf<SP`<S/i=cLj?C8g>SXi?SDj>CDk>4<m?cY4>3Xg=CHj>STh>CPj
=SHm>cPj?3i:@d10?3/m?dE4@CPm?Cm6?3i4>c`n?STm@Shg>d0k?CPlAc4f>CU6
?CXi?Clo?3lj@CTd>Cdj?Chl<C8k>3Xk>3@j=cTk?3Pj>c/mASPm?3hi?3hnB;Cn
lCGdl]gMh]fCJgYCFDi@@dM:Og5XLgIFG6Y<?SbPgN?UhnOYjNc/jn_Xi:i8@FMV
LV1<@TXcATooIGeSG5Xk<C8e=c4d>CHb>30b>cTg=cXm<SLj>STn=CXi=C/h@cdo
>T@h>SLe=SXj>CPi>3Xf=Sdk>3Xl?TY3@40l>cdoADA1>3dm?c`nA3/l?Shi?D8n
=c]0>cdh?4La=STiASdj>Cdo?c`o>T4i=3Tm>Sdn?34b>cPj>cPd>SLB>C/l>3Xk
>ce6>3dl?STl?Si8]?kaJOCbgMgRgI=[NU=ICU13AdYoLFQcMUILJT`n?:3MhnGS
inWYk>c[jnST[TQ1IfIbH4a2BS=6CfEUHeaJ>c4b=CLa=3Tf<SP`<S/i=cLj?C8g
>SXi?SDj>CDk>4<m?cY4>3Xg=CHj>STh>CQN>SHf?C/h>S`nBT=0@3`k?Cm5A44h
?Cdo?3i4>c`n?STm@Shg>d0k?CPlAc4f>CU6?CXi?Clo?3lj@CTd>Cdj?Chl<C8k
>3Xk>3@j=cTk?3Pj>c/mASPm?3hi?3hnB;Cnl@7dlP9YGmgLh]jKNGa6?d8oB4e4
JVYdMh1_J6=?B4RGfnWWhN;Uh^g]k>SVjhe1B71WJDdm?3LdBE=EEVMWK4@g=3Te
>3<k=c<h<S@h?STc>cDd=CM7?Clj>3]0B3hm?cLh>D93>ohl73Pi>C`k@40m?cU8
AT<n@C]1?491?d4j>Slh>T12Ochl?3i2>c/j?3le=THlAD0j?T=2H4I7B496Ce=A
ASm3>3DfCdE9@D8l>SLf=c/l?3Th?d10@T4f>CLn@E4d=C`h>Cm5?DVcl?3emOOM
g>;NVgUlASm2?dQ=A6YZM7N0KfQSCdQ8Um_Yin7RiN;]kNcXi^^=@DQ`IfU=?C`g
=4UC:eEFIfM/A3Ld>CDh<c/g<cPb=3Pn>C<k=C@e=dLm?cXh>d18?Sdo=cPi@T<k
oSa@>3Ti?3]0@3do>DQ6@ci1>d4l@T4o@CXj?cPj@48n?3`n@S/k>S`o=CI6?4E0
>Si3@V16AdQ2ATmCDDHo@cPe=Tm5BD52?3Xg=SLk?3`i>3m0Md12@CHi=ci1DC@e
?3Pi?dDmBK?`l?GemmgLh]jKNGa6?d8oB4e4JVYdMh1_J6=?B4RGfnWWhN;Uh^g]
k>SVjhe1B71WJDdm?3LdBE=EEVMWK4@g=3Te>3<k=c<h<S@h?STc>cDd=CM7?Clj
>3]0B3hm?cLh>D93>ohl13Pi>C`kod1Q?CliB4I3?T4k@Ca2@Cm1>SXo>3Y0@Shl
?3i2>c/j?3le=THlAD0j?T=2H4I7B496Ce=AASm3>3DfCdE9@D8l>SLf=c/l?3Th
?d10@T4f>CLn@E4d=C`h>Cm5?DVcl?3emOL2JF3Ng>3PRDA;?d@nADA6AD91?SU:
I6aPC3dlF:OShNR_Vh?7jN[YkZIM@DEWIUQ:>dU1=4=OIU5KFD<i=c0f>3Ha=CPj
=c<g=CXk>3/h=SDi>CPe=SPi<cI2@C/j>Si1?419oSXK>3/k>S/m@D4l>Si0@dDn
?cHh?DHm@Chj>3dm?_lj?c/m?T12=Si0>SHm?C/k>S`i>S`i?S/i=cLh?SHe=CXh
>T4nA40n?3di>Si6?cdk>3Tm=D4k=S<e=cPj=CTi?3Sn?3Y8]?7`l_?dg]cPh8U4
Bcm4?TE4ATE2@ChiBVA/H4`m?5RWhn7X[i^3anWZjNjVGD55IfIHBS]9@CA3GbaV
DE]I@cTg<3Hh=S4e>3Xg<cLe>S/h>cPf=CTi>3Df>3Tc=T91>cXj?T4l@4Wn>Tlh
>c/j>ce1@C`j?T13ACho=SPmASe1?SXh?Cdn>SXk?Ci0@SHn@3Xf?Cdk>cXl>CXl
>Chk>CLg>3hf=CDj>3Y1?TA0?S`m>CXnASlm>cPi?@de@C/f<cDg>3Xe>CTl>?hl
IdRdlO3bloCNg>3PRDA;?d@nADA6AD91?SU:I6aPC3dlF:OShNR_Vh?7jN[YkZIM
@DEWIUQ:>dU1=4=OIU5KFD<i=c0f>3Ha=CPj=c<g=CXk>3/h=SDi>CPe=SPi<cI2
@C/j>Si1?419oSX3>3/k>UTk?D51?3Xn@4=5?Slf>3e6?D4n>SPm?Chj>S/m?T12
=Si0>SHm?C/k>S`i>S`i?S/i=cLh?SHe=CXh>T4nA40n?3di>Si6?cdk>3Tm=D4k
=S<e=cPj=CTi?3Sn?0I8]?7`l_?d0VUoh=oPgY]JBDECD61METQ8CT]6R7aMEEM4
CdF:g/?]/]>IfNKOe>eYBe9@JT`oED2;K3TjBjMIHDe3=34b<CHg>3Pg?3Dc<cE2
@CLh>3]??c`i>cTl?3I2ASdj>ca5Acm3C3a5?cXg=CHi>SHkBD=2@cU0?dDn?T92
?T0o@450@cmo?3i1@3m2@ca3?c/l@Cln?3/jBd4o>CLi>CXgD40i?3LiAdA6>d8l
@Sho@TA5@3ln@T<o?c/k?3Pb=3dk?3Lm>dDl?40kCK[am?CemN3Oh=jKFTU5De1P
GEI8B4i;AXQlGEEGA4m5R]k3kK;CVMWVgmC]JD]BD6Y<?eE0Rf`i>T]oYeUQCD<d
<C8a=SLh>3Ll=C<c=D91=cPh>dlo?3Tk>C`l=T96?CXk?4E7?d=<?4Do>SLe=STj
=S]9@d93>D0oAChn@T8n@3m0@D13?c`n@D0o@T<l@clk?44o?S`k>T]1?cTg>CTj
=e10>C`g>DM4AS]2?48n?d94AD0o?T93?coo>gdl>38d?C/l=cdkAC`l@3]=^_7d
m?Geh=oPgY]JBDECD61METQ8CT]6R7aMEEM4CdF:g/?]/]>IfNKOe>eYBe9@JT`o
ED2;K3TjBjMIHDe3=34b<CHg>3Pg?3Dc<cE2@CLh>3]??c`i>cTl?3I2ASdj>ca5
Acm3C3a5?cXg=CIS>CXf>dU3@T<i@3m5?Si2@Si0?d11@4<o?3i1@3m2@ca3?c/l
@Cln?3/jBd4o>CLi>CXgD40i?3LiAdA6>d8l@Sho@TA5@3ln@T<o?c/k?3Pb=3dk
?3Lm>dDl?40kCK[am?Cem@9YOmkOh]jFCD17AT9@BU96CDQ@CFIJFeYBBD]4AkOP
i[F3O=gXjMne>DI:CFPm@EE1>Bhh?E9VB4<oC3X`<C<j>S`i?cTe=3U2@3Ll>CLg
?Chi=cPg?CTi?cXo?3/l?Ca0@TLmASTk=SLk=cHb?3Hh=cLa@3Tm=S@n>cdn>T11
?493Ochl?d13?3dmACXk=SXe?3`m=CPg=C4a>Chf>D<l?Clf=d0m>SPk>CLl>CXj
?STh<CTk@3U2>cHe<cU0?411?ce1>Ca2?dfml?7bm?GNgn;NUTe0AdI2D4YBATe8
D4eVFU]JDTU;A4Ngh>JePgcMj>WO]CU6BTeX?D5E@CT^>3eBOfI8@cm<>S0a<cXj
?3To>CDd>D90=c`i=cLm?STg>3Lm>CTo>Sll>c`m?412Ace6>C/f=c/g=S8l=SPg
=c50>Cdf=3hk?Chj@44l@T<n?3m0@c`m?DDj>cHj=C`l?CDh=cDa<CTn=SU3?3do
=SM0?CXh>cTg?3Tj>Shi>34i>d0iOd8k=SDc>D0l@44o?D4i?48oCKg`lO;dmMkO
h]jFCD17AT9@BU96CDQ@CFIJFeYBBD]4AkOPi[F3O=gXjMne>DI:CFPm@EE1>Bhh
?E9VB4<oC3X`<C<j>S`i?cTe=3U2@3Ll>CLg?Chi=cPg?CTi?cXo?3/l?Ca0@TLm
ASTk=SLkHcLf<S`f>3Lg<D0i?CHd?S/m?SY0@Ca2@chl?d13?3dmACXk=SXe?3`m
=CPg=C4a>Chf>D<l?Clf=d0m>SPk>CLl>CXj?STh<CTk@3U2>cHe<cU0?411?ce1
>Ca2?dfml?7bm?D2JGoMg^3OZ6UNK7QjPGilHFQhMGeVGeEKJ6e;CD=MVmRC[IVS
`N6PE4QDCTmM@VAVPchf=45KFT=5CFPl>CI0AcXn>d0m>3E=@3Xo?C<j?DDg>CDc
?T<o>3Pk@cXf?ce2C4I=>Ce3A3]5@C`o@3/m>S`n=cLf?S/g>cPd?SXk?d91?7lm
>S`l@c/i>CPg?Sli>3dk>3]5<cDo?D=0AT0n>cHk?S`f=cLl=S/l>SPk?D8e>Sm2
=d8j?3Tl=c]0Achn@3dm?cll?Sa9^o;cmoGegMkPgjQYGVahNX5nO65XN7EmIUmE
FfQ]Bde3GI_HTjfIXl7QX5A8E4i?GD9TIX<n=SA1FgmJ@dE=J3`i=T17>Shk@3dh
=De0>Slm<cXmACLi=C<n@clh>3]3>SHo?D9<ATdi?D=4>dE1?3m0>cdj?3hg=cHn
>cLk>3@n>S/o@T4l?CXl?4<k>CTh=cho>CPm>cPkAC<e?ce3@4I0?S/f>chl=SLg
?3Hk?3Xh>ce2=CXo@SM2>Wll>C`g>d17?Si0?Cdo?c`n?4Vkl_?gmOGMg^3OZ6UN
K7QjPGilHFQhMGeVGeEKJ6e;CD=MVmRC[IVS`N6PE4QDCTmM@VAVPchf=45KFT=5
CFPl>CI0AcXn>d0m>3E=@3Xo?C<j?DDg>CDc?T<o>3Pk@cXf?ce2C4I=>Ce3A3]5
@F<l?d0k?CXl?SLg=Shk=c/h=3hj>cm2@C`m>S`l@c/i>CPg?Sli>3dk>3]5<cDo
?D=0AT0n>cHk?S`f=cLl=S/l>SPk?D8e>Sm2=d8j?3Tl=c]0Achn@3dm?cll?Sa9
^o;cmoGe0VUogMoPgYeTDeIOGF1RIU=FFEQRI6YNFeaQFe9;A4M:DEQ<AT92?TE2
DD]GC4QDEfaUACQ6EdhoC6A`@Cle>T@m?Si1?3Df>Cll=CDd>cdk?3dh>ci1?T0k
=cU3=cTi?d4oA3dk?DM1AD0k?cm7@TI1@CXh=cXi?D0m=C`h=cDo>ci7>3Tn?clg
=cHi>3ln?Chm@SLk@415@dM0>TY5@T51?3/j<cTi?S/g?Sdk=c]6?Clj@d13@C`h
?cLn>Sho@CXo@D10?c/nB[O`o_@dm]gOh=jMI5=FGeePHVICEUUHHVAZGU]LHE]B
BdA7BU5HC4I2@Si5@U5;Eda8E5M/IDDhAUMoCSm<I711?cDjA3dn?T4l=CHi?c`e
=C@k?C/l?CPk?T4n@3/g>D<g>CTo@Cm4?C/mAd55@3/o?dM2AT51>SPg>STm@3de
?3Pg=Clk?SPi?Slo=cLf>CPo?Sdn?D8g>d10AD=7@3Y:AD91@C`k>S<i>Chk=chm
>cLkASdo>T=0@d4C?3Po=chj?Sm1>Sm1@40o>ci:]o3nm6SfgMoPgYeTDeIOGF1R
IU=FFEQRI6YNFeaQFe9;A4M:DEQ<AT92?TE2DD]GC4QDEfaUACQ6EdhoC6A`@Cle
>T@m?Si1?3Df>Cll=CDd>cdk?3dh>ci1?T0k=cU3=cTi?d4oA3dk?DM1AD1O>clo
Ad96@D4j>3Lj>Ce0?CDl>3Le?c/n>3Tn?clg=cHi>3ln?Chm@SLk@415@dM0>TY5
@T51?3/j<cTi?S/g?Sdk=c]6?Clj@d13@C`h?cLn>Sho@CXo@D10?c/nB[O`o_@0
mP9YOn3Oh>6HHEiXKFUPFeUOKVebGeYLI6miNFaNAde?Dd2<JTM1BDE8EfM:DDAM
YlZl`jMGV8ID?5iWH40l>E17AD@i?T<m=SPk@CPl@DDo?CXk?D90?Tm8@Shi@4M4
ACll@451@dU=@d4lA4A2BDTm>ci4?TE9BCm3?3e:AD91@chjOci:CdY4@44n?cm2
@cln?4I5A4E:@T0lA49=ATTn@D4o@dM1?S`j>T98BT50@S/o?DU8@d51=chlACY4
@40j@TDo?C/n?e>dl_KdmOGPgn3QV65NJ6eYH5]IGfi]LUmJG6A_NGU/GTM=Ce=0
S6Y7@DU5B5MWBU54GJO:_<>WEiR6Oe@lGVMP@3`iD4M5A3Tn@cdf>3]1>3a1AClm
>S/m@T0nCdQ2?SU0AdA5?ca0@D53BDe3@Ca4A499BCdk?T@nADU9?d<l?DY5@T53
?SXnBTm:A411?Slo@T<o?Sa6ADA5BT90?4A2CDI9?T51?d=7@Chl>SY2B4Y1@48k
?ce9B4=1Od4g?Sa5>TA0@3Y2AClm>choDkCbm_CemN3Oh>6HHEiXKFUPFeUOKVeb
GeYLI6miNFaNAde?Dd2<JTM1BDE8EfM:DDAMYlZl`jMGV8ID?5iWH40l>E17AD@i
?T<m=SPk@CPl@DDo?CXk?D90?Tm8@Shi@4M4ACll@451@dU=@d4lodAQ@TU9?C/n
A3i5BDTo@c`mBTE2@D<n>Si:CdY4@44n?cm2@cln?4I5A4E:@T0lA49=ATTn@D4o
@dM1?S`j>T98BT50@S/o?DU8@d51=chlACY4@40j@TDo?C/n?e>dl_KdmOD2JGWM
h>?PUeYKGGIaKF]NGfY/MFU]HV=TJWQaKU5;Ae54K5Q:B4e9Fg1SD51:HFeiLgUM
@F=A@TEcM7I5?3Y6BTm;?3ll>CLm>chk?CXo=Sdk@D<m?Ca5BdE1>d51?DM3ADI1
@Cm3BDE5@D<n>TU5A3Xn@3i1BTE7ACllA_i10TA6?WloA44nA44o?450B4=4@494
A4E;BDA6A4A2@ci2@4HnACe3@dU4@CY4AT53@Shl@Se5@dM8@S]2>T0n?413?D4k
A3Q0ADA>/_?cm?CfgN3Sh9MJFeefLFe[GUmZK7EYKF9SI6YhLFiABdMAA6aHBTQ=
BE]`He1@BV5]NG=iGD5SDDE2AG=dMTDl>TI:Cd/l?c`i=cdk?S/m>Slf?C]1@cdm
?4E;AD4k@D4mAd=5AT51?d=9ADE1@chjBDE4>Si0?T5:ADM5?ca6oT4fA4Hn?dA1
?TA1?ca1@4Q3A412A4A5BdU4ATA4@T<n@T16?TDm@d=9A44jA4I1@d8n?48mAD=7
B7m2>d8j@3hl@4<m@C]4>415A4jblo?dm?KMh>?PUeYKGGIaKF]NGfY/MFU]HV=T
JWQaKU5;Ae54K5Q:B4e9Fg1SD51:HFeiLgUM@F=A@TEcM7I5?3Y6BTm;?3ll>CLm
>chk?CXo=Sdk@D<m?Ca5BdE1>d51?DM3ADI1@Cm3BDE5@A53?SY9AD@j?T0n@DY5
AdDo?4Kn@Di4AShoA44nA44o?450B4=4@494A4E;BDA6A4A2@ci2@4HnACe3@dU4
@CY4AT53@Shl@Se5@dM8@S]2>T0n?413?D4kA3Q0ADA>/_?cm?Cf0VUogn;Sh^3C
d]7EemcJeM;>d]gNgM37b]3Id]?8`l;1^lJcYZjd`=3E`Z6GVk;0b[^IRh:=PiBW
Zh^>NgMjOWmWIFUTG5AAEUUJFEAADEIHCUECDTmDEe14ATY=CTU=ATQ9Cdm8CDY6
A4E7C4]<ATi3D55HBTHnBTU0?Di7BD]5BTXYB4m4@T90@dA@A4U9Ad55Bd]8DDE<
CT]IBd`o@D=9A4e9DDA4@Ci6Be5?oTUBCUA<CD92ADE6Bd55A3e0A4U4Ada7@T=3
AKOdloKemMoRhn;Pdm;AeMOLf]GBc];Mg]g@al[@fM;Cb<?2`K_6/jJ^]<3@eL:Q
Ui^b`<ZkVH^2SH=eU:N[RhikMgYnOfMUJFALE55FFEYIE55AEUQ>EE=BCeAGD4A6
BTe>BDe6B4U?CdQ=BTI4ADM<Bda6CT=@DEQ:ASi:BD0mCTM9BdE:BTQ?A492@4=4
D4A9BDM1AD];B555C4i;FD]<?d53BDA=BE54A44nAT]ACoi91TiDC4e2@TEoADI;
@DE4?D14BDA7C4M2@d=5]oCcm_Gegn;Sh^3Cd]7EemcJeM;>d]gNgM37b]3Id]?8
`l;1^lJcYZjd`=3E`Z6GVk;0b[^IRh:=PiBWZh^>NgMjOWmWIFUTG5AAEUUJFEAA
DEIHCUECDTmDEe14ATY=CTU=ATQ9Cdm8CDY6A4E1Ada;C4I>@e1AF4Y6?TY9@3e>
AdU;ADY:B4m4@T90@dA@A4U9Ad55Bd]8DDE<CT]IBd`o@D=9A4e9DDA4@Ci6Be5?
oTTNCUA<CD92ADE6Bd55A3e0A4U4Ada7@T=3AKOdloKem@9Y@mgPhN;Qgm_Nh=oW
in7Uh^C/k^kVi^g[k>caj^c[kNc`k^c[l>gcl_?Xi^O/knk_kNcVinKYj^_/kNOU
i>CUhn;UhmcHo]8hf=KFd<c:c<_?b<:ma[ji/JRPWJFQYjBOUi>BTXf5QX9fN820
QgEmKG9_LfQWH6ELFEAIEeIFFDm<@DM@F5M>BT=2DUAAD4a9BDiBD6U9BdiDD5MJ
BDa@AdQ?DUM?AdI8@deBBeE9CDe@CE1?C4M8Bde7CTi;AT4o?T=;AOi3>UBilO?e
m?CMh>7RhMoKg^3OinOQiN;Tk>k^i^K]jnc/lN[/jng/l>k/jo3]lo;cj>KWk>o^
kng/i^OV3nWZjnc]inGTi>GSh^GSg=SndVcHe]K@c<[<blo8`[g6_[VaZ:2MYJ6W
Y9nGTi:BSHF6PWIhP827MGe]LVmcJ6MPIEaIE5UGEUIICda7D5QGCTY3@U9DDE1<
BDU>DU1YBD]>E51GFTU<D4M8Ce9GCdM6B4==DT]EBDe=D4e@Cda73DQ;CDM>CT]6
@Cln@d]5oT=:E;WaloGdm=gPhN;Qgm_Nh=oWin7Uh^C/k^kVi^g[k>caj^c[kNc`
k^c[l>gcl_?Xi^O/knk_kNcVinKYj^_/kNOUi>CUhn;UhmcHo]8Pf=KFd<c:c<_?
b<:ma[ji/JRPWJFQYjBOUi>BTXf5QX9fFGR0P8MeOFebKg=XIf1UG5UDFEMFEUU?
C4M@F5M>BT=2DUAAD4a9BDiBD6U9BdiDD5MJBDa@AdQ?DUM?AdI8@deBBeE9CDe@
CE1?C4M8Bde7CTi;AT4o?T=;AOi31UBilO?em?@2JGoPhN?Rgn;Ui>KSj^GWj^[X
j^c`j>gcknkbl>oem?OdmOCemoGbmOKfio7el?3cmo;cloOgm?7eloC`mo3_lOOi
m_Wel?;clo3cl^k`l_O`nO?^l?OckO3elNo`jnkbm?;dm?Gako;ak^ofko3cmO?c
mO[alO3dlo?blnc[kNc^k`Galo3`lo;nlgK`l^g[k^oalNo^jno^k>g^lNo`k^_Z
k>KXiNOTi=kOiN?TgN?QhN3NgmoKe]C>cMGFclg9`[k3cLJj^[NohO3dmoSih>7S
h]oRiNCVhn[Uin[Zj>[/l>S]lno^l_3_mOCgm?GdmOOel_Gfm^OamO3`loOblo?g
me7dlOGcm?3gl>oamoWfnOG`l_?cl??bk_3bmo3ilnk`mo?]l?Gako3[k_;dl_Cd
mO7_l_7^koK_l??elo?en_7al?Cclo;ck>_]k>k_lO?`l??bo_<Zl?;]jnk_lO7_
k^__k^c]k_7_l>k[j^cVj>GWi>CNgnGSi=gShN7Pg]oOfgoFe<k=eMK?cLW2_/?=
a[Zj]koQl?Cgn?WPhN?Rgn;Ui>KSj^GWj^[Xj^c`j>gcknkbl>oem?OdmOCemoGb
mOKfio7el?3cmo;cloOgm?7eloC`mo3_lOOim_Wel?;clo3cl^k`l_O`nO?^l?Oc
kO3elNo`jnkbm?;dm?Gako;akQg_m^o`loGcloGjlO7`m??cl_?/jng/k^oalo3`
lo;nld;`l^g[k^oalNo^jno^k>g^lNo`k^_Zk>KXiNOTi=kOiN?TgN?QhN3NgmoK
e]C>cMGFclg9`[k3cLJj^[NohO3dmoSi0VUKg]oRh^3Ri^CTi^WXj>c]jn_/l>O/
lNgblo3_mOWflO;an?Odl_?el_7gmo3/l_Gcl_Kdm_Ccm??bko?eloChn?Gimo;d
k>kcmO7^l?3ZkO7bl_?elO3cmoKcl_3nlaK`lOCel_3glnocm_?_l_OcmOKgl_?c
l_kc1_Cbl_Chl_0dm?;ckoKemOCgmOWelO7blnoalo;ako3cmO?dmO?bko?ak^[`
l?7[ko?ako;dko3^k^c^k>knj`G^jn[/kNcnkOo[?>o/k>gbl_GfnMkOh^;Ph^KT
i>KYj>S/kN_[k?3Wk?7]l_?`koGim_7blOSgm?;cmO;amoO`k?;elo;fm?HWm??d
lo;_loGcm?ShmOWgl_C/k_?elNk`l>[]lO;bloGal??gm_?bl?kc5_3am?Gbl?Oc
ko?flnobmo?em_Oblo?bo_<jm?;bm?Sbl?CblnofmOGdmoGimO7al_?_lO?blNo`
loGcm?Gcl^oclNkZl?3ajnoclNobm>o`k^k/k^`0k_k[1Nk[j^c]k?k]on]Tknc/
kO;bmOKig]oRh^3Ri^CTi^WXj>c]jn_/l>O/lNgblo3_mOWflO;an?Odl_?el_7g
mo3/l_Gcl_Kdm_Ccm??bko?eloChn?Gimo;dk>kcmO7^l?3ZkO7bl_?elO3cmoKc
l_3nl`S`lOCel_3glnl=loKcko;gloGfmo;clo;nlc_dl_;dn?;`m?;ckoKemOCg
mOWelO7blnoalo;ako3cmO?dmO?bko?ak^[`l?7[ko?ako;dko3^k^c^k>knj`G^
jn[/kNcnkOo[2>o/k>gbl_Gfn@9YE^7Oi>;Qh^?UhnG[kNk/k^g]jo;^lO3`mO?^
k_Ohn_C_lo[hl?3gl^odnOc_l?;hloKhnOOblOSdl>ogm?Kjn_Whn?Cel^gamOOg
m_Wcm_;am_Oemo7`m?kg9OGdm_Ofl_Ogn?3bmoKgn_SfmO3emO_knOKemO7bmOCf
l??hn?;e;OGfmNogmOKgno[mnOCdm_C`mOKemoCamoKimoOdlNcdm_C_lOCelO;d
mOCemoKnm@W^ko3clo3`lnoao_91lO3clO7cm?G_lOSfmoSQgnCRhN;SiN?Ujng^
k>k]kN_bk_7`l?Gck^kgn?[dko?jn?3`mo;_m?Wlko3bn??fn?Wg8_;an?C`koOd
m_[jnOShm?GbkO7emoOfnO?fl_7fmoGglO3do_MCmOCfmoKbmoOhl?;gm_Ojn?Ke
l?Geno_im_GelO;em?K`loShl_Gem_G_moGfmo_joOWdm?Kdl?GfmOOdlOOfnOOg
m?7/m?Kdko7dmO7bm?GdmOOfo_D2k^o`oo?ol0;cko7nlVCal??alO?dmNoan?Kg
n>7Oi>;Qh^?UhnG[kNk/k^g]jo;^lO3`mO?^k_Ohn_C_lo[hl?3gl^odnOc_l?;h
loKhnOOblOSdl>ogm?Kjn_Whn?Cel^gamOOgm_Wcm_;am_Oemo7`m?kg3OGdm_Of
l_Ogn?3bmoKgAO[hm_G`mOGknoWfmOGal_Gdm_3cn?SbmOGfmNogmOKgno[mnOCd
m_C`mOKemoCamoKimoOdlNcdm_C_lOCelO;dmOCemoKnm@W^ko3clo3`lnoao_8=
lO3clO7cm?G_lOSfmoP2JOoPHn?Pg^;Vi^CXjN_/k^_[kN[`k?3`k_7dkO3hn?Kc
koKjnOG_m_?]lOWhjnk`n?7bn?WflO7hm_3amOCblOSgn?Welo7amOSgloChn?Kb
l_GhloC`l?Oin?Sel_GfmOCfnOW`lOGnn03go_D6n?Ogn?Oemokeoo@6m_;enO[c
lgofm?;]m_SgmoSjnoSdlOGcm_KemoO/k^k[nOCel_;]ko7dl??cm_7bloCalOGe
mo?dl^o`l_7dlO;`l_7clO7_lo7`l_Kdk_?fmoShh>3Sh=kRi^KTj>W[k>k[jngZ
l>c`l>kam>g`n?Sflnofn_WekoKckO7in>_^l?Sal_Sim_oa;oSfl?7em?;an?Oh
nOGclO7en?Ocm?Shm_;bmOScm?3`moWhn?GbmOKem?KinO3amOkh0?Onm@KhmoOh
moGgo_Gom3[fl_Gin_?cm_CbkOKhmoOhn__hm?7eloKfmOOgk>k^joWdmO;bkNoa
m?3cloKal_?dlO7emOOcm?;_l7oblOCal_3blO?alNoclO3bm_C^loKgn?SPh>?P
g^;Vi^CXjN_/k^_[kN[`k?3`k_7dkO3hn?KckoKjnOG_m_?]lOWhjnk`n?7bn?Wf
lO7hm_3amOCblOSgn?Welo7amOSgloChn?Kbl_GhloC`l?Oin?Sel_GfmOCfnOW`
lOGhn07hmoke1_SgmoSgmOOnmOodD_KbmOWjlo?fm?;]m_SgmoSjnoSdlOGcm_Ke
moO/k^k[nOCel_;]ko7dl??cm_7bloCalOGemo?dl^o`l_7dlO;`l_7clO7_lo7`
l_Kdk_?fmoSh0VThgn7Ph^7Sj>CUi^_Zj^WYj>c^l^g`kn_^loCbm_Gfl?3fnOOh
loWilo;hn_7bm?[bkoKkm^k_nOSdo_I3lo3fn_[imO;dmo;amNodmOKdkOChm_Oa
kOSkn?WimO7dn?Gbm?ShlOGgm_Gfm_C_loOfn_Oej?OimoOdm?KcmoShl?4fmo[f
lO_gnochn_cdm_;jn?GcmoKfl_Ggn?[inOKbm?Oem_?eloCbl_KflO3hn?Ofm_;`
lOKdm?kbANoem?7^koCclOCdl_7fm_Ofn=oQh>;QhnSTiNK[j^[YjNS/k_;]l>o[
k_?dl_Kem_3`m_Wgn??inO?bn?[al_Cjl^ofnoH4k^oin?CnmWOcl?Kjn_Wel_Cg
l_7ekoCem_C]m?Sfmo7]n?_hnOWelOChmO;dn?SamOOfmOKfm>ocmoKjmoGXmoWg
moCdm_?gn?S`lOOjm_7kmo_ln?[lm?Kbn_SeloOfm_;emoSjnOWfl_CgmOKcmO?d
l_;fm_7`n?Sgm_Kbl?42m_Cdo_9:koGdlNk_m??am?CblOKfmoKhgn7Ph^7Sj>CU
i^_Zj^WYj>c^l^g`kn_^loCbm_Gfl?3fnOOhloWilo;hn_7bm?[bkoKkm^k_nOSd
o_H[lo3fn_[imO;dmo;amNodmOKdkOChm_OakOSkn?WimO7dn?Gbm?ShlOGgm_Go
mTcdko?gm_[gmNSgnOOgm?CfloOhn?3amo[flO_gnochn_cdm_;jn?GcmoKfl_Gg
n?[inOKbm?Oem_?eloCbl_KflO3hn?Ofm_;`lOKdm?kb4Noem?7^koCclOCdl_7f
m_Ofn09U3moPhmkRh^KVinKZk>cWi^cnkfc`kncZlO?fm??gmO7bn_cgn??gmoSc
l_KdlOCkn?CdmoGdl?OeloKel_?hnO_ko?Sdm_WbkOKiloOflo?in_[inO?jm_[j
o?O^m_Gel?Cdm_;gn_Wcm??al_Oln?WhnOGgm_3bmoSilo?fn?Gg5_OfmOCjn_cj
nogknOOdnOShm?Whm?Kjo__on1Ogn?GgmoKbmo[hl_Cdm_CenO[gm_Kgm?;mm@kf
mOGdloCcm_KclOGfmO7nma7hn]oPhmkRh^KVinKZk>cWi^cnkb3`kncZlO?fm??g
mO7bn_cgn??gmoScl_KdlOCkn?CdmoERm?3gmO?fmO;cn?Wknochm?Kil^gfnO?g
m_?cnO[jnOWcn_Kjn_cgk_KemO3dm?Kbmo[iloCclO;go?Sin?WemoK`l_OhnO?c
m_SemoOfmOCjn_cjnogknOOdnOShm?Whm?Kjo__on1Ogn?GgmoKbmo[hl_Cdm_Ce
nO[gm_Kgm?;mm@kfmOGdloCcm_KclOGfmO7nma7hn]oPhmkRh^KVinKZk>cWi^cn
keC`kncZlO?fm??gmO7bn_cgn??gmoScl_KdlOCkn?CdmoGdl?OeloKel_?hnO_k
o?Sdm_WbkOKiloOflo?in_[inO?jm_[jo?O^m_Gel?Cdm_;gn_Wc;_CclO;go?Si
n?WemoK`l_OhnO?cm_SemoOfmOCjn_cjnogknOOdnOShm?Whm?Kjo__on1Ogn?Gg
moKbmo[hl_Cdm_CenO[gm_Kgm?;mm@kfmOGdloCcm_KclOGfmO7nm`7hnP9V3>3R
hn7Ti>OWjNOZkN[nkQ7al_3am?Cam?Ggn?Ofm??enoWnn5[en?Sjm_KdlOGjn_Gg
mO?dm?[enOOgmOGinocjo?WemOKfm?KjmoGcmoWjnOWjn?Wko?cjmoSdmOOdl_O`
m_Cin?[gmo;`m?KjnoSinoKflnocn_Wgm?CgmoGc1o?dloGjn_Wio_X>m_Ofm_Sj
moWfmOOio?Sio_L4m?Ocm_Knlb7fl?Gen?KhnOSimOKdm?GclOGcmO;fmO?bloGe
lo?dmOCdoOL=m^3Rhn7Ti>OWjNOZkN[nkQ7al_3am?Cam?Ggn?Ofm??enoWnn0ke
n?Sjm_KdlOGjn_GgmO?om57jmOWgmoGenO_ln_cimOGfm_Cfn_OeloOin_Win_Si
nocln_Ohm?Ggm?;gl?KdnOSjmoObl?Cfn__hnO_fm_?_lo[imoCdmoOelo?dloGj
n_Wio_X>m_Ofm_SjmoWfmOOio?Sio_L4m?Ocm_Knl`kfl?Gen?KhnOSimOKdm?DB
lo7eloGbm_Gcl_?emO?cm?Gdm?gg3OKPh^?Qi>CWinWWj^gZo^hAlO;`lOCdlOCe
moSgm_CcmO_io_Q2mOShn_Kfm?7en_[emoGcm?CjmOWgmoGenO_ln_cimOGfm_Cf
n_OeloOin_Win_Sinocln_Ohm?Ggm?;gl?KdnOSjmaogl_3dm_[kn?Wkm_Kcko?j
nOOdm?OgmO?cm??en_[inOkj3_Kgm_Khn_Oim_GgnOchnOkg1?CgloKfo_<Qm_3e
mOSfn?WhnOGfm?Celo7eloGbm_Gcl_?emO?cm?Gdm?gg0?H2Hb7Ph^?PinKWjN_[
kNo^l^kalO;eloGimoShmoWhn_Sjnocgo_X0o?kjoo/FmoGfo?cjnO_imoWknocj
n_clno_in?[lo0Ohn__joOWjn?kl1OWkn?Wlo?kkoo`RnoWino_lno[knO[kn_Wk
n_Wjn__jnocknO_jo?cjn_Wio?/6n?Wko?_ln_kl2__hmoKlo?_kn?Wlo_/Jn_Wj
n__hn?_jn_SjnoWdnoWgn_KjnO[lm_Sho_L<n?OjmOKbmOGgm_Wgmokf9oOin__j
n>3Rhn3Wi^OYjn_]knkbk_7al_GcmOWgn?SgnOSjn?[ko?OnnP3lo_[on`SgmOKl
o?[inoT=moWknocjn_clno_in?[lo0Ohn__joOWjn?kl1OWkn?Wlo?kkoo`YnoWi
no_lno[knO[kn_Wkn_Wjn__jnocknO_jo?cjn_Wio?_hnO_lnocjo_`:noSgm_cl
no_hnOcnna_jnO[jnoShno[jn?[knOCknOOjm_[in_cfn?SgooL<n?OjmOKbmOGg
m_Wgmokf9oOin__jn>3Rhn3Wi^OYjn_]knkbk_7al_GcmOWgn?SgnOSjn?[ko?On
nP3lo_[onaKgmOKlo?[inoWgnO_ko?[jo?cknoWhn_cl1oSjno[mnO[ho_`5nO_h
nOclo__oo0[knOWknockn__inQkkn_Wkn_Wjn__jnocknO_jo?cjn_Wio?_hnO_l
nocjo_`:noSgm_clno_hnOcnna[jnO[jnoShno[jn?[knOCknOOjm_[in_cfn?Sn
m`chmo[em_;emOOfnOOgo_H5moWjno[h0VOogQ7RhnCXj>WZj^_[knc_l?;bmOGn
mQSenOSjm_GgnO[jnocinO_in_cjn??^l_[jo_/@m_Ccno_hno_hn_[hn__jno[n
nooj7?gknoWkn?Whn_Wjn?[lo?_jo?Kio?_inocim_SfoOXEnOckn?WhnO_ko?Sj
nockn_WinogknP?gnOWjo_/_moglnocln_cgnO_kmOSknO[lnoWlnO[jnoKjnO[k
o?Wimo[kn__ln_Wfn?_fmoSjo_LUn_KinOKfnOCgn_SimoOen?Oeg]kRhnCXj>WZ
j^_[knc_l?;bmOGnmQSenOSjm_GgnO[jnocinO_in_cjn??^l_[jo_/0mPodlo_k
n?_kn?[jn?[kn__jo__onQcmno_inoSin?[in_Sjo?ckn_cfnOcknO_lnOKhm_gj
6OWlnoSin?Wknochn__lno[inO_mno[gnOWjo_//moglnocln_cgnO_kmOSknO[l
noWlnO[jnoKjnO[ko?Wimo[kn__ln_Wfn?_f0_Ohn_kg9O[fnOWfm_Wdmo[hnOOg
mOSgmMkNh^?Tj>SYj^[[jno/ko3bl_Geo_HHmOWhn_KemoWjn__lnOWknO[ln_Sc
k_;jn_kk4?Kdlo_kn?_kn?[jn?[kn__jo__onQkmno_inoSin?[in_Sjo?ckn_cf
nOcknO_lnOKhm_[jooXInOckn?WhnO_ko?Sjnockn_Winogkn_OinO[nnbogoOck
o?cjo?Oino_en?_in_cknOcin_[km_[in__lnOWgn__jnocjnOKhnoKgn?[nma7j
m_Wim_Kim?Ojn?WgmoGhmoD2FOoPH>?TinKXjN_[k>o^k>kam??bmOKfn?KgnO[l
nO_loO_jnOglo?[jo_cjlo;bn?cmo?Wfm_Oin?gjnoWmn?[lo?gko?glnocmo?cn
n_cnoO_jnockoOcloO_mn_ckoOcknoSno?ok0?gmna;mno[jno_loO_jnocjo?_i
n?_l1O_ioO_ln?kl0Ogko?cmn`cmn__mo?gho?[knoWgo_/;o?gkn__ko?_lnocj
o_U<m_Sko?ShnO_knOWhn?_gmo_im_WhnO[im^3PhnCWi^SYjn_/knk/k_7dlo;e
m_Khm_Oin_cinocmno[ioOcln_[no?[cl_;ho?glnOH^m_Oin?gjnoWmn?[lo?gk
o?glnocmo?cnn_cnoO_jnockoOcloO_mn_ckoOcknoSno?ok0?gmnaSmno[jno_l
oO_jnocjo?_in?_lnoWmnocho_`1oO_lo?gk3?gjnogloOSln__knOOnn`_loO_j
no_lnocko?[nn@3fN_Sko?ShnO_knOWhn?_gmo_im_WhnO[im^3PhnCWi^SYjn_/
knk/k_7dlo;em_Khm_Oin_cinocmno[ioOcln_[no?[cl_;ho?glnOKfmoWhoO[k
nOghn_cloO_loOcko?glo?kjo?kmno[ko?_mo?cmnogjo?_mo?_kn?kloo/0oOgk
6?gkn_[knocmno[ko?[lnoWhnocknOgko?Sno07mnocloO/<oO[koOcmn?cjno_i
mokk2ocmno[knocko?_ln_ki6?Khnochn?WknoWin?SkmoOknOKin?WjnOH2IOoP
on<<iNOXj>_]kNc[inkal_kd0_Oem_kgooSon@7jnOkk4OcjoOWjo?_lmoKhn__j
no_gnOkh3_[kn_SknoWfl?ckoO_moOgk0?[no07mn_kl9oWkn_cjnOchno[lno[k
nogjn?cjo?Wlo?[kn_[io?_ln_WkoOcko?Snn`3mo_cooOoi6O[loOcloOckno[j
oOcjnogmnOgho?_koOcho_conool1oWknocknOSho__omROjo?[jno[jmoWhmoOe
n?KfmoKimoKfmn3Phn?UinSXjng]k>_Wk_7bo_@2moGfo_Oon?oi0O[io_/@o?[m
nO[lnocgm_Sjno[knoL0nOkh3_[kn_SknoWfl?ckoO_moOgk0?[no07mn_kl9oWk
n_cjnOchno[lno[knogjn?cjo?Wlo?[kn_[io?_ln_WkoOcko?Snn`3mo_cooOoi
6O[loOcloOckno[joOcjnogmnOgho?_koOcho_conool1oWknocknOSho_/0mRSf
n_cjn__jn_Oin?OgmOSfm_OfnOOfm_OPh>?SiNOXj>_]kNc[inkal_kd0_Oem_kg
ooSon@7jnOkk4OcjoOWjo?_lmoKhn__jno_gnOkh3_[kn_SknoWfl?ckoO_moOgk
0?[no07mn_kl4oWkn_cjnOchno[lno[knogjn?cj4ocio?cjno[jnOcko?[inogl
nocho_/0oOkloogonAWjo?glo?glno_jn_gln__moOWmn?cknogln?kloo_oo0Oi
no_lnoWhn?kkooHFn_cjn__jn_Oin?OgmOSfm_OfnOOfm_L2G_oP9N?ViNGXj^_/
jnk`ko3aloKimOOgn?OimoOjo?cko?_koOgloOclo_/8nOglnoglno[lo_/JnOcm
no_mn__jnOgloOglnoglo__lnogko?ckoO`7oOcnn?_jno[mo17mo?_knO_ko?cm
oO_in?_no?gmo0Oko?_lnogln_kl4?[loO_lo?gmo?glo?[koOklo_goo0Cmn_cl
nokl1oWlo?gno?_mo_`1oOWnnPgko?Ohno_lo?_lo?_jnokj<O_hn_[knoSimo[P
h>?ViNGXj^_/jnk`ko3aloKimOOgn?OimoOjo?cko?_koOgloOclo_/8nOglnogl
no[lo_/JnOcmno_mn__jnOgloOglnoglo__lnogko?ckoO`7oOcnn?_jno[mo17m
o?_knO_ko?cmoO_in?_no?gmo0Oko?_lnogln_kl4?[loO_lo?gmo?glo?[koOkl
o_goo0Cmn_clnokl1oWlo?gno?_mo_`1oOWnnP;ko?L:n?_ko?cko?ckn__nnS7k
n?[jno_hnOOjh>3Si^GUj>[[k>_^l>o`lO?fnOGgmoSgnOOgn_clnocknogmo?gl
o?kk2?Wmo?_mo?_jo?kk6_WloO_koO[kn_Wmo?gmo?_mo?kko?_mnoclnogl1ogl
o_Skn__joO`5oOcknoWk2o_lo?gmnoWhnokloOgl1o_lnockoOcjo_`@n_cmnocl
oOgloOcln__mo_cnoOol1?gjo?cko_`7nOcloOklnogno07mnOkj3O_lmoSknocl
noclno[ko_X9noSjn__kn?WgnP9P4n3Ri>CViNKXjnc]k>g^ko3cl_Sfo_Oon0Wg
m_[ho?glnoWjo__oo?ok2o[lo_gjo?glo?[ln_kl3O[ln?[kno[jnocno?_jo_`_
nokln__lno_loO_jo?ckno[jo?[ko?_lo?_jo?_ko?cjnocmn?Wino_lno_moO_k
o_`2oOckoo/@o?_mn?[fn__lo?gjn__lo?gmo0?mnocko?`on?cko?cmnogkn__k
o_gjn_Kio?Wko?Sgn__lnoWin_Wim_WjnO_jn_;jnO[Ph^CTi^GVj>_/kNc]k^o`
lo;hm_kgooP9moKjn?cmo?_in_kkoocon`Wjo?kmn_cmo?cj0Ocjo_`=n_chn__k
n_[ko?klno[no2oko_cjnocknocmno[lo?_kn_[ln__lnoclno[lno_lo?[ko?gh
nOWknocknogmno_no07mo?kk4?ckoOSjm_[ko?cmn_[ko?cmoO`3oO_lnocl4oSl
nocloO_mno[knokmn_[fnOci:o_ln?OjnocknOWjnOWfnO[ino[jl_[in^3Ri>CV
iNKXjnc]k>g^ko3cl_Sfo_Oon0Wgm_[ho?glnoWjo__oo?ok2o[lo_gjo?glo?[l
n_kl3O[ln?[kno[jnocno?_jo_`Mnokln__lno_loO_jo?ckno[jo?[ko?_lo?_j
o?_koo`?n__loOSinO_ko?_koOgknokl0Oglo_/@o?_mn?[fn__lo?gjn__lo?gm
o0?mnocko?`[n?cko?cmnogkn__ko_gjn_Kio?Wko?Sgn__lnoWin_Wim_WjnO_j
n_;jnOX2DQcQh^CUjNOYjN_^k>g_ko;alo?hnOSgmOKhn_WjnOkk3ocmn_glo?gm
o?cko?gloOgmo?om0Okmo_`5n_clnocmo_con@Slno_nnocmo_[no0?nnocko_go
o0Cmn?SkoOcl0Oglo_/>n_gloO_lo?kloOckn__lo_d0o?kmoo`0oOkl8_gko?gl
o?gmo_cloOgloO_loOSmo?gko_gmnogmo?[lnogko?`:oOcjnogjoOcin?_lo2[k
n__lno_ln_[lno[knn7Ri>GYinWYjnk/kNo_l_7cloSin?Oem_SjnO[io_/?o?gj
oOcloOglo?_loOcmoOglood1o_gno0Gjo?cko?gno?oi2?cknokko?gnn_kl0okk
o?_noOol1?ghn?_mo?`1oOcnn`kjoOcmnoclo_cmo?_jnocno@3lo_goo03mo_`R
oO_loOcloOgno?cmoOcmnocmn?gloO_noOgkoOgln_ckoO_lo0Gmo?[koOX4oOci
n?_lo2[kn__lno_ln_[lno[knn7Ri>GYinWYjnk/kNo_l_7cloSin?Oem_SjnO[i
o_/?o?gjoOcloOglo?_loOcmoOglood1o_gno0Gjo?cko?gno?oi2?cknokko?gn
n_kl0okko?_noOol1?ghn?_mo?`2oOckoo/>n_gloO_lo?kloOckn__lo_d0o?km
oo`0oOkl8_gko?glo?gmo_cloOgloO_loOSmo?gko_gmnogmo?[lnogko?`:oOcj
nogjoOcin?_lo0gkn__lno_ln_[lno[kn`9A1=kOh^CVo^M9j^cZi^S/ko7cm?Cc
m_Ohm_WimoOjnO_kn__ko?cmo?glo?kmo?_mo?Wgmo_mo?glo?_lno[lno[inoOi
nOSjn?[nnocko?[no?cno@3jo_/1oOcmnP;koOgmo03koO`Do_[mnoWjnocln_gk
o?glo?gloOcm2?ckoOclnOckoOgl3?gjno_loO_loOcmoOcnnogm1_cjnocln_[n
o0;koOclnagio?_kn_gknoWjo?WjnoSlo?Win?_jno_jg]oRi>Knib_Zk>[Vj>c_
lO?dm??fmoSfnOWgmo[ino_jno_lo?gloOclo_glnoglnOOgnagmo?glo?_lno[l
no[inoOinOSjn?[nnocko?[no?cno@3jo_/1oOcmnP;koOgmo03koO`Mo_[mnoWj
nocln_gko?glo?gloOcmo?_mo?cio?_moO`<oO[knocmnocmo?gmo?kkoOd6o?[k
o?cjn_kl0__mo?ck0?TLo?_kn_gknoWjo?WjnoSlo?Win?_jno_jg]oRi>KnidWZ
k>[Vj>c_lO?dm??fmoSfnOWgmo[ino_jno_lo?gloOclo_glnoglnOOgnogloOcl
nockn_ckn_WkmoWin?[hn_kko?_ln_klo?km0?[nn`7mo?gj0__moOgl0O_lo_`M
o_[mnoWjnocln_gko?glo?gloOcmo?_mo?cio?_moO`<oO[knocmnocmo?gmo?kk
oOd6o?[ko?cjn_kl0__mo?ck6?Wlno_joO_knO[lnO[kn?clnOWhno[knoX2E@OO
hNCUj>K[j_k/3nCXk>oaloGdmOOhmoGjno[nn`7ioOkj4__loOcloO_ko?ckoO[g
mO_lo?_no?ok6?cgn_glo?Sen_ckm_Ggo?cno?cmo_gloOgmo?om3OkgnogloOgl
oOcmoOclo?dBo?[fmo[loOcmo?cko?cmoOkmo0cmo?gmo?cjoOgloOglo?d0nokl
2ogloOgko?cmo_gko?gm0?_no@;ko?gno1Smo?cko?[mno[ho?cjn_gkno[jnogi
n_glo_/7gn7TiNSVjn[nk0oTj>c_lO?em?Ggn?Oen__jo_/1nOgnnQ3ko?glo?gk
noclnogjmoGko07lnokloo/Ho?OjoOcln?Gjo?_fmOOlo?klo?gnoOcmoOglood=
o_OkoOcmoOcmo?gmo?cloAoln_Kgn_cmo?glo?_lo?gmo_gloOcmoOcln_gmo?gm
o?cm0?_no0_mo?gmnocloOkmnocmo@3ko_d2nocmo_`3oOclnaCln_gkn_Slo?[j
oO_kn_[koOWjoOcnn`OOhNCUj>K[j_k/3nCXk>oaloGdmOOhmoGjno[nn`7ioOkj
4__loOcloO_ko?ckoO[gmO_lo?_no?ok6?cgn_glo?Sen_ckm_Ggo?cno?cmo_gl
oOgmo?om3OkgnogloOgloOcmoOclo?dOo?[fmo[loOcmo?cko?cmoOkmo?gloOgl
o?[moOcmoOclo@3ko_`;oOcmoO_lo?gnoO_loOd0nokm0__loOkl6?glo?_ln_gk
n_Slo?[joO_kn_[koOWjoOcnn`9?5=kQhn?Wi^SXjn_Zin[]l?3aloOem?ke0oSi
nO_nn@_lno[jo?cmoO_jo?_nnPWlnoWho?[knOcmo?/UnO_ho?cgno[hmOOgo?cn
o?cko?cjoOglnocloOcmnOWjnogko?gio0Gmo?gikoGno03ko_`7n__loO_ko?dQ
oOcmo?glnocnoOcmo?_jn_Slno_lno_loOckoO_mo?gko?gm1O_mo?glnokm2__l
nOgio?[kn?KgoO/Rn_Wjn_chn_[fnO[ln_cNhN?SinKXj>_[j^OZkO3`lO?gmOCn
m@?hnOWko_T;o?_jn_cloOgkn_cko_X5o?_in?cj0o_io?glnbGinoSlo?Okn_Se
moOlo?klo?_lo?[moOcko?cmo?ginO[koO_loOWl1OgloOW_mOkl0?_no2Wjnocm
no_loOgloOcmo?_lo_gloOckn_[ho?_ko?_ko?glnogkoOcmnocmo@GkoOcmo?_n
o@Cko?Wmn@Gln__hm_Omnb;jnO[jo?Sjn_Kin_cjo=kQhn?Wi^SXjn_Zin[]l?3a
loOem?ke0oSinO_nn@_lno[jo?cmoO_jo?_nnPWlnoWho?[knOcmo?/UnO_ho?cg
no[hmOOgo?cno?cko?cjoOglnocloOcmnOWjnogko?glo?kl1OgloOW_mOkl0?_n
o2Wjnocmno_loOgloOcmo?_lo_gloOckn_[ho?_ko?_ko?glnogkoOcmnocmo@Gk
oOcmo?_no@[ko?WmnOcjnoSfmogk3O[in_[ln?[jm_Wjo?[l0U/3gn7Si_kW;NW]
k>cWjno`loCcm?CfmOCfmo[jnOShnogkn_glo?gknOcmo?KgnO_lo?[lo?knoOkl
4O[kn__io?gmn_Sfl_GkoOglnokm3ocno?_mo?klo?gmn_[ko?kno@3knodEo?gm
o_[fnOcloOcjn_kmooglo?gloP3loOd5o?glo?_lo_dLnO[ko?gloO_koOcmo?gj
o_gnnocmo?gmo?gmo?cnnb7lnOgknocmn_cimO;hnoSho?[ln_cmoO_ino_moOcO
hN?Vo^L/jNg/k>O[ko3cm??dm?Kem?Kgn_[in?SkoO_joOcloO_io?glm_Oinocl
n_cl0?knoOkl4O[kn__io?gmn_Sfl_GkoOglnokm3ocno?_mo?klo?gmn_[ko?kn
o@3knodFo?gmo_[fnOcloOcjn_kmooglo?glo_cmo@GloOclnocnoAcin__loOcm
no_mo?gloO[noOkko?gloOgloOglo?kk1OcioO_ko1_mn_cimO;hnoSho?[ln_cm
oO_ino_moOcOhN?Vo^L]jNg/k>O[ko3cm??dm?Kem?Kgn_[in?SkoO_joOcloO_i
o?glm_Oinocln_clo_kmo_`An__jnoWloOgjn?KbmO_moOcko_d?o?klnoglo_cl
oOgjn__lo_km0?_moOom5_cmoOkjm_Wlo?gln_[noOomo?cmo?kloOd5o?glo?_l
o_dLnO[ko?gloO_koOcmo?gjo_gnnocmo?gmo?gmo?cnnaglnOgknocmn_cimO;h
noSho?[ln_cmoO_ino_moO`2JD[PhNCSgm[Ng>GUinC/k^o[knoam>cSjO;emoGb
l>Obm_?fm_gkoOWioOcjm_CenOchm_gloOOjmoWhnoKhm_Ogn?Gcm_OhlNodmo_n
o?on5_Oam?_mn_cmo?cmnochmOOin_cjnoWho_`EoO[io?Sgm_cloOclno_loO_m
nogknRcknOcko?ckn_glo?gmnoGfn_cmn?_ko?glno_mn_glnoSknocjoO_loO_k
o?cnnTolnocjno[knO?dn__imoWknoKjnochlo?gno_ih>7ThmoJg]cUiNOTk>k_
jno_lOC/hnWbmOOel_3Wl_Kcm_KmnoginOgln_KdmOWln?Kmo1Kmmo[gnOSkm_Sf
moOhmO?fmoSakoCgnokloohFmo7dnogjo?glo?gko?SemoWjo?[knOSno4;mn_Wl
n?Ofo?cmo?cknocmnogkoO_jnoWlnoclno[mo?cmoO_em_[loOSknocmo?_koO[m
o?_hno_ln_gko?gknoclo_X3o?_lnV;kn__iloCjnoWgnO_km_[ko?ScloOknoWP
hNCSgm[Ng>GUinC/k^o[knoam>cSjO;emoGbl>Obm_?fm_gkoOWioOcjm_CenOch
m_gloOOjmoWhnoKhm_Ogn?Gcm_OhlNodmo_no?on5oOam?_mn_cmo?cmnochmOOi
n_cjnoWho?ol@_gjnOchmoKlo?glo?_ko?gkoO_mno[knOcko?ckn_glo?gmnoGf
n_cmn?_ko?glno_mn_glnoSknocjoO_loO_ko?cnnQ_lnocjno[knO?dn__imoWk
noKjnochlo?gno_i0V=Eh^7TdImZK7MnRM?Uj>k[j_;blMMmJlOemoOcjH]ff?Gk
n_Ckn_klnogkoOOfm__lm_Kmo?ghn_Semo[hm_Kam[B/Z;;Gm_G5/KS=o_gmo?c]
k?KmnOclo@7io?ki7oOQ`m7dm__jn?cmnOSim_CgoOcklnSUinO[m?[hnockooXY
m_[kk=_/n_OkoO_dlOCjo?cinOcjnoWio?_jnO_kmoOfm_cmoOkmoOWko_U@n?_j
oOcln?WhmoKlnOSfm?OjmoOknoGem??knO[RhNCAWfY/Mgj9dnGXk^_Zl_;aege[
aoGgmo?YRgKHmO_jm?_jo_ckoO_mmoKfnocfm_gl8Oghn_Semo[hm_Kam[B/Z;;G
m_G5/KS=o_gmo?c]k?KmnOclo@7io?kiBoOQ`m7dm__jn?cmnOSim_CgoOcklnSU
inO[m?[hnockn_[fn__/fncjmo_mnoCam?[lo?Wio?[knOWlno[ino_gmoKfo?gm
o_gmnO_nn@Chno[mo6gln?WhmoKlnOSfm?OjmoOknoGem??knO[RhNCAWfY/Mgj9
dnGXk^_Zl_;aege[aoGgmo?YRgKHmO_jm?_jo_ckoO_mmoKfnocfm_gloOSjn?Gg
n_Sfm_7f]:bX/]OfmLFa^<gnoOglo>g/m_gio?cm0OWlo_T7mn73dOCfnoY3n?cm
nOSim_CgoOcklnSUinO[m?[hnockn_[fn__/fncjmo_mnoCam?[lo?Wio?[knOWl
no[ino_gmoKfo?gmo_gmnO_nnAchno[mo?chnOSgm_cin?Kdmo[gmo_kmOGdlo_i
nP9VOn3Rhn3IA5Na^UI;Mn[^jN[`l_CRJE71knRoi>QTElcgnOWgnO[lnocino_f
m?GlnoGbo?chmoWkn_ClnOSfm_ZeGT_1iOO`e5fBeOcmoOckj^ggn_Ggo?gmo?ck
o?Skmo5cEIcjnoghmoSimOKjmOGdoOcjfIY9JgikGW72moKj4?WhmoWNHf?An_Sg
noggloCloOX<n?Wln_WjoOKdn_[gnokh0ogjnogno03io_Q?moSjmOSgn??fn?cj
n?Oimo_hn_WkmOKdmO[dm>3Rhn3IA5Na^UI;Mn[^jN[`l_CRJE71knRoi>QTElcg
nOWgnO[lnocino_fm?GlnoGbo?aLn?Oino[do?Whm_Kj]Ei;`NGgl=AMT]GloOgl
nn[]mo[emocmoOclnochnoOaLeFLn__mn?OhnOGfn_Gem?gln]VJBF]nNeia`_Of
n_WhmoWNHf?An_SgnoggloCloOX<n?Wln_WjoOKdn_[gnokh0ogjnogno03io_P3
moSjmGohmoScm_Sln_SgnOOkn?[inoGfm?Gjm?CPh^?PfDAG/KYFBgOZk^WZl?;d
hVUA`NoX_nCXI5O<moWimoWjo?_lnO_km_Ceo?_el_cln?Oino[do?Whm_Kj]Ei;
`NGgl=AMT]GloOglnn[]mo[emocmoOclnochnoOaLeFLn__mn2Sgn?Wem_[emOCm
o?[IVTU[OW]NLL;gm_[in?OigV=SdO[hmo_mmo?do?gj3?Sio?[in_gfm?[jmo_n
n0?mn__mo_`0nOkh6oOhn_GhmoScm_Sln_SgnOOkn?[inoGfm?Gjm?@2HdcOhNCR
h4]QcNBmEE[]kng_l_7bl7]=`^jfOmcdN5;=n?[in??inOSjmo_kn_Ognocfl_cj
nOKln_SenoGbmoSkmlY</_7im>^AlOWloOkl1OKdloSfmogmo_`RnoWfmZmBW_Kd
k_Win__knO_jmOGoo_ckkd]jjo2LCVWhmoaoo?Wim_QgH]?in?Kjo?cgn_gko?_k
n?cmo?WlmoGknocjn_Ofn?_ko_gln__ln_Wfn?GjmoOjoOOen?chmoOin?gln_cl
noSdmoKgm]oQi>;PBf7=i;eEF^g_kNoblO;`Ndg2k[Iog?AhD/ghn_WhloWin?[g
no_jmoOko?Kbo?XHnOKln_SenoGbmoSkmlY</_7im>^AlOWloOkl1OKdloSfmogm
o_aFnoWfmZmBW_Kdk_Win__knO_jmOGoo_ckkd]jjo2LCVWhmoclnOWfn7MRdoWh
m_[lo?OjoO_lno_ho?glnOcgmO_ko?[jmoKhno_noOcjnocjnOKhmO[gI?OjoOOe
n?chmoOin?gln_clnoSdmoKgm]oQi>;PBf7=i;eEF^g_kNoblO;`Ndg2k[Iog?Ah
D/ghn_WhloWin?[gno_jmoOko?Kbo?[im_cjn?GkmO;gn?_gbTbblOWdji7anOcm
o_`5m_Ccn?KgoOgno0[knOKf[e:Nm_C^nF?in__knO_jmOGoo_ckkd]jjo2LCVWh
moclnOWfn7MRdoWhm_[lo?OjoO_lno_ho?glnOcgmO_ko?[jmoKhno_noOcjnocj
nOKhmO[gmo[mmoGho?SgmoWhoOcjo?ckn?Cgm_Of0VUoh>;ThN=8H/cSVTAAk>Vd
OZAfj^iiD/WDAdidggU@Wg5Rb?;dX96>S=WhgYJPT?3ffi6LQNO_iiW;Oic[n_3e
oO[YBEZlm_6_NOSghIfGZ_;^g;KRVI_bn_glo?gnmNj/XZ=CXOOfhjk5k?O`eO;2
g^_lo?kkkdAbj?;7H5Gcl^QodMk`n?aaJMCjno_jo?[fmOclnOShm_clno[im_;k
oOSjn_Kfmo_ko?cmo?_jnO[in_Chm_OinoScm?Ojn?KjnO_kn?gknoC`mOOfm^3R
i>7SB6;<hiY4DNcY]7jTM^[^NE;9e4M>M=miD9maH/Sbm:2ASXcIn=jFX93`m]^A
W8EoinoWVL]oW>_jl?Gmn^U9F[cflJmin?OQWINZl^kL]^:IVo;joOcloOkekZbR
Xe>QmoKS[/G/mo3El/;Njoclo___A7;Xl/MPEO?bj=7Nl?SlLFWDn__kn_cjm_Gl
o?Whn?Klo?_jnOKbnoghn_[fm_OknocloOckn_WjnO[dn?IomoWkn??dmo[hm_[i
no_hoO_km?3emoKfh>;ThN=8H/cSVTAAk>VdOZAfj^iiD/WDAdidggU@Wg5Rb?;d
X96>S=WhgYJPT?3ffi6LQNO_iiW;Oic[n_3eoO[YBEZlm_6_NOSghIfGZ_;^g;KR
VI_bn_glo?gnmNj/XZ=CXOOfhjiSaNcgl=Gb`]k[o?cnnnm4L^Sbaf1Elo;XdMk`
n?aaJMCjno_jo?[fmOclnOShm_clno[im_;koOSjn_Kfmo_ko?cmo?_jnO[in_Ch
m_OinoScm?Ojn?KjnO_kn?gknoC`mOOfmP9YOn3Ri>3TB49RGTmU_>bkGi7ZCZ[[
NDk9kE5YcnmiBgC?DEK=iFG@f6mTcf>KjhcZbU]kk5b2fj=AQVedhO[cn?cklH5=
IOK:OZck]EN>geVmfY9ER8m=TOKloOckn[=YQ]9SCZ7bQINXJ5?=Se6GE9K/oO_j
nNe8L>?]OE1JlGN=7;=cHLSjL6OEo?_jnocjm_OkmOKfn_cjnO_hn?Ggo_`6loKh
n_[mo?km3?cjn__lmoOco?Kgn_WnmdGknO[inO_lno_ln?[gloOem_KPh^CPi4Q2
HUi?IKc/^enAjTjZjgU>bNeAJLo_ND]dce5FcNEUd=Q_I<mSVn^<j/YKNnaLJ8;K
Xe66KGCQn_?ho?_aPDeUm/Yn[?^eEhkOFKgJTUF8SdfAm_cmo?_j/fV6dV=>XO:5
UjQXDlf?DIMDU^cmno[ikDQ`hnemD5[aMhfcLf78nW1WeOckn__ln_KgnoGfm_[l
n_Wkn?Semokl1_?fn?[joOcno@Wln_[ko?Oglocf0_OjnOkgNO_in_Winocknoch
n_OcmoGfm^3Ri>3TB49RGTmU_>bkGi7ZCZ[[NDk9kE5YcnmiBgC?DEK=iFG@f6mT
cf>KjhcZbU]kk5b2fj=AQVedhO[cn?cklH5=IOK:OZck]EN>geVmfY9ER8m=TOKl
oOckn[=YQ]9SCZ7bQINX=6QCcHmAUeBFk?gkn_W]B73SkGe@F_5gSK=cHLSjL6OE
o?_jnocjm_OkmOKfn_cjnO_hn?Ggo_`6loKhn_[mo?km3?cjn__lmoOco?Kgn_Wn
ma7knO[inO_lno_ln?[gloOem_H2JGoPh^GOhdQNa=1[BX?YhlGEfDZPjW]Bbo9M
LMkeMUS@m7UBbO36k]Y^G]QVG>SPlnR``O=FLn7YHLg`m?Wnmo[moOGMK4c_V9S`
o=JBb_=CXoCAHMW`DGc^o_clnoU`NN_iYU:XhWS<e;9Jbl]Gg>g]m?clno__BUnW
VEn@gLiUm7ok/4elng5VfogloOcmn_Oho?cho?kkn__kn_SkmogmnoKho?_koOgn
oOgln_[lo?[fmo[dnoclnO[io?[gmoShoOcmnokjm?GjnOWgh>;Ugn=8G/C@JdZ3
jN?5eMU:X>YkD/_bGG7NmGIHd?AiD/W`a^kJKUkHIUcXh??X/<7cEWmchNUQcO3d
nOkgn_gmmMe/C>nHV?3leY;:le>Sm=5QfO1AO>kno?cknG1ijoVVDZSRN<cD/U[;
beOLkNgdo?cknnm:GjNIGi3McVGdnk1=O?]aI]_mo?gloO[gn?cln?cnno[kno[h
noOmoO_fn?cknogmo_gmo?[jo?cjm_Ojm7oko?cin_Wln_Ogn?Smo?gko_[dmO[i
nOOPh^GOhdQNa=1[BX?YhlGEfDZPjW]Bbo9MLMkeMUS@m7UBbO36k]Y^G]QVG>SP
lnR``O=FLn7YHLg`m?Wnmo[moOGMK4c_V9S`o=JBb_=CXoCAHMW`DGc^o_clnoU`
NN_iYU:XhWS<e6>bF/_;Emc]kOClo?_kkdYOYiUOT=g>IOCk/4elng5VfogloOcm
n_Oho?cho?kkn__kn_SkmogmnoKho?_koOgnoOgln_[lo?[fmo[dnoclnO[io?[g
moShoOcmnokjm?GjnOWg0VUoh>7ThN97H<kWb5Y3h^:VPJ57YN]eClccEW;RmGMK
d_EgCLOgW9NSG5gaYE5<Ho3adiBWBW;Qif3<lOOhn?Ggn_chl:16X6k3mOchfZB^
CJ7_cV3Jle9nkJ5VI6GVD93]mJQ=XKaCUj2MTMK=EncglGQfMhONkDEKTjVhkNn=
D?=on]ISDOU^I=3gnOKgn__inogjo?[gnocjnoWgn?_mo?[emo_hm_glo?gmo?_j
nOSgn?GjmoOio?ShmO_gn?GjnO_koOckn?KgmOWem>3Qi>7RAf3>ilQJ@n;RYX6Q
AjG[MDo<leIbh_EgFm;eMdg7mibGXeaMlJEAC6?`lM>DYdYoL^7WH<camoShmOOj
o?S`X4JPK/?eo?SJY:i=XNo>H=[cDWk]XFITINI@T>geZ4fQ_5>GX9fAe/eGk?Oa
N7IgQmk]AE^CZKS]khe@lo[FHe7iKVC@moWfmo[knO_mn_cjmo_ln__imoSkoOcj
mOOkn?Kmo?cmoOckn_WhmoSen_MomoWln?SenoOhmO[ino_mo?_hm_OenOGdh>7T
hN97H<kWb5Y3h^:VPJ57YN]eClccEW;RmGMKd_EgCLOgW9NSG5gaYE5<Ho3adiBW
BW;Qif3<lOOhn?Ggn_chl:16X6k3mOchfZB^CJ7_cV3Jle9nkJ5VI6GVD93]mJQ=
XKaCUj1SWI7FcEO/mo5hMWN7g^e5Fi>Y^>g_SE3cn]ISDOU^I=3gnOKgn__inogj
o?[gnocjnoWgn?_mo?[emo_hm_glo?gmo?_jnOSgn?GjmoOio?ShmO_gn?GjnO_k
oOckn?KgmOWem09Y?n;Qi>CRBVWGjNIkAmnaFjg/C:G^O5C?leYchO=_F]KiMTo<
iGSNih1WmO3GV5c5cg>?mEakjNYNboWmoO[inocnnSc^@UUWmO[lcGBPm5>RllmO
i?MDO?;A^kbekTf9koV[DZ>lE>Sgn?Ogd5c/n?>LUi2Nh>m=N^[in_cdVece=_WZ
L5CfKf_Imo_loOghnOgno?ghm_[lo?_jnO[lo_kmn?Sko?[mo?_no?gln_Sin_[h
o?Oen__nn4Gim_WinoWjno_mmoSgn?OhnOGRhNCThTYYenWVNdOO/E^]k4bUkWaD
co=JLn7cKe[FnGI?c>Ehg^N0IoG`eiQLaLmcSoEL2g_YjUk;nOgmn_Wko?kjL>i2
FFOen_c=M:3dDj;cceoTmeAll]6k_;G^CHW_nJ]BXkaDj?OhmoO@G>chlibGT9kP
kdejj_Wjo?BKG?GijW1DmVm[fOOko?gmn?Wmo_cmn?Kjo?ckn_Wjo?knoOShnocj
oOcko_cmo?[hnO[jn?cg0_GjnokhDOWfnOWknO[knoggn?OhmoSimN;Qi>CRBVWG
jNIkAmnaFjg/C:G^O5C?leYchO=_F]KiMTo<iGSNih1WmO3GV5c5cg>?mEakjNYN
boWmoO[inocnnRC^@UUWmO[lcGBPm5>RllmOi?MDO?;A^kbekTf9koV[DZ>lE>Sg
C_Sgmm1Lk?ScW9N@W^3_CG[ZnO[lm9]LmOWZL5CfKf_Imo_loOghnOgno?ghm_[l
o?_jnO[lo_kmn?Sko?[mo?_no?gln_Sin_[ho?Oen__nn17im_WinoWjno_mmoSg
n?OhnOD2JGoPh^GThTQTb]j7C4WWOdZG`DbDf7MAao=HHL_GLeK=mWQAbKI?d[YS
Hlf:h?5MWhe>Rn=AK]WXHm3jo?glnogkoOgknV5<I?_mng5M`^Q:X>k>HNCjF83[
n_SknOQBDk7hW5>Wc52?hoBOaliGk?WkmoSemo[_D7[Xnocmn[=MePgifFUNn71/
g?cio?cmo?kmooa/nO_mo?_mnoSgn__mno[gmo[goOcmoOkkoO_koO_jnogjmoWn
n_[io?_jo?_kn_[ln?OknOWjnOSfh>;Ui>98I<[NQda9igm:Ul5<U=QgDLOcF67;
eg=FcOIhDLVfCm:jHf?=R^3aGIn=CX_SDEU^fNQSd?[loOckoO_moO_jHDaTnogk
LEg2j4ZPk/iQi?YHP>_jn?_in59C/ORLDjO<D8oSm9o7cUO/nO_gn?Ggn^m@N^Sk
o?gj/egFnMUYG_Q`K=clnOcloOcnoOol8?WkoOckoO_hmo[koO_jmoOjmogloOgn
nogknogkn__mnWognOkjn_Wlno[lno_jn_chmo_inO[in?KPh^GThTQTb]j7C4WW
OdZG`DbDf7MAao=HHL_GLeK=mWQAbKI?d[YSHlf:h?5MWhe>Rn=AK]WXHm3jo?gl
nogkoOgknV5<I?_mng5M`^Q:X>k>HNCjF83[n_SknOQBDk7hW5>Wc52?hbGdWlO>
EncinoOhmOOjke1jj?_loOZcGMKifFUNn71/g?cio?cmo?kmoo`hnO_mo?_mnoSg
n__mno[gmo[goOcmoOkkoO_koO_jnogjmoWnn_[io?_jo?_kn_[ln?OknOWjnOSf
0VWohSWUejm?CVmfGHK9kK1DDI5GF8aQCiobRe=UbU]@Z?1OE:KGDV]fPU2/JiKR
Qn:`EeQoGTmgcEbblOcko_d7o?gmn_VmIlKnoCF=DfV;B7FZ_eOGmU=miooloOcl
[5ARcFE=M^]KDgBHN_;7F^Kho?gmnockjdi]g_kmn_[cF9`dl:QedoaWJM[mo?gm
o?gnnogmo_ckoOcjn__knOSjoOglo?_km?[noOcmo?cmoOklo_cmoO_no07koOkl
oo]0o?gln?SjoOcknO_jnn;RiMN_Cdi_MUf6bNf`E56AEeR<HDnOlX]CILYKD:S`
GeBVee9[MX9@[6^FhXOR/5MHOeh7CgO=G;;ao?_no@OloOgjnKeWa_kmJHeCJH]8
MJZoEmOfDggWoocmo?b/E6;=IDefje]CM9Qjl/MJi_SloOgko?_[CVgNo_gjn_=H
W?2XMM?lIfWJoOcmoOcmo__moOklnogln_[knoWhn_gmo?cknoCjo_gloOcloOgn
o?kloOd0nokl0O_mo_condSloOchn?[mo?_ino[kh^;Uejm?CVmfGHK9kK1DDI5G
F8aQCiobRe=UbU]@Z?1OE:KGDV]fPU2/JiKRQn:`EeQoGTmgcEbblOcko_d7o?gm
n_VmIlKnoAf=DfV;B7FZ_eOGmU=miooloOcl[5ARcFE=M^]KDgA<V7[bae[Vn?cm
oO_lnn]>KMknoO[jleRLl:QedoaWJM[mo?gmo?gnnogmo_ckoOcjn__knOSjoOgl
o?_km?[noOcmo?cmoOklo_cmoO_no07koOkloo/<o?gln?SjoOcknO_jn`9GF>7S
i=_8_[o2aL_Tk>cXakCT`;[Mb/K9l^:k_>O7alg[b<78mK>^dmZYiL_1^l;hkl>P
f;nL_;n`]lomo?kmnocjoOcmjkK_oOgkdHmid967^jZ:/Mb9T;_koOdRk[]/OJ6:
]_VkN660`lj>K:KKo?glnocGX69YU??lnoWj[gX=UY;Dmn1PGZOloOgknOcmo@gn
oO[jo_kko?_lmOOinokj0_gknogl0_gloOkk1?cin__mo_`1oO_ko3omo?[ln__j
nockn_cQhnCKb;jo`/G;i>c/j<Ndi<2jgL[6bO;R^kcWalO=jlS1b?Fc[]?JZNG;
`K_2n>o3X=Ro99bl_k2gcoglo_gko?[mo?g[]^omoO_ASgW@THNkZXZag8V@^o_m
oC3^^famXHZfnK]hHH33cXi/Y]_loOcko=NPHVVDlocknOZ_NYJBe?OPH5jWo?gm
noWloOd=o_gjn_knnocko?GgnO_nnP;mno_mo0;mo?gnn`?lnO[k0?gno07mno_l
I?gln_cjno[ko?_jo>7Si=_8_[o2aL_Tk>cXakCT`;[Mb/K9l^:k_>O7alg[b<78
mK>^dmZYiL_1^l;hkl>Pf;nL_;n`]lomo?kmnocjoOcmjkK_oOgkdHmid967^jZ:
/Mb9T;_koOd:k[]/OJ6:]_VkN64UP<?>SVbVfocmo?_lej1RJICco?_inZmjUY;D
mn1PGZOloOgknOcmo@gnoO[jo_kko?_lmOOinokj0_gknogl0_gloOkk1?cin__m
o_`1oO_ko0_mo?[ln__jnockn_`2I_oQH>GSj>OWjNc[knc`lO3al?;am?GfmOKg
mOOhn?_jn_Wgo?gjo?_jo?cmnocko?glnoginocmn_kmoognoOcloOcjn__ko?gk
no;gnO[ko?glno_jo?_koOcmo?gko?Clo?gmnaShno_io?Shn_gmo_gnoO_inO[j
oOcko_gl1oGfnO[mnOOlo_dco?gno_cno_gmo?gko?cmoO[inogln?_moOcmo?gl
nogloOckoOglo?_io?kmoOckoOgko_kl?O_jn__inocln_WQhNGSj>OWjNc[knc`
lO3al?;am?GfmOKgmOOhn?_jn_Wgo?gjo?_jo?cmnocko?glnogi;__loO[noOom
o_glo?gln_[knocmno_bmoWjnocmo?_kn_cknogloOcmnocdo?cmoO/Pn?_knOch
n?[moOkmo_gknOWjn_glnokmo?GfnO[mnOOlo_dXo?gno_cno_gmo?gko?cmoO[i
nogln?_moOcmo?glnogloOckoOglo?/:nOcnoOglnogmnokno6ckn_[knO_lo?[i
hN7UhnSWinW/jno/l?7`lO3blOCem_GfmoGgn?Skn_[imocmn_ckn_cloO_lnocm
o?_mnO_loO[noOomo_glo?gln_[knocmno_bmoWjnocmo?_kn_cknogloOcmnocd
o?cmoO/0n?ok7OWln?SjoOgnoOkmnoWin_[mo?_noOcem_WjoOWgo?km<ocmo_kl
o_kmoOcmnocloOgjnO_mo?SkoOgloOcmo?_mo?glnogmo?cknOcnoOglnogmnokn
o0Wkn_[knO_lo?[i0TdRh^7ShnOVj>[[k>[/ko7`l?CamO;emOKhmoOfn_Sjn__h
no[mo0Gmo?cko?cnn`;mn_cln`;inokno1_jo?gloOgko?cmoOcen?gmo?_koO_n
o?_ko?ckoO`EoOcmoOcloOckn__jnO[kn__kn_cloOgloO_oo07mo?ojo_`5n__k
o?cko?`5nocjnOcjo_/;o?_loOckoO_lo?glo_e6o_glo?glno_jnOcjnocmoO_j
o?_lnoglno_lo?_lnOgln_[lh^7ShnOVj>[[k>[/ko7`l?CamO;emOKhmoOfn_Sj
n__hno[mo0Gmo?cko?cnn`?mn_ckoO/2nO_no_`Kn_cmo?gmnocloOglmOSmoOck
nogko_cknoclnogl5OgloOglo?glno[kn_Wjno[kno[lo?gmo?gkoo`3oOcjn_kl
1O[knoclnocl1O_ln_Wln_kk2ocko?glnogko?cmo?km2okmo?cmo?_kn_WlnS[k
o?gmno[lnockoOcknoclnocioOcjn_cRhN?SinKXj^_/j^c_lO3`m?7el_Gem_Sg
moKjn?[jnoSkn_gl1Oglo?_lo?kk0_gjo?ck0_Wko_kl6o[loOcmoO_lo?gmo?Gh
oOglno_mnoklno_lo?_mo0Wmo?gmo?cmo?_j2o_jnO[kn__kn_cloOgloO_oo0?m
o?[jo_`5n__ko?cko?`5nocjnOcjo_/;o?_loOckoO_lo?glo_dSo_glo?glno_j
nOcjnocmoO_jo?_lnoglno_lo?_lnOgln_[l0T/4hn;TiNKnj1S[j^g]lO;`l_Cg
m_Kem_Ogn?Ohn_Kmo?[ioOcooOol1O_loO_koOkl3_kjo__mo?gloOcooOkmo?km
0ocmoOclo@Kon_gmo?cno_d1nogno07no?km0?cnoOolood1n_gno07ko?gmoocm
o@Gko_gnoOd:o?gmo?gmo_cnnocnoOojo_`Amo[moOkmn_cmo?gko?_lo?[ko_gm
o?om1?kmo?glo_[no@7joOkk4_olno[lo?_ko?gjnocmhn;TiNKnj1S[j^g]lO;`
l_Cgm_Kem_Ogn?Ohn_Kmo?[ioOcooOol1O_loO_koOkl0Okj3?kkoOcmo?gloogn
oOcno@?loOglo?d6oo[moOclo_km0O_mo_`1o_cno@3lo_goo?om0O[mo_`1nocm
oOoloOd@nokmo_gmo?gmo?gmo_cnnocnoOojo_`Amo[moOkmn_cmo?gko?_lo?[k
o_gmo?om1Okmo?gln_ojo_d1n_gnna;oo?_jo?cknocmn__loN?Ri>GVo^PHjn[]
kO7bl?;dmoKfmOKgmoSgn?[foOcjnOgloogoo0Gko?gknogno0knn_kkoOcmo?gl
oognoOcno@?loOglo?d6oo[moOclo_km0O_mo_`1o_cno@3lo_goo03m0_gjoOkl
0O_loOgoo?gm4?_noOkmoOcmoOcmoOklo__lo_gon_kl4OOjoOgnoO[loOcmnock
o?cjnokmoOcoo@CnoOcmo?kjo_d1n_gnn`goo?_jo?cknocmn__lo@924^7RhN;W
i>KWjnKZj>g_ko7dm?Knm@GdmOKgn?Wnnagln_[ko?[no?cmo?_ko?_lo?gko?[k
o?cgnOglnokko0Smnocmno_mo?gno07no?Smo_`2nocmo_coo@[lnoclnO_koOck
oOkl2Okkn_gkoOclo_cnoOol6_gln_Sjo?gno?cmo?glo?_lno_mnOSin_cmn_kl
0Oglo_/;oOSmnocloOcmn__kno`Wn__mo?_jo?gjno[lnocmnoghmoWjhN;Qh^OT
i^O[i^[XkNo_lOCdm_ke1OCem_OhnOkk5?cjn__ln_klo?glno_lnocloO_lnPSk
o?cgnOglnokko0Smnocmno_mo?gno07no?Smo_`2nocmo_coo@[lnoclnO_koOck
oOkl2Okkn_gkoOclo_cnoOol6_gln_Sjo?gno?cmo?glo?_lno_mnOSin_cmn_kl
0Oglo_/;oOSmnocloOcmn__ko_cno2Ojnoglno[loO[kn_cko?gkoOSgnO[Qh^7R
inCVin_Vj^S]knoam?Cfo_D5m?GfmoSio_/Mo?[jnocjo_cloOcknocko?cmnocj
noclmoWmo?_nno`8oO_loO_koOcmo_`1o_choOkl0__loOklood2o?_l1ocino_m
o?_mo_`9o__joO_mo?cno?kmoo`JoOcjn?[loOklo?gloOclnocknogin?Wjo?gj
o_`1oOcnn`_mn?gko?cmo?gjno_ko1Cjnoglno[loO[kn_cko?gkoOSgnOX2B1KQ
hnCTinGVjN_Zj>S]lO7cmOGfmO?imokd6_Whn__ko?WinoSco__lo?glmoWkoO_m
o?cko?gk1?cmo?kmo?cloOol3_gln_[loOWknokmn_gmo_kmoocooPKln__nno_l
o_gmo?om1?Wlo?gkoOd6o?gnoOkmoBCmo_cloO_loOkmo_gloOgloOgjoOglnO[i
o?[loOgloOglnoWlo?d1o?_no0gkoOcjn__joOgnn_klnokm8__jo?[kn?[kno[k
n>7Si>CWiNKYjn[Xj>galO?emOKeloWgo_@InOSjno_lnOWkn??nnocloOcgnO_m
noglo?/0o?gk1?cmo?kmo?cloOol3_gln_[loOWknokmn_gmo_kmoocooPKln__n
no_lo_gmo?om1?Wlo?gkoOd4o?gnoOknoB?no?cmnocmo_gnoOcmoOcmoO[moOci
n_Wln_cmoOcmoOcknOclo@7lnokl1?_mo?[j2?_joOgnn_klnokm8__jo?[kn?[k
no[kn>7Si>CWiNKYjn[Xj>galO?emOKeloWgo_@JnOSjno_lnOWkn??nnocloOcg
nO_mnoglo?_loO/4o?glo_glo?cmoo`>oOcjn_cmnO_ko_gjoOgno_goo?on1ocj
nokknocmoogmo?om1?Wlo?gkoOd4o?gnoOknoB?no?cmnocmo_gnoOcmoOcmoO[m
oOcin_Wln_cmoOcmoOcknOclo@7lnokl3O_mo?[jno[moOkjo_cko_d;no[ln__h
n__kn__h0VTThN3Rc8m[KGaoT<cQkNo_l_Cbm_Cem?Kcm?Cgm_Wjn_JFK<Sdm_km
2O[moOCgmo_mno_no0;in_cno@7jnOkl8_WfaZ6^nn6H/__lnoWho?_gm?Wml[Rl
m_gloOclnocloOGio_d7o?_jn__lo?gnnool3?WRdo?lo?gmnogmo?hJoOcmo?kl
no_noOgkn_cmnocmoOcln__jk^Gdo_goo0Oko?[dj_clnokmAO_lnoclnoSln?Wf
n?[jo?ckoOcmnochn_[kn_ShnO_kmN7Ph/b?JfelOi3<hNg_ko;dl_KdmOCfloCd
moKin_[fUVc8m?Kno@_joOgdmoOkoO_ko?`3o?Wjo?km0O[io_`RnOK6XJkkhIRb
nocknOSlnoOdnOgb^;cfoOcmo?cko?cmmOWno@Olno[jnocloOkkoo`WnN;Clocl
oOgkoOglo_gloOcno?_ko_gmno[loO_loOglo?[kn^kUm?kmoo`7nocjm>[lo?_n
o@Sko?_lo?_ho?PlnOKhn_[lo?_mo?gko?Sjn__jn?Sino_ehN3Rc8m[KGaoT<cQ
kNo_l_Cbm_Cem?Kcm?Cgm_Wjn_JFK<Sdm_km2O[moOCgmo_mno_no0;in_cno@7j
nOkl8_WfaZ6^nn6H/__lnoWho?_gm?Wml[Rlm_gloOclnocloOGio_d1o?_onP?k
o?cmo__oo2Oih]?co?cmoO_moOcnoOcmo?klno_noOgkn_cmnocmoOcln__jk^Gd
o_goo0Oko?[dj_clnokm8?_lnoclnoSln?Wfn?[jo?ckoOcmnochn_[kn_ShnO_k
m@9Don0RhN;BAG?6`6YQUNg`lO7em_OfmoCdl_;inOchno[bJdg;moWno0Gno?cg
mo[noOkloo/Rn_coo?kho_cmo?c^R5J@n[aTN_cko_clo_geloWmb5:<l__lo@Ol
oOgknocmo?kmo?`;oOkmo_[LLGgXoOgooOd1n_goo1WmnocmoOcnoOgjo?gmn_gl
o?glo?[iUW;?o?kmoo`Ko_RiM_Gjnocjnocln__inoWkno[fn?Slnocjo?kk0Ogk
o_X[nOKjnOWgmN3PhN;BAG?6`6YQUNg`lO7em_OfmoCdl_;inOchno[bJdg;moWn
o0Gno?cgmo[noOkloo/Rn_coo?kho_cmo?c^R5J@n[aTN_cko_clo_geloWmb5:<
l__lo@OloOgknocmo?kmo?`;oOkmo_[LLGgXoOgooOdMn_glo?gko?gmo?kmoO[l
oOgjoOcloOcln_VFL/olo_goo1;nn;UfmO[ko?[ko?cjnoWknO_k2?[fn?Slnocj
o?kk0Ogko_X[nOKjnOWgmN3PhN;BAG?6`6YQUNg`lO7em_OfmoCdl_;inOchno[b
Jdg;moWno0Gno?cgmo[noOkloo/Rn_coo?kho_cmo?c^R5J@n[aTN_cko_clo_ge
loWmb5:<l__lo@WloOgknocmo?gm0?glo0_mo_gnn]aaONSmoOomoAgjoOcloO_l
oOglo_gmn_cmoO[mo?cmo?cjnIIbcocnoOol6okh^GKen__ln__lo?[knO_ino_j
m_Sho?_ln_cnn`7mnokj1_Wfn_WimoD2H4WNh>CRgdF:h^SCQDN:iNo]lO7elO;/
NMO^nOCfm?[inH=>`oKgn_ckmoWhloKhnoSknockn_WjmoWlo?Wlo?_kn_[2E87g
jko>oOkk5?cjo?OgnO[fChWan__mnogjnocmnogl4o[lno_ioO[in_[E^?CdGFgR
o?_noOd1no`JoOcknogknOOlo?[gno_lnoWknoghd?OlSVC:o_[nn@OlmZUKm?Sl
o?ki0_cjnOkj1o_jmoCgmoWjo_]2nO_jnO_ln_WimOSgn?Seg^3Th]m5R^;XdhE7
R^G_kO7amO7bk7WGk_Wdm_CjnOV3C/?fmo[lnoOin??fn?_hno_lnaGjnO[gnOcl
nOclno_jn/9DPOO[_lkmo_/Do?[lmoOin_I?RO7jnogkoO[ko?gkoO`Cn_cknoWm
n_Wjn]Fhm?AMKN;lnokmoAcko?glno_mnoWgo?cjmo_ko?_ino_mn=3go8iTb_kj
o_T7o?JYFoCho?cnn@;ln_WnnP7knPGgm?OgnO[nneSino[inocjnOWen?Ohn?GN
h>CRgdF:h^SCQDN:iNo]lO7elO;/NMO^nOCfm?[inH=>`oKgn_ckmoWhloKhnoSk
nockn_WjmoWlo?Wlo?_kn_[2E87gjko>oOkk5?cjo?OgnO[fChWan__mnogjnocm
nogl0O[loo/?nOgjnO[jeKSdm5e]h_cko_gm7?_loOcknogknOOlo?[gno_lnoWk
noghd?OlSVC:o_[nn@OlmZUKm?Slo?ki0_cjnOkj1o_jmoCgmoWjo_/>nO_jnO_l
n_WimOSgn?Se0VUoh>?Sh]i7P]oZinA?F/3MgnkXhn;]bF;8hOK`kM_YkoEoB<GS
gOGkno;dmoKfn_7Vl_Shlo3`l^W^m?kimOWbm__k_eN8lOKgmO[in_C`lo_in_C`
lUF@l_[ho?Sin_[ioOCfn?Cgn?SjnoSgmOOhmhRIk_INKnCknokmo_cmnOcon@Ol
n_ggloSioOkj6__jn?gjoO[XWO?jn?SdnOGlno[ho?ghm?_io?kjE?Wno?Sgn_Wj
moWfmoWnnoglo__ko?_lno_im_Ghmo[fl^3Shn;NAh;Oj^OTCe[0gMo^j>?RkLUR
b>7fl>gKjNoeOdS5hmgeno_bm?Ofm_[ai_;hn??ol5?bjNkdo_WenO;fno^oEhSa
m_Oen_Wjm?3cnoWjm?3bEI3bn_Sln?Wjn_Wmm?Khm?Ohn?[kn?OemoSgR9W^mUi_
i?_ko_gno?gio?Wio?[mmo?hnOgnnQ[kn_Smn_gjj9gcn_Shm?Weo?_jn?cmn?Ck
nOcnnPSio_chmo[in_MonOKgnOkkoOcnno_lnocknoWfmOSgn_Kbh>?Sh]i7P]oZ
inA?F/3MgnkXhn;]bF;8hOK`kM_YkoEoB<GSgOGkno;dmoKfn_7Vl_Shlo3`l^W^
m?kimOWbm__k_eN8lOKgmO[in_C`lo_in_C`lUF@l_[ho?Sin_[ioOCfn?Cgn?PQ
n__hmoGgn?N8VNkfGVoTno_noOkloOWlnOWln_ggloSioOkj6__jn?gjoO[XWO?j
n?SdnOGlno[ho?ghm?_io?kj8?Wno?Sgn_WjmoWfmoWnnoglo__ko?_lno_im_Gh
mo[flP9Yon5mi>7O@HOMj^SVGTB9X5kKchiCghi9O9_^NYJMNU?/OTE_L5YZgoGb
n?GbkfFAVWmVmWm?Fh]QBXoEDU5eLUN1nkmCOo2;CFCghhb?PV36mnN0WI]<RNki
mo_kn:a/DIImE8>?Le:6mMMm[6ZGi/9:IiC_GF5mKUg:n_VJTV]`@[nmOF2hHURR
YfERZ_O/YH2GLNk3Idili[9j^oC_bY2:PnSUaH[amNNITX?Mlk2:^iEbfoCel_Wj
no[jnoWfm?Oim_Gnmooe=oOimNoQhNCQgd67gN[XiUi4RJ1Nfln>Dmn>BGbKkWZF
WGYCk7i5Kg1JJ]oel_Sel^mUTIYoI_IoOdmKRf5:SmEBDGEbEh7k_e=ol8]=I?OS
S8n2H<Kgih2MVdb9k_Wgno_h[6aAUWeDPhmcDXKeegf/JYOV`TYWU>mMHGe^GL[j
nIZBJg2o_GeP^69HXZMUHZ[gk:F0Ug7^`fM>O>JbN[_dklZ@RX?XiLF:lOGWVI:3
gO>`R[^EL]_d3_GbnO[kn_[knOKdmoWfmOkgooE[moWekn7Qi>7O@HOMj^SVGTB9
X5kKchiCghi9O9_^NYJMNU?/OTE_L5YZgoGbn?GbkfFAVWmVmWm?Fh]QBXoEDU5e
LUN1nkmCOo2;CFCghhb?PV36mnN0WI]<RNkimo_kn:a/DIImE8>?Le:6F_GGOJaZ
UnK2BVNDkeeQOFiMb_[iVY9[L;nmOF2hHURRYfERZ_O/YH2GLNk3Idili[9j^oC_
bY2:PnSUaH[amNNITX?Mlk2:^iEbfoCel_Wjno[jnoWfm?Oim_Gnmooe0oOimNl2
JOoSonAkh4R=hN_[jHA5NLiPgNniDNGKH/gZeW;^l/=[kgY6/>YlELSflockmNiF
/?2RE_FfE6__^V1Im6=D^mQ/E?K2F83feUaOm9j9h_1?PNR_J?O`DY7`nOSlo?gW
WTkAg7m>e=imEO>ME>^;GL_YBh_Xnf5=Tn1BQ>gVRn_4HgmXgWe5^/YUE[[<JUog
]Uf`k5kAkJEBfnEaCkGe_7k9hUje^W=:kNbOL^9XT_1/CG>[EH7TmoKgnO[loO[l
n_GhnOCbm__hmoOinOGchn?Ti>18SN7[jnV4AGW>H=g_^E7Uff;=j]Ibk_;3Jnmj
A[3ZO5G8m_?lnoG^E[3`XUKe]WmDJnnjH5WdHeBkf6aDm/9HP?KFG5odWXWRl4n1
j:mXmo1BTO3in?cloNNNC]7LOdkDgWeElieDjh]MbnU;RnSkHDfCh5:4kNJ;jlAS
J=imAK[:IEJjc6YOmkIM/>aNdNfUD]_ULDnemKanbN9N]KYcB^g/Wg;RJ9;`K4ec
ZeF1i7ogm_Oin_cmn_cjmOSim?;fnoSgmoWimO?ShnCTh4R=hN_[jHA5NLiPgNni
DNGKH/gZeW;^l/=[kgY6/>YlELSflockmNiF/?2RE_FfE6__^V1Im6=D^mQ/E?K2
F83feUaOm9j9h_1?PNR_J?O`DY7`nOSlo?gWWTkAg7m>e=imEF?cWEC[Reg;jD^;
j?]QCI?PDXC]iX_[a6=XgWe5^/YUE[[<JUog]Uf`k5kAkJEBfnEaCkGe_7k9hUje
^W=:kNbOL^9XT_1/CG>[EH7TmoKgnO[loO[ln_GhnOCbm__hmoOinOGc0VWoh7gR
hMdoP]oYi^=`@Wk<Fmc`^dkTgEkEkHeQl_KciO1iB/K[Q530l^ckno;d^MbMLD[`
^eQmmNN>Bo9SI=kdYe?V_EJ<n]aNGO9FLZ2YC6?:FFkjmdj6kOKho?gllZ1;lnfM
B_;aVe;`[73XLTfbk4J?kOQPIMSbGF7KQeF7PgAoCNj@A_?/Se3^kh]@mYeJ^N5=
/?FXCNggUDf/l6:al_1NY>j_C>[PMVWZKe[bTDb4kGAJ^oOcmoSknocjnOWcmoSa
loSimoCfmoKclN3Ph^7M?h;OjNKSL49nc5_Ll;]>i=eNeNf=HO;flnG`ND[6jhA@
`?;/no_bm;WLWG5:l;]oF7geihi;lV=Tg_BWDnJmEXcjg5iMlUIbX:U<HlYIK_[g
CXK]m_SloOcbX4_ckIe:l_6KD_2/L>QbCK;/AXo]n61Uf?9MHM^7EHN3M4g^T4Kc
k8m@k^n;D?JMF[WQCK3eZ4g]miE=[?1R/O;`GZC^[dcZh7IYjVmJlY5<Q>edF[]o
mo?gn?_ko?[inO?gn?7cn?Wgm?Kgm_?ah>3RhMdoP]oYi^=`@Wk<Fmc`^dkTgEkE
kHeQl_KciO1iB/K[Q530l^ckno;d^MbMLD[`^eQmmNN>Bo9SI=kdYe?V_EJ<n]aN
GO9FLZ2YC6?:FFkjmdj6kOKho?gllZ1;lnfMB_;aVe9Sl:a`j79=/^a6SnghH6GH
lUeQfhMEQh=dCNj@A_?/Se3^kh]@mYeJ^N5=/?FXCNggUDf/l6:al_1NY>j_C>[P
MVWZKe[bTDb4kGAJ^oOcmoSknocjnOWcmoSaloSimoCfmoKcl@9YOn3OhMkK?HWP
jNOJBE6dbekIkkU>i=]OdnZ:Do;hmm_[Mdk;lhIFa?;cn__bjV^6`iU6l[]@N_?c
[e?aHEkNn<EHikaCS?WJHF?bD8k[l?Cc]e1in_Q:Q^kfnOcjnO6MB_7^WDKemYm6
klQfY8E?]Ne:U>ciGV_NmUmUg6mYi^SY>NG_TTgflYI@l_:CC_CRUX^WDZobZDS]
n9M:ZnYVf_Ccl_Gb^To]l=nH]EmHkY=>Y>mnEkkbk?Sin_[nnd;im_Cdl_Ghn?Od
mOOjm_?Pgn7Nfcf9h>WWfTUA]<]NfNniC^CKGm?ZRU?bn?OKjgM>bo>6E/Cblo[k
l^Y[Q/>IA_:kOe1jlo>_Do5QG]khaESW_5><nMYQHo9@S^_`m?>gD7Wjn4Z6k_Ki
o?[ilIe:lNjMA_GfWdK_b7JTQDnekDZDk?UNJmkfGfGLKfWVj>WUki9=m_:FD?;b
TdkdhYJ;Ye:_lZU8kORGBZ_ZI][dlo;el[Y?kO3OV;EOF>jCCZC_OUNn1O;/n?Wj
n_kkM_Wfm?CbmOShmoCemo[fln3OhMkK?HWPjNOJBE6dbekIkkU>i=]OdnZ:Do;h
mm_[Mdk;lhIFa?;cn__bjV^6`iU6l[]@N_?c[e?aHEkNn<EHikaCS?WJHF?bD8k[
l?Cc]e1in_Q:Q^kfnOcjnO6MB_7^WDKemYm6DNo8MZB5CkG]BYC/nEi[g_IOIMa_
JNKXjNG_TTgflYI@l_:CC_CRUX^WDZobZDS]n9M:ZnYVf_Ccl_Gb^To]l=nH]EmH
kY=>Y>mnEkkbk?Sin_[nn`kim_Cdl_Ghn?OdmOOjm_<2J?kRomej@HcPj=fQDLK/
dF;Fkjm=i^1KdNZ`El[bljCYNU36l8AA`_?boO_/eFGLmIi8lK]BN??cUUcgHf7M
mkEKmKY=QO?NI6KeE67:moC7^E]Vn?M>R_3gm_[knO6NBOC^WTceliU6lGMZmi1@
/nm>UnkgH7;SmF=XgW]An_3]Bm7WUe7fki9Cm?>DBo>AILS_EK7dYdW^mY]B[^aC
^_?clNW`/Dg/gXUgkG1KlI9:X^enFKgdl_Oko?cmno[jn?GaloSjn?Wdm_WhmO;n
h_oM;T6<h>SMXE76k=5Re^n_CNKPFm7Z/5O:l_>TjGY@a_24DL;cl_gkk=EUg?FN
B?6kOe9hlo>FG?MSHMgg]E_e^Tf5lmiTI_EDHL[gm<NiFfKhmdj:l?Ofn__ilIi9
m>jNC?GcVDKaMf[gT52ckdjGk_MPL^?eHfSNNe7jl>gAiiMAm^nBDoCcU4_cTFG8
keFam:M9k_JKDZk/Dk[clo7Yl;5=k=j9Mne`Fo6BBZ;]OUVm5oCbmo_lo?gkn_[h
mO7cn?[hnOCfnOSel_kRomeR@HcPj=fQDLK/dF;Fkjm=i^1KdNZ`El[bljCYNU36
l8AA`_?boO_/eFGLmIi8lK]BN??cUUcgHf7MmkEKmKY=QO?NI6KeE67:moC7^E]V
n?M>R_3gm_[knO6NBOC^WTceliU6Ho5gJ_N@D;?_CYO^mf1bhoESJ=ikDO[`kM7W
Ue7fki9Cm?>DBo>AILS_EK7dYdW^mY]B[^aC^_?clNW`/Dg/gXUgkG1KlI9:X^en
FKgdl_Oko?cmno[jn?GaloSjn?Wdm_WhmO82JOoQONC<T4=IM7IcEF_Yk]e?Efei
CKSRE5b;f4I<DG^7jfM>T^A[DIC`koSgkMI;F7AfAYBiCE32QW^CnF]@OiJ0No6?
D73]_EmHkgQ9BWI^T]UaDXJ?AenWm_Ghn?O/Sdk^jI=>ko2AC>eID;AVAhCYAfbX
dEm`foANImZPBfjUS7n6jX]?knVCCNo_SdcaI5BZ^dJWhjA8e^6CC;3_CE=kd8Zd
k;1?i:YDO^ILFNN@CYg_MeJilO?gmochn?Wgn_7clo7imoWgmoShn_?dhN7Tc913
FGAfLeE[jNkMCeM]NDfhhUALRmQ6C55kQn]WCY;TJe6Dl>ohmngFBeQdMTJD^Gm=
D<:6Ni?iJe1oUX1klHm@L>fmGeS_N4U:MVjBfG5BQXm7GjOfmOShmnb?C^kYTdk_
l95<kEU@]6I7Q>U7K:SAGg3Km5iWfZ1;KZF<Q^Z;CnoYTdg_khm<lFADZ[]6Yn>T
B=KQTdb`kdeCNm2:]>b`CnBZE7kVG5WWT4jMkgMF^GoaloOgo?ShnOOjlO?clOWg
nOOgn?SjloCQhNC<T4=IM7IcEF_Yk]e?EfeiCKSRE5b;f4I<DG^7jfM>T^A[DIC`
koSgkMI;F7AfAYBiCE32QW^CnF]@OiJ0No6?D73]_EmHkgQ9BWI^T]UaDXJ?AenW
m_Ghn?O/Sdk^jI=>ko2AC6?]FE2dITN4jDM/Z=5OL=_dGVOJX4]^YHb6jX]?knVC
CNo_SdcaI5BZ^dJWhjA8e^6CC;3_CE=kd8Zdk;1?i:YDO^ILFNN@CYg_MeJilO?g
mochn?Wgn_7clo7imoWgmoShn_?d0VKohGgTflS5b<K@e^OYk^o_d[o>im__m<Bm
h?CVbkSQl>c9a<WZb<[9m??hm?Sg]9o2ijCI^difVIc[n?YTH9V@g_3/YYZLgjJH
U=K`bgMmXoKhlHecN9:ji?OenOOh_HMh`kj2L[k3Pf^kZUan]6=Vl8AQK]5WJjWN
IVF/lWUJFHi1e/QeFMK3LUKAc7EJehmAE9EDFIG@DgKINef>l[M/DEYclMV=DLo:
I4b7KTZaN4jEkF]EXnkdmo[lmoWhnoOcmO?goO[omCOjmoKfhN7TflS5b<K@e^OY
k^o_d[o>im__m<Bmh?CVbkSQl>c9a<WZb<[9m??hm?Sg]9o2ijCI^gm>MYVLjoSj
I62IT=k`k:JJW=nVV9CFl<]gOJ?fn?6=LgRB^^CgmOWgn;f7N<>nPW:n`h=[^jYL
O[ASI_24HFkAIf^YgVIU[?9iFUV>e/QeFMK3LUKAc7EJehmAE9EDFIG@DgKINef>
l[M/DEYclMV=DLo:I4b7KTZaN4jEkF]EX`g^m?Ojo?Oin?_gloGcmogjooE[n_Of
m^7Qi=_8aLS6d=KWjNk_km:oc^OKkoC4_N3di/^hhO3/bLC9j/S:bOCcn?ChmkBO
`^NTfK]>MYVLjoSjI62IT=k`k:JJW=nVV9CFl<]gOJ?fn?6=LgRB^^CgmOWgn;f7
N<>nPW:n`h=[FK^ZG7jdHfK`Q65^dFM[ZMiVIJcbNEYIS]K8MEWF`g9FdLaeF]N?
DEBEE5VEd5=ffG]MS_:gK55JLo7ISE7?bVA<Qfi:/GQ>UNe[EJ?^m?Ojo?Oin?_g
loGcmogjooD3n_OfmP9Yon4FhnGUhnGWj^W/kNk^ko3bl_?dm?KdloCnmV?dn??g
m_Cin_Oimo_mo?cknoCcmoSanKYAOo3cnochI6GLlo?hn?;`lO7bm??hmO7ZjoGk
moSWinc^n?Wen?_kn_3]k??]jn[]l^_PjNcKi^cLg_WZe^3]g]kSk^7Kh__ZeL[_
?OORemGOe/g@gmoDdmSV_K3Z^[[RkJc1hlJn`>g^f:>ef?G5/ZjniLV>_/F9fZ:H
XN6MT9_]mOSgn??gmo[io_DSm?ShmoKbloOgm_GQhN?UiN?Uin[Yk>g^k^o`l_;c
m?Cfm??do_HGm?ScmoKdnO[gnOOkoOclno_dloOhlOVjOe5ol??ko?QTIMccloSh
l_3alO;dloSelN[[mO_gn>OWk>khnOGhno_jl>g/lng[j^gbjn3Yk=_Vk=cNnN[F
h>gNg^?^hM_Rnn[Eb^ogh]OEgmK=d=oOe=?Hi[f`j[Zjh^f/`N?6_/3]k]RS]MSe
aK:^_^G9S[k5RMZRV:7QWI2K2Ngen?OhloOgn_WnmB?dn?Sgm_;cmoOfmN7QhnGU
hnGWj^W/kNk^ko3bl_?dm?KdloCnmT_dn??gm_Cin_Oimo_mo?cknoCcmoSanKYA
Oo3cnochI6GLlo?hn?;`lO7bm??hmO7ZjoGkmoSWinc^n?Wen?_kn_3]k??]jn[]
l^_PENW/fnK/g=kij]KPkMkNhnkQfn;kj]G:koORemGOe/g@gmoDdmSV_K3Z^[[R
kJc1hlJn`>g^f:>ef?G5/ZjniLV>_/F9fZ:HXN6MT9_]mOSgn??gmo[io_D:m?Sh
moKbloOgm_D2HRkOh>;UiNKXj^c]kng`l>k_lo;emOKfmoSjnO[hn__in?_noOgk
o?_lo?gkoOklo?gkAkE?Po[lo?gjI6_No?_in_chm_OhnOSln?Winockn?cinOSi
noWhn_cinOSln_kjmoGgmo[emoKhm_Slno[koOWkmO;cm_Oim?kmoo/eoOWin_Sj
n?KjoO_ln_WjnOOinochnoSkno[ho?Whn_[em_Ogm_KgmoCem?Cfm?7bmO7cl_Cf
o_T8moSjnOSfn?GeoOPdm_CfnOSggn3RiNGVj>[/kNo]l?3^ko?bmOGfm_Ohn_Wj
n?[knOSko_gmnocko?cmnogno?cmn`2eATn3n_cloOYTJmklnoWjo?SfmoSin?ch
nOWko?_ho?Win?WknOSjo?Win?cjo_[gmOOgn_Ggm_Sfn?ckn__mnO_el_?fmoWd
o_gonc?mnOWjn?[hm_[mnocjnO[imoWko?Skn?_kn_SlnOSjn_GfmoOfm_Ogm?Gd
m?KdlO;elO?b0OCfo_T8moSjnOSfn?GeoOPdm_CfnOSggn3RiNGVj>[/kNo]l?3^
ko?bmOGfm_Ohn_Wjn?[knOSko_gmnocko?cmnogno?cmncBeCh?jo?cmnVA[g_ck
nO[ln?Kgn?Who?SinO_lnoSlnOWhnO_in?[lnOWho?[nn_OemoOjmA;gm_Sfn?ck
n__mnO_el_?fmoWdo_goncGmnOWjn?[hm_[mnocjnO[imoWko?Skn?_kn_SlnOSj
n_GfmoOfm_Ogm?Gdm?KdlO;elO?bm?Knn@Sgn?[in?KhmOGmn0Gfm?Kin?L2HaCN
h^?TinOXj^c[k>o`l>g`l_Gfm_Onn0Kin?OjnO_jo_conoglC__lnoclnoghn__i
RU=Uho_lnnMMGKSino[jnOWfn?Oemo_kmoOmn_[ho?_ln?Klno[hoOchn?Wko?Of
moWjm_Ohn_Shm__jo?[ko?[gmNknm@GgoOcko?h3nOKemOki2O[knoSgn?KknO[n
nDcjno[ln?_io?_ln__hn?Ofmo_gn?Kdm_Gcm??emO;floGgmoKfmOShnOOgm_Oe
loKin?OfmoSgm]kRhnCWinSZk>_/ko3`kO3bmOKfmokh1_Whmo[ino[no?okoO`;
nocko?ckoOSjnoV:@U=Uho_lnnMMGKSino[jnOWfn?Oemo_kmoOmn_[ho?_ln?Kl
no[hoOchn?Wko?OfmoWjm_Ohn_Shm__jo?[ko?[gmNknm@WgoOcko?kim_Geo_T9
n__kn?Ohm__in_ki7o[kn_chnoWlnocjnoShmoKgnoOhm_CfmO?dloGel_Kc;?Gg
moKfmOShnOOgm_OeloKin?OfmoSgm]kRhnCWinSZk>_/ko3`kO3bmOKfmokh1_Wh
mo[ino[no?okoO`onocko?ckoOSjnoV:DfGSnockieeM^?Wkn_[inOKhmoGgno_g
mogjn_Slnochm_ckn_Smo?ShnO_lmoKgnO[fm`khn_Shm__jo?[ko?[gmNknm@Wg
oOcko?kim_Geo_T9n__kn?Ohm__in_ki=o[kn_chnoWlnocjnoShmoKgnoOhm_Cf
mO?dloGel_KcmOOgm_Ken?SimoOfmoGcm_WhmoKgn?Of0VKoh0oViNOWjNKZk>g]
l?7^l?;bo_DMm_SinO[go?_lnokknocko?gloOgloocnoOcnoOclo_T@nocmoOce
mo[io?_mnoOhn__no?kj<_cko?WkoOcjn_gko?[lo?[fn?[lnO[ino_jmoSgm_Sf
n_[mnocmoOGflo[fnOWlnoglo2onnocjnO[kn_gjnO_hnOSin_Win_cko?ckoO[k
o?gln_KgnO[inoOhn?[hnOSgmOGnmb[fm?SemoKenoWin?Kgn?SaloKjm_Wfn?We
h>3ViNOWjNKZk>g]l?7^l?;bo_DNm_SinO[go?_lnokknocko?gloOgloocnoOcn
oOclnOoi4?_loOglmOOjnOckoO_gn?[ko_cnnV;lnocinogln_[mnocjo?cjm_Sj
o?WjnO_kn_OhmoKhm_[joO_loOgem_?jm_Wio?_mo?cnnocjnO[kn_gjnO_hnOSi
n_Win_cko?ckoO[ko?gln_KgnO[inoOhn?[hnOSgmOGnm`3f:OChmOOfmO_inOSf
moShlO?fn_Kim_SimN3Pi^GWinWVj^c]kO3ak_3bl_ke7OKhnOWjmocko?_nno_l
nocmo?gmo?olo_glo_glo?ki4?_loOglmOOjnOckoO_gn?[ko_cnnQ[lnocinogl
n_[mnocjo?cjm_Sjo?WjnO_kn_M7n?Ofn?Kjn_gko?gmmOKcn_KinOckoOclo__l
n_Wjno[mn_Wkn?WhnO[inO[lnoclnogjnocmo?[fmoWjnO_gn?Sjn?WhmoGeo_LH
m_ChmOOfmO_inOSfmoShlO?fn_Kim_Sim@9M3>;Qi>CUinWXj^c^k_3nk_od6oGd
m_Kem_ChnOSjnocln__joOcmno[ioOglo?_lo0Wjno[jo?gkoOcmoO/3o?_jm_gl
oo/dm_Omno[eno_jnO[mnOOgoO[im_GjoOWjno_jm_Oin_WhnO[jno[mo?gknO[i
moOin__knO`KoO_kn__hn_cmn__knOKgnO_lnoWkn_cln_[kn_kk4_Wfn?Sjmo_d
m_Ghn?KgmOGflo?nmR?gn?Sfm_[jmoKcmoSgm_WjmoKgmoWknn;Qi>CUinWXj^c^
k_3nk_od6oGdm_Kem_ChnOSjnocln__joOcmno[ioOglo?_lo03j2?_jn_cmnogl
oOgk0ockn_Kmo?okD?KgoO_jmO_kn_WjoOWgmogjnOKen_gin__kn_KgnO[in?Wj
n__joOcmnoWjnOOgnO[knoWloO_kn__hn_cmn__knOKgnO_lnoWkn_cln_[kn_kk
5?Wfn?Sjmo_dm_Ghn?KgmOGflo?fmRCfmoShm_Kjn_OfloOhmoKin_OfmoOino_R
hNCTiNOYj>[/k^k`o^kom1_em?KfmOKdn?Whn__lo?[kn_gloO_jnOgmo?cko?`9
n__jn_cmnogloOgk0ockn_Kmo?ok7?KgoO_jmO_kn_WjoOWgmogjnOKen_gin__k
n_Kg<oWjnOSin_[kn_gloO_in_WgmoWjno_io?gkno[kn?[loO[knoWfmoWko?_i
no[lo?[jno[nna;im_Shn_Okm?Ken?SfmoGem_?co_HFmoShm_Kjn_OfloOhmoKi
n_OfmoOino/2IP;Ri>GniPWZjncZl>k`l?7co_Gom1G`ho7gnO_io?_ko?cno?kl
oOcmoOcno_dBnocmo?ojlO?mo?_moO[in_cjo_kl>oSknogkoOWhmokjn_Wjno[f
n_gjn_KlmoGfnO_mn_Ojo?[emoKin_WinoKinOglo?_jnOcemOSkn_Wko?ojoo`3
noSgn_klo_U0n__jo?ckoOkloO_lo?[ko?[fn?_ko?[imoSimo[knOOfn?Sfm_Sh
mo[gn_OhnOWknOOgl?Kho?_hn_Sino_Ri>GniPWZjncZl>k`l?7co_Gom1G`ho7g
nO_io?_ko?cno?kloOcmoOcno_d5nocmo?oj3?7coOckoOgjnO[ln_kno4?hno_m
nogin?Onn_[in__jm_[mn_[fo?Oem_WkoO[gn_cjmOOfnO[inO_fnOWmo?ckn_Wl
mOGhno[inocjn_clnoSgn_klo_TUn__jo?ckoOkloO_lo?[ko?[fn?_ko?[imoSi
mo[knOOfn?Sfm_PJn?Ojmo[gn?WinoWgmo3fn?ckn?[hnO_kh^CUo^H9j^_/j_3^
l?3alokeoo@El>?amoWknOcknoclo_cno?gloOglo_km4__loOcon_7coOckoOgj
nO[ln_kno2?hno_mnogin?Onn_[in__jm_[mn_[fo?Oem_WkoO[gn_cjmOLOm_Wj
nOWkm_WioOclno[io?Gen?_jnO_ln_[lo?_hmo[no?ki?O[kn_clnogno?gko?cj
nocjm_SknocjnOOhnOOjnoWgm_Shm_Khn?Ojmo[gn?WinoWgmo3fn?ckn?[hnO_k
0VHIh>;Ui^GWj>[[k>g^l?3_l?;em_CFWeKZm_Onn`[lnOghn__mo?cjnOklood0
nokl3O_mcVMhnoGmnoWgo?cko_dmo?Wen_[lnOgemoWlno_in?[imoWkm]fUjHUD
E;S/o=>QIZ_>UeQ`RWRTg^F:J66gh_cgmg>GQ6UYQHB;[O@Jm_SimoKgn_[gm_Ke
nOShm_Sjnoglo?[mno_loO/3m_Okn_ki?oOjmoC@m?WfmoShn_OfmoSjnOShno[i
m?GalNgemoSin?Oino[hh>;Ui^GWj>[[k>g^l?3_l?;em_CFWeKZm_Onn`[lnOgh
n__mo?cjnOklood0nokl0__mcPYWN?_eoO_imoclnokmF?cimO[jo?WmmOOio?_k
nOSjnOOinoKMYNV9E5Bhk?cCXFJ[cYMHL8YhY=kURVQQ]n;lmoMcUhAYJHF4Rjgd
m_SimoKgn_[gm_KenOShm_Sjnoglo?[mno_loO/3m_Okn_ki3OOjmoC@m?WfmoSh
n_Of<OOhn_Whn?_jnOCelO7]mOOhnOSgnO_jn>3RiNKUinSZjnc]k_3`ko3bmOKd
eYmFj_Kgo_/:o?Wmn?[koOcln_Wno?om0?_no0gkoLiWN?_eoO_imoclnokm9Oci
mO[jo?WmmOOio?_knOSjnOOinoKMYNV9E5Bhk?cCXFJ[cYMH<W2:N:CNiHYXHKOR
o?OgLiN4JFV5Q8^]m?KhnOOfmo[jmoKfmOWhn?Khn__mo?cjoO_ko?gk0oKgno[n
nBGgn_Odd?Cim_Ohn?[gm_Ohn_Whn?_jnOCelO7]mOOhnOSgnO_jn09M3>3RiNCW
in_Zk>_]knknl1OdmOKblKaFk?Oin?[knocjnOSloOglno_mo0;mnogmo0_dcMGm
mO_ko__koO_noOol0O[ko?conc;loOcko?_im_SmgY35n/IECo7goOWSM>kee4ZD
j8MDMO>mE5;an_ggm6No`5U>glZ?FM0In?[hno[ko?_km??gnoWhn?_ln_gmo?cm
oOcnnc_joOgkno[jm__fm_Sh/lGfmo_fnO_lmo[go?_imoSinOGhmoWgnOWknoWg
mogjnn3RiNCWin_Zk>_]knknl1OdmOKblKaFk?Oin?[knocjnOSloOglno_mo0;m
nogmo03d2/gEoOGknokknogko_goo07jnocloo]<o?glnocknOKhoMj@aO[6EDoa
mogihgC^mMA:U>R7E7Gc_EABlO[mmoAW_l1IC]o:SeW@n?[hno[ko?_km??gnoWh
n?_ln_gmo?cmoOcnnaKjoOgkno[jm__fm_Sh/lGfmo_fnO_lmbCjmocknOOhnOWe
n?OimoWino_imoOmn__Ph^GTinO[j^c[kNo^o_0Gm?Gfl_6lE^cgnOSjno_ln_Wh
o?gmo?_koO`2oO_moO`;m<gEoOGknokknogko_goo07jnocloo/Jo?glnocknOKh
oMj@aO[6EDoamogihgC^mMA:<ICXQeAelkeDD_7joOOdIko0FDkObXmId?Sjn?_j
nocknoCcmo_in?Sko?[moOcloOglo_/^n_gmno_jn_Kkm_Khn;?5m_Okm_Wko?Oj
mocknOOhnOWen?OimoWino_imoOmn_/2JGoOh>?TiLg0an[[jM;Xb/[Tlo;bf/b`
D^_fmoSin__gm=[SlOWjmn_eio3in_gcjnWimOWkn?Gln?[dnNodnogkn??do?_l
oOKamoOlo?Wim?Ohno[fn_IcY?3lceM>n?[mn_69moSTC9gdhX1<g<IIDOWio?[B
JNKDHd[`m^A>HcCHnO_ino[knOMog_ShOl?inO_jnOSinogjn__ln_[inO[jn?Wk
nOOinoW/TM;enOKln_cimokiAoKdmo[jnOSfnOWgn_[gn?_jnoWkgn3Si>G=`<OZ
jnWBj<[:i??bl][</5;[m_OhnO[kmoCJho7in_O[mNO`nO[mln_YnOGingohmOch
n_CikoCkoO_hloClnocmm_7gmoclnOWdmoSkn_KjmW>Tl?c?Edkhn_gjlHWgn>A<
WOCRP4cLaUUAnOWln]9Yi]ASB_3fi4iSf?WknO_jnoWgOmkhn7o3nOWkn_WhnO_m
n_[ko?[jnOWjn_SinoWgnO_ik97BmOWfo?[ln@3go_Ukm_Cgn_[in?KinOOjn_Oh
no[knO_Oh>?TiLg0an[[jM;Xb/[Tlo;bf/b`D^_fmoSin__gm=[SlOWjmn_eio3i
n_gcjnWimOWkn?Gln?[dnNodnogkn??do?_loOKamoOlo?Wim?Ohno[fn_IcY?3l
ceM>n?[mn_69moSTC4bMm>:0C=c6FE7inOcjdVWVe6=:l?KTCV?HnO_ino[knOMo
g_ShOl?inO_jnOSinogjn__ln_[inO[jn?WknOOinoW/TM;enOKln_cimoki4oKd
mo[jnOSfnOWgn_[gn?_jnoWk0VWohGgUhmN3XH3EhJ]c^fEESo;aeY2@MTgYm_Si
n?SjiZmjKIOfdIal]FJ3n__jXI>:/<oYg;:@o<jTV[R5]nkjlZ>:U_3jnm>VT<Wb
nMJea9W0n?[hn?[UKnojoM1FD_WnoOc_QOOkhDjQm_JRD][8FUGjo?kf/6Ohf65;
moWfDV8^eoSji=SPn?OCIM;/i52ejO_ckO;Xi_?dj_Kfo?Wii^[fn?Sfl_S/m?Wk
n92;jOOnnDglnO_gm_SlnoWln_Kin?Ggn?_kmoSko?_jo>7QiN?GPj60eN6[Lk]U
EHoblMJ@T7I=jOKhnOShn^J_NVfGm]6LO;EVPo[knZ6CR[3?jMaj/Y3lcZBJ^8Fg
k_[bXhZFl?[kdjJ@bO;ie[G4VL3hn_Shn^E_ko[md5IBnOkmo>n5mo_QCZ7fmZ9B
f/QJEO[lo_J`IoSHHD_gnOIBH]Ohn^CHh?SgdfGBk>A@]NWklngbj>Kcm>[fm_ci
nNKZm_Shm_;hk?CinoR@RnWgo_T1o?UonoOfn?cknOcjm_WhmOOhno_gn?_lno[l
hN7UhmN3XH3EhJ]c^fEESo;aeY2@MTgYm_Sin?SjiZmjKIOfdIal]FJ3n__jXI>:
/<oYg;:@o<jTV[R5]nkjlZ>:U_3jnm>VT<WbnMJea9W0n?[hn?[UKnojoM1FD_Wn
oOc_QOOkhDi6XOKfXU;Jb5YEn_cnm[1Wn=QQBoOimU9ReoSji=SPn?OCIM;/i52e
jO_ckO;Xi_?dj_Kfo?Wii^[fn?Sfl_S/m?Wkn92;jOOnnAWlnO_gm_SlnoWln_Ki
n?Ggn?_kmoSko?_jo09Yon4Fhn6>FnAKOMj`CXFkJ4S/WVJ@g8A=j_Gnn6?imW>V
hJMFaL5[CZ>CEMWfYU[UPTaOb8]GG?ZGEUVLJDf=`gRHd65VeKijc8EKILmMBViC
NOOjm?GbUeSgo?g;EE?ho?gllHKjn^19X_6gH4_Ua5=?nO_me6]dnm5PALo4TD]h
=n;ZSi65F8CTS59iSI]8KGoLDUnAMU5oX7AI]oR3Pi^9J_FhHeFLP5ZSn_VgIY;g
no[jo?[kn__ho_/9n_OinO_jmo_jnoki7?SjnOWQhN?QSU_TFggN/4j5^fQ8k9iV
T=b4CN[eo_PGnOIcY^6WE/G1JdjSTeGImZIJiH9<GlR;OeMLnYMFFIaYCHg3N9S@
HFKE_W[<QE]Ucee:KU=imo[dmO:GF?OloL]EDoSloOcaQ_[jh4VRlKMPBnG4Ddoi
nogDJgCkdF15clBABgSRjXnAQER4i8aBNHfKB6eog59OTGIAOj1dFKOhPh>KRF[e
^6=EW81JXo[i]fJBmo_jn_cj0o_jnoSnn`WjmoWino[gno[ko_TLn?[inN7Qhn6>
FnAKOMj`CXFkJ4S/WVJ@g8A=j_Gnn4_imW>VhJMFaL5[CZ>CEMWfYU[UPTaOb8]G
G?ZGEUVLJDf=`gRHd65VeKijc8EKILmMBViCNOOjm?GbUeSgo?g;EE?ho?gllHKj
n^19Cj;a]f1;iLACCoWkoMA[M?_AH4G?a95;N>;ZSi65F8CTS59iSI]8KGoLDUnA
MU5oX7AI]oR3Pi^9J_FhHeFLP5ZSn_VgIY;gno[jo?[kn__ho_/9n_OinO_jmo_j
noki0oSjnOT2JGoQgnGV`jkMF7SNdV?IkJQ8kFidgo>cE>cfm_SjnnaMSiNHHj[^
Q5SeffSFkhQ@m]YYLO_SLeKhdF9Zn<5CPX]Z/;mYEjj1JKnaGE?fIF7?n?Sko?cj
jWiNnOgmcEeHnOcmoOF=moWTAgF/JVfcnlIBC_cmoJmVc?cHIdUnI4mWk7oj^G_J
l6YL`MQ/h_W`D/GdmF5[eOEHK?C3Ei3hHXcacVW`jX=@kM9TNoWheg5gnO_jnOcj
o?cmnoklo?[kn_gknOcln_SinO_io?[hhMoUi/>^gEQhg]9SfNfXB>e^M=oc/eC/
m_Khn__/GHnGV6>ZkXAHmM]Xe^n8D?KJJG7khgmcE_SAHV[h`E>2RfZ`_fUG[X5Y
_k5MDoIUHLohn?_lo?[ZOUkioOg=GESio?gmmHggnNA7MJaZKK?kaU9>o?gm[fK<
o=QWBGiTCfO/n[Ukf_1ZG<7HK>;il5;5m?EQJmGeF6cd`eN@n6:<lLiYl>Z3D>gB
I7_in=MaMoWkn_Wln_olOOgko_cln__joO_io?cjn?WinoWln_SQgnGV`jkMF7SN
dV?IkJQ8kFidgo>cE>cfm_SjnnaMSiNHHj[^Q5SeffSFkhQ@m]YYLO_SLeKhdF9Z
n<5CPX]Z/;mYEjj1JKnaGE?fIF7?n?Sko?cjjWiNnOgmcEeHnOcmoOF=moWTAf=e
[6Y]/o_6DTkloOf_I/clf6M9OVA?Incj^G_Jl6YL`MQ/h_W`D/GdmF5[eOEHK?C3
Ei3hHXcacVW`jX=@kM9TNoWheg5gnO_jnOcjo?cmnoklo?[kn_gknOcln_SinO_i
o?[h0U]?gn7Th]2>V55gh/iNeN^ZBNYENNOc^5;[m?Ghn_OGHl_Eem;RjX9Gmn9T
eNn8B=k3IW_hgfeJlm1NL?W0DGmTM:je[ZgBHVRXZJNRmf5Tf?_lo2[VLF;loOc<
FEGgoO_ll8Kgmmi1MY^ZhOCm`eEAn?[iJgSWo=QVBnOKYeEC;k=XGgn:HF2_eVWQ
n>m@bOWfFgGWmeeemm9MN_RVa;6GE^g/RF?dgW9amoKQMUginO_kBOckn_[lnock
oOWgnO[hn_cin_[ko?_OhNCRd8jHDGORcUkEjjY9jUEiio>hD^_dmOSjmmMSbmGG
d^;ZPUOghVCEkhQ8g/=VNoSO6feJlm1NL?W0DGmTM:je[ZgBHVRXZJNRmf5Tf?_l
o5[VLF;loOc<FEGgoO_ll8Kgmmi1MY^ZhOCm`eEAn?[iJgSWo=QVBnOKYeEC/fQO
OhYQH:oFJN7hke39nOIKMNOgGGGgdUejn:K4/IMFkNb9HoCNLW7gm^5fGOWioO_o
nfGlno[jo?_lnogimoWjn?[lnO[jnockgn7Th]2>V55gh/iNeN^ZBNYENNOc^5;[
m?Ghn_OGHl_Eem;RjX9Gmn9TeNn8B=k3IW_hgfeJlm1NL?W0DGmTM:je[ZgBHVRX
ZJNRmf5Tf?_lo1;VLF;loOc<FEGgoO_ll8Kgmmi1AgJKZ^7doL=EDOSjnF]hiocH
IT_WfjMEDk=XGgn:HF2_eVWQn>m@bOWfFgGWmeeemm9MN_RVa;6GE^g/RF?dgW9a
moKQMUginO_k5Ockn_[lnockoOWgnO[hn_cin_[ko?/2J53Oh^G;GfGTGWCNbV3I
k:Q8jeUK^?6`C>[ckoOjnn1CWnoheK3^PegkhVKHln]QRH^Zj_kQL5[fc5m`n[aC
P6AI_OOfhKUPFOOilkG`IFgLo?cnoB_kjWaWnocldUe@mOcmn>27n?WPCJ_en__l
oL=BC_WjkV_8n?c@H57in_YaCC1lHVWCnoSei]IXhOW]DLSgmef1jOQJN_OCGWgf
N9NP`eO[jX9Pmmm]L_Sjg7ATmoWlo_/Bn_cmo?cjn__in_[knOSkn?cknokl=O_i
gn;UbemUi5idg/YPfNbXB>]IFkSa/4cZlnogn__PDio_n=F`kX=Mnn9Vf??[HHV;
Z^[nhAa`F_K<Gg3j_5>0I5VmmoKQ^F1ImoWc]O1UKMclo?kmG?_ZO6Oko?cBGE3e
o?ghh8OhnN1=ZoGjnocm`e9>nO[^JlSho=1PDOWjnW5=O69Ydo_hmNKFJ>7ikE78
moMMPNWhFW[gdeimmWRGX<=GjnZ2H?OOKG;hn]adI?Oio?kk4_[loOcln_[knO[j
noWhnoSlno_no5;knMoRiL]OINANM=k:H=W/Z4S[FE^hlK1<j_?_mo[kh5>OkoSE
/>j3GO_RI]Scjf69Rj[Zo^5`F_K<Gg3j_5>0I5VmmoKQ^F1ImoWc]O1UKMclo?km
4o_ZO6Oko?cBGE3eo?ghh8OhnN1=B:_en__loL=BC_WjkV_8n?c@H57in_YaCGaR
JM?kn?GVeVSQnNeAb?OgGH7Yn5Yjmm=NOOIhUj33En_ZPV3ggfebn?[LM6CgnOcn
na;jo?glo?[jnoWjn__in?_ho?_ko_`1noT2IQSRg^C9FUK@DFc@c63HjZ5;jiM?
Kmj9CMCco_YSo?IBF:CJSMC[OEghhVKGlk1[fn;]mO_NKf3ibeibn[QFQie@KN[C
T/B?Bl_/d9GbIFOIoOkmoOkmmZUOnOgmkYE=j?Wml[:InoSJC:_dno[ko<9BCOSd
fF_cn__DHTkin_IPCCJLQ4jEm_K6ZmEUiOW_E/CdmF20k_]PO_S>HX7`Fk_caE[_
iWaSmmi/K?Ojg79in_[ln_cimo_koO`YoOclno_lnOcinOSko?[knogRg^C9FUK@
DFc@c63HjZ5;jiM?Kmj9CMCco_XGo?IBF:CJSMC[OEghhVKGlk1[fn;]mO_NOfmP
nL]NL_ZhEXNMD6gZdi;4Sd_;k=2ElVEWfOgnoOgnoOJYGoWmoNjECNSioO:bVO_h
fTb[m?_jnoc2DTghm=U[lo[ke69>nO[fH4fLQ4jEm_K6ZmEUiOW_E/CdmF20k_]P
O_S>HX7`Fk_caE[_iWaSmmi/K?Ojg79in_[ln_ci0_Oknogl:Oglo?_ko?WlnOWh
nocjno_mh]kTbEYFd55/d<aPf>ZQBn^GCfoNRDgDlokjBocfDURTfXgDjgeMn>9V
eo>`Jm_RkOGkgVmPnL]NL_ZhEXNMD6gZdi;4Sd_;k=2ElVEWfOgnoOgnoOJYGoWm
oNjECNSioO:bVO_hfTa>ZoCkn__l`U9=n?CIJo?jnmARC_WjmV1=W8A>UOKfaZ_E
INGikeK4m?EPP>kkH7khcV:1l5^kllEJknIlHoONK6cgn]abNO[jo?[lnOOknogl
4?glo?_ko?WlnOWhnocjno_m0VWoh7gSfGm:Jf9?NJaI_mB1DM?LPEIlN5RRkOOi
moWiV5UDHG7f`65AeKEN/]nMCeiTJ6C/YV5HdYYKJ=nFD7OLME9RK:S`cdeUHG>T
eF1NTO[noO_loO[?J>klo?K?G5i`QgZ0dOZmOe1/[__lo>MnEUBmiI=OnOcaT5I<
V8a^CFaockACFF5PRMCKEWRFke5/U>MBK]S`H7Sd_E]ikeIRSI5HU==fG>o;Ig;a
n;EWU?[jn?Wjn?cjnOSjn__moOcjmoWgnOSim_[im__io>3PhmUoBV]RCgV/FKoD
PE7Cg85FO7QHX^ggnOOinIQIE65am/1QDMFeG[;OWDmNI6QTk:IoHESBVU]XgiI@
MmaeDV9/Z?3?CFEQLjCEH5jAn_kmnocmn/mXk_clm/mLGW27NX3An[eoD6b^nocl
igiFE;gUTeoio?6@ETbHS6i=K<ndDeUQH8WDfeIhU^mAK9CWDVkHl61hm;eKNNmF
HXfAF9CCMUc_bfMblOReIiCjn_Sin_Qoo?[in?[jnogmo?[gnOOin?Wfn_WfnoWl
h>3SfGm:Jf9?NJaI_mB1DM?LPEIlN5RRkOOimoWiV5UDHG7f`65AeKEN/]nMCeiT
J6C/YV5HdYYKJ=nFD7OLME9RK:S`cdeUHG>TeF1NTO[noO_loO[?J>klo?K?G5i`
QgZ0dOZmOe1SK:kko?cWOUID_NFCGoWllI1FC9R<KTe/ckACFF5PRMCKEWRFke5/
U>MBK]S`H7Sd_E]ikeIRSI5HU==fG>o;Ig;an;EWU?[jn?Wjn?cjnOSjn__moOcj
moWgnOSim_[im__io09Yon8hiNCVi>KVj>_Zj^k^l>obm??^l?Cdn?Sjno_loO[h
m_Oio?[gm?OhmOSKS;K_j^RDgOSem?Sel_;jo_;oo17^kO;ko?_fj^Ggn_C^j^[m
oOknoOol:7g8nO[hn_7Jbm;Rn?_li]_JgMgko?ccgMOIg>O3c__klLk<b<[=e=gg
OoWjlK6__OOjoJN[eo^^UkoCYjg2f:n^iK>[Y>F/QJGYP[JdWYKD[I>EiOF9RnSl
n__in_Oknogknogmo?_io?SimoWhmoSgno_jno[Rh^GTi^CVi^S[j^[^k_3_l_Cc
k_3dm?Shn__ko?gjn?KgnOcjmoCgn?Ghfhbfkn[XU=gh1_Gdn?Gbl_[nl_ol4Nk]
l__lnoKZiOOjm>kZj_gmo_kmooaLOLSin_SjlM[;d^;hnocVfm[MgO_lo??MemWL
il?>no_ac/c8b/gDgOOin_6a[kggn_fWZmOk[YNodjN]`]R_[^FcZjCU[8FUjH:f
]9jFe:fCUNGeRH_Xo?[knO[goo]@oO_koOglnoWln?WgnOSgn?Okno[kn^;RiNCV
i>KVj>_Zj^k^l>obm??^l?Cdn?Sjno_loO[hm_Oio?[gm?OhmOSKS;K_j^RDgOSe
m?Sel_;jo_;oo17^kO;ko?_fj^Ggn_C^j^[moOknoOol47g8nO[hn_7Jbm;Rn?_l
i]_JomeQnocllmgGfMcW`lkkno7>c<S:cMCMmoWjlK6__OOjoJN[eo^^UkoCYjg2
f:n^iK>[Y>F/QJGYP[JdWYKD[I>EiOF9RnSln__in_Oknogknogmo?_io?SimoWh
moSgno_jnoX2FP3Po^7oiooY4>_]k>k`lO;`lo;fm?CgmoKio_X9nogkn_Sjn__j
oOki2OckTU:Nj^WAWnWnn`Omo?_jo?_kn_km3__in_[lo?[gnoWmo?cjo?_m6?_5
W:ogn_[hn?_jm_Wino_gm_Oknogko?gnn@[jnocknocknOKinOkk8?_hnOKgm_[k
o_Wino[eloGhlO;dn_Gho?Ogm_SiloCil?ke7O?em?;cmN:7d_Cino[imoSho?_i
n__ln__kn_Ken_gi1_Oko?Semn3nhOoWonT@jng/k_3al_3cl_Kdm?Ogm_WnnPWk
oO_jn?[jno[mo_T:o?^BDYkZjM6OjO_on`Omo?_jo?_kn_km3__in_[lo?[gnoWm
o?cjo?_m6?_5W:ogn_[hn?_jm_Wino_gm_Oknogko?gnn@[jnocknocknOKinOgk
7oSim_Ofn__nnOWkn_GcmOSal_CjmOSlmoOfn?Wcm?W`o_D?loGdl_?ehXOBm?Wk
n_Wgn0gho?_in__ln__kn_Ken_gi1_Oko?Semn3nhOoWonT@jng/k_3al_3cl_Kd
m?Ogm_WnnPWkoO_jn?[jno[mo_T9o?^BDYkZjM6OjOkk1oglno[lno_jo_d>noWj
n_cln_OknOglo?[lnodAnlFL[oOjn_Shno[fnOWknoOf1_Oknogko?gnn@[jnock
nocknOKinOgk7oSim_Ofn__nnOWkn_GcmOSal_CjmOSlmoOfn?Wcm?W`o_DMloGd
l_?ehXOBm?Wkn_Wgn?SlnoWjnocjno_jm_GjoOT5mo_ln?Gg0U<6hN;ThnKXj_k/
onh9lO;`l_?em_SemOkh8o[inoWjoO_lo?[lo?gmn_cko=1mFWAjVLgloOclo_cm
o_gko_gmoo`;n_gno?cmnogno__ioOgooQ;mo?ceb?CloOcnoOkjo?cmoOcho_cm
o@7ln_gl2_Wko_gooOckoO_looX6o?[ln__ko_km2?kloOgln_[ko?gmo_`Mo_gi
nO_mno[jo?Wln_FTaOOkn_[lno[hnO[loOgno_`En__ho?ginO_fmo_ln?WihN;T
hnKXj_k/onh9lO;`l_?em_SemOkh6_[inoWjoO_lo?[lo?gmn_cko=1mFWAjVLgl
oOol1_kloOkmnokmoOol2o[mo_cloO_mo_kknOgmoohBoOclmLSdo?glo_gnn_cl
oOgln?kloOd1o?[mo1?inokmooglnogko?[jo?[ln__ko_km2?kloOgln_[ko?gm
o_`Go_ginO_mno[jo?Wln_FTaOOkn_[lno[h1OWjo?gmo_kl5O[kn?cmnOWkm_Ok
o?SinN7Ri>?Vj>[nk?o^2O7bl?;cmOKhmOGnn2?jnO_in_gko?cjo?cmoO[lnoc@
OEYdNYW=o?glo?kloOkmnokmoOol2o[mo_cloO_mo_kknOgmoohBoOclmLSdo?gl
o_gnn_cloOgln?kloOd1o?[mo1?inokmooglnogko?[jo?[ln__ko_km2?kloOgl
n_[ko?gmo_`Mo_ginO_mno[jo?Wln_FTaOOkn_[lno[hnO[loOgno_`>n__ho?gi
nO_fmo_ln?Wi0T/Dgn;UiNOWj>_^k>_/k^obloCemOCfo_L2mO[io_X1no[mna;l
oO_ko_ckmnRXY[G^n?cloOcno?gmo0Cmo?_lo?km1ocgn_[mmoOko_cooAglnO[m
m_Wjo?[lo?_jn?cmo?WenO_mo__ko?ckoOcnn`7jo?gm0o[moO`7n_Oko?gin?ck
o@[lnoWkn__lno_`o?gk@ocjn__mnoWgo?OenOS<l_WhnO_knO[inoWio?gjo?[k
n__gno_lnOKhnogkn?Skgn;UiNOWj>_^k>_/k^obloCemOCfo_L2mO[io_X1no[m
n`oloO_ko_ckmnRXY[G^n?cl0_glo_cmoO`4oOcko?cno@Olmo[joOOgnokloodM
o?WjoOKin_cjo?ckn_SloOcimOWkoOkknoclnoglo_/1n_cmo@_joOgln_Oko?gi
n?cko@[lnoWkn__lno_`o?gk5_cjn__mnoWgo?OenOS<l_WhnO_knO[i;?_inOcm
n_cjno[kmo_ko?Wfn?_mnoShnmoRiNGWinS[k^c[k>k_l_?dmOGdm_kg0_GjnOkj
0O_joO/Bo?gknoklnoOXZ:Jek_Slo?glo_cmoO`4oOcko?cno@Olmo[joOOgnokl
oodBo?WjoOKin_cjo?ckn_SloOcim@[inognno_lo?_mo?kk0O[loOd;n_gmo?[g
nocmnOSlnod:o?_ino[ko?_kl?cmnbkln_[koO_imocgmOWhc?;in?WknoWjnO_i
nOcmn_cjno[kmo_ko?Wfn?_mnoShn`3o\>"], "Graphics",
  TextAlignment->Center,
  ImageSize->{204, 330},
  ImageMargins->{{183, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Balthazar van der Pol (1889-1959)
-------------------------------------------------------------\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
Picture from Modern Differential Equations, Martha L. Abell \
andJames P. Braselton, Saunders, 1996.
\
\>", "Text",
  TextAlignment->Center]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  The van der Pol Equation", "SectionFirst"],

Cell["\<\
\tThe van der Pol equation, in what is now considered to be \
standard form, is given by\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        OverscriptBox[
          StyleBox["x",
            FontSlant->"Italic"], "\[DoubleDot]"], " ", "+", " ", 
        RowBox[{"\[Mu]", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontSlant->"Italic"], "2"], "-", " ", "1"}], ")"}], 
          OverscriptBox[
            StyleBox["x",
              FontSlant->"Italic"], "."]}], " ", "+", 
        StyleBox["x",
          FontSlant->"Italic"]}], 
      StyleBox[" ",
        FontSlant->"Plain"], 
      StyleBox["=",
        FontSlant->"Plain"], 
      StyleBox[" ",
        FontSlant->"Plain"], 
      StyleBox[\(\(0\)\(\ \ \)\(.\)\),
        FontSlant->"Plain"]}]], "NumberedEquation",
  TextAlignment->Center,
  FontFamily->"Times"],

Cell[TextData[{
  "We see that it is a an oscillator with a linear spring force and a \
nonlinear damping force.  In all that follows, we take \[Mu] \[GreaterEqual] \
0.  The time in the equation has been scaled so that the frequency associated \
with the spring force alone is unity.  The damping force varies in an \
interesting way.  For \[VerticalSeparator]",
  StyleBox["x",
    FontSlant->"Italic"],
  "\[VerticalSeparator] < 1, the damping is actually negative and hence \
produces an amplification of the motion.  For \[VerticalSeparator]",
  StyleBox["x",
    FontSlant->"Italic"],
  "\[VerticalSeparator] > 1, there is true damping and the motion decays.  \
These observations suggest the possibility of an oscillation, in which the \
system starts at small ",
  StyleBox["x, ",
    FontSlant->"Italic"],
  "is  driven to large ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "by the amplification, and is then damped back to small ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  We will explore this possibility by using DynPac to construct orbits.  \
We define the equation for DynPac, after converting it to the following \
system:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  ",
  StyleBox["y",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  "  = -",
  StyleBox["x",
    FontSlant->"Italic"],
  " - \[Mu](",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  "-1)",
  StyleBox["y",
    FontSlant->"Italic"],
  "  ."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[BoxData[
    \(sysid\)], "Input",
  CellLabel->"In[259]:="],

Cell[BoxData[
    \(plotreset; intreset;\)], "Input"],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{\[Mu]}]; 
    slopevec = {y, \(-x\) - \[Mu]\ \((x\^2 - 1)\) y};\)], "Input",
  CellLabel->"In[260]:="],

Cell[BoxData[
    \(\(sysname = "\<van der Pol\>";\)\)], "Input",
  CellLabel->"In[261]:="],

Cell["\<\
For our initial explorations, we take the parameter \[Mu] = \
1.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {1};\)\)], "Input",
  CellLabel->"In[262]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  Equilibrium and Stability", "SectionFirst"],

Cell["\<\
\tThere is an equilibrium at the origin, and it is ovious from the \
slope vector that there are no other equilibria.  We give this equilibrium a \
name, and then look at the eigenvalues of the derivative matrix at the \
equilibrium, which we call eqmat.\
\>", "Text"],

Cell[BoxData[
    \(\(eq = {0, 0};\)\)], "Input",
  CellLabel->"In[263]:="],

Cell[BoxData[
    \(eqmat = dermat /. Thread[statevec \[Rule] eq]\)], "Input",
  CellLabel->"In[264]:="],

Cell[BoxData[
    \(Eigenvalues[eqmat]\)], "Input",
  CellLabel->"In[265]:="],

Cell["\<\
We see that if 0 <  \[Mu] < 2, the equilibrium is an unstable \
spiral. For \[Mu] > 2, the equilibrium is an unstable node.  Because there \
are no other equilibria, the only possible attractors for this system are the \
point at infinity, or a periodic solutions or solutions.  We will let the \
computer tell us which.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.  The Limit Cycle", "SectionFirst"],

Cell["\<\
\tWe begin our numerical work with a phase portrait based on four \
selected initial conditions.\
\>", "Text"],

Cell[BoxData[
    \(\(initset = {{0.5, 0}, {\(-0.5\), 0}, {3.0, 0}, {\(-3.0\), 
            0}};\)\)], "Input",
  CellLabel->"In[266]:="],

Cell["We set the integration parameters.", "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 500;\)], "Input",
  CellLabel->"In[267]:="],

Cell["We set the plotting parameters.", "Text"],

Cell[BoxData[
    \(asprat = 1.0; plrange = {{\(-4\), 4}, {\(-4\), 4}}; 
    labshift = 15;\)], "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/15};\)], "Input",
  CellLabel->"In[269]:="],

Cell[BoxData[
    \(\(graph1 = portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input",
  CellLabel->"In[270]:="],

Cell["\<\
This looks very much like a globally attracting limit cycle.  Let's \
try to construct the pure limit cycle.\
\>", "Text"],

Cell[BoxData[
    \(\(sol2 = limcyc[{2, 0}, t0, h, nsteps];\)\)], "Input",
  CellLabel->"In[271]:="],

Cell[BoxData[
    \(\(graph2 = phaser[sol2];\)\)], "Input",
  CellLabel->"In[272]:="],

Cell[BoxData[
    \(period[sol2]\)], "Input",
  CellLabel->"In[273]:="],

Cell[TextData[{
  "\tThe remarkable fact about this oscillator is that every initial \
condition in the phase plane ultimately leads to this periodic motion with a \
period of 6.66.  (Our calculations only suggest the truth of that statement.  \
It requires a rigorous mathematical analysis which we do not consider here.  \
There are a number of references which deal with this, including ",
  StyleBox["Nonlinear Vibrations",
    FontWeight->"Bold"],
  ", J.J. Stoker, Interscience 1950.)"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.  Dependence of the Limit Cycle on the Parameter", "SectionFirst"],

Cell["\<\
\tHow does the shape of this limit cycle change as the parameter \
\[Mu] changes?  We construct a sequence of limit cycles with the parameter \
\[Mu] varying from 0 to 3.  We begin by looking at the two end-points of that \
\[Mu]-range to get an idea of the period range and the range of function \
values in the graph.  We first define a function cycgraph[\[Mu]val] which \
returns a graph of the cycle for \[Mu] = \[Mu]val. \
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input",
  CellLabel->"In[274]:="],

Cell[BoxData[
    \(\(parmval = {0};\)\)], "Input",
  CellLabel->"In[275]:="],

Cell[BoxData[
    \(cycgraph[\[Mu]val_] := \((parmval = {\[Mu]val}; 
        labon = SequenceForm["\<van der Pol             \[Mu] = \>", 
            PaddedForm[First[parmval], {4, 2}]]; \ 
        phaser[limcyc[{2, 0}, t0, h, nsteps]])\)\)], "Input",
  CellLabel->"In[276]:="],

Cell["We try out our function on the graph we just constructed.", "Text"],

Cell[BoxData[
    \(\(cycgraph[1];\)\)], "Input",
  CellLabel->"In[277]:="],

Cell["\<\
Now the smallest and largest \[Mu]-values in our range.\
\>", "Text"],

Cell[BoxData[
    \(\(cycgraph[0];\)\)], "Input",
  CellLabel->"In[278]:="],

Cell["\<\
For \[Mu] = 0 we get a circle, as we easily could have predicted by \
looking at equation (1) for \[Mu] = 0.  Now \[Mu] = 3.\
\>", "Text"],

Cell[BoxData[
    \(\(cycgraph[3];\)\)], "Input",
  CellLabel->"In[279]:="],

Cell[TextData[{
  "We see that the range of ",
  StyleBox["y",
    FontSlant->"Italic"],
  " for \[Mu] = 3 exceeds our graph range.  We set a larger plotting window \
and try again."
}], "Text"],

Cell[BoxData[
    \(\(plrange = {{\(-5.1\), 5.1}, {\(-5.1\), 5.1}};\)\)], "Input",
  CellLabel->"In[280]:="],

Cell[BoxData[
    \(\(cycgraph[3];\)\)], "Input",
  CellLabel->"In[281]:="],

Cell["Now we create a sequence of graphs suitable for animation.", "Text"],

Cell[BoxData[
    \(Do[\((\[Mu]val = \ 0.02*i; cycgraph[\[Mu]val])\), {i, 0, 
        150}]\)], "Input",
  CellLabel->"In[282]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.  Real-Time Orbits", "SectionFirst"],

Cell["\<\
\tThe shapes of the orbits for the larger \[Mu] values are both \
surprising and interesting.  We can get some insight into those shapes by \
constructing graph sequences which show a real-time traversal of the orbit.  \
We do that using the function phaseseq.  \
\>", "Text"],

Cell["\<\
\tAs we know, the van der Pol oscillator is amplified for \
\[VerticalSeparator]x\[VerticalSeparator] < 1 and damped for \
\[VerticalSeparator]x\[VerticalSeparator] > 1.  It is helpful to show those \
lines on the graph sequence, and we do this by first constructing a reference \
graph with only those lines.\
\>", "Text"],

Cell[BoxData[
    \(\(refgraph1 = 
        ParametricPlot[{\(-1\), t}, {t, \(-5.1\), 5.1}, 
          PlotRange \[Rule] plrange, AspectRatio \[Rule] 1, 
          ImageSize \[Rule] imsize, \ 
          PlotStyle \[Rule] {Dashing[{0.02, 0.02}], RGBColor[1, 0, 0]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  CellLabel->"In[283]:="],

Cell[BoxData[
    \(\(refgraph2 = 
        ParametricPlot[{1, t}, {t, \(-5.1\), 5.1}, PlotRange \[Rule] plrange, 
          AspectRatio \[Rule] 1, ImageSize \[Rule] imsize, \ 
          PlotStyle \[Rule] {Dashing[{0.02, 0.02}], RGBColor[1, 0, 0]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  CellLabel->"In[284]:="],

Cell[BoxData[
    \(\(refgraph = 
        Show[{refgraph1, refgraph2}, 
          DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  CellLabel->"In[285]:="],

Cell["\<\
Now we construct a sequence of graphs showing the motion of two \
phase points around the orbit.  We will do this for \[Mu] = 3.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {3};\)\)], "Input",
  CellLabel->"In[286]:="],

Cell["\<\
We first construct the solution so that we can get a point on the \
limit cycle to use as an initial condition.\
\>", "Text"],

Cell[BoxData[
    \(initvec = {1.5, 0}; t0 = 0.0; h = 0.02; nsteps = 500;\)], "Input",
  CellLabel->"In[287]:="],

Cell[BoxData[
    \(\(vansol = limcyc[initvec, t0, h, nsteps];\)\)], "Input",
  CellLabel->"In[288]:="],

Cell[BoxData[
    \(\(phaser[vansol];\)\)], "Input",
  CellLabel->"In[289]:="],

Cell[BoxData[
    \(period[vansol]\)], "Input",
  CellLabel->"In[290]:="],

Cell["\<\
It is instructive to look at the time plot also.  We first shift \
the time back to beginning at 0.   \
\>", "Text"],

Cell[BoxData[
    \(\(vansolshift = timeshift[vansol, \(-10\)];\)\)], "Input",
  CellLabel->"In[291]:="],

Cell[BoxData[
    \(\(plrange = {{0, 10}, {\(-5.1\), 5.1}};\)\)], "Input",
  CellLabel->"In[292]:="],

Cell[BoxData[
    \(\(timeplot[vansolshift, 1];\)\)], "Input",
  CellLabel->"In[293]:="],

Cell["\<\
\tNow we construct the sequence showing the orbits traversed in \
real time.  By scanning the solution vansol, we find two points that are \
separated by approximately half the cycle.  These points are\
\>", "Text"],

Cell[BoxData[
    \(initvec1 = {2.02330, 0.00253}; 
    initvec2 = {\(-2.02324\), 0.01618};\)], "Input",
  CellLabel->"In[294]:="],

Cell["For h = 0.02, the number of time steps in one cycle is", "Text"],

Cell[BoxData[
    \(period[vansol]/h\)], "Input",
  CellLabel->"In[295]:="],

Cell["\<\
We alter our time step slightly so that there are 500 steps in a \
cycle.\
\>", "Text"],

Cell[BoxData[
    \(h = period[vansol]/500\)], "Input",
  CellLabel->"In[296]:="],

Cell["\<\
We will make 100 graphs in the sequence and they will cover two \
periods, so we take 10 time steps between each picture.  After constructing \
the graphs, we will delete the first 50, so that the remaining graphs show \
the complete cycle.\
\>", "Text"],

Cell[BoxData[
    \(npics = 100; nstepic = 5; intlist = {initvec1, initvec2};\)], "Input",
  CellLabel->"In[297]:="],

Cell[BoxData[
    \(\(arrowflag = False;\)\)], "Input",
  CellLabel->"In[298]:="],

Cell[BoxData[
    \(\(plrange = {{\(-5.1\), 5.1}, {\(-5.1\), 5.1}};\)\)], "Input",
  CellLabel->"In[300]:="],

Cell[BoxData[
    \(\(phaseseq[intlist, t0, h, nstepic, npics, 1, 2, 
        refgraph];\)\)], "Input",
  CellLabel->"In[301]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.  Relaxation Oscillations", "SectionFirst"],

Cell["\<\
\tThe orbit we have just seen is an example of a relaxation \
oscillation -- a kind of oscillation in which very slow segments are followed \
by very rapid segments.  Let's see if we can use the van der Pol equation to \
understand why this happens.  We rewrite the equation as\
\>", "Text"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{"\[Mu]", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontSlant->"Italic"], "2"], "-", " ", "1"}], ")"}], 
          OverscriptBox[
            StyleBox["x",
              FontSlant->"Italic"], "."]}], " ", "=", " ", 
        RowBox[{
          RowBox[{"-", 
            StyleBox["x",
              FontSlant->"Italic"]}], 
          StyleBox[" ",
            FontSlant->"Italic"], 
          StyleBox["-",
            FontSlant->"Italic"], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Plain"]}]], 
          RowBox[{
            OverscriptBox[
              StyleBox["x",
                FontSlant->"Italic"], "\[DoubleDot]"], 
            StyleBox[
              RowBox[{" ", 
                StyleBox["  ",
                  FontSlant->"Plain"]}]], 
            StyleBox[".",
              FontSlant->"Plain"]}]}]}]}]], "NumberedEquation",
  TextAlignment->Center,
  FontFamily->"Times"],

Cell[TextData[{
  "When \[Mu] is large, either ",
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is small or the term on the left hand side is large.  If the term on the \
left is large, then it must be balanced by a large term on the right.  The \
term ",
  StyleBox["x",
    FontSlant->"Italic"],
  " on the right is not large, so the only possibility is that ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  " is large.  In a rough way, these arguments suggest that at any given \
point in the cycle, either the motion is very slow, in which case \[Mu](",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^2\)\(\ \)\)\)]],
  "-1)",
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  " is small and is balanced by -",
  StyleBox["x",
    FontSlant->"Italic"],
  ", or the motion is rapid, in which case \[Mu](",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^2\)\(\ \)\)\)]],
  "-1)",
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  " is large and is balanced by ",
  Cell[BoxData[
      \(TraditionalForm\`x\&\[DoubleDot]\)]],
  ".  If you go back and look at the movie again, you will see that the \
motion is consistent with these ideas.  Here is a more detailed description.  \
We start approximately at ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 2 and ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "= 0.  The system is heavily damped, and there is a kind of creeping motion \
in which the damping force is balanced by the spring force, very much like a \
screen door closer.  When ",
  StyleBox["x",
    FontSlant->"Italic"],
  " becomes less than 1, the damping changes to amplification.  The system is \
accelerated and passes rapidly through the region from ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 1 to ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = -1.  When the system reaches the region to the left of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = -1, it is heavily damped, but it now has a lot of inertia.  Because of \
the damping, the system velocity falls to near 0 when ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is approximately -2.  Then the system creeps back toward ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 0, with damping and spring force in balance.  When it reaches ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = -1, the amplication begins again and the system is rapidly accelerated \
from ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = -1 to ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 1.  At ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = 1, the system becomes heavily damped again, but inertia carries it out \
to about ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "= 2, where the velocity falls to zero, and the creeping motion begins \
again.  It is possible to turn these qualititative ideas into a perturbation \
analysis of the system, based on the parameter \[Mu] being large.  This is \
discussed in section 7.5 of Strogatz, and he gives there an approximate \
formula for the period \[Tau] for large \[Mu], originally derived by Mary \
Cartwright in 1952.  The formula is   "
}], "Text"],

Cell[TextData[{
  "\[Tau] = (3 - 2 ln2)\[Mu] +2\[Alpha]",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\^\(\(-1\)/3\)\)]],
  "  ,"
}], "NumberedEquation",
  TextAlignment->Center],

Cell["where \[Alpha] \[TildeTilde] 2.338.", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{718, 679},
WindowMargins->{{76, Automatic}, {Automatic, 20}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000md0801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 52, 3, 114, "Title"],

Cell[CellGroupData[{
Cell[1816, 58, 40, 0, 63, "SectionFirst"],
Cell[1859, 60, 1354, 23, 146, "Text"],
Cell[3216, 85, 46, 0, 25, "Text"],
Cell[3265, 87, 1571, 22, 175, "Text"],
Cell[4839, 111, 276059, 4249, 340, 275940, 4245, "GraphicsData", "PICT", \
"Graphics"],
Cell[280901, 4362, 144, 4, 40, "Text"],
Cell[281048, 4368, 150, 5, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[281235, 4378, 52, 0, 63, "SectionFirst"],
Cell[281290, 4380, 112, 3, 25, "Text"],
Cell[281405, 4385, 809, 26, 27, "NumberedEquation"],
Cell[282217, 4413, 1160, 26, 103, "Text"],
Cell[283380, 4441, 418, 20, 26, "NumberedEquation"],
Cell[283801, 4463, 64, 2, 28, "Input"],
Cell[283868, 4467, 53, 1, 28, "Input"],
Cell[283924, 4470, 149, 3, 32, "Input"],
Cell[284076, 4475, 91, 2, 28, "Input"],
Cell[284170, 4479, 88, 3, 25, "Text"],
Cell[284261, 4484, 77, 2, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284375, 4491, 53, 0, 63, "SectionFirst"],
Cell[284431, 4493, 278, 5, 40, "Text"],
Cell[284712, 4500, 75, 2, 28, "Input"],
Cell[284790, 4504, 104, 2, 28, "Input"],
Cell[284897, 4508, 77, 2, 28, "Input"],
Cell[284977, 4512, 346, 6, 55, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[285360, 4523, 43, 0, 63, "SectionFirst"],
Cell[285406, 4525, 120, 3, 25, "Text"],
Cell[285529, 4530, 137, 3, 28, "Input"],
Cell[285669, 4535, 50, 0, 25, "Text"],
Cell[285722, 4537, 92, 2, 28, "Input"],
Cell[285817, 4541, 47, 0, 25, "Text"],
Cell[285867, 4543, 130, 3, 28, "Input"],
Cell[286000, 4548, 95, 2, 28, "Input"],
Cell[286098, 4552, 111, 2, 28, "Input"],
Cell[286212, 4556, 132, 3, 25, "Text"],
Cell[286347, 4561, 100, 2, 28, "Input"],
Cell[286450, 4565, 85, 2, 28, "Input"],
Cell[286538, 4569, 71, 2, 28, "Input"],
Cell[286612, 4573, 503, 9, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[287152, 4587, 74, 0, 63, "SectionFirst"],
Cell[287229, 4589, 450, 7, 55, "Text"],
Cell[287682, 4598, 80, 2, 28, "Input"],
Cell[287765, 4602, 77, 2, 28, "Input"],
Cell[287845, 4606, 278, 5, 76, "Input"],
Cell[288126, 4613, 73, 0, 25, "Text"],
Cell[288202, 4615, 75, 2, 28, "Input"],
Cell[288280, 4619, 79, 2, 25, "Text"],
Cell[288362, 4623, 75, 2, 28, "Input"],
Cell[288440, 4627, 148, 3, 25, "Text"],
Cell[288591, 4632, 75, 2, 28, "Input"],
Cell[288669, 4636, 194, 6, 26, "Text"],
Cell[288866, 4644, 108, 2, 28, "Input"],
Cell[288977, 4648, 75, 2, 28, "Input"],
Cell[289055, 4652, 74, 0, 25, "Text"],
Cell[289132, 4654, 130, 3, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[289299, 4662, 44, 0, 63, "SectionFirst"],
Cell[289346, 4664, 286, 5, 40, "Text"],
Cell[289635, 4671, 333, 6, 40, "Text"],
Cell[289971, 4679, 350, 7, 76, "Input"],
Cell[290324, 4688, 334, 6, 76, "Input"],
Cell[290661, 4696, 165, 4, 28, "Input"],
Cell[290829, 4702, 152, 3, 25, "Text"],
Cell[290984, 4707, 77, 2, 28, "Input"],
Cell[291064, 4711, 135, 3, 25, "Text"],
Cell[291202, 4716, 112, 2, 28, "Input"],
Cell[291317, 4720, 103, 2, 28, "Input"],
Cell[291423, 4724, 78, 2, 28, "Input"],
Cell[291504, 4728, 73, 2, 28, "Input"],
Cell[291580, 4732, 126, 3, 25, "Text"],
Cell[291709, 4737, 104, 2, 28, "Input"],
Cell[291816, 4741, 100, 2, 28, "Input"],
Cell[291919, 4745, 88, 2, 28, "Input"],
Cell[292010, 4749, 225, 4, 40, "Text"],
Cell[292238, 4755, 130, 3, 28, "Input"],
Cell[292371, 4760, 70, 0, 25, "Text"],
Cell[292444, 4762, 75, 2, 28, "Input"],
Cell[292522, 4766, 97, 3, 25, "Text"],
Cell[292622, 4771, 81, 2, 28, "Input"],
Cell[292706, 4775, 264, 5, 40, "Text"],
Cell[292973, 4782, 116, 2, 28, "Input"],
Cell[293092, 4786, 81, 2, 28, "Input"],
Cell[293176, 4790, 108, 2, 28, "Input"],
Cell[293287, 4794, 129, 3, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[293453, 4802, 51, 0, 63, "SectionFirst"],
Cell[293507, 4804, 301, 5, 55, "Text"],
Cell[293811, 4811, 1152, 37, 27, "NumberedEquation"],
Cell[294966, 4850, 3171, 86, 229, "Text"],
Cell[298140, 4938, 180, 6, 25, "NumberedEquation"],
Cell[298323, 4946, 51, 0, 25, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

