(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67593,       2171]*)
(*NotebookOutlinePosition[     92473,       3072]*)
(*  CellTagsIndexPosition[     92429,       3068]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
A Catalogue of Equilibria
for Systems of
Two Linear Autonomous First Order Equations\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
\tIn this notebook, we look at solutions of equations of the \
following form:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"a", " ", "x"}],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", 
            StyleBox[
              RowBox[{"b", " ", "y"}],
              FontSlant->"Italic"]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                 ", "\n", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"c", " ", "x"}],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", 
            RowBox[{
              StyleBox["d",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Here ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", ",
  StyleBox["c",
    FontSlant->"Italic"],
  " and ",
  StyleBox["d",
    FontSlant->"Italic"],
  " are constants, and, unless otherwise specified, we assume that "
}], "Text"],

Cell[TextData[{
  "                                                                           \
       a d",
  StyleBox[" - ",
    FontSlant->"Plain"],
  "b c  \[NotEqual]  ",
  StyleBox[
  "0.                                                                         \
      ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell["These equations have solutions of the form", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {
                    StyleBox["x",
                      FontSlant->"Italic"]},
                  {
                    StyleBox["y",
                      FontSlant->"Italic"]}
                  }], "\[NegativeThinSpace]", ")"}], " ", "=", " ", 
            RowBox[{
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {
                      StyleBox["u",
                        FontSlant->"Italic"]},
                    {
                      StyleBox["v",
                        FontSlant->"Italic"]}
                    }], "\[NegativeThinSpace]", ")"}], " ", 
              SuperscriptBox[
                StyleBox["e",
                  FontSlant->"Italic"], 
                StyleBox["rt",
                  FontSlant->"Italic"]]}]}], " ", ","}]}], TextForm]], "Text",\

  TextAlignment->Center],

Cell[TextData[{
  "where ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", ",
  StyleBox["u",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["v",
    FontSlant->"Italic"],
  " satisfy"
}], "Text"],

Cell[TextData[{
  "(",
  StyleBox["a",
    FontSlant->"Italic"],
  " - ",
  StyleBox["r",
    FontSlant->"Italic"],
  ") ",
  StyleBox["u ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["b v ",
    FontSlant->"Italic"],
  " =  0 , \n                                                                 \
                                                                              \
                                         \n",
  StyleBox["c u",
    FontSlant->"Italic"],
  " + (",
  StyleBox["d",
    FontSlant->"Italic"],
  " - ",
  StyleBox["r",
    FontSlant->"Italic"],
  ") ",
  StyleBox["v",
    FontSlant->"Italic"],
  "  =  0."
}], "Text",
  TextAlignment->Center],

Cell["\<\
For these two homogeneous linear equations to have a non-trivial \
solution, the determinant of the coefficient array must vanish. Thus\
\>", 
  "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "                                                                       \
                         ", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox["r",
                FontSlant->"Italic"], "2"], " ", "-", " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["a",
                    FontSlant->"Italic"], " ", "+", " ", 
                  StyleBox["d",
                    FontSlant->"Italic"]}], ")"}], " ", 
              StyleBox["r",
                FontSlant->"Italic"]}], 
            StyleBox[
              RowBox[{
                StyleBox[" ",
                  FontSlant->"Italic"], " "}]], "+", " ", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[
                  RowBox[{"a", " ", "d"}],
                  FontSlant->"Italic"], "  ", "-", "  ", 
                StyleBox[
                  RowBox[{"b", " ", "c"}],
                  FontSlant->"Italic"]}], ")"}]}], "  ", "=", "  ", 
          RowBox[{"0", " ", "."}]}], 
        "                                                                     \
                  "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Each of the two roots of this quadratic determines a solution.  The \
solution is completed by solving the equations for ",
  StyleBox["u",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  " for each value of ",
  StyleBox["r",
    FontSlant->"Italic"],
  ".  Because the equations are homogeneous, the vector (",
  StyleBox["u,",
    FontSlant->"Italic"],
  "v",
  StyleBox[") ",
    FontSlant->"Italic"],
  "is determined only to within a constant multiple, which may be chosen at \
convenience.  The two solutions can then be assembled into the general \
solution of the problem:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {
                  StyleBox["x",
                    FontSlant->"Italic"]},
                {
                  StyleBox["y",
                    FontSlant->"Italic"]}
                }], "\[NegativeThinSpace]", ")"}], " ", "=", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["C",
                  FontSlant->"Italic"], "1"], " ", 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {
                      SubscriptBox[
                        StyleBox["u",
                          FontSlant->"Italic"], "1"]},
                    {
                      StyleBox[
                        SubscriptBox["v", 
                          StyleBox["1",
                            FontSlant->"Plain"]],
                        FontSlant->"Italic"]}
                    }], "\[NegativeThinSpace]", ")"}], 
              SuperscriptBox[
                StyleBox["e",
                  FontSlant->"Italic"], 
                RowBox[{\(r\_1\), 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "  ", "+", "  ", 
            RowBox[{
              SubscriptBox[
                StyleBox["C",
                  FontSlant->"Italic"], "2"], " ", 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {
                      SubscriptBox[
                        StyleBox["u",
                          FontSlant->"Italic"], "2"]},
                    {
                      StyleBox[\(v\_2\),
                        FontSlant->"Italic"]}
                    }], "\[NegativeThinSpace]", ")"}], 
              RowBox[{
                SuperscriptBox[
                  StyleBox["e",
                    FontSlant->"Italic"], 
                  RowBox[{\(r\_2\), 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "  ", "."}]}]}]}]}], 
      TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "\tThe stability of the equilibrium is determined by the eigenvalues ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["r", "1"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["r", "2"], TraditionalForm]]],
  ".  If they are negative or if they are complex with negative real parts, \
then the solutions decay as ",
  StyleBox["t",
    FontSlant->"Italic"],
  " \[LongRightArrow]\[Infinity], and the equilibrium is called strictly \
stable.  If either or both of the eigenvalues is positive (or if the real \
part is positive for a pair of complex conjugate eigenvalues), then there are \
growing solutions in the neighborhood of the equilibrium and it is unstable. \
If the eigenvalues are pure imaginary so that the solution is oscillatory, \
the equilibrium is called stable (but not strictly stable).  It is usual and \
useful to classify the possible equilibria on the basis of the eigenvalues, \
and this is done in Table One below.  We have omitted some sub-categories \
that are sometimes included. "
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"  ", 
              StyleBox[
                RowBox[{"Character", " ", "of", " ", "Eigenvalues"}],
                FontWeight->"Bold"], 
              StyleBox["  ",
                FontWeight->"Bold"]}], 
            StyleBox[
              RowBox[{
                RowBox[{"Name", " ", "of", " ", "Equilibrium"}], "  "}],
              FontWeight->"Bold"], 
            RowBox[{" ", 
              StyleBox["Stability",
                FontWeight->"Bold"], 
              StyleBox["        ",
                FontWeight->"Bold"]}]},
          {
            RowBox[{"real", ",", " ", 
              RowBox[{"both", " ", "negative"}]}], "node", 
            RowBox[{"strictly", " ", "stable"}]},
          {
            RowBox[{"real", ",", " ", 
              RowBox[{"both", " ", "positive"}]}], "node", "unstable"},
          {
            RowBox[{"real", ",", " ", 
              RowBox[{
              "one", " ", "negative", " ", "one", " ", "positive"}]}], 
            "saddle", "unstable"},
          {
            RowBox[{
              RowBox[{"complex", " ", "conjugate"}], ",", " ", 
              RowBox[{"negative", " ", "real", " ", "part"}]}], "spiral", 
            RowBox[{"strictly", "  ", "stable"}]},
          {
            RowBox[{
              RowBox[{"complex", " ", "conjugate"}], ",", " ", 
              RowBox[{"positive", " ", "real", " ", "part"}]}], "spiral", 
            "unstable"},
          {
            RowBox[{
              RowBox[{"complex", " ", "conjugate"}], ",", " ", 
              RowBox[{"zero", " ", "real", " ", "part"}]}], "center", 
            "stable"}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True], TextForm]], "Text",
  TextAlignment->Center],

Cell["\<\
Table One --  Classification of Equilibria
\
\>", "Text",
  TextAlignment->Center,
  FontWeight->"Bold"],

Cell["\<\
\tIn the remainder of this notebook, we analyze a sequence of \
examples, with emphasis on constructing in each case a good phase portrait.  \
Ttaken together, the examples illustrate the range of possibilities for \
linear second order autonomous systems.  Before starting the examples, we \
discuss briefly the software to be used here.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Examples", "Section"],

Cell[CellGroupData[{

Cell["Defining the Equation for DynPac", "Subsection"],

Cell[TextData[{
  "\tIn every case, we are integrating equations of the form ",
  StyleBox["dx",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt",
    FontSlant->"Italic"],
  " = ",
  StyleBox["a x ",
    FontSlant->"Italic"],
  " + ",
  StyleBox["b y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dy",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt",
    FontSlant->"Italic"],
  " = ",
  StyleBox["c x ",
    FontSlant->"Italic"],
  " + ",
  StyleBox["d y",
    FontSlant->"Italic"],
  ".  The state vector for the system is {",
  StyleBox["x",
    FontSlant->"Italic"],
  ",",
  StyleBox["y",
    FontSlant->"Italic"],
  "}, which we declare now for DynPac:"
}], "Text"],

Cell[BoxData[
    \(\(setstate[{x, y}];\)\)], "Input"],

Cell[TextData[{
  "The parameters in the problem are the four coefficients {",
  StyleBox["a",
    FontSlant->"Italic"],
  ",",
  StyleBox["b",
    FontSlant->"Italic"],
  ",",
  StyleBox["c",
    FontSlant->"Italic"],
  ",",
  StyleBox["d",
    FontSlant->"Italic"],
  "}, which are declared as follows:"
}], "Text"],

Cell[BoxData[
    \(\(setparm[{a, b, c, d}];\)\)], "Input"],

Cell["\<\
Before carrying out any solutions, we will have to assign values to \
all four of these parameters.  \
\>", "Text"],

Cell["\<\
\tThe slope vector is the vector of right-hand sides, and we now \
define it for DynPac:\
\>", "Text"],

Cell[BoxData[
    \(\(slopevec = {a\ x\  + \ b\ y, \ c\ x\  + \ d\ y};\)\)], "Input"],

Cell["Finally, we name our system LinEq:", "Text"],

Cell[BoxData[
    \(\(sysname = "\<LinEq\>";\)\)], "Input"],

Cell["\<\
We can check what we have defined at any time by typing \
sysreport:\
\>", "Text"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
\tAs we work each example, we will first set values for the \
coefficients, then choose a set of initial conditions, and finally ask DynPac \
to carry out integrations and plot the solutions.  We begin with nodes, which \
are systems with two real eigenvalues of the same sign.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stable Nodes", "Subsection"],

Cell["\tFor our first case, we take the equations", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{"-", 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["x",
              FontSlant->"Italic"]}]}], 
        StyleBox[
          RowBox[{
            StyleBox[" ",
              FontSlant->"Italic"], " "}]], ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                   ", "\n", "       ", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", 
          StyleBox[
            RowBox[{"  ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            RowBox[{
              StyleBox["-",
                FontSlant->"Italic"], " ", "2"}], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["y",
              FontSlant->"Italic"]}]}], "  ", ","}], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "corresponding to ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = -1, ",
  StyleBox["b",
    FontSlant->"Italic"],
  " = 0, ",
  StyleBox["c",
    FontSlant->"Italic"],
  " = 0, and ",
  StyleBox["d",
    FontSlant->"Italic"],
  " = -2.  We set these values for DynPac:"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {\(-1\), 0, 0, \(-2\)};\)\)], "Input"],

Cell["\<\
For our first task, we ask DynPac to classify this equilibrium, \
using the function classify2D, which takes the location of the equilibrium as \
its argument:\
\>", "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["\<\
DynPac tells us that this is a strictly stable node.  We can get \
the eigenvalues as follows:\
\>", "Text"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell["\<\
We see that the eigenvalues are -2 and -1 -- both real and both \
negative, as they should be for a stable node.  We can also get the \
eigenvectors and eigenvalues together:\
\>", "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell["\<\
The eigenvector {0,1} goes with the eigenvalue -2, and the \
eigenvector {1,0} goes with the eigenvalue -1.  \
\>", "Text"],

Cell[TextData[{
  "\tNow its time to construct a picture.  We will use a plotting window of \
{-5,5} in both ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ".  We specify the window for Dynpac."
}], "Text"],

Cell[BoxData[
    \(\(plrange = {{\(-5\), 5}, {\(-5\), 5}};\)\)], "Input"],

Cell["We set the image size to 380.", "Text"],

Cell[BoxData[
    \(\(imsize = 380;\)\)], "Input"],

Cell["\<\
We also ask for one arrow at the mid-point of each solution curves \
to indicate the positive time direction.\
\>", "Text"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell["We check our graphics settings with plotreport:", "Text"],

Cell[BoxData[
    \(plotreport\)], "Input"],

Cell["\<\
Because the solutions go inward to the origin, we start our \
integration on the frame of the plotting window.  We will use a set of 16 \
initial conditions, spaced more or less uniformly around the frame.  We \
define the initial conditions now.\
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {5, 2.5}, {5, 5}, {2.5, 5}, {0, 5}, {\(-2.5\), 
            5}, {\(-5\), 5}, {\(-5\), 2.5}, {\(-5\), 
            0}, {\(-5\), \(-2.5\)}, {\(-5\), \(-5\)}, {\(-2.5\), \(-5\)}, {0, \
\(-5\)}, {2.5, \(-5\)}, {5, \(-5\)}, {5, \(-2.5\)}};\)\)], "Input"],

Cell["\<\
For the numerical integration, we must specify the initial time t0, \
the integration step size h, and the number of integration steps, nsteps. \
\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.01; nsteps = 500;\)], "Input"],

Cell["\<\
Now we use the DynPac function portrait to get a phase \
portrait.\
\>", "Text"],

Cell[BoxData[
    \(\(node1 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tThe arrows help by showing the flow direction.  The graph is \
labeled by the values of the parameters used in the integration.  \
\>", 
  "Text"],

Cell[TextData[{
  "\tNotice that the solutions are all tangent to the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-axis at the origin, except for the solutions which start on the ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-axis -- they remain on the ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-axis as they approach the origin.  This can be understood by looking at \
the analytical form of the general solution, namely"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "                                                                       \
                    ", 
        RowBox[{
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {
                  StyleBox["x",
                    FontSlant->"Italic"]},
                {
                  StyleBox["y",
                    FontSlant->"Italic"]}
                }], "\[NegativeThinSpace]", ")"}], " ", "=", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["C",
                  FontSlant->"Italic"], "1"], " ", 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NegativeThinSpace]", ")"}], 
              SuperscriptBox[
                StyleBox["e",
                  FontSlant->"Italic"], 
                RowBox[{
                  RowBox[{"-", "2"}], 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "  ", "+", "  ", 
            RowBox[{
              SubscriptBox[
                StyleBox["C",
                  FontSlant->"Italic"], "2"], " ", 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"1"},
                    {"0"}
                    }], "\[NegativeThinSpace]", ")"}], 
              RowBox[{
                SuperscriptBox[
                  StyleBox["e",
                    FontSlant->"Italic"], 
                  RowBox[{"-", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "  ", "."}]}]}]}], 
        "                                                                     \
                      "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "We see that when ",
  StyleBox["t",
    FontSlant->"Italic"],
  " gets very large, the first term gets much smaller than the second term, \
so that for any solution in which ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "2"], TraditionalForm]]],
  " \[NotEqual] 0, we have  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
      "                                                                       \
                    ", 
        RowBox[{
          RowBox[{
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {
                    StyleBox["x",
                      FontSlant->"Italic"]},
                  {
                    StyleBox["y",
                      FontSlant->"Italic"]}
                  }], "\[NegativeThinSpace]", ")"}], " ", "\[TildeTilde]", 
            "   ", 
            RowBox[{
              SubscriptBox[
                StyleBox["C",
                  FontSlant->"Italic"], "2"], " ", 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"1"},
                    {"0"}
                    }], "\[NegativeThinSpace]", ")"}], 
              SuperscriptBox[
                StyleBox["e",
                  FontSlant->"Italic"], 
                RowBox[{"-", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "   ", "as", " ", 
              RowBox[{
                StyleBox["t",
                  FontSlant->"Italic"], " ", "\[LongRightArrow]", 
                "\[Infinity]"}]}]}], "  ", ","}], 
        "                                                                     \
                   "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "which shows that all such solutions become asymptotically tangent to the ",
  
  StyleBox["x",
    FontSlant->"Italic"],
  "-axis."
}], "Text"],

Cell["\<\
\tLet's look at a second example of a stable node.  We consider the \
equations\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"               ", 
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox["dx", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", "  ", 
            RowBox[{
              RowBox[{
                RowBox[{"-", " ", "4"}], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["x",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["-",
                FontSlant->"Italic"], " ", 
              RowBox[{"2", 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["y",
                  FontSlant->"Italic"]}]}]}], "  ", ",", "\n", 
          "                                                                   \
                                                                              \
                                                                              \
                                                 ", "\n", "   ", 
          RowBox[{
            StyleBox[
              FractionBox["dy", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox["x",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["-",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell["We set the parameter values for DynPac.", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-4\), \(-2\), 1, \(-1\)};\)\)], "Input"],

Cell["We classify the equilbrium:", "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["\<\
DynPac tells us that this is a strictly stable node.  We get the \
eigenvalues:\
\>", "Text"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell["\<\
We see that the eigenvalues are -3 and -2 -- both real and both \
negative, as they should be for a stable node.  We can also get the \
eigenvectors and eigenvalues together:\
\>", "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell["\<\
The eigenvector {-2,1} goes with the eigenvalue -3, and the \
eigenvector {-1,1} goes with the eigenvalue -2 .  We can predict from this \
that as the orbits approach the origin, they will do so tangent to the vector \
{-1,1}, except for a single orbit along the line {-2,1}.  We construct the \
phase portrait using the parameters defined for the preceding example, after \
a slight modification of the list of initial conditions.  \
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {5, 2.5}, {5, 5}, {0, 5}, {\(-2.5\), 5}, {\(-5\), 
            5}, {\(-5\), 2.5}, {\(-5\), 
            0}, {\(-5\), \(-2.5\)}, {\(-5\), \(-5\)}, {0, \(-5\)}, {2.5, \(-5\
\)}, {5, \(-5\)}, {5, \(-2.5\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(node2 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tWe see clearly that all of the solutions approach the equilibrium \
point tangent to the direction {-1,1}, except the single solution along the \
direction {-2,1}.  \
\>", "Text"],

Cell["\tNow we look at a few unstable nodes.  Our first example is", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"-", " ", "2"}], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", 
            RowBox[{"5", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["y",
                FontSlant->"Italic"]}]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                               ", "\n", "   ", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"-", " ", "3"}], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", 
            StyleBox[" ",
              FontSlant->"Italic"], 
            RowBox[{"6", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell[BoxData[
    \(\(parmval = {\(-2\), 5, \(-3\), 6};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell["\<\
Thus we have two positive eigenvalues, so this is an unstable node, \
as classify2D has already told us.  We must change our integration strategy \
slightly, because now orbits starting on the frame of our plotting window \
will in general leave the window and head off to infinity.  To get orbits \
connecting the origin with the plotting frame, we integrate backwards in \
time, so that we start on the plotting frame and go toward the origin.  We do \
this by assigning a negative value to the time step.\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = \(-0.01\); nsteps = 500;\)], "Input"],

Cell["We use the following  initial conditions:", "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 5}, {2, 5}, {1, 5}, {3, 5}, {0, 
            5}, {\(-5\), \(-5\)}, {\(-3\), \(-5\)}, {\(-1\), \(-5\)}, \
{\(-2\), \(-5\)}, {0, \(-5\)}, {5, 3}, {\(-5\), \(-3\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(node3 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
The arrows point away from the origin, consistent with our finding \
that this is an unstable equilibrium.\
\>", "Text"],

Cell["\tOur next node illustrates the case of a repeated root.", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"  ", 
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox["dx", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox["x",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], "+", " ", 
              StyleBox["y",
                FontSlant->"Italic"]}]}], "  ", ",", "\n", 
          "                                                                   \
                                                                              \
                                                                              \
                                                 ", "\n", "            ", 
          RowBox[{
            StyleBox[
              FractionBox["dy", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", " ", 
            RowBox[{
              RowBox[{"-", 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["x",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "+", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{"3", 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["y",
                    FontSlant->"Italic"], "  ", "."}]}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell["We set the parameter values.", "Text"],

Cell[BoxData[
    \(\(parmval = {1, 1, \(-1\), 3};\)\)], "Input"],

Cell["\<\
We classify the system and find the eigenvalues and eigenvectors.\
\
\>", "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell[TextData[{
  "\tNote that DynPac has called this a spiral-node transition.  The \
explanation for this is the following. For a node there are two real roots.  \
For a spiral, there are two complex conjugate roots of the form \[Alpha] \
\[PlusMinus] ",
  StyleBox["i",
    FontSlant->"Italic"],
  "\[Beta]",
  StyleBox[".  ",
    FontSlant->"Italic"],
  "Now we can imagine that we change a parameter of the system so that the \
eigenvalues change.  Suppose the parameter change causes \[Beta] to decrease \
to zero and \[Alpha] to remain non-zero.  Just as \[Beta] reaches zero, we \
have a repeated real root, which we normally call a node.  But we see that it \
could equally well be regarded as the limit of a spiral as the oscillation \
frequency goes to zero.  Thus this case of a repeated real root is exactly in \
between a spiral and a node, and so it is called a spiral-node transition."
}], "Text"],

Cell[TextData[{
  "\tWe see that our repeated root comes with only one independent \
eigenvector, namely {1,1}.  (See the next example for a repeated root with \
two independent eigenvectors.)  Thus the solution will contain ",
  StyleBox["t",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["e", "t"], TraditionalForm]]],
  " terms as well as ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["e", "t"], TraditionalForm]]],
  " terms.  We can verify this by asking DSolve for the analytical solution."
}], "Text"],

Cell[BoxData[
    \(DSolve[{\(x'\)[t] == x[t] + y[t], \(y'\)[t] == \(-x[t]\) + 3\ y[t]}, {x[
          t], y[t]}, t]\)], "Input"],

Cell["\<\
The form verifies our prediction.  As we did in the last example, \
we integrate this one backwards in time, so that orbits starting on the \
plotting window frame will move toward the origin.\
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {5, 2.5}, {5, 5}, {2.5, 5}, {0, 5}, {\(-2.5\), 
            5}, {\(-5\), 5}, {\(-5\), 
            0}, {\(-5\), \(-2.5\)}, {\(-5\), \(-5\)}, {\(-2.5\), \(-5\)}, {0, \
\(-5\)}, {2.5, \(-5\)}, {5, \(-5\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(node4 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
As we go back in time, all of the solutions will approach the \
origin tangent to {1,1}, which is the only eigenvector.\
\>", "Text"],

Cell["\<\
\tWe do one last node example.  It is slightly artificial but \
interesting nonetheless.  The equations are\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"  ", 
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox["dx", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            StyleBox[
              RowBox[{
                RowBox[{"-", "2"}], "x"}],
              FontSlant->"Italic"]}], "  ", ",", "\n", 
          "                                                                   \
                                                                              \
                                                                              \
                                                 ", "\n", "   ", 
          RowBox[{
            StyleBox[
              FractionBox["dy", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", " ", 
            RowBox[{
              RowBox[{"-", 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["2",
                  FontSlant->"Italic"]}], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell["We set the parameter values.", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-2\), 0, 0, \(-2\)};\)\)], "Input"],

Cell[TextData[{
  "The artificial feature is that the equations are uncoupled.  We can solve \
for ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "independently of ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["y ",
    FontSlant->"Italic"],
  "independently of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  Of course we can also solve them as a system, which we do now.  First \
we classify the equilibrium and then find the eigenvalues and eigenvectors."
}], "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell[TextData[{
  "We get a repeated eigenvalue but two independent eigenvectors, so there \
are no ",
  StyleBox["t",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["e", "t"], TraditionalForm]]],
  " terms in the solution, which we verify with DSolve:"
}], "Text"],

Cell[BoxData[
    \(DSolve[{\(x'\)[t] == \(-2\)\ x[t], \(y'\)[t] == \(-2\)\ y[t]}, {x[t], 
        y[t]}, t]\)], "Input"],

Cell[TextData[{
  "No ",
  StyleBox["t",
    FontSlant->"Italic"],
  " terms, as predicted.  Now we construct the phase portrait.  Because the \
system is stable, we integrate forward in time, starting on the frame of our \
plotting window."
}], "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {5, 2.5}, {5, 5}, {2.5, 5}, {0, 5}, {\(-2.5\), 
            5}, {\(-5\), 5}, {\(-5\), 2.5}, {\(-5\), 
            0}, {\(-5\), \(-2.5\)}, {\(-5\), \(-5\)}, {\(-2.5\), \(-5\)}, {0, \
\(-5\)}, {2.5, \(-5\)}, {5, \(-5\)}, {5, \(-2.5\)}};\)\)], "Input"],

Cell[TextData[{
  "We restore the time direction to forward by taking the time step ",
  StyleBox["h",
    FontSlant->"Italic"],
  " positive."
}], "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.01; nsteps = 500;\)], "Input"],

Cell[BoxData[
    \(\(node5 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
The graph, which is startling at first glance, makes perfect sense \
if you remember that y[t]/x[t] = C[1]/C[2] = constant for any solution, so \
all of the orbits are straight lines through the origin.\
\>", "Text"],

Cell["\<\
\tSometimes the terminology for nodes is refined to distinguish \
some of the various special cases discussed above, such as the repeated root \
with one eigenvector and the repeated root with two eigenvectors.  However, \
there is a serious lack of uniformity in this terminology in the literature, \
so it is of limited usefulness and we do not consider it here. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spirals", "Subsection"],

Cell["\tThe equations for our next example are", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{"-", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", 
            RowBox[{"3", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["y",
                FontSlant->"Italic"]}]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                  ", "\n", " ", 
        RowBox[{
          StyleBox[
            FractionBox[
              RowBox[{" ", "dy"}], "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "3"}], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], 
            StyleBox["  ",
              FontSlant->"Italic"], 
            RowBox[{
              StyleBox["y",
                FontSlant->"Italic"], "  ", "."}]}]}]}], TextForm]], "Text",
  TextAlignment->Center],

Cell["We define the equation for DynPac and then classify it.", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-1\), 3, \(-3\), \(-1\)};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["We have a stable spiral.  The eigenvalues are", "Text"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell["The eigenvectors will be complex:", "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell["\<\
Although our goal here is to produce phase portraits, we take a \
small detour to show how to get real-valued solutions for this equation \
(something that DSolve can't manage).  We start by giving names to the \
eigenvalues and eigenvectors.\
\>", "Text"],

Cell[BoxData[
    \({r1, r2} = {First[First[eigsys[{0, 0}]]], 
        Last[First[eigsys[{0, 0}]]]}\)], "Input"],

Cell[BoxData[
    \({vec1, vec2} = {First[Last[eigsys[{0, 0}]]], 
        Last[Last[eigsys[{0, 0}]]]}\)], "Input"],

Cell["\<\
Now we get a real valued solution by taking the real part of the \
complex-valued solution:\
\>", "Text"],

Cell[BoxData[
    \(firstsol = ComplexExpand[Re[vec1\ Exp[r1\ t]]]\)], "Input"],

Cell["\<\
We get the second solution as the imaginary part of the \
complex-valued solution:\
\>", "Text"],

Cell[BoxData[
    \(secondsol = ComplexExpand[Im[vec1\ Exp[r1\ t]]]\)], "Input"],

Cell["\<\
\tNow we construct the phase portrait.  We choose initial \
conditions around the frame of the plotting window, which is still \
{{-5,5},{-5,5}}.  \
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {2.5, 5}, {\(-2.5\), 5}, {\(-5\), 2.5}, {\(-5\), 
            0}, {\(-2.5\), \(-5\)}, {0, \(-5\)}, {5, \(-2.5\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(spiral1 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tWe look at one last example of a spiral, this time unstable.  The \
equations are\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", 
          StyleBox[
            RowBox[{"  ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            StyleBox["x",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            RowBox[{
              StyleBox["3",
                FontSlant->"Plain"], 
              StyleBox["y",
                FontSlant->"Italic"]}]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                  ", "\n", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{"3", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", 
            RowBox[{
              StyleBox["y",
                FontSlant->"Italic"], "  ", "."}]}]}]}], TextForm]], "Text",
  TextAlignment->Center],

Cell["\<\
Notice that these are the same as the equations for the previous \
example, except the right-hand sides have the opposite sign.  An interesting \
way to produce these equations is to change the direction of time in the \
previous equations.  That transformation induces a minus sign on each left \
hand side which can then be transferred to the right hand side.  Given that \
observation, we expect to get the same picture as above, but with the arrows \
reversed in direction.  Let's try it.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {1, \(-3\), 3, 1};\)\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell["The eigenvalues indicate an unstable spiral.", "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell["We use the same initial conditions as in the last example.", "Text"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {2.5, 5}, {\(-2.5\), 5}, {\(-5\), 2.5}, {\(-5\), 
            0}, {\(-2.5\), \(-5\)}, {0, \(-5\)}, {5, \(-2.5\)}};\)\)], "Input"],

Cell["\<\
We must now integrate backwards in time to get to the origin from \
the plot window frame, so we make the time step negative.\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = \(-0.01\); nsteps = 500;\)], "Input"],

Cell[BoxData[
    \(\(spiral2 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
As predicted, we get the same picture with the arrows \
reversed.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Centers", "Subsection"],

Cell[TextData[{
  "\tThere is an interesting connection between spirals and centers, which \
can be seen by looking again at how these objects are defined by the \
properties of their eigenvalues.  A stable spiral has eigenvalues of the form \
\[Alpha] \[PlusMinus] ",
  StyleBox["i",
    FontSlant->"Italic"],
  "\[Beta]",
  StyleBox[", ",
    FontSlant->"Italic"],
  "where \[Alpha] < 0.  An unstable spiral has eigenvalues of the form \
\[Alpha] \[PlusMinus] ",
  StyleBox["i",
    FontSlant->"Italic"],
  "\[Beta], where \[Alpha] > 0.  A center has eigenvalues of the form \
\[PlusMinus] ",
  StyleBox["i",
    FontSlant->"Italic"],
  "\[Beta].  Thus we see that a center is a kind of transition system between \
stable and unstable spirals.  Let's look at this a little more, by \
introducing a system with a parameter \[Epsilon] which can be varied.  The \
system is "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          StyleBox["y",
            FontSlant->"Italic"]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                  ", "\n", 
        "                      ", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{"-", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], " ", 
            RowBox[{"\[Epsilon]", " ", 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell[TextData[{
  "(You might recognize this as the system form of a damped oscillator with ",
  
  StyleBox["m",
    FontSlant->"Italic"],
  " = 1, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 1, and ",
  StyleBox["b",
    FontSlant->"Italic"],
  " = \[Epsilon].)  We define the system for DynPac:"
}], "Text"],

Cell[BoxData[
    \(Clear[\[Epsilon]]\)], "Input"],

Cell[BoxData[
    \(\(parmval = {0, 1, \(-1\), \(-\[Epsilon]\)};\)\)], "Input"],

Cell[TextData[
"We now look at three cases:  \[Epsilon] = 0.5, 0, and -0.5.  In each case we \
will classify the equilibrium."], "Text"],

Cell[BoxData[
    \(\[Epsilon] = 0.5; classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(\[Epsilon] = 0.0; classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(\[Epsilon] = \(-0.5\); classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[TextData[
"We see exactly the transition we talked about above.  As \[Epsilon] goes \
from positive to negative, the system goes from a stable spiral to an \
unstable spiral, with the transition occurring at \[Epsilon] = 0, for which \
the system is a center.  Although we are focusing mostly on centers here, we \
plot all three cases just to show the transition.  We start with the stable \
spiral.  We specify the list of initial conditions, on the frame of the \
plotting window, and we specify forward integration in time."], "Text"],

Cell[BoxData[
    \(\(initlist = {{2.5, 5}, {\(-2.5\), 
            5}, {\(-2.5\), \(-5\)}, {0, \(-5\)}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.01; nsteps = 2000;\)], "Input"],

Cell[BoxData[
    \(\(\[Epsilon] = 0.5;\)\)], "Input"],

Cell[BoxData[
    \(\(precenter = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[
"\tLet's look now at the transition case, the center when \[Epsilon] = 0."], 
  "Text"],

Cell[BoxData[
    \(\(\[Epsilon] = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {{5, 0}, {4, 0}, {3, 0}, {2, 0}, {1, 0}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.01; nsteps = 630;\)], "Input"],

Cell["\<\
This particular diagram looks better with two arrows, so we ask for \
arrows at the 1/8 and 5/8 points of each orbit.\
\>", "Text"],

Cell[BoxData[
    \(\(arrowvec = {1/8, 5/8};\)\)], "Input"],

Cell[BoxData[
    \(\(center = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[
"\tFinally we look at the unstable spiral for \[Epsilon] = -0.5.  We start on \
the plotting window frame and integrate backwards in time."], "Text"],

Cell[BoxData[
    \(\(\[Epsilon] = \(-0.5\);\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {{2.5, 5}, {\(-2.5\), 
            5}, {\(-2.5\), \(-5\)}, {2.5, \(-5\)}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = \(-0.01\); nsteps = 2000;\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell[BoxData[
    \(\(postcenter = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[
"This is the unstable spiral associated with \[Epsilon] < 0."], "Text"],

Cell["\<\
\tWe do one last center, unrelated to the sequence we just did.  \
The equations are\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{"2", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], " ", "-", " ", 
            RowBox[{"2", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["y",
                FontSlant->"Italic"]}]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                  ", "\n", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{"4", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], " ", 
            RowBox[{"2", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell["We define the system for DynPac:", "Text"],

Cell[BoxData[
    \(\(parmval = {2, \(-2\), 4, \(-2\)};\)\)], "Input"],

Cell["We classify the system and look at the eigenvalues:", "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell["\<\
This is a center. The motion is periodic with angular frequency 2.  \
We construct the portrait, and we ask for two arrows.\
\>", "Text"],

Cell[BoxData[
    \(\(arrowvec = {1/8, 5/8};\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {{2.5, 0}, {1.5, 0}, {0.5, 0}, {2, 0}, {1, 
            0}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.01; nsteps = 315;\)], "Input"],

Cell[BoxData[
    \(\(center2 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[{
  "\tWe see that rotation is the opposite way for this center.  Is there an \
easy way to tell which way the rotation is going to be?  There are several \
ways.  Perhaps the best is to calculate the curl of the direction field, \
namely ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{"\[PartialD]", "G"}], 
          RowBox[{"\[PartialD]", "x"}]], TraditionalForm]]],
  "- ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{"\[PartialD]", "F"}], 
          RowBox[{"\[PartialD]", "y"}]], TraditionalForm]]],
  ".  If it is positive, then the rotation is counterclockwise.  If it is \
negative, the rotation is clockwise.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saddles", "Subsection"],

Cell["\<\
\tOur final category is saddles --equilibria for which there is one \
negative and one positive eigenvalue.  Our first example is very simple and \
somewhat artificial, but also typical in most ways.\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"        ", 
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox["dx", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", "  ", 
            RowBox[{"-", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}]}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontSlant->"Italic"], " "}]], ",", "\n", 
          "                                                                   \
                                                                              \
                                                                              \
                                                     ", "\n", "      ", 
          RowBox[{
            StyleBox[
              FractionBox["dy", "dt"],
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", " ", 
            RowBox[{"2", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell["\<\
These are very similar to our first node example, and artificial in \
the same way:  the equations are uncoupled and can be solved independently of \
one another.  Nevertheless, they make a useful two-dimensional example.  We \
define the equation for DynPac and then look at the eigenvalues.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-1\), 0, 0, 2};\)\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["\<\
Both eigval and classify2D tell us that this is a saddle point.  We \
get the eigenvectors too.\
\>", "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell[TextData[{
  "Thus the ",
  StyleBox["x-",
    FontSlant->"Italic"],
  "axis goes with the eigenvalue -1, and the ",
  StyleBox["y-",
    FontSlant->"Italic"],
  "axis goes with the eigenvalue 2.  We will see from the phase portrait that \
these are special straight line solutions of the equations.  We construct the \
phase portrait now.  We revert to one arrow.  We use a somewhat different \
technique here.  We integrate both directions in time, starting with initial \
points along the diagonals ",
  StyleBox["y = x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = -",
  StyleBox["x",
    FontSlant->"Italic"],
  ".   We also use range checking and stop the integration as soon as it goes \
out of the box. "
}], "Text"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell[BoxData[
    \(\(rangeflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(bothdirflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(ranger = plrange;\)\)], "Input"],

Cell[BoxData[
    \(\(initlist = {{1.4, 1.4}, {2, 2}, {2.8, 2.8}, {3.5, 3.5}, {\(-1.4\), 
            1.4}, {\(-2\), 2}, {\(-2.8\), 2.8}, {\(-3.5\), 
            3.5}, {\(-1.4\), \(-1.4\)}, {\(-2\), \(-2\)}, {\(-2.8\), \
\(-2.8\)}, {\(-3.5\), \(-3.5\)}, {1.4, \(-1.4\)}, {2, \(-2\)}, {2.8, \
\(-2.8\)}, {3.5, \(-3.5\)}, {5, 0}, {\(-5\), 0}, {0, 
            0.05}, {0, \(-0.05\)}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.01; nsteps = 400;\)], "Input"],

Cell[BoxData[
    \(\(saddle = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[{
  "For every starting point except along the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-axis, the solutions eventually head off to inifinity.  In every \
neighborhood of the origin, there are starting points from which solutions go \
to infinity.  Thus the equilibrium at the origin is unstable.  Solutions \
starting on the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-axis head toward the equilibrium at the origin.  However, such solutions \
are unstable, because the slightest perturbation will knock them off the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-axis onto an orbit which is heading for infinity.  The ",
  StyleBox["x-",
    FontSlant->"Italic"],
  "axis is called the ",
  StyleBox["stable manifold",
    FontSlant->"Italic"],
  " of the saddle point, and the ",
  StyleBox["y",
    FontSlant->"Italic"],
  "-axis is called the ",
  StyleBox["unstable manifold",
    FontSlant->"Italic"],
  " of the saddle point.  These manifolds divide the phase plane into four \
disjoint quadrants.  Because solutions cannot cross, a  solution remains in \
the quadrant in which it starts.    "
}], "Text"],

Cell["\<\
\tWe do one more saddle point, this time for the more typical case \
when the equations are coupled.  Our system is\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", 
          StyleBox[
            RowBox[{"  ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            StyleBox["x",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", " ", 
            RowBox[{"3", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["y",
                FontSlant->"Italic"]}]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                  ", "\n", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{"3", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox["y",
                FontSlant->"Italic"], "  ", "."}]}]}]}], TextForm]], "Text",
  TextAlignment->Center],

Cell["\<\
We define the system for DynPac, and then get the classification, \
the eigenvalues and the eigenvectors.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {1, 3, 3, 1};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell["\<\
Now we construct the phase portrait moving our arrow location to \
the 3/5 point of the orbit.\
\>", "Text"],

Cell[BoxData[
    \(\(arrowvec = {3/5};\)\)], "Input"],

Cell[TextData[{
  "We see that the stable manifold (belonging to eigenvalue -2) is the line \
along {-1,1} -- i.e., ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = -",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  The unstable manifold (belonging to eigenvalue 4) is the line along \
{1,1} -- i.e., ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  Now the picture.  First the initial condition list."
}], "Text"],

Cell[BoxData[
    \(\(initlist = {{1.0, 0}, {2.0, 0}, {3.0, 0}, {4, 0}, {\(-1.0\), 
            0}, {\(-2.0\), 0}, {\(-3.0\), 0}, {\(-4\), 0}, {1, 
            1}, {\(-1\), \(-1\)}, {1, \(-1\)}, {\(-1\), 1}, {0, 1.0}, {0, 
            2.0}, {0, 3}, {0, 
            4}, {0, \(-1.0\)}, {0, \(-2.0\)}, {0, \(-3\)}, {0, \
\(-4\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(saddle2 = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
\tThe previous two saddles are atypical in that the stable and \
unstable manifolds meet at right angles.  Let's look at one last saddle that \
is more typical in that respect.  The equations are\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox["dx", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", 
          StyleBox[
            RowBox[{"  ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            RowBox[{"3", 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "+", 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox[
              RowBox[{"2", "y"}],
              FontSlant->"Italic"]}]}], "  ", ",", "\n", 
        "                                                                     \
                                                                              \
                                                                              \
                                                  ", "\n", "    ", 
        RowBox[{
          StyleBox[
            FractionBox["dy", "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            RowBox[{
              RowBox[{"-", "2"}], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["x",
                FontSlant->"Italic"]}], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], " ", 
            RowBox[{"2", 
              RowBox[{
                StyleBox["y",
                  FontSlant->"Italic"], "  ", "."}]}]}]}]}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell["\<\
We enter the parameters for DynPac, classify the system and then \
get the eigenvalues and eigenvectors.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {3, 2, \(-2\), \(-2\)};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell["\<\
Thus the stable manifold, belongin to the eigenvalue -1, is along \
the vector {-1,2}.  The unstable manifold, belongin to the eigenvalue 2, is \
along the vector {-2,1}.  We first construct a portrait with just these two \
manifolds.  We continue to integrate both directions in time, and we start \
the integrations on these manifolds.\
\>", "Text"],

Cell[BoxData[
    \(\(initlist = {{\(-1\), 2}, {1, \(-2\)}, {2, \(-1\)}, {\(-2\), 
            1}};\)\)], "Input"],

Cell[BoxData[
    \(\(saddle3man = portrait[initlist, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["\<\
With this picture, it is somewhat easier to pick other initial \
conditions to fill in the rest of the picture.\
\>", "Text"],

Cell[BoxData[
    \(\(initlist2 = {{1, 1}, {2, 2}, {3, 3}, {4, 
            4}, {\(-1\), \(-1\)}, {\(-2\), \(-2\)}, {\(-3\), \(-3\)}, \
{\(-4\), \(-4\)}, {2, \(-2\)}, {3, \(-3\)}, {4, \(-4\)}, {\(-2\), 
            2}, {\(-3\), 3}, {\(-4\), 4}};\)\)], "Input"],

Cell[BoxData[
    \(\(saddle3fill = portrait[initlist2, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell["Now we get our final picture with a Show command:", "Text"],

Cell[BoxData[
    \(\(saddle3 = Show[saddle3man, saddle3fill];\)\)], "Input"],

Cell["\<\
\tThis concludes our catalogue.  These pictures are important in \
understanding the behavior of linear systems, and are conceptual building \
blocks for thinking about more complicated nonlinear systems.
\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{763, 546},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 109, 4, 228, "Title"],
Cell[1851, 57, 38, 1, 27, "Input"],
Cell[1892, 60, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1970, 65, 31, 0, 50, "Section"],
Cell[2004, 67, 102, 3, 30, "Text"],
Cell[2109, 72, 1514, 43, 91, "Text"],
Cell[3626, 117, 302, 14, 32, "Text"],
Cell[3931, 133, 360, 12, 32, "Text"],
Cell[4294, 147, 58, 0, 30, "Text"],
Cell[4355, 149, 997, 28, 43, "Text"],
Cell[5355, 179, 198, 11, 32, "Text"],
Cell[5556, 192, 671, 29, 66, "Text"],
Cell[6230, 223, 162, 4, 30, "Text"],
Cell[6395, 229, 1258, 34, 31, "Text"],
Cell[7656, 265, 646, 20, 66, "Text"],
Cell[8305, 287, 2085, 56, 43, "Text"],
Cell[10393, 345, 1080, 22, 112, "Text"],
Cell[11476, 369, 1814, 49, 137, "Text"],
Cell[13293, 420, 114, 5, 50, "Text"],
Cell[13410, 427, 362, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13809, 438, 31, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[13865, 442, 54, 0, 46, "Subsection"],
Cell[13922, 444, 675, 32, 48, "Text"],
Cell[14600, 478, 54, 1, 27, "Input"],
Cell[14657, 481, 317, 14, 32, "Text"],
Cell[14977, 497, 59, 1, 27, "Input"],
Cell[15039, 500, 125, 3, 30, "Text"],
Cell[15167, 505, 112, 3, 30, "Text"],
Cell[15282, 510, 85, 1, 27, "Input"],
Cell[15370, 513, 50, 0, 30, "Text"],
Cell[15423, 515, 59, 1, 27, "Input"],
Cell[15485, 518, 92, 3, 30, "Text"],
Cell[15580, 523, 42, 1, 27, "Input"],
Cell[15625, 526, 301, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15963, 536, 34, 0, 46, "Subsection"],
Cell[16000, 538, 59, 0, 30, "Text"],
Cell[16062, 540, 1401, 40, 91, "Text"],
Cell[17466, 582, 303, 14, 32, "Text"],
Cell[17772, 598, 70, 1, 27, "Input"],
Cell[17845, 601, 183, 4, 46, "Text"],
Cell[18031, 607, 51, 1, 27, "Input"],
Cell[18085, 610, 118, 3, 30, "Text"],
Cell[18206, 615, 47, 1, 27, "Input"],
Cell[18256, 618, 198, 4, 46, "Text"],
Cell[18457, 624, 47, 1, 27, "Input"],
Cell[18507, 627, 133, 3, 30, "Text"],
Cell[18643, 632, 259, 9, 32, "Text"],
Cell[18905, 643, 74, 1, 27, "Input"],
Cell[18982, 646, 45, 0, 30, "Text"],
Cell[19030, 648, 50, 1, 27, "Input"],
Cell[19083, 651, 133, 3, 30, "Text"],
Cell[19219, 656, 54, 1, 27, "Input"],
Cell[19276, 659, 54, 1, 27, "Input"],
Cell[19333, 662, 63, 0, 30, "Text"],
Cell[19399, 664, 43, 1, 27, "Input"],
Cell[19445, 667, 270, 5, 46, "Text"],
Cell[19718, 674, 291, 4, 43, "Input"],
Cell[20012, 680, 170, 4, 30, "Text"],
Cell[20185, 686, 66, 1, 27, "Input"],
Cell[20254, 689, 90, 3, 30, "Text"],
Cell[20347, 694, 85, 1, 27, "Input"],
Cell[20435, 697, 158, 4, 30, "Text"],
Cell[20596, 703, 446, 12, 48, "Text"],
Cell[21045, 717, 1769, 47, 43, "Text"],
Cell[22817, 766, 320, 10, 32, "Text"],
Cell[23140, 778, 1381, 36, 43, "Text"],
Cell[24524, 816, 162, 6, 32, "Text"],
Cell[24689, 824, 103, 3, 30, "Text"],
Cell[24795, 829, 1896, 53, 91, "Text"],
Cell[26694, 884, 55, 0, 30, "Text"],
Cell[26752, 886, 75, 1, 27, "Input"],
Cell[26830, 889, 43, 0, 30, "Text"],
Cell[26876, 891, 51, 1, 27, "Input"],
Cell[26930, 894, 103, 3, 30, "Text"],
Cell[27036, 899, 47, 1, 27, "Input"],
Cell[27086, 902, 198, 4, 46, "Text"],
Cell[27287, 908, 47, 1, 27, "Input"],
Cell[27337, 911, 457, 7, 62, "Text"],
Cell[27797, 920, 261, 4, 43, "Input"],
Cell[28061, 926, 85, 1, 27, "Input"],
Cell[28149, 929, 191, 4, 46, "Text"],
Cell[28343, 935, 76, 0, 30, "Text"],
Cell[28422, 937, 1775, 51, 91, "Text"],
Cell[30200, 990, 70, 1, 27, "Input"],
Cell[30273, 993, 51, 1, 27, "Input"],
Cell[30327, 996, 47, 1, 27, "Input"],
Cell[30377, 999, 531, 8, 78, "Text"],
Cell[30911, 1009, 71, 1, 27, "Input"],
Cell[30985, 1012, 57, 0, 30, "Text"],
Cell[31045, 1014, 215, 3, 43, "Input"],
Cell[31263, 1019, 85, 1, 27, "Input"],
Cell[31351, 1022, 130, 3, 30, "Text"],
Cell[31484, 1027, 72, 0, 30, "Text"],
Cell[31559, 1029, 1732, 48, 91, "Text"],
Cell[33294, 1079, 44, 0, 30, "Text"],
Cell[33341, 1081, 65, 1, 27, "Input"],
Cell[33409, 1084, 91, 3, 30, "Text"],
Cell[33503, 1089, 51, 1, 27, "Input"],
Cell[33557, 1092, 47, 1, 27, "Input"],
Cell[33607, 1095, 47, 1, 27, "Input"],
Cell[33657, 1098, 913, 17, 96, "Text"],
Cell[34573, 1117, 553, 14, 64, "Text"],
Cell[35129, 1133, 129, 2, 27, "Input"],
Cell[35261, 1137, 216, 4, 46, "Text"],
Cell[35480, 1143, 261, 4, 43, "Input"],
Cell[35744, 1149, 85, 1, 27, "Input"],
Cell[35832, 1152, 143, 3, 30, "Text"],
Cell[35978, 1157, 131, 3, 30, "Text"],
Cell[36112, 1162, 1435, 40, 91, "Text"],
Cell[37550, 1204, 44, 0, 30, "Text"],
Cell[37597, 1206, 70, 1, 27, "Input"],
Cell[37670, 1209, 496, 16, 48, "Text"],
Cell[38169, 1227, 51, 1, 27, "Input"],
Cell[38223, 1230, 47, 1, 27, "Input"],
Cell[38273, 1233, 298, 9, 32, "Text"],
Cell[38574, 1244, 121, 2, 27, "Input"],
Cell[38698, 1248, 253, 7, 48, "Text"],
Cell[38954, 1257, 291, 4, 43, "Input"],
Cell[39248, 1263, 155, 5, 32, "Text"],
Cell[39406, 1270, 66, 1, 27, "Input"],
Cell[39475, 1273, 85, 1, 27, "Input"],
Cell[39563, 1276, 226, 4, 46, "Text"],
Cell[39792, 1282, 389, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40218, 1293, 29, 0, 46, "Subsection"],
Cell[40250, 1295, 56, 0, 30, "Text"],
Cell[40309, 1297, 1723, 49, 91, "Text"],
Cell[42035, 1348, 71, 0, 30, "Text"],
Cell[42109, 1350, 75, 1, 27, "Input"],
Cell[42187, 1353, 51, 1, 27, "Input"],
Cell[42241, 1356, 61, 0, 30, "Text"],
Cell[42305, 1358, 47, 1, 27, "Input"],
Cell[42355, 1361, 49, 0, 30, "Text"],
Cell[42407, 1363, 47, 1, 27, "Input"],
Cell[42457, 1366, 266, 5, 46, "Text"],
Cell[42726, 1373, 112, 2, 27, "Input"],
Cell[42841, 1377, 114, 2, 27, "Input"],
Cell[42958, 1381, 115, 3, 30, "Text"],
Cell[43076, 1386, 79, 1, 27, "Input"],
Cell[43158, 1389, 106, 3, 30, "Text"],
Cell[43267, 1394, 80, 1, 27, "Input"],
Cell[43350, 1397, 171, 4, 46, "Text"],
Cell[43524, 1403, 171, 2, 43, "Input"],
Cell[43698, 1407, 87, 1, 27, "Input"],
Cell[43788, 1410, 107, 3, 30, "Text"],
Cell[43898, 1415, 1663, 48, 91, "Text"],
Cell[45564, 1465, 516, 8, 78, "Text"],
Cell[46083, 1475, 65, 1, 27, "Input"],
Cell[46151, 1478, 47, 1, 27, "Input"],
Cell[46201, 1481, 60, 0, 30, "Text"],
Cell[46264, 1483, 47, 1, 27, "Input"],
Cell[46314, 1486, 74, 0, 30, "Text"],
Cell[46391, 1488, 171, 2, 43, "Input"],
Cell[46565, 1492, 149, 3, 30, "Text"],
Cell[46717, 1497, 71, 1, 27, "Input"],
Cell[46791, 1500, 87, 1, 27, "Input"],
Cell[46881, 1503, 89, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47007, 1511, 29, 0, 46, "Subsection"],
Cell[47039, 1513, 886, 22, 82, "Text"],
Cell[47928, 1537, 1326, 37, 91, "Text"],
Cell[49257, 1576, 317, 12, 32, "Text"],
Cell[49577, 1590, 50, 1, 27, "Input"],
Cell[49630, 1593, 79, 1, 27, "Input"],
Cell[49712, 1596, 136, 2, 30, "Text"],
Cell[49851, 1600, 69, 1, 27, "Input"],
Cell[49923, 1603, 47, 1, 27, "Input"],
Cell[49973, 1606, 69, 1, 27, "Input"],
Cell[50045, 1609, 47, 1, 27, "Input"],
Cell[50095, 1612, 74, 1, 27, "Input"],
Cell[50172, 1615, 47, 1, 27, "Input"],
Cell[50222, 1618, 543, 7, 78, "Text"],
Cell[50768, 1627, 120, 2, 27, "Input"],
Cell[50891, 1631, 67, 1, 27, "Input"],
Cell[50961, 1634, 54, 1, 27, "Input"],
Cell[51018, 1637, 89, 1, 27, "Input"],
Cell[51110, 1640, 102, 2, 30, "Text"],
Cell[51215, 1644, 54, 1, 27, "Input"],
Cell[51272, 1647, 89, 1, 27, "Input"],
Cell[51364, 1650, 66, 1, 27, "Input"],
Cell[51433, 1653, 141, 3, 30, "Text"],
Cell[51577, 1658, 59, 1, 27, "Input"],
Cell[51639, 1661, 86, 1, 27, "Input"],
Cell[51728, 1664, 164, 2, 30, "Text"],
Cell[51895, 1668, 59, 1, 27, "Input"],
Cell[51957, 1671, 122, 2, 27, "Input"],
Cell[52082, 1675, 72, 1, 27, "Input"],
Cell[52157, 1678, 54, 1, 27, "Input"],
Cell[52214, 1681, 90, 1, 27, "Input"],
Cell[52307, 1684, 86, 1, 30, "Text"],
Cell[52396, 1687, 108, 3, 30, "Text"],
Cell[52507, 1692, 1645, 47, 91, "Text"],
Cell[54155, 1741, 48, 0, 30, "Text"],
Cell[54206, 1743, 70, 1, 27, "Input"],
Cell[54279, 1746, 67, 0, 30, "Text"],
Cell[54349, 1748, 51, 1, 27, "Input"],
Cell[54403, 1751, 47, 1, 27, "Input"],
Cell[54453, 1754, 147, 3, 30, "Text"],
Cell[54603, 1759, 59, 1, 27, "Input"],
Cell[54665, 1762, 108, 2, 27, "Input"],
Cell[54776, 1766, 66, 1, 27, "Input"],
Cell[54845, 1769, 87, 1, 27, "Input"],
Cell[54935, 1772, 699, 18, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55671, 1795, 29, 0, 46, "Subsection"],
Cell[55703, 1797, 223, 4, 46, "Text"],
Cell[55929, 1803, 1310, 36, 91, "Text"],
Cell[57242, 1841, 316, 5, 46, "Text"],
Cell[57561, 1848, 65, 1, 27, "Input"],
Cell[57629, 1851, 47, 1, 27, "Input"],
Cell[57679, 1854, 51, 1, 27, "Input"],
Cell[57733, 1857, 119, 3, 30, "Text"],
Cell[57855, 1862, 47, 1, 27, "Input"],
Cell[57905, 1865, 770, 22, 82, "Text"],
Cell[58678, 1889, 54, 1, 27, "Input"],
Cell[58735, 1892, 54, 1, 27, "Input"],
Cell[58792, 1895, 60, 1, 27, "Input"],
Cell[58855, 1898, 54, 1, 27, "Input"],
Cell[58912, 1901, 396, 6, 59, "Input"],
Cell[59311, 1909, 66, 1, 27, "Input"],
Cell[59380, 1912, 86, 1, 27, "Input"],
Cell[59469, 1915, 1141, 29, 118, "Text"],
Cell[60613, 1946, 139, 3, 30, "Text"],
Cell[60755, 1951, 1672, 48, 91, "Text"],
Cell[62430, 2001, 129, 3, 30, "Text"],
Cell[62562, 2006, 60, 1, 27, "Input"],
Cell[62625, 2009, 51, 1, 27, "Input"],
Cell[62679, 2012, 47, 1, 27, "Input"],
Cell[62729, 2015, 47, 1, 27, "Input"],
Cell[62779, 2018, 118, 3, 30, "Text"],
Cell[62900, 2023, 54, 1, 27, "Input"],
Cell[62957, 2026, 470, 16, 50, "Text"],
Cell[63430, 2044, 343, 6, 59, "Input"],
Cell[63776, 2052, 87, 1, 27, "Input"],
Cell[63866, 2055, 219, 4, 46, "Text"],
Cell[64088, 2061, 1707, 50, 91, "Text"],
Cell[65798, 2113, 128, 3, 30, "Text"],
Cell[65929, 2118, 70, 1, 27, "Input"],
Cell[66002, 2121, 51, 1, 27, "Input"],
Cell[66056, 2124, 47, 1, 27, "Input"],
Cell[66106, 2127, 361, 6, 62, "Text"],
Cell[66470, 2135, 114, 2, 27, "Input"],
Cell[66587, 2139, 90, 1, 27, "Input"],
Cell[66680, 2142, 135, 3, 30, "Text"],
Cell[66818, 2147, 260, 4, 43, "Input"],
Cell[67081, 2153, 92, 1, 27, "Input"],
Cell[67176, 2156, 65, 0, 30, "Text"],
Cell[67244, 2158, 77, 1, 27, "Input"],
Cell[67324, 2161, 229, 5, 62, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

