(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     55241,       2131]*)
(*NotebookOutlinePosition[     81478,       2991]*)
(*  CellTagsIndexPosition[     81434,       2987]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Using Eigenvector Methods with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to Solve Linear Autonomous Systems of First Order Differential Equations \
"
}], "Title"],

Cell[CellGroupData[{

Cell["1.  Introduction", "SectionFirst"],

Cell[TextData[{
  "\tIn this notebook, we use the methods of linear algebra -- specifically \
eigenvector and eigenvalue analysis -- to solve systems of linear autonomous \
ordinary differential equations.  Although the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " routines DSolve and NDSolve could be used to attack these problems \
directly, we do not use them here.  Our purpose is to make clear the \
underlying linear algebra, and to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to do all of the calculations.  The canonical problem under consideration \
is the following:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Plain"], "."], " "}], TraditionalForm]]],
  "= ",
  StyleBox["AX + b ",
    FontWeight->"Bold"],
  " ,"
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "  ",
  StyleBox["X",
    FontWeight->"Bold"],
  "(0) = ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"], TraditionalForm]]],
  " ,"
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is a constant ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x ",
  StyleBox["n",
    FontSlant->"Italic"],
  " matrix, ",
  StyleBox["b ",
    FontWeight->"Bold"],
  "is a constant ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x 1 vector, and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"], TraditionalForm]]],
  ", the initial vector, is a given ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x 1 vector."
}], "Text"],

Cell[TextData[{
  "\tThe general approach to this problem is the following.  We first find a \
particular solution, which is defined to be any solution of equation (1).  We \
call the particular solution ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Plain"], "p"],
          FontSlant->"Italic"], TraditionalForm]]],
  ".  The general solution ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "g"], TraditionalForm]]],
  "of the equation is then  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], " "}], TraditionalForm]]],
  "=  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "h"], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Plain"], "p"],
          FontSlant->"Italic"], TraditionalForm]]],
  " , "
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "h"], TraditionalForm]]],
  "is the most general solution of the homogeneous equation: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          OverscriptBox[
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Plain"], "."], "h"], TraditionalForm]]],
  " = ",
  StyleBox["A",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "h"], TraditionalForm]]],
  " ."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "\tThe homogenous equation (4) has ",
  StyleBox["n",
    FontSlant->"Italic"],
  " linearly independent solutions.  We call them ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((1)\)], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((2)\)], TraditionalForm]]],
  ", . . . ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((n)\)], TraditionalForm]]],
  ".  The most general ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "h"], TraditionalForm]]],
  " is a linear combination of these.  To solve the initial-value problem, we \
form the general solution ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "g"], TraditionalForm]]],
  "in terms of ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "constants ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ", . . . , ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "g"], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "p"], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((1)\)], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((2)\)], TraditionalForm]]],
  " + . . . + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((n)\)], TraditionalForm]]],
  "."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "We now impose the initial condition (2) on the solution (5).  This gives \
the following set of linear equations to solve for the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((1)\)], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((2)\)], TraditionalForm]]],
  " + . . . + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((n)\)], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "0"], TraditionalForm]]],
  " - ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Plain"], "p"],
          FontSlant->"Italic"], TraditionalForm]]],
  " at ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "The linear independence of the vectors ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((i)\)], TraditionalForm]]],
  " guarantees that the matrix in the above equations is nonsingular and \
hence the solution for the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "is unique.  "
}], "Text"],

Cell[TextData[{
  "\tThe rest of this notebook provides the details in carrying this out, and \
shows how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to advantage at each step.  We will begin with a brief review of matrix \
manipulations in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  Then we will consider the problem of finding the particular solution.  \
After that, we will solve the homogeneous equation, in the following sequence \
of cases of increasing difficulty:  distinct real eigenvalues; distinct \
complex eigenvalues; repeated eigenvalues.  Detailed examples will be done at \
each step."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Basic Matrix Manipulations in Mathematica", "SectionFirst"],

Cell[TextData[{
  "\tIn ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", a matrix is a list of lists.  Each component list is a row of the \
matrix.  As an example, we define a matrix named A for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and then use MatrixForm to print it out in traditional form."
}], "Text"],

Cell[BoxData[
    \(\(A = {{1, \(-2\), 3}, {\(-2\), \(-1\), 4}, {3, 4, 5}};\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(MatrixForm[A]\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
One way to find out whether  A is singular is to compute the \
determinant.\
\>", "Text"],

Cell[BoxData[
    \(Det[A]\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Because the determinant is not zero, A is not singular, and thus \
has an inverse.\
\>", "Text"],

Cell[BoxData[
    \(B = Inverse[A]\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
We check the inverse by forming the product of A and the inverse of \
A.  The product should be the identity matrix.  Matrix products are indicated \
by a period.\
\>", "Text"],

Cell[BoxData[
    \(A . B\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(B . A\)], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
\tWe can use this inverse to solve a set of linear algebraic \
equations in which A is the coefficient matrix.  Consider the equations \
\
\>", "Text"],

Cell[TextData[{
  "x",
  StyleBox[" - 2",
    FontSlant->"Plain"],
  "y",
  StyleBox[" + 3",
    FontSlant->"Plain"],
  "z",
  StyleBox[" = 1 ,\n\n-2",
    FontSlant->"Plain"],
  "x",
  StyleBox[" -",
    FontSlant->"Plain"],
  "y",
  StyleBox[" +4",
    FontSlant->"Plain"],
  "z ",
  StyleBox["= 0 ,\n\n3",
    FontSlant->"Plain"],
  "x",
  StyleBox[" +4",
    FontSlant->"Plain"],
  "y",
  StyleBox[" +5",
    FontSlant->"Plain"],
  "z",
  StyleBox[" = -1.\n",
    FontSlant->"Plain"]
}], "NumberedEquation",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell["\<\
The coefficient matrix is the matrix A, and the right-hand side is \
the vector \
\>", "Text"],

Cell[BoxData[
    \(\(b = {1, 0, \(-1\)};\)\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
We can use the inverse we have already calculated to solve these \
equations.  We call the solution sol.\
\>", "Text"],

Cell[BoxData[
    \(sol = B . b\)], "Input",
  CellLabel->"In[8]:="],

Cell["We check this:", "Text"],

Cell[BoxData[
    \(A . sol - b\)], "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  "\tAn alternative method of solution is to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s LinearSolve."
}], "Text"],

Cell[BoxData[
    \(sol2 = LinearSolve[A, b]\)], "Input",
  CellLabel->"In[10]:="],

Cell["We get the same result.", "Text"],

Cell[TextData[{
  "\tIn the above calculations, all the elements of A were integers, so ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " did an exact calculation.  If one or more elements of A are written as \
real numbers, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will do a numerical rather than exact calculation. "
}], "Text"],

Cell[BoxData[
    \(\(Amod = {{1. , \(-2\), 3}, {\(-2\), \(-1\), 4}, {3, 4, 
            5}};\)\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Inverse[Amod]\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
\tFor the present calculations, it doesn't matter much which way we \
do them.  For larger matrices and more difficult calculations, such as \
eigenanalysis, it is crucial to do the calculations numerically.  We shall \
see an example of this shortly.\
\>", "Text"],

Cell[TextData[{
  "\tThe determination of eigenvalues and eigenvectors is the central linear \
algebra calculation for solving systems of first-order linear autonomous \
differential equations.  Given a square matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  ", we say that a non-zero vector ",
  StyleBox["c",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "is an eigenvector of ",
  StyleBox["A",
    FontWeight->"Bold"],
  " with eigenvalue \[Lambda] if ",
  StyleBox["Ac",
    FontWeight->"Bold"],
  " = \[Lambda]",
  StyleBox["c",
    FontWeight->"Bold"],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a lot of built-in power to find eigenvectors and eigenvalues.  We go \
back to our matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find its eigenvalue. "
}], "Text"],

Cell[BoxData[
    \(eigvals = Eigenvalues[A]\)], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[{
  "We are getting a graphic reminder about the difference between numerical \
and exact.  Would you guess from the above expression that the eigenvalues of \
",
  StyleBox["A",
    FontWeight->"Bold"],
  " are real?  Because ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is symmetric it must have real eigenvalues.  Let's evaluate the above \
numerically."
}], "Text"],

Cell[BoxData[
    \(N[eigvals]\)], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  "We see that they are real, plus a tiny imaginary part due to numerical \
error.  It is much easier just to get the eigenvalues numerically in the \
first place by using the modified form ",
  StyleBox["Amod",
    FontWeight->"Bold"],
  ", which contains a real number among its entries",
  "."
}], "Text"],

Cell[BoxData[
    \(eigvals = Eigenvalues[Amod]\)], "Input",
  CellLabel->"In[15]:="],

Cell[TextData[{
  "The eigenvectors are also easy to get.  The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command is Eigenvectors."
}], "Text"],

Cell[BoxData[
    \(Eigenvectors[Amod]\)], "Input",
  CellLabel->"In[16]:="],

Cell["To get all of this information at once, we use Eigensystem.", "Text"],

Cell[BoxData[
    \(Eigensystem[Amod]\)], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
Let's repeat this command and assign the eigenvalues to the symbols \
\[Lambda]1, \[Lambda]2, \[Lambda]3, and the eigenvectors to the symbols v1, \
v2, v3.\
\>", "Text"],

Cell[BoxData[
    \({{\[Lambda]1, \[Lambda]2, \[Lambda]3}, {v1, v2, v3}} = 
      Eigensystem[Amod]\)], "Input",
  CellLabel->"In[18]:="],

Cell["We sample these assignments:", "Text"],

Cell[BoxData[
    \(\[Lambda]1\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(v1\)], "Input",
  CellLabel->"In[20]:="],

Cell["Let's check that these eigenvectors and eigenvalues work.", "Text"],

Cell[BoxData[
    \(Amod . v1 - \[Lambda]1*v1\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(Amod . v2 - \[Lambda]2*v2\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(Amod . v3 - \[Lambda]3*v3\)], "Input",
  CellLabel->"In[23]:="],

Cell["Close enough!\t", "Text"],

Cell[TextData[{
  "\tThere are three other ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " matrix commands which are useful in the present context.  The first is \
MatrixPower, which raises a matrix to an integer power.  For example, the \
command below raises the matrix Amod to the third power."
}], "Text"],

Cell[BoxData[
    \(Amod3 = MatrixPower[Amod, 3]\)], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
As a check, we can verify that Amod3 has the same eigenvectors as \
Amod, but with the eigenvalues cubed.  We do this for v1 and \
\[Lambda]1.\
\>", "Text"],

Cell[BoxData[
    \(Amod3 . v1 - \((\[Lambda]1)\)^3.  v1\)], "Input",
  CellLabel->"In[25]:="],

Cell[TextData[{
  "\tThe second command is NullSpace.  If a matrix ",
  StyleBox["M",
    FontWeight->"Bold"],
  " is singular, then there are some vectors ",
  StyleBox["v",
    FontWeight->"Bold"],
  " for which ",
  StyleBox["M.v",
    FontWeight->"Bold"],
  " = 0.  The set of all set vectors is a vector space, and it is called the \
nullspace of ",
  StyleBox["M",
    FontWeight->"Bold"],
  ".  An alternative way of expressing this:  the nullspace of ",
  StyleBox["M",
    FontWeight->"Bold"],
  " is the set of all solutions of the homogeneous equations ",
  StyleBox["M",
    FontWeight->"Bold"],
  ".",
  StyleBox["v",
    FontWeight->"Bold"],
  " = 0.  The command NullSpace[M] returns a basis for the nullspace.  For \
example,"
}], "Text"],

Cell[BoxData[
    \(NullSpace[Amod]\)], "Input",
  CellLabel->"In[26]:="],

Cell[TextData[{
  "Because ",
  StyleBox["Amod ",
    FontWeight->"Bold"],
  "is not singular, there are no vectors in the nullspace other than the zero \
vector.  A more interesting example follows.  In solving the eigenvalue \
problem ",
  StyleBox["Ac",
    FontWeight->"Bold"],
  " = \[Lambda]",
  StyleBox["c",
    FontWeight->"Bold"],
  ", one can rewrite it as (",
  StyleBox["A",
    FontWeight->"Bold"],
  " - \[Lambda]",
  StyleBox["I",
    FontWeight->"Bold"],
  ")",
  StyleBox["c",
    FontWeight->"Bold"],
  " = 0, where ",
  StyleBox["I",
    FontWeight->"Bold"],
  " is the identity matrix.  Thus the matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " - \[Lambda]",
  StyleBox["I ",
    FontWeight->"Bold"],
  "is singular and has a non-trivial nullspace.  In fact the nullspace is the \
eigenvector associated with \[Lambda].  Let's try that.  We define the \
identity matrix first, using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function IdentityMatrix[n], which gives the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x ",
  StyleBox["n",
    FontSlant->"Italic"],
  " identity matrix."
}], "Text"],

Cell[BoxData[
    \(Id = IdentityMatrix[3]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(NullSpace[Amod - \[Lambda]1*Id]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(v1\)], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
Apart from a non-essential minus sign, we get the same thing, as we \
must.\
\>", "Text"],

Cell[TextData[{
  "\tThe third command is CharacteristicPolynomial, which returns the \
polynomial Det[",
  StyleBox["A",
    FontWeight->"Bold"],
  " - \[Lambda]",
  StyleBox["I",
    FontWeight->"Bold"],
  "] .  The roots of this polynomial are the eigenvalues of ",
  StyleBox["A",
    FontWeight->"Bold"],
  ".  Let's try it."
}], "Text"],

Cell[BoxData[
    \(poly = CharacteristicPolynomial[Amod, \[Lambda]]\)], "Input",
  CellLabel->"In[30]:="],

Cell[TextData[{
  "It is convenient that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has returned the polynomial in factored form, from which we see that the \
roots are indeed the eigenvalues  calculated earlier.  We also could \
accomplish all of this \"by hand\" in the following way."
}], "Text"],

Cell[BoxData[
    \(poly2 = Det[Amod - \[Lambda]\ *\ Id]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(Solve[poly2 \[Equal] 0, \[Lambda]]\)], "Input",
  CellLabel->"In[32]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  Finding the Particular Solution", "SectionFirst"],

Cell[TextData[{
  "\tWe seek any particular solution of equation (1) -- the simpler the \
better.  Nothing could be simpler than an equilbrium solution (i.e, ",
  StyleBox["X",
    FontWeight->"Bold"],
  " = constant), so we look for one, and we find that if the matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is nonsingular, then "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "p"], TraditionalForm]]],
  "= -",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["A",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  StyleBox["b  ",
    FontWeight->"Bold"],
  "."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "which is an equilibrium solution.  If ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is singular, equation (8) is not a valid solution, and the situation is \
more complicated.  It turns out that there may or may not be an equilibrium \
solution, depending on both ",
  StyleBox["A",
    FontWeight->"Bold"],
  " and ",
  StyleBox["b",
    FontWeight->"Bold"],
  ".  Of course there is always a particular solution, whether or not there \
is an equilibrium solution.  It is an interesting excursion into linear \
algebra to sort all of this out, but it would be a distraction for us, \
because our main purpose here is to develop the tools for stability analysis, \
and it is the homogeneous equation that provides what we need.  We will not \
consider any further the case of singular ",
  StyleBox["A",
    FontWeight->"Bold"],
  " here.  We just note that in all cases, one can always find a particular \
solution in the form of a vector with components which are polynomials in ",
  StyleBox["t.  ",
    FontSlant->"Italic"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.  Solving the Homogeneous Equation", "SectionFirst"],

Cell[CellGroupData[{

Cell["4.1 Basic Concepts", "Subsection"],

Cell["\<\
\tWe attack the homogeneous equation (4), using the basic theory of \
eigenvalues and eigenvectors.  Because the equation is homogeneous and \
constant coefficient, we would guess from our experience in elementary \
differential equations that there will be solutions of the form\
\>", "Text"],

Cell[TextData[{
  StyleBox["X",
    FontWeight->"Bold"],
  "  ",
  "=  ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\[Lambda]t\)]],
  StyleBox["c ",
    FontWeight->"Bold"],
  ","
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where the constant \[Lambda] and the constant vector ",
  StyleBox["c",
    FontWeight->"Bold"],
  " are to be determined.  We substitute this form into equation (4) to get"
}], "Text"],

Cell[TextData[{
  StyleBox["Ac  ",
    FontWeight->"Bold"],
  "=  \[Lambda]",
  StyleBox["c",
    FontWeight->"Bold"],
  " ,"
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "which is the matrix eigenvalue problem for ",
  StyleBox["A",
    FontWeight->"Bold"],
  ".  As we noted earlier, the condtion for (11) to have a nontrivial \
solution is that"
}], "Text"],

Cell[TextData[{
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) = 0 ,  where ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) = det(",
  StyleBox["A",
    FontWeight->"Bold"],
  StyleBox[" -",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "\[Lambda]",
  StyleBox["I)  ",
    FontWeight->"Bold"],
  "."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Here ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) is the characteristic polynomial and is of degree ",
  StyleBox["n, ",
    FontSlant->"Italic"],
  "where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the order of the system (i.e., ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x 1).  Thus ",
  StyleBox["p",
    FontSlant->"Italic"],
  " will have ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "roots.  For each root \[Lambda], we can generate a solution of the form \
(10).  We need ",
  StyleBox["n",
    FontSlant->"Italic"],
  " such linearly independent solutions for a solution basis of (4), and this \
is consistent with the fact that ",
  StyleBox["p",
    FontSlant->"Italic"],
  " has ",
  StyleBox["n",
    FontSlant->"Italic"],
  " roots.  Although this all does work, there are complications.  In the \
simplest case, ",
  StyleBox["p",
    FontSlant->"Italic"],
  " has ",
  StyleBox["n",
    FontSlant->"Italic"],
  " distinct real roots, and thus ",
  StyleBox["n",
    FontSlant->"Italic"],
  " independent solutions of the form (10). This case is dealt with in \
section 4.2 below. Complex roots present a minor difficulty, mainly because \
in general we seek real-valued solutions of these real equations.  It is not \
hard to convert the complex roots into real solutions, and this is done in \
section 4.3 below. The most troublesome case is that of repeated roots.  This \
requires the introduction of the concept of generalized eigenvectors.  This \
is done in section 4.4, and some practical computational tools are given \
there also.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Real Distinct Eigenvalues", "Subsection"],

Cell[TextData[{
  "\tThis case is straightforward.  By assumption, the eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  ", . . . , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  "are real and distinct, and the associated eigenvectors are also real.  \
Each pair (\[Lambda],",
  StyleBox["c",
    FontWeight->"Bold"],
  ")",
  " gives rise to a real solution of the form (10).  The general solution of \
the the homogeneous equation (4) is then"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["X",
            FontWeight->"Bold",
            FontSlant->"Plain"], "h"], TraditionalForm]]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((1)\)], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(\[Lambda]\_1\) t\)\)]],
  " +  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((2)\)], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(\[Lambda]\_2\) t\)\)]],
  " + . . . + ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((n)\)], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(\[Lambda]\_n\) t\)\)]],
  " .   "
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "The only possible remaining question is whether the solutions ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((i)\)], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(\[Lambda]\_i\) t\)\)]],
  " are linearly independent.  For simplicity in writing, let ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(\[Lambda]\_i\) t\)\)]],
  ".  Then if the solutions are linearly dependent, we must have"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["c",
              FontSlant->"Plain"], 
            RowBox[{"(", 
              StyleBox["1",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]],
          FontWeight->"Bold"], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`b\_2\)]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["c",
              FontSlant->"Plain"], 
            RowBox[{"(", 
              StyleBox["2",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]],
          FontWeight->"Bold"], TraditionalForm]]],
  "+ . . . + ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["c",
              FontSlant->"Plain"], 
            RowBox[{"(", 
              StyleBox["n",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]],
          FontWeight->"Bold"], TraditionalForm]]],
  "= 0"
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "for not all ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  "= 0.  Operate on the above equation with the matrix"
}], "Text"],

Cell[TextData[{
  "(",
  StyleBox["A",
    FontWeight->"Bold"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  StyleBox["I",
    FontWeight->"Bold"],
  ")",
  "(",
  StyleBox["A",
    FontWeight->"Bold"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_3\)]],
  StyleBox["I",
    FontWeight->"Bold"],
  "). . . ",
  "(",
  StyleBox["A",
    FontWeight->"Bold"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  StyleBox["I",
    FontWeight->"Bold"],
  ") ."
}], "NumberedEquation",
  TextAlignment->Center],

Cell["The result is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_2\)]],
  ")(",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_3\)]],
  "). . .(",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  ")",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((1)\)], TraditionalForm]]],
  "= 0 ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Because the eigenvalues are distinct and because ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((1)\)], TraditionalForm]]],
  "\[NotEqual] 0, it follows that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  "= 0.  In the same way, one shows that all ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "= 0.  Hence only the trivial combination vanishes, and the solutions ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], \((i)\)], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(\[Lambda]\_i\) t\)\)]],
  "are linearly independent.   "
}], "Text"],

Cell[TextData[{
  "\tConsider an example.  We use our earlier matrix ",
  StyleBox["Amod.",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
    \(MatrixForm[Amod]\)], "Input",
  CellLabel->"In[33]:="],

Cell[TextData[{
  "\nWe solve the system (1) with ",
  StyleBox["A",
    FontWeight->"Bold"],
  " = ",
  StyleBox["Amod",
    FontWeight->"Bold"],
  ", and "
}], "Text"],

Cell[BoxData[
    \(\(b = {\(-3\), 4, \(-5\)};\)\)], "Input",
  CellLabel->"In[34]:="],

Cell["We will impose the initial condition", "Text"],

Cell[BoxData[
    \(\(X0 = {1, 1, 1};\)\)], "Input",
  CellLabel->"In[35]:="],

Cell["We start by finding the particular solution.", "Text"],

Cell[BoxData[
    \(Xp = \(-Inverse[Amod] . b\)\)], "Input",
  CellLabel->"In[36]:="],

Cell[TextData[{
  "We check the eigenvalues of ",
  StyleBox["Amod ",
    FontWeight->"Bold"],
  "to see if they are distinct."
}], "Text"],

Cell[BoxData[
    \(Eigenvalues[Amod]\)], "Input",
  CellLabel->"In[37]:="],

Cell["\<\
They are distinct.  Now we find the eigenvectors, and name the \
eigenvalues and eigenvectors:\
\>", "Text"],

Cell[BoxData[
    \({{\[Lambda]1, \[Lambda]2, \[Lambda]3}, {v1, v2, v3}} = 
      Eigensystem[Amod]\)], "Input",
  CellLabel->"In[38]:="],

Cell["We form the homogeneous solution.", "Text"],

Cell[BoxData[
    \(Xh = 
      a1*v1*Exp[\[Lambda]1*t] + a2*v2*Exp[\[Lambda]2*t] + 
        a3*v3*Exp[\[Lambda]3*t]\)], "Input",
  CellLabel->"In[39]:="],

Cell[TextData[{
  "The general solution is the sum of ",
  StyleBox["Xh",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Xp",
    FontWeight->"Bold"],
  ".  We impose the initial conditions on the general solution to determine \
the values of the constants ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(coeff = 
      Solve[\((\((Xh + Xp)\) /. t \[Rule] 0)\) \[Equal] X0, {a1, a2, 
          a3}]\)], "Input",
  CellLabel->"In[40]:="],

Cell["\<\
Now we use a replacement operation to put these values into the \
formula and thereby generate the solution, which we call Xsole.\
\>", "Text"],

Cell[BoxData[
    \(Xsole = \((Xh + Xp)\) /. Thread[Flatten[coeff]]\)], "Input",
  CellLabel->"In[41]:="],

Cell["Let's check it.", "Text"],

Cell[BoxData[
    \(Simplify[D[Xsole, t] - Amod . Xsole - b]\)], "Input",
  CellLabel->"In[42]:="],

Cell["\<\
We see very small residuals associated with numerical error, but \
they are essentially zero.  Now the initial condition:\
\>", "Text"],

Cell[BoxData[
    \(\((Xsole /. t \[Rule] 0)\) - X0\)], "Input",
  CellLabel->"In[43]:="],

Cell["This checks.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3 Distinct Complex Eigenvalues", "Subsection"],

Cell[TextData[{
  "\tIf \[Lambda] is a complex eigenvalue, then the eigenvector ",
  StyleBox["c",
    FontWeight->"Bold"],
  " will be complex, and the solution ",
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  StyleBox["c",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`e\^\[Lambda]t\)]],
  "is complex-valued.  If we don't mind having complex valued solutions in \
our solutions basis, then the solution obtained in the above section  works \
just as well for distinct complex eigenvalues.  However, we generally prefer \
a real-valued solution basis for our real equations.  In this section, we see \
how to obtain such a basis."
}], "Text"],

Cell[TextData[{
  "\tBecause the coefficient matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " is real, it follows that if ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is a complex-valued solution of equation (4), then both the real and \
imaginary parts of ",
  StyleBox["X",
    FontWeight->"Bold"],
  " are also solutions.  In this way, we can generate two real-valued \
solutions from a pair of complex conjugate eigenvalues.  The separation of a \
complex valued solution into real and imaginary parts requires a few special \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands and options.  The best way to see how all of this is done is to \
work through an example in detail.  We consider equation (4) with   "
}], "Text"],

Cell[BoxData[
    \(\(A = {{8, 3, 15}, {0, \(-1\), 
            0}, {\(-3\), \(-3\), \(-4\)}};\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[TextData[{
  "We check the eigenvalues of ",
  StyleBox["A",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input",
  CellLabel->"In[45]:="],

Cell["\<\
We have three distinct eigenvalues, with two of them being complex. \
 We construct the eigenvectors, and name the eigenvalues and \
eigenvectors.\
\>", "Text"],

Cell[BoxData[
    \({{\[Lambda]1, \[Lambda]2, \[Lambda]3}, {v1, v2, v3}} = 
      Eigensystem[A]\)], "Input",
  CellLabel->"In[46]:="],

Cell["The real-valued solution is", "Text"],

Cell[BoxData[
    \(X1 = v1*Exp[\[Lambda]1*t]\)], "Input",
  CellLabel->"In[47]:="],

Cell["The first complex-valued solution is", "Text"],

Cell[BoxData[
    \(C2 = v2*Exp[\[Lambda]2*t]\)], "Input",
  CellLabel->"In[48]:="],

Cell[TextData[{
  "Now we will parlay this into two real-valued solutions, by taking the real \
and imaginary parts.  To do this, you must know that the command \
ComplexExpand is necessary to force ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to split things into real and imaginary parts.  The command for the real \
part is Re, and the command for the imaginary part is Im.  There is one more \
difficulty -- a logical one that we can't blame on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has no way of knowing whether our independent variable ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is real or complex.  We know that it is real, but we must tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that.  The standard way of passing such information to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4 is as an assumption in a Simplify command.  In this case the relevant \
assumption is that ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "is real, which in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language is t \[Element] Reals.  Note that the symbol \[Element] is NOT \
epsilon (\[Epsilon] or \[CurlyEpsilon]), but is the set inclusion symbol on \
the basic typesetting palette (in the block with the integral signs on the \
first row).  Now we are finally ready to generate our two additional \
solutions. "
}], "Text"],

Cell[BoxData[
    \(X2 = Simplify[Re[ComplexExpand[C2]], t \[Element] \ Reals]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(X3 = Simplify[Im[ComplexExpand[C2]], t \[Element] \ Reals]\)], "Input",
  CellLabel->"In[50]:="],

Cell["The general solution for this homogeneous problem is then", "Text"],

Cell[BoxData[
    \(Xgen = a1*X1 + a2*X2 + a3*X3\)], "Input",
  CellLabel->"In[51]:="],

Cell["\<\
We can use this to solve any particular initial value problem.  You \
might want to think about how we were able to generate a complete solution \
basis without ever using the third eigenvalue or eigenvector.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.4 Repeated Eigenvalues", "Subsection"],

Cell[TextData[{
  "\tIn this last section, we tackle the more intricate case of repeated \
eigenvalues.  We will not repeat all of the theory given in class, but all of \
the computational tools are given here, along with some summary of the basic \
theory.  As we discussed in class, with an eigenvalue ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " of ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ",
  "of multiplicity ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", our computational effort centers on finding the generalized eigenvectors \
-- namely the solutions ",
  StyleBox["v ",
    FontWeight->"Bold"],
  "of"
}], "Text"],

Cell[TextData[{
  "(",
  StyleBox["A - ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  StyleBox["I",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\()\^m\)\)]],
  StyleBox["v",
    FontWeight->"Bold"],
  " = 0  ."
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Linear algebra guarantees us ",
  StyleBox["m",
    FontSlant->"Italic"],
  " linearly independent solutions.  Each such solution ",
  StyleBox["v ",
    FontWeight->"Bold"],
  "may be transformed into a solution ",
  StyleBox["X ",
    FontWeight->"Bold"],
  "of the differential equation (4), by using the formula"
}], "Text"],

Cell[TextData[{
  StyleBox["X",
    FontWeight->"Bold"],
  " = ",
  "{I + t(A-\[Lambda]I) + ",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\/\(2!\)\)]],
  "(A-\[Lambda]I",
  Cell[BoxData[
      \(TraditionalForm\`)\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\^\ \)\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`t\^3\/\(3!\)\)]],
  "(A-\[Lambda]I",
  Cell[BoxData[
      \(TraditionalForm\`)\^3\)]],
  " + . . . + ",
  Cell[BoxData[
      \(TraditionalForm\`t\^\(m - 1\)\/\(\((m - 1)\)!\)\)]],
  "(A-\[Lambda]I",
  Cell[BoxData[
      \(TraditionalForm\`)\^\(m - 1\)\)]],
  "}",
  StyleBox["v",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`e\^\[Lambda]t\)]],
  "  . "
}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "A ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function which carries out this transformation from ",
  StyleBox["v",
    FontWeight->"Bold"],
  " to ",
  StyleBox["X",
    FontWeight->"Bold"],
  " is given below, following a definition of the identity matrix of \
dimension ndim."
}], "Text"],

Cell[BoxData[
    \(Id := IdentityMatrix[ndim]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(solmake[A_, \[Lambda]_, m_, v_, t_] := \ 
      Module[{ans, i, term}, ans = Id; 
        Sum[term = 
            MatrixPower[\((A - \[Lambda]*Id)\), 
                i]*\((\((t^i)\)/\((\(i!\))\))\); 
          ans = ans + term, {i, 1, m - 1}]; \ 
        ans\  = Exp[\[Lambda]*t]*\((ans . v)\); ans]\)], "Input",
  CellLabel->"In[53]:="],

Cell[TextData[{
  "The principle computational problem is the solution of (16).  After the \
matrix ",
  "(",
  StyleBox["A - ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  StyleBox["I",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\()\^m\)\)]],
  " is formed by using MatrixPower, we ask for its NullSpace, and that will \
return a set of ",
  StyleBox["m",
    FontSlant->"Italic"],
  " linearly independent solutions of (16).  We illustrate all of this by a \
number of examples."
}], "Text"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection"],

Cell["\tWe try all of this on the following simple example.", "Text"],

Cell[BoxData[
    \(\(A = {{1, \ 1, \ 0}, {0\ , 1\ , 1}, {0, \ 0, \ 1}};\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(\(ndim = 3;\)\)], "Input",
  CellLabel->"In[55]:="],

Cell["The first step is to get the eigenvalues of A.", "Text"],

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input",
  CellLabel->"In[56]:="],

Cell["\<\
On the off-chance that A might have three linearly independent \
eigenvectors, we ask for them.\
\>", "Text"],

Cell[BoxData[
    \(Eigenvectors[A]\)], "Input",
  CellLabel->"In[57]:="],

Cell["\<\
No such luck.  Only one eigenvector, so we must use our technique \
of generalized eigenvectors.  The multiplicity is 3, so we form (A - \
\[Lambda]I)^3.\
\>", "Text"],

Cell[BoxData[
    \(\(m = 3;\)\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(\(\[Lambda] = 1;\)\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(M = MatrixPower[\((A - \[Lambda]*Id)\), m]\)], "Input",
  CellLabel->"In[60]:="],

Cell["\<\
The generalized eigenvectors span the nullspace of M.  In this case \
every vector is in the nullspace of M, so we may choose our three generalized \
eigenvectors at convenience.  We choose them as\
\>", "Text"],

Cell[BoxData[
    \(\(e1 = {1, 0, 0};\)\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(\(e2 = {0, 1, 0};\)\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(\(e3 = {0, 0, 1};\)\)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
Now we construct the solutions associated with each of these.\
\>", \
"Text"],

Cell[BoxData[
    \(\(Clear[X1, X2, X3];\)\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(X1[t_] = solmake[A, \[Lambda], m, e1, t]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(X2[t_] = solmake[A, \[Lambda], m, e2, t]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(X3[t_] = solmake[A, \[Lambda], m, e3, t]\)], "Input",
  CellLabel->"In[67]:="],

Cell["These form a solution basis for the homogeneous equation.", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Section"],

Cell["\tLet's consider an example of a fifth order system.  ", "Text"],

Cell[BoxData[
    \(\(A = {{1, 1, 1, 1, 1}, {0, 1, 1, 1, 1}, {0, 0, 1, 1, 1}, {0, 0, 0, 1, 
            1}, {0, 0, 0, 0, 1}};\)\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(Eigenvectors[A]\)], "Input",
  CellLabel->"In[70]:="],

Cell["\<\
We have an eigenvalue of multiplicity 5, with only one linearly \
independent eigenvector.  Thus we must use generalized eigenvectors.  We have\
\
\>", "Text"],

Cell[BoxData[
    \(\(\[Lambda] = 1;\)\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(\(m = 5;\)\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(\(ndim = 5;\)\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(M = MatrixPower[A - \[Lambda]*Id, 5]\)], "Input",
  CellLabel->"In[74]:="],

Cell["\<\
Again this is the zero matrix, so again we may any choice that is \
convenient for the five linearly independent generalized eigenvectors. \
\>", \
"Text"],

Cell[BoxData[
    \(\(e1 = {1, 0, 0, 0, 0};\)\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(\(e2 = {0, 1, 0, 0, 0};\)\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(\(e3 = {0, 0, 1, 0, 0};\)\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(\(e4 = {0, 0, 0, 1, 0};\)\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(\(e5 = {0, 0, 0, 0, 1};\)\)], "Input",
  CellLabel->"In[79]:="],

Cell["\<\
Now we use solmake to construct our five linearly independent \
solutions.\
\>", "Text"],

Cell[BoxData[
    \(\(Clear[X1, X2, X3, X4, X5];\)\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(X1[t_] = solmake[A, \[Lambda], m, e1, t]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(X2[t_] = solmake[A, \[Lambda], m, e2, t]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(X3[t_] = solmake[A, \[Lambda], m, e3, t]\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(X4[t_] = solmake[A, \[Lambda], m, e4, t]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(X5[t_] = solmake[A, \[Lambda], m, e5, t]\)], "Input",
  CellLabel->"In[85]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Section"],

Cell[TextData[{
  "\tWe do another example, in which the generalized eigenvectors are more \
interesting.  This example is from ",
  StyleBox["Elementary Differential Equations",
    FontWeight->"Bold"],
  ", 3rd edition, C.H. Edwards and D.E. Penney, 1994, p. 436."
}], "Text"],

Cell[BoxData[
    \(\(A = {{0, 0, 1, 0}, {0, 0, 0, 1}, {\(-2\), 2, \(-3\), 1}, {2, \(-2\), 
            1, \(-3\)}};\)\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(\(ndim = 4;\)\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input",
  CellLabel->"In[88]:="],

Cell["\<\
We get two distinct eigenvalues, one of multiplicity 3.  We look at \
the eigenvectors:\
\>", "Text"],

Cell[BoxData[
    \(Eigensystem[A]\)], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
We get two linearly independent eigenvectors for \[Lambda] = -2, \
but we still need a third solution for this case, so we use our generalized \
eigenvectors.  First we find the solution associated with the non-degenerate \
eigenvalue \[Lambda] = 0.\
\>", "Text"],

Cell[BoxData[
    \(\(\[Lambda] = 0;\)\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(\(ndim = 4;\)\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(\(m = 1;\)\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(\(v = {1, 1, 0, 0};\)\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(\(Clear[X1, X2, X3, X4, Xgen, Xsole];\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(X1[t_] = solmake[A, \[Lambda], m, v, t]\)], "Input",
  CellLabel->"In[95]:="],

Cell["\<\
Now we find the generalized eigenvectors associated with \[Lambda] \
= -2.\
\>", "Text"],

Cell[BoxData[
    \(\(\[Lambda] = \(-2\);\)\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(\(m = 3;\)\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(M = MatrixPower[\((A - \[Lambda]*Id)\), 3]\)], "Input",
  CellLabel->"In[98]:="],

Cell["\<\
By asking for the nullspace of M, we will get a set of three \
linearly independent generalized eigenvectors.\
\>", "Text"],

Cell[BoxData[
    \(ns = NullSpace[M]\)], "Input",
  CellLabel->"In[99]:="],

Cell["Our three generalized eigenvectors are", "Text"],

Cell[BoxData[
    \(e2 = ns[\([1]\)]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(e3 = ns[\([2]\)]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(e4 = ns[\([3]\)]\)], "Input",
  CellLabel->"In[102]:="],

Cell["Now we construct a solution from each of these.", "Text"],

Cell[BoxData[
    \(X2[t_] = solmake[A, \[Lambda], m, e2, t]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(X3[t_] = solmake[A, \[Lambda], m, e3, t]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(X4[t_] = solmake[A, \[Lambda], m, e4, t]\)], "Input",
  CellLabel->"In[105]:="],

Cell["Our general solution is", "Text"],

Cell[BoxData[
    \(Xgen[t_] = a1*X1[t] + a2*X2[t] + a3*X3[t] + a4*X4[t]\)], "Input",
  CellLabel->"In[106]:="],

Cell["\tAs an example, we solve an initial value problem.", "Text"],

Cell[BoxData[
    \(\(Xinit = {0, 0, 2, 2};\)\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(ans = Solve[Xgen[0] == Xinit, {a1, a2, a3, a4}]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(Xsole[t_] = Xgen[t] /. Thread[Flatten[ans]]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(Xsole[t_] = Simplify[%]\)], "Input",
  CellLabel->"In[110]:="],

Cell["\<\
\tLet's check both the differential equations and the initial \
conditions.\
\>", "Text"],

Cell[BoxData[
    \(D[Xsole[t], t] - A . Xsole[t]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(Xsole[0] - Xinit\)], "Input",
  CellLabel->"In[112]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Section"],

Cell["\<\
\tAs a final example, we will consider a system with repeated \
complex eigenvalues.\
\>", "Text"],

Cell[BoxData[
    \(A = {{0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}, {\(-25\), 20, \(-14\), 
          4}}\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input",
  CellLabel->"In[114]:="],

Cell["We have two eigenvalues of multiplicity 2, both complex.", "Text"],

Cell[BoxData[
    \(\(m = 2;\)\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(\(ndim = 4;\)\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(\(\[Lambda] = 1 + 2  I;\)\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(M = MatrixPower[\((A - \[Lambda]*Id)\), m]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(ans = NullSpace[M]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(e1 = ans[\([1]\)]\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(e2 = ans[\([2]\)]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(Z1[t_] = solmake[A, \[Lambda], m, e1, t]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(Z2[t_] = solmake[A, \[Lambda], m, e2, t]\)], "Input",
  CellLabel->"In[123]:="],

Cell[TextData[{
  "We get from this four real-valued solutions by taking real and imaginary \
parts.  To do this cleanly, we need to be able to tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that t is real.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3, this requires a package called Algebra ReIm, which allows us to \
declare quantities as real.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4, it is much simpler.  We may make such a declaration in a simplify \
statement."
}], "Text"],

Cell[BoxData[
    \(\(Clear[X1, X2, X3, X4];\)\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(X1[t_] = 
      Simplify[Re[ComplexExpand[Z1[t]]], t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(X2[t_] = 
      Simplify[Im[ComplexExpand[Z1[t]]], t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(X3[t_] = 
      Simplify[Re[ComplexExpand[Z2[t]]], t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(X4[t_] = 
      Simplify[Im[ComplexExpand[Z2[t]]], t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[128]:="],

Cell["We check these.", "Text"],

Cell[BoxData[
    \(D[X1[t], t] - A . X1[t]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(Simplify[D[X2[t], t] - A . X2[t]]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(Simplify[D[X3[t], t] - A . X3[t]]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(Simplify[D[X4[t], t] - A . X4[t]]\)], "Input",
  CellLabel->"In[133]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{651, 686},
WindowMargins->{{5, Automatic}, {Automatic, 3}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000mf0801T1T00000000000
00000000003ooP00003ooP004G<00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 198, 6, 186, "Title"],

Cell[CellGroupData[{
Cell[1962, 61, 40, 0, 63, "SectionFirst"],
Cell[2005, 63, 622, 13, 84, "Text"],
Cell[2630, 78, 327, 13, 26, "NumberedEquation"],
Cell[2960, 93, 300, 13, 26, "NumberedEquation"],
Cell[3263, 108, 602, 27, 26, "Text"],
Cell[3868, 137, 672, 20, 39, "Text"],
Cell[4543, 159, 684, 26, 25, "NumberedEquation"],
Cell[5230, 187, 270, 9, 24, "Text"],
Cell[5503, 198, 494, 19, 26, "NumberedEquation"],
Cell[6000, 219, 1438, 53, 56, "Text"],
Cell[7441, 274, 1124, 43, 25, "NumberedEquation"],
Cell[8568, 319, 233, 6, 38, "Text"],
Cell[8804, 327, 1245, 49, 26, "NumberedEquation"],
Cell[10052, 378, 432, 13, 39, "Text"],
Cell[10487, 393, 654, 14, 84, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11178, 412, 69, 0, 63, "SectionFirst"],
Cell[11250, 414, 340, 9, 42, "Text"],
Cell[11593, 425, 114, 2, 28, "Input"],
Cell[11710, 429, 70, 2, 28, "Input"],
Cell[11783, 433, 99, 3, 24, "Text"],
Cell[11885, 438, 63, 2, 28, "Input"],
Cell[11951, 442, 106, 3, 24, "Text"],
Cell[12060, 447, 71, 2, 28, "Input"],
Cell[12134, 451, 186, 4, 38, "Text"],
Cell[12323, 457, 62, 2, 28, "Input"],
Cell[12388, 461, 62, 2, 28, "Input"],
Cell[12453, 465, 161, 4, 38, "Text"],
Cell[12617, 471, 559, 30, 100, "NumberedEquation"],
Cell[13179, 503, 104, 3, 24, "Text"],
Cell[13286, 508, 80, 2, 28, "Input"],
Cell[13369, 512, 128, 3, 24, "Text"],
Cell[13500, 517, 68, 2, 28, "Input"],
Cell[13571, 521, 30, 0, 24, "Text"],
Cell[13604, 523, 68, 2, 28, "Input"],
Cell[13675, 527, 151, 5, 26, "Text"],
Cell[13829, 534, 82, 2, 28, "Input"],
Cell[13914, 538, 39, 0, 24, "Text"],
Cell[13956, 540, 357, 9, 42, "Text"],
Cell[14316, 551, 133, 3, 28, "Input"],
Cell[14452, 556, 71, 2, 28, "Input"],
Cell[14526, 560, 275, 5, 38, "Text"],
Cell[14804, 567, 922, 32, 72, "Text"],
Cell[15729, 601, 82, 2, 28, "Input"],
Cell[15814, 605, 386, 11, 54, "Text"],
Cell[16203, 618, 68, 2, 28, "Input"],
Cell[16274, 622, 324, 8, 40, "Text"],
Cell[16601, 632, 85, 2, 28, "Input"],
Cell[16689, 636, 159, 5, 26, "Text"],
Cell[16851, 643, 76, 2, 28, "Input"],
Cell[16930, 647, 75, 0, 24, "Text"],
Cell[17008, 649, 75, 2, 28, "Input"],
Cell[17086, 653, 179, 4, 38, "Text"],
Cell[17268, 659, 137, 3, 28, "Input"],
Cell[17408, 664, 44, 0, 24, "Text"],
Cell[17455, 666, 68, 2, 28, "Input"],
Cell[17526, 670, 60, 2, 28, "Input"],
Cell[17589, 674, 73, 0, 24, "Text"],
Cell[17665, 676, 83, 2, 28, "Input"],
Cell[17751, 680, 83, 2, 28, "Input"],
Cell[17837, 684, 83, 2, 28, "Input"],
Cell[17923, 688, 31, 0, 24, "Text"],
Cell[17957, 690, 320, 7, 54, "Text"],
Cell[18280, 699, 86, 2, 28, "Input"],
Cell[18369, 703, 166, 4, 38, "Text"],
Cell[18538, 709, 94, 2, 28, "Input"],
Cell[18635, 713, 754, 25, 72, "Text"],
Cell[19392, 740, 73, 2, 28, "Input"],
Cell[19468, 744, 1146, 42, 90, "Text"],
Cell[20617, 788, 80, 2, 28, "Input"],
Cell[20700, 792, 89, 2, 28, "Input"],
Cell[20792, 796, 60, 2, 28, "Input"],
Cell[20855, 800, 99, 3, 24, "Text"],
Cell[20957, 805, 342, 12, 42, "Text"],
Cell[21302, 819, 106, 2, 28, "Input"],
Cell[21411, 823, 315, 7, 40, "Text"],
Cell[21729, 832, 94, 2, 28, "Input"],
Cell[21826, 836, 92, 2, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21955, 843, 59, 0, 63, "SectionFirst"],
Cell[22017, 845, 352, 9, 40, "Text"],
Cell[22372, 856, 463, 18, 26, "NumberedEquation"],
Cell[22838, 876, 1060, 24, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23935, 905, 60, 0, 63, "SectionFirst"],

Cell[CellGroupData[{
Cell[24020, 909, 40, 0, 42, "Subsection"],
Cell[24063, 911, 303, 5, 52, "Text"],
Cell[24369, 918, 230, 11, 26, "NumberedEquation"],
Cell[24602, 931, 204, 5, 26, "Text"],
Cell[24809, 938, 174, 8, 26, "NumberedEquation"],
Cell[24986, 948, 207, 6, 40, "Text"],
Cell[25196, 956, 417, 19, 26, "NumberedEquation"],
Cell[25616, 977, 1824, 60, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27477, 1042, 51, 0, 42, "Subsection"],
Cell[27531, 1044, 567, 17, 54, "Text"],
Cell[28101, 1063, 1170, 42, 25, "NumberedEquation"],
Cell[29274, 1107, 654, 19, 40, "Text"],
Cell[29931, 1128, 1299, 47, 25, "NumberedEquation"],
Cell[31233, 1177, 152, 5, 24, "Text"],
Cell[31388, 1184, 563, 29, 26, "NumberedEquation"],
Cell[31954, 1215, 29, 0, 24, "Text"],
Cell[31986, 1217, 700, 30, 25, "Text"],
Cell[32689, 1249, 797, 24, 40, "Text"],
Cell[33489, 1275, 127, 4, 26, "Text"],
Cell[33619, 1281, 74, 2, 28, "Input"],
Cell[33696, 1285, 169, 8, 40, "Text"],
Cell[33868, 1295, 86, 2, 28, "Input"],
Cell[33957, 1299, 52, 0, 24, "Text"],
Cell[34012, 1301, 77, 2, 28, "Input"],
Cell[34092, 1305, 60, 0, 24, "Text"],
Cell[34155, 1307, 85, 2, 28, "Input"],
Cell[34243, 1311, 139, 5, 26, "Text"],
Cell[34385, 1318, 75, 2, 28, "Input"],
Cell[34463, 1322, 118, 3, 24, "Text"],
Cell[34584, 1327, 137, 3, 28, "Input"],
Cell[34724, 1332, 49, 0, 24, "Text"],
Cell[34776, 1334, 154, 4, 28, "Input"],
Cell[34933, 1340, 329, 12, 40, "Text"],
Cell[35265, 1354, 151, 4, 28, "Input"],
Cell[35419, 1360, 153, 3, 38, "Text"],
Cell[35575, 1365, 105, 2, 28, "Input"],
Cell[35683, 1369, 31, 0, 24, "Text"],
Cell[35717, 1371, 98, 2, 28, "Input"],
Cell[35818, 1375, 145, 3, 24, "Text"],
Cell[35966, 1380, 89, 2, 28, "Input"],
Cell[36058, 1384, 28, 0, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36123, 1389, 54, 0, 42, "Subsection"],
Cell[36180, 1391, 670, 17, 68, "Text"],
Cell[36853, 1410, 755, 19, 86, "Text"],
Cell[37611, 1431, 134, 3, 28, "Input"],
Cell[37748, 1436, 108, 5, 26, "Text"],
Cell[37859, 1443, 72, 2, 28, "Input"],
Cell[37934, 1447, 170, 4, 38, "Text"],
Cell[38107, 1453, 134, 3, 28, "Input"],
Cell[38244, 1458, 43, 0, 24, "Text"],
Cell[38290, 1460, 83, 2, 28, "Input"],
Cell[38376, 1464, 52, 0, 24, "Text"],
Cell[38431, 1466, 83, 2, 28, "Input"],
Cell[38517, 1470, 1528, 38, 146, "Text"],
Cell[40048, 1510, 116, 2, 28, "Input"],
Cell[40167, 1514, 116, 2, 28, "Input"],
Cell[40286, 1518, 73, 0, 24, "Text"],
Cell[40362, 1520, 86, 2, 28, "Input"],
Cell[40451, 1524, 234, 4, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40722, 1533, 46, 0, 42, "Subsection"],
Cell[40771, 1535, 652, 19, 70, "Text"],
Cell[41426, 1556, 320, 14, 26, "NumberedEquation"],
Cell[41749, 1572, 347, 11, 42, "Text"],
Cell[42099, 1585, 753, 31, 34, "NumberedEquation"],
Cell[42855, 1618, 326, 12, 40, "Text"],
Cell[43184, 1632, 84, 2, 28, "Input"],
Cell[43271, 1636, 358, 8, 76, "Input"],
Cell[43632, 1646, 555, 18, 56, "Text"],

Cell[CellGroupData[{
Cell[44212, 1668, 34, 0, 34, "Subsubsection"],
Cell[44249, 1670, 69, 0, 24, "Text"],
Cell[44321, 1672, 112, 2, 28, "Input"],
Cell[44436, 1676, 71, 2, 28, "Input"],
Cell[44510, 1680, 62, 0, 24, "Text"],
Cell[44575, 1682, 72, 2, 28, "Input"],
Cell[44650, 1686, 119, 3, 24, "Text"],
Cell[44772, 1691, 73, 2, 28, "Input"],
Cell[44848, 1695, 177, 4, 38, "Text"],
Cell[45028, 1701, 68, 2, 28, "Input"],
Cell[45099, 1705, 76, 2, 28, "Input"],
Cell[45178, 1709, 100, 2, 28, "Input"],
Cell[45281, 1713, 221, 4, 38, "Text"],
Cell[45505, 1719, 77, 2, 28, "Input"],
Cell[45585, 1723, 77, 2, 28, "Input"],
Cell[45665, 1727, 77, 2, 28, "Input"],
Cell[45745, 1731, 87, 3, 24, "Text"],
Cell[45835, 1736, 80, 2, 28, "Input"],
Cell[45918, 1740, 98, 2, 28, "Input"],
Cell[46019, 1744, 98, 2, 28, "Input"],
Cell[46120, 1748, 98, 2, 28, "Input"],
Cell[46221, 1752, 73, 0, 24, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46355, 1759, 28, 0, 57, "Section"],
Cell[46386, 1761, 70, 0, 24, "Text"],
Cell[46459, 1763, 165, 3, 44, "Input"],
Cell[46627, 1768, 72, 2, 28, "Input"],
Cell[46702, 1772, 73, 2, 28, "Input"],
Cell[46778, 1776, 169, 4, 38, "Text"],
Cell[46950, 1782, 76, 2, 28, "Input"],
Cell[47029, 1786, 68, 2, 28, "Input"],
Cell[47100, 1790, 71, 2, 28, "Input"],
Cell[47174, 1794, 94, 2, 28, "Input"],
Cell[47271, 1798, 165, 4, 38, "Text"],
Cell[47439, 1804, 83, 2, 28, "Input"],
Cell[47525, 1808, 83, 2, 28, "Input"],
Cell[47611, 1812, 83, 2, 28, "Input"],
Cell[47697, 1816, 83, 2, 28, "Input"],
Cell[47783, 1820, 83, 2, 28, "Input"],
Cell[47869, 1824, 98, 3, 24, "Text"],
Cell[47970, 1829, 88, 2, 28, "Input"],
Cell[48061, 1833, 98, 2, 28, "Input"],
Cell[48162, 1837, 98, 2, 28, "Input"],
Cell[48263, 1841, 98, 2, 28, "Input"],
Cell[48364, 1845, 98, 2, 28, "Input"],
Cell[48465, 1849, 98, 2, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48600, 1856, 28, 0, 57, "Section"],
Cell[48631, 1858, 278, 6, 42, "Text"],
Cell[48912, 1866, 156, 3, 28, "Input"],
Cell[49071, 1871, 71, 2, 28, "Input"],
Cell[49145, 1875, 72, 2, 28, "Input"],
Cell[49220, 1879, 111, 3, 24, "Text"],
Cell[49334, 1884, 72, 2, 28, "Input"],
Cell[49409, 1888, 273, 5, 38, "Text"],
Cell[49685, 1895, 76, 2, 28, "Input"],
Cell[49764, 1899, 71, 2, 28, "Input"],
Cell[49838, 1903, 68, 2, 28, "Input"],
Cell[49909, 1907, 79, 2, 28, "Input"],
Cell[49991, 1911, 97, 2, 28, "Input"],
Cell[50091, 1915, 97, 2, 28, "Input"],
Cell[50191, 1919, 98, 3, 24, "Text"],
Cell[50292, 1924, 81, 2, 28, "Input"],
Cell[50376, 1928, 68, 2, 28, "Input"],
Cell[50447, 1932, 100, 2, 28, "Input"],
Cell[50550, 1936, 133, 3, 24, "Text"],
Cell[50686, 1941, 75, 2, 28, "Input"],
Cell[50764, 1945, 54, 0, 24, "Text"],
Cell[50821, 1947, 75, 2, 28, "Input"],
Cell[50899, 1951, 75, 2, 28, "Input"],
Cell[50977, 1955, 75, 2, 28, "Input"],
Cell[51055, 1959, 63, 0, 24, "Text"],
Cell[51121, 1961, 99, 2, 28, "Input"],
Cell[51223, 1965, 99, 2, 28, "Input"],
Cell[51325, 1969, 99, 2, 28, "Input"],
Cell[51427, 1973, 39, 0, 24, "Text"],
Cell[51469, 1975, 111, 2, 28, "Input"],
Cell[51583, 1979, 67, 0, 24, "Text"],
Cell[51653, 1981, 84, 2, 28, "Input"],
Cell[51740, 1985, 106, 2, 28, "Input"],
Cell[51849, 1989, 102, 2, 28, "Input"],
Cell[51954, 1993, 82, 2, 28, "Input"],
Cell[52039, 1997, 99, 3, 24, "Text"],
Cell[52141, 2002, 88, 2, 28, "Input"],
Cell[52232, 2006, 75, 2, 28, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52344, 2013, 28, 0, 57, "Section"],
Cell[52375, 2015, 108, 3, 24, "Text"],
Cell[52486, 2020, 143, 3, 28, "Input"],
Cell[52632, 2025, 73, 2, 28, "Input"],
Cell[52708, 2029, 72, 0, 24, "Text"],
Cell[52783, 2031, 69, 2, 28, "Input"],
Cell[52855, 2035, 72, 2, 28, "Input"],
Cell[52930, 2039, 84, 2, 28, "Input"],
Cell[53017, 2043, 101, 2, 28, "Input"],
Cell[53121, 2047, 77, 2, 28, "Input"],
Cell[53201, 2051, 76, 2, 28, "Input"],
Cell[53280, 2055, 76, 2, 28, "Input"],
Cell[53359, 2059, 99, 2, 28, "Input"],
Cell[53461, 2063, 99, 2, 28, "Input"],
Cell[53563, 2067, 541, 14, 56, "Text"],
Cell[54107, 2083, 85, 2, 28, "Input"],
Cell[54195, 2087, 133, 3, 28, "Input"],
Cell[54331, 2092, 133, 3, 28, "Input"],
Cell[54467, 2097, 133, 3, 28, "Input"],
Cell[54603, 2102, 133, 3, 28, "Input"],
Cell[54739, 2107, 31, 0, 24, "Text"],
Cell[54773, 2109, 82, 2, 28, "Input"],
Cell[54858, 2113, 70, 2, 28, "Input"],
Cell[54931, 2117, 92, 2, 28, "Input"],
Cell[55026, 2121, 92, 2, 28, "Input"],
Cell[55121, 2125, 92, 2, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

