(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18715,        663]*)
(*NotebookOutlinePosition[     43596,       1564]*)
(*  CellTagsIndexPosition[     43552,       1560]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
S-E-I-R Model of Epidemics
Part 1
Basic Model and Example\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["1. Introduction", "Subtitle"],

Cell[CellGroupData[{

Cell["Description of the Model", "Subsection"],

Cell[TextData[{
  "\tIn this notebook, we develop the S-E-I-R model for epidemics.  For the \
integration of the nonlinear differential equations, we use the package \
DynPac.  Although some familiarity with DynPac is assumed, brief descriptions \
of some DynPac commands are given as they are used.  The integrations in this \
notebook also can be done easily with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function NDSolve."
}], "Text"],

Cell[TextData[{
  "\tThe S-E-I-R model is the S-I-R model with one additional category -- the \
category E of those individuals exposed but not yet infectious.  (This is a \
variation of the basic S-I-R model, which was discussed in the two notebooks \
SIRModelPart1 and SIRModelPart2).  We denote the numbers in each class by ",
  StyleBox["s",
    FontSlant->"Italic"],
  ", ",
  StyleBox["e",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["r",
    FontSlant->"Italic"],
  ".  The total population is then  \t  "
}], "Text"],

Cell[TextData[{
  "\t            n ",
  StyleBox["= ",
    FontSlant->"Plain"],
  "s ",
  StyleBox["+ ",
    FontSlant->"Plain"],
  "e +",
  StyleBox[" ",
    FontSlant->"Plain"],
  "i",
  StyleBox[" + ",
    FontSlant->"Plain"],
  "r",
  StyleBox[
  "  .                                                                        \
      ",
    FontSlant->"Plain"],
  StyleBox["(1)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["\<\
In this notebook, we look only at short-term dynamics, so we omit \
births, and deaths not associated with the disease.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Equations and Parameters of the Model", "Subsection"],

Cell["\tThe basic differential equations are as follows: ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(ds\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{"-", 
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]]}]}], "   ", ",", 
        "                                                                     \
                                        ", 
        StyleBox[\((2)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(de\/dt\),
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["e",
                  FontSlant->"Italic"]}]]}]}], "  ", ",", 
        "                                                                     \
                               ", 
        StyleBox[\((3)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(di\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["e",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]]}]}], " ", ",", 
        "                                                                     \
                                 ", 
        StyleBox[\((4)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(dr\/dt\),
          FontSlant->"Italic"], "=", "  ", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Beta]", 
              StyleBox["i",
                FontSlant->"Italic"]}]], "   ", ".", 
          "                                                                   \
                                               ", 
          StyleBox[\((5)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "These equations describe the transitions of individuals from S to E to I \
to R.  By adding the four equations, we show easily that the total population \
",
  StyleBox["n",
    FontSlant->"Italic"],
  " is constant.  We will call the parameter \[Alpha] the transmissivity.  \
The term \[Alpha]",
  StyleBox["si",
    FontSlant->"Italic"],
  " is a standard kinetic term, based on the idea that the number of \
encounters per unit time between susceptibles and infectives will be \
proportional to the numbers of each.  The transmissivity \[Alpha] is \
determined by both the encounter frequency and the efficiency with which the \
disease is transmitted per encounter.  The parameter \[Gamma] describes \
transitions from the exposed state to the infectious state.  One can show \
that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\^\(-1\)\)]],
  "is the average time an individual spends in the exposed state.  The \
parameter \[Beta] describes the transitions between infected and recovered, \
and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\^\(-1\)\)]],
  "is the average time an individual spends in the infected state. "
}], "Text"],

Cell[TextData[{
  "\tWe can treat the first three of the four equations given by (2) - (5) as \
a set of three equations in ",
  StyleBox["s, ",
    FontSlant->"Italic"],
  "e and ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  After these three equations are solved, we can calculate ",
  StyleBox["r",
    FontSlant->"Italic"],
  " from equation (1).  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conditions for an Epidemic", "Subsection"],

Cell["\<\
\t\tAs we have seen in an earlier notebook, the condition for an \
epidemic in an S-I-R model is\
\>", "Text"],

Cell[TextData[{
  "  s ",
  StyleBox[
  "> \[Beta]/\[Alpha]  .                                                      \
                                ",
    FontSlant->"Plain"],
  StyleBox["(6)",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox["  ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "If equation (6) is satisfied, the number of infectives will increase.  \
Thus for an initial number of susceptibles ",
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  ", the condition in an S-I-R model for an epidemic to occur is that the \
parameter ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "exceed 1, where"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= ",
  StyleBox["\[Alpha]",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_0\)]],
  "/",
  StyleBox[
  "\[Beta]                                                                    \
                   ",
    FontSlant->"Plain"],
  StyleBox["(7)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["\<\
is called the reproduction ratio of the epidemic.  We will begin \
our study of the S-E-I-R model by seeing how this condition is modified by \
the presence of the E category.  To do this, we look at equilibrium and \
stability.  First we must define the system for DynPac. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Defining the Equations for DynPac", "Subtitle"],

Cell["\<\
\tIn much of what follows, we will be integrating equations (2) - \
(4) numerically.  In this section, we define the equations for DynPac.  We \
start by defining the state vector, the parameter vector and the slope \
vector.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{s, e, i}];\)\)], "Input"],

Cell[TextData[{
  "This tells DynPac that the two state variables are ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(setparm[{\[Alpha], \[Gamma], \[Beta]}];\)\)], "Input"],

Cell[TextData[
"This tells DynPac that the\"official\" system parameters are \[Alpha], \
\[Gamma] and \[Beta]."], "Text"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Alpha]\)*s*
            i, \[Alpha]*s*i - \[Gamma]*e, \[Gamma]*e - \[Beta]*
              i\ };\)\)], "Input"],

Cell["\<\
This defines the slope vector of the equations for DynPac.  Now we \
look at the stability of the state with no infectives or exposed.  The \
eigenvalues of that state will tell us when we get an epidemic.\
\>", "Text"],

Cell[BoxData[
    \(\(interest;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Conditions for an Epidemic", "Subtitle"],

Cell[TextData[{
  "\tIt is easy to show that the only equilibrium states are those in which \
both ",
  StyleBox["e",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  " are zero.  In such an equilibrium, ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "may have any value -- call it s0.  Then the equilibrium state is"
}], "Text"],

Cell[BoxData[
    \(\(eq = {s0, 0, 0};\)\)], "Input"],

Cell["We look at the eigenvalues in this state:", "Text"],

Cell[BoxData[
    \(eigval = Eigenvalues[dermat /. Thread[statevec -> eq]]\)], "Input"],

Cell[TextData[{
  "The zero eigenvalue corresponds to a shift in s0, with ",
  StyleBox["e",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  " remaining zero.  If the square root in the other two eigenvalues is \
imaginary, then both roots have negative real parts and there is no epidemic. \
 If the square root is real, the middle root is always negative, and so the \
existence of an an epidemic is determined by the third root.  It is easy to \
show that the condition that the third root be positive reduces exactly to \
equation (7), as in the S-I-R model.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Example", "Subtitle"],

Cell[TextData[{
  "\tAs an example, we look again at the severe flu epidemic in the English \
boarding school (which we discussed in the notebook SIRModelPart1), taken \
from J.D. Murray, ",
  StyleBox["Mathematical Biology",
    FontWeight->"Bold"],
  ", 2nd edition, Springer-Verlag, 1993, section 19.1, (based on data \
compiled by the British Communicable Disease Surveillance Centre in British \
Medical Journal, March 4 1978, p. 587).  Our focus here is not the comparison \
of theory and data, but the comparison of a model with an E category to one \
without.  In making the comparison, we will generally make the simplifying \
assumption that the latent time for the exposed is equal to the duration of \
the infection -- that is, that \[Beta] = \[Gamma].  We now define the \
parameter values for DynPac:"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2.18*10\^\(-3\), 0.441, \ 0.441};\)\)], "Input"],

Cell["\<\
We also specify time units, which will be used in graph displays.\
\
\>", "Text"],

Cell[BoxData[
    \(\(timeunit = "\<day\>";\)\)], "Input"],

Cell["We save this system under the name SEIR.", "Text"],

Cell[BoxData[
    \(\(savesys[SEIR];\)\)], "Input"],

Cell["\<\
We now define the basic SIR system.  After doing that, we will \
compare solutions from the two systems.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{s, i}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[Alpha], \[Beta]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Alpha]\)*s*
            i, \[Alpha]*s*i - \[Beta]*i};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {2.18*10\^\(-3\), 0.441};\)\)], "Input"],

Cell[BoxData[
    \(\(timeunit = "\<day\>";\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[SIR];\)\)], "Input"],

Cell["\<\
\tWe now carry out an integration for the SIR model.  We define the \
integration parameters.\
\>", "Text"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.05;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 500;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(s0 = 762; i0 = 1;\)], "Input"],

Cell["Now we perform the integration.", "Text"],

Cell[BoxData[
    \(\(sirsol = integrate[{s0, i0}, t0, h, nsteps];\)\)], "Input"],

Cell["The final value in the integration run is", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
Thus after 25 days, there are only a little over 19 susceptibles \
left, and with only 0.3 infectives, the epidemic is over.  We plot these \
results now.\
\>", "Text"],

Cell[BoxData[
    \(\(sciflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(imsize\  = \ 410;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(sirgraph = timeplot[sirsol, {1, 2}];\)\)], "Input"],

Cell["\<\
\tNow we carry out and plot the solution for the SEIR model.  We \
start the epidemic with 762 susceptibles, one exposed and zero infectives.  \
We integrate a little further, on the assumption that the delay associated \
with the E class will lengthen the epidemic.\
\>", "Text"],

Cell[BoxData[
    \(\(restoresys[SEIR];\)\)], "Input"],

Cell[BoxData[
    \(\(initvec = {762, 1, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps = 1000;\)\)], "Input"],

Cell["Now we carry out the integration.", "Text"],

Cell[BoxData[
    \(\(seirsol = integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell["The final point in the integration is", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
After 50 days, we have a little over 19 susceptibles, and \
essentially zero exposed and infected.  We plot these results.\
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Green, Magenta, Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(seirgraph = timeplot[seirsol, {1, 2, 3}];\)\)], "Input"],

Cell[TextData[{
  "It is of some interest to look at the sum of the exposed and infectives.  \
We define a new solution vector which has susceptibles ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "and the sum ",
  StyleBox["e",
    FontSlant->"Italic"],
  " + ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  We do this by using the DynPac function transol, which applies \
functional transformations to a solution."
}], "Text"],

Cell[BoxData[
    \(\(funclist = {s, e + i};\)\)], "Input"],

Cell[BoxData[
    \(\(modseirsol = transol[seirsol, funclist];\)\)], "Input"],

Cell["\<\
Now we plot these two quantities, first changing the axes labels to \
something appropriate.\
\>", "Text"],

Cell[BoxData[
    \(\(axlabon = {"\<t (days)\>", "\<s, e+i\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Green, \ Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(modseirgraph\  = \ timeplot[modseirsol, {1, 2}];\)\)], "Input"],

Cell["\tNow we compare theS-I-R and S-E-I-R models graphically.", "Text"],

Cell[BoxData[
    \(\(show[sirgraph, seirgraph];\)\)], "Input"],

Cell[TextData[{
  "\tNow we compare the SIR graph with the graph of ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["i",
    FontSlant->"Italic"],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(show[sirgraph, modseirgraph];\)\)], "Input"],

Cell["\tLet's look at the peaks for the two epidemics.", "Text"],

Cell[BoxData[
    \(staterange[seirsol]\)], "Input"],

Cell[BoxData[
    \(\(setstate[{s, eplusi}];\)\)], "Input"],

Cell[BoxData[
    \(staterange[modseirsol]\)], "Input"],

Cell[BoxData[
    \(\(restoresys[SIR];\)\)], "Input"],

Cell[BoxData[
    \(staterange[sirsol]\)], "Input"],

Cell[TextData[{
  "\tWhat are the conclusions from the graphs and state ranges?  The most \
obvious difference is that the infective peak is both later and lower in the \
SEIR model.  The peak of ",
  StyleBox["e",
    FontSlant->"Italic"],
  " + ",
  StyleBox["i",
    FontSlant->"Italic"],
  " in the SEIR model is nearly identical in amplitude with the peak in ",
  StyleBox["i",
    FontSlant->"Italic"],
  " in the SIR model, but the SEIR peak is much later.  The total number who \
eventually get the flu is essentially the same in the two models.  The main \
effect of the latent period is to make the epidemic longer and less intense, \
but with essentially the same number of total illnesses."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{-2, Automatic}, {Automatic, 2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000[V0801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 82, 4, 190, "Title"],
Cell[1824, 57, 38, 1, 27, "Input"],
Cell[1865, 60, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1943, 65, 35, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[2003, 69, 46, 0, 46, "Subsection"],
Cell[2052, 71, 459, 9, 82, "Text"],
Cell[2514, 82, 579, 17, 80, "Text"],
Cell[3096, 101, 487, 23, 32, "Text"],
Cell[3586, 126, 143, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3766, 134, 72, 0, 46, "Subsection"],
Cell[3841, 136, 67, 0, 30, "Text"],
Cell[3911, 138, 533, 15, 45, "Text"],
Cell[4447, 155, 897, 27, 45, "Text"],
Cell[5347, 184, 664, 19, 45, "Text"],
Cell[6014, 205, 505, 14, 45, "Text"],
Cell[6522, 221, 1172, 25, 144, "Text"],
Cell[7697, 248, 370, 12, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8104, 265, 48, 0, 46, "Subsection"],
Cell[8155, 267, 120, 3, 30, "Text"],
Cell[8278, 272, 344, 13, 32, "Text"],
Cell[8625, 287, 360, 10, 46, "Text"],
Cell[8988, 299, 444, 18, 32, "Text"],
Cell[9435, 319, 298, 5, 62, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9782, 330, 56, 0, 56, "Subtitle"],
Cell[9841, 332, 249, 5, 46, "Text"],
Cell[10093, 339, 57, 1, 27, "Input"],
Cell[10153, 342, 185, 8, 32, "Text"],
Cell[10341, 352, 76, 1, 27, "Input"],
Cell[10420, 355, 121, 2, 30, "Text"],
Cell[10544, 359, 149, 3, 27, "Input"],
Cell[10696, 364, 229, 4, 46, "Text"],
Cell[10928, 370, 46, 1, 27, "Input"],
Cell[10977, 373, 47, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11061, 379, 49, 0, 56, "Subtitle"],
Cell[11113, 381, 362, 12, 50, "Text"],
Cell[11478, 395, 53, 1, 27, "Input"],
Cell[11534, 398, 57, 0, 30, "Text"],
Cell[11594, 400, 87, 1, 27, "Input"],
Cell[11684, 403, 610, 13, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12331, 421, 30, 0, 56, "Subtitle"],
Cell[12364, 423, 827, 14, 128, "Text"],
Cell[13194, 439, 81, 1, 31, "Input"],
Cell[13278, 442, 91, 3, 30, "Text"],
Cell[13372, 447, 58, 1, 27, "Input"],
Cell[13433, 450, 56, 0, 30, "Text"],
Cell[13492, 452, 51, 1, 27, "Input"],
Cell[13546, 455, 128, 3, 30, "Text"],
Cell[13677, 460, 54, 1, 27, "Input"],
Cell[13734, 463, 66, 1, 27, "Input"],
Cell[13803, 466, 107, 2, 27, "Input"],
Cell[13913, 470, 72, 1, 31, "Input"],
Cell[13988, 473, 58, 1, 27, "Input"],
Cell[14049, 476, 50, 1, 27, "Input"],
Cell[14102, 479, 117, 3, 30, "Text"],
Cell[14222, 484, 46, 1, 27, "Input"],
Cell[14271, 487, 46, 1, 27, "Input"],
Cell[14320, 490, 50, 1, 27, "Input"],
Cell[14373, 493, 46, 1, 27, "Input"],
Cell[14422, 496, 47, 1, 27, "Input"],
Cell[14472, 499, 50, 1, 27, "Input"],
Cell[14525, 502, 47, 0, 30, "Text"],
Cell[14575, 504, 81, 1, 27, "Input"],
Cell[14659, 507, 57, 0, 30, "Text"],
Cell[14719, 509, 39, 1, 27, "Input"],
Cell[14761, 512, 178, 4, 46, "Text"],
Cell[14942, 518, 52, 1, 27, "Input"],
Cell[14997, 521, 50, 1, 27, "Input"],
Cell[15050, 524, 54, 1, 27, "Input"],
Cell[15107, 527, 53, 1, 27, "Input"],
Cell[15163, 530, 73, 1, 27, "Input"],
Cell[15239, 533, 290, 5, 62, "Text"],
Cell[15532, 540, 54, 1, 27, "Input"],
Cell[15589, 543, 59, 1, 27, "Input"],
Cell[15651, 546, 51, 1, 27, "Input"],
Cell[15705, 549, 49, 0, 30, "Text"],
Cell[15757, 551, 81, 1, 27, "Input"],
Cell[15841, 554, 53, 0, 30, "Text"],
Cell[15897, 556, 39, 1, 27, "Input"],
Cell[15939, 559, 146, 3, 30, "Text"],
Cell[16088, 564, 70, 1, 27, "Input"],
Cell[16161, 567, 78, 1, 27, "Input"],
Cell[16242, 570, 432, 13, 64, "Text"],
Cell[16677, 585, 59, 1, 27, "Input"],
Cell[16739, 588, 77, 1, 27, "Input"],
Cell[16819, 591, 116, 3, 30, "Text"],
Cell[16938, 596, 78, 1, 27, "Input"],
Cell[17019, 599, 62, 1, 27, "Input"],
Cell[17084, 602, 85, 1, 27, "Input"],
Cell[17172, 605, 73, 0, 30, "Text"],
Cell[17248, 607, 63, 1, 27, "Input"],
Cell[17314, 610, 235, 11, 32, "Text"],
Cell[17552, 623, 66, 1, 27, "Input"],
Cell[17621, 626, 64, 0, 30, "Text"],
Cell[17688, 628, 52, 1, 27, "Input"],
Cell[17743, 631, 59, 1, 27, "Input"],
Cell[17805, 634, 55, 1, 27, "Input"],
Cell[17863, 637, 53, 1, 27, "Input"],
Cell[17919, 640, 51, 1, 27, "Input"],
Cell[17973, 643, 714, 16, 98, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

