(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    105678,       3473]*)
(*NotebookOutlinePosition[    130593,       4375]*)
(*  CellTagsIndexPosition[    130549,       4371]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
S-E-I-R Model of Epidemics
Part 2
Effect of Vital Dynamics
and
Vaccination \
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["1. Introduction", "Subtitle"],

Cell[CellGroupData[{

Cell["Description of the Model", "Subsection"],

Cell[TextData[{
  "\tIn this notebook, we extend the S-E-I-R model to include births, deaths, \
and vaccination.  For discussion of the basic S-E-I-R model, see the notebook \
SEIRPart1.nb.  Here we base our formulation in part on (1) the summary given \
by B.T. Grenfell and B.M. Bolker, \"Population Dynamics of Measles,\" in ",
  StyleBox["Parasitic and Infectious Diseases:  Epidemiology and Ecology",
    FontWeight->"Bold"],
  ", ed. M.E. Scott and G. Smith, Academic Press, 1994, p. 219, and in part \
on (2) the treatment given by R.M. Anderson and R.M. May in \"",
  StyleBox["Infectious Diseases of Humans",
    FontWeight->"Bold"],
  ",\" Oxford Press, 1991, Chapter 6.  We use a scaling in this notebook \
which is different than that used in previous notebooks in this series.  All \
populations are scaled by the total population.  For the unscaled variables \
(as used in previous notebooks) we will use capital letters, with lower case \
being used for the scaled variables.  In association with this different \
scaling, we will reconsider the transmissivity \[Alpha].    "
}], "Text"],

Cell[TextData[{
  "\tIn the S-E-I-R model, we have four classes of individuals:  the \
susceptibles S with numbers ",
  StyleBox["S; ",
    FontSlant->"Italic"],
  "the exposed E, who are infected but not infectious, with numbers ",
  StyleBox["E;",
    FontSlant->"Italic"],
  " the infectives I, who are infectious, with numbers ",
  StyleBox["I;",
    FontSlant->"Italic"],
  " and the recovered R, who are immune, with numbers ",
  StyleBox["R.  ",
    FontSlant->"Italic"],
  " The total population is"
}], "Text"],

Cell[TextData[{
  "\t            N ",
  StyleBox["= ",
    FontSlant->"Plain"],
  "S ",
  StyleBox["+ ",
    FontSlant->"Plain"],
  "E +",
  StyleBox[" ",
    FontSlant->"Plain"],
  "I",
  StyleBox[" + ",
    FontSlant->"Plain"],
  "R",
  StyleBox[
  "  .                                                                        \
      ",
    FontSlant->"Plain"],
  StyleBox["(1)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[
"The processes included in the model are the transitions S\[Rule]E\[Rule]I\
\[Rule]R, births and deaths not associated with the disease, and vaccination. \
 We assume that the birth rate and the death rate are equal, so that the \
population is stationary in size.  Age structure and spatial heterogeneities \
are ignored.  "], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Equations and Parameters of the Model", "Subsection"],

Cell["\tThe basic differential equations are as follows: ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(dS\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            RowBox[{"-", 
              StyleBox[
                RowBox[{"\[Alpha]", 
                  StyleBox["SI",
                    FontSlant->"Italic"]}]]}], "  ", "+", " ", 
            RowBox[{"\[Mu]", 
              RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", 
                  StyleBox["v",
                    FontSlant->"Italic"]}], ")"}], 
              StyleBox["N",
                FontSlant->"Italic"]}], "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["S",
                  FontSlant->"Italic"]}]]}]}], "  ", ",", 
        "                                                                     \
                       ", 
        StyleBox[\((2)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["E",
                    FontSlant->"Italic"]}]], "dt"],
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["SI",
                  FontSlant->"Italic"]}]], 
            StyleBox["-",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["E",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["E",
                  FontSlant->"Italic"]}]]}]}], " ", ",", 
        "                                                                     \
                                               ", 
        StyleBox[\((3)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["I",
                    FontSlant->"Italic"]}]], "dt"],
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["E",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["I",
                  FontSlant->"Italic"]}]], "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["I",
                  FontSlant->"Italic"]}]]}]}], " ", ",", 
        "                                                                     \
                                                  ", 
        StyleBox[\((4)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"and", "                  ", 
          StyleBox[
            FractionBox[
              StyleBox["dR",
                FontSlant->"Italic"], "dt"],
            FontSlant->"Italic"]}], "=", "  ", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Beta]", 
              StyleBox["I",
                FontSlant->"Italic"]}]], "+", " ", 
          StyleBox[
            RowBox[{"\[Mu]", 
              StyleBox["vN",
                FontSlant->"Italic"]}]], " ", "-", " ", 
          RowBox[{
          "\[Mu]R", "   ", ".", 
            "                                                                 \
                                               ", 
            StyleBox[\((5)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "\tConsider now the parameters in these equations.  We call \[Alpha] the \
transmissivity.  The term \[Alpha]",
  StyleBox["SI",
    FontSlant->"Italic"],
  " is a standard kinetic term, based on the idea that the number of \
encounters per unit time between susceptibles and infectives will be \
proportional to the numbers of each.  The transmissivity \[Alpha] is \
determined by both the encounter frequency and the efficiency with which the \
disease is transmitted per encounter.  The parameter \[Gamma] describes \
transitions from the exposed state to the infectious state.  One can show \
that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\^\(-1\)\)]],
  "is the average time an individual spends in the exposed state.  The \
parameter \[Beta] describes the transitions between infected and recovered, \
and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\^\(-1\)\)]],
  "is the average time an individual spends in the infected state.  The \
parameter \[Mu] is the birth and death rate.  It is assumed that all births \
are into the susceptible class, except for a fraction ",
  StyleBox["v",
    FontSlant->"Italic"],
  " which are vaccinated and thereby appear in the recovered class.  The \
death rate is assumed to be the same for all classes.  By adding the four \
equations, we show easily that the total population ",
  StyleBox["N ",
    FontSlant->"Italic"],
  "is constant.         "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scaled Equations", "Subsection"],

Cell[TextData[{
  "\tWe now look more closely at the parameter \[Alpha].  Consider a single \
susceptible.  Let \[Omega] be the number of encounters per unit time this \
single susceptible has with other people.  In a homogeneously mixed \
population, a fraction ",
  StyleBox["I",
    FontSlant->"Italic"],
  "/",
  StyleBox["N",
    FontSlant->"Italic"],
  " of those encounters will be with infectives.  Let \[Rho] be the \
probability that such an encounter leads to an infection for the susceptible. \
 Then the number of new infections per unit time per susceptible is \[Rho]\
\[Omega](",
  StyleBox["I",
    FontSlant->"Italic"],
  "/",
  StyleBox["N",
    FontSlant->"Italic"],
  ")",
  StyleBox[", ",
    FontSlant->"Italic"],
  "so the total number of new infections per unit time is \[Rho]\[Omega](",
  StyleBox["I",
    FontSlant->"Italic"],
  "/",
  StyleBox["N",
    FontSlant->"Italic"],
  ")",
  StyleBox["S  ",
    FontSlant->"Italic"],
  "= (\[Eta]",
  StyleBox["/N)IS, ",
    FontSlant->"Italic"],
  "where \[Eta] = \[Rho]\[Omega]",
  StyleBox[".  ",
    FontSlant->"Italic"],
  "This is the same quantity as \[Alpha]",
  StyleBox["SI",
    FontSlant->"Italic"],
  ", so    "
}], "Text"],

Cell[TextData[{
  "\[Alpha] = \[Eta]/",
  StyleBox["N",
    FontSlant->"Italic"],
  "   .                                                                       \
         ",
  StyleBox["(6)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "The encounter frequency \[Omega] will in reality depend strongly on life \
style, age, and perhaps on population density, but we would not expect it to \
depend on total population.  The probability \[Rho] will depend on the nature \
of the disease as well as the life style.  Clearly the real situation is much \
more complicated than the model, and in the real situation these parameters \
will be different for different classes of individuals.  We ignore such \
heterogeneity here.  Within the context of this simple model, \[Eta] is the \
same for every individual, and it is reasonable to assume that \[Eta] is \
independent of total population ",
  StyleBox["N",
    FontSlant->"Italic"],
  ".  Then we see from equation (6) that the transmissivity \[Alpha], used in \
earlier notebooks, is expected to be inversely proportional to total \
population.  A formulation in terms of \[Eta] will make it more convenient to \
determine how results depend on total population.    "
}], "Text"],

Cell["\tWe introduce the scaled populations ", "Text"],

Cell[TextData[{
  "{",
  StyleBox["s",
    FontSlant->"Italic"],
  ", ",
  StyleBox["e",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", ",
  StyleBox["r",
    FontSlant->"Italic"],
  "}  =  {",
  StyleBox["S",
    FontSlant->"Italic"],
  ", ",
  StyleBox["E",
    FontSlant->"Italic"],
  ", ",
  StyleBox["I",
    FontSlant->"Italic"],
  ", ",
  StyleBox["R",
    FontSlant->"Italic"],
  "}/",
  StyleBox["N",
    FontSlant->"Italic"],
  "    .                                                                ",
  StyleBox["(7)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["Then ", "Text"],

Cell[TextData[{
  "s ",
  StyleBox["+ ",
    FontSlant->"Plain"],
  "e",
  StyleBox[" + ",
    FontSlant->"Plain"],
  "i",
  StyleBox[" + ",
    FontSlant->"Plain"],
  "r",
  StyleBox[
  " = 1   ,                                                                   \
       ",
    FontSlant->"Plain"],
  StyleBox["(8)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["and the equations become", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(ds\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            RowBox[{"-", 
              StyleBox[
                RowBox[{"\[Eta]", 
                  StyleBox["si",
                    FontSlant->"Italic"]}]]}], "  ", "+", " ", 
            RowBox[{"\[Mu]", 
              RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", 
                  StyleBox["v",
                    FontSlant->"Italic"]}], ")"}]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["s",
                  FontSlant->"Italic"]}]]}]}], "  ", ",", 
        "                                                                     \
                        ", 
        StyleBox[\((9)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(de\/dt\),
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Eta]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontSlant->"Italic"], \(\[Gamma]\  + \ \[Mu]\), ")"}], 
              StyleBox["e",
                FontSlant->"Italic"]}]}]}], " ", ",", 
        "                                                                     \
                                       ", 
        StyleBox[\((10)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(di\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["e",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            RowBox[{\((\[Beta]\  + \ \[Mu])\), 
              StyleBox["i",
                FontSlant->"Italic"]}]}]}], " ", ",", 
        "                                                                     \
                                        ", 
        StyleBox[\((11)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{"and", "                  ", 
            StyleBox[\(dr\/dt\),
              FontSlant->"Italic"]}], "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]], " ", "+", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["v",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Mu]", 
                  StyleBox["r",
                    FontSlant->"Italic"]}]], "   ", ".", 
              "                                                               \
                                              ", 
              StyleBox[\((12)\),
                FontWeight->"Bold"]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "\tWe can treat the first three of the above four equations as a set of \
three equations in ",
  StyleBox["s, ",
    FontSlant->"Italic"],
  "e and ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  After these three equations are solved, we can calculate ",
  StyleBox["r",
    FontSlant->"Italic"],
  " from equation (8).  "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Defining the Equations for DynPac", "Subtitle"],

Cell["\<\
\tIn much of what follows, we will be exploring the equilibrium \
states of equations (9) - (11).  Later we will be integrating them \
numerically.  In preparation for this, we define here the equations for \
DynPac.  We start with the state vector, the parameter vector and the slope \
vector.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{s, e, i}];\)\)], "Input"],

Cell[TextData[{
  "This tells DynPac that the three state variables are ",
  StyleBox["s, e",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["i",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(setparm[{\[Eta], \[Beta], \[Gamma], \[Mu], v}];\)\)], "Input"],

Cell[TextData[{
  "This tells DynPac that the\"official\" system parameters are \[Eta], \
\[Beta], \[Gamma], \[Mu], and ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Eta]\)*s*i + \[Mu]*\((1 - v)\) - \[Mu]*s, \[Eta]*s*
              i - \[Gamma]*e - \[Mu]*e, \[Gamma]*e - \[Beta]*i - \[Mu]*
              i};\)\)], "Input"],

Cell["\<\
This defines the slope vector of the equations for DynPac.  Now we \
look at equilibrium states and their stability.  Because births and deaths \
are included, we expect the possibility of endemic states.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Equilibrium States", "Subtitle"],

Cell[CellGroupData[{

Cell["Finding the Equilibrium States", "Subsection"],

Cell["\<\
\tWe start by using the DynPac function findpolyeq, which finds \
equilibrium states for systems with polynomial right-hand sides.\
\>", "Text"],

Cell[BoxData[
    \(equil = Simplify[findpolyeq]\)], "Input"],

Cell[TextData[{
  "As we expected, there are two equilibrium states.  The first one is a \
disease-free state with ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = 1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i",
    FontSlant->"Italic"],
  " = 0, ",
  StyleBox["e",
    FontSlant->"Italic"],
  " = 0, and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  The second equilibrium state is the endemic equilibrium, in which the \
disease is present.  Our main task here is to determine how the stability of \
these equilibria depends on the parameters of the system."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stability of Equilibria", "Subsection"],

Cell["\<\
\tWe expect that for any given set of parameters, only one of the \
two equilibrium states exists as a stable equilibrium.  We now investigate \
that point.  First we name the two equilibria.\
\>", "Text"],

Cell[BoxData[
    \(eqfree = \ equil[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(eqend = equil[\([2]\)]\)], "Input"],

Cell[TextData[{
  "In the disease-free equilibrium, the fraction of susceptibles is (1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  "), which is just the fraction of population not vaccinated at birth.  \
Let's look at the stability of this state."
}], "Text"],

Cell[BoxData[
    \(eigfree\  = \ 
      Eigensystem[\((dermat /. Thread[statevec -> eqfree])\)]\)], "Input"],

Cell[TextData[{
  "The third eigenvalue is -\[Mu], and the associated eigenvector, {1,0,0}, \
represents a deviation of ",
  StyleBox["s",
    FontSlant->"Italic"],
  " from the equilibrium value (with an equal and opposite deviation of ",
  StyleBox["r",
    FontSlant->"Italic"],
  ").  This is still a disease-free state, and the return to equilibrium for \
this type of perturbation occurs on the generation time scale ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\^\(-1\)\)]],
  ".  The other two eigenvalues are a little more complicated.  They are \
roots of a quadratic, which we now obtain explicitly, by dividing the \
characteristic polynomial in \[Lambda] by the factor (\[Lambda] + \[Mu])."
}], "Text"],

Cell[BoxData[
    \(poly = 
      Collect[Simplify[\(-CharacteristicPolynomial[\((dermat /. 
                    Thread[statevec -> 
                        eqfree])\), \[Lambda]]\)/\((\[Lambda] + \[Mu])\)], \
\[Lambda]]\)], "Input"],

Cell[TextData[
"Thus the coefficient of \[Lambda] is (\[Beta]+\[Gamma]+2 \[Mu]), and the \
constant term is  "], "Text"],

Cell[TextData[{
  "\[Beta] \[Gamma]-\[Gamma] \[Eta]+v \[Gamma] \[Eta] +",
  Cell[BoxData[
      \(\(\ \[Beta]\ \[Mu] + \[Gamma]\ \[Mu] + \[Mu]\^2\)\)]],
  " = (\[Beta] + \[Mu])(\[Gamma] + \[Mu]) - \[Eta]\[Gamma](1-",
  StyleBox["v",
    FontSlant->"Italic"],
  ")",
  StyleBox["  .                                        ",
    FontSlant->"Italic"],
  StyleBox["(13)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["\<\
 The equilibrium is stable if and only if both of these are \
positive.  The first is always positive and the second is positive provided\
\
\>", "Text"],

Cell[TextData[{
  "(\[Beta] + \[Mu])(\[Gamma] + \[Mu]) > \[Eta]\[Gamma](1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ")  ,                                                                       \
   ",
  StyleBox["(14)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["\<\
and this is the condition for stability of the disease-free state.  \
If you compare this with the expression for the state variables in the \
endemic equilibrium state, you see, after a little algebra, that when (14) is \
satisfied, two of the endemic state variables are negative, and hence that \
state is irrelevant (this is easier to see from the expressions given below \
for the equilibrium state).  If (14) is violated, then the disease-free state \
is unstable, and any infectives introduced will cause an epidemic.  One \
interesting interpretation of (14) is that it defines a minimum vaccination \
fraction to prevent an epidemic:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(v\_crit\),
          FontSlant->"Italic"], " ", "=", "  ", 
        RowBox[{"1", " ", "-", " ", 
          RowBox[{
          \(\(\((\[Beta]\  + \ \[Mu])\) 
                  \((\[Gamma]\  + \ \[Mu])\)\)\/\[Eta]\[Gamma]\), "   ", ".", 
            "                                                                 \
                             ", 
            StyleBox[\((15)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "\tNow we use equation (14) as the basis for defining two closely related \
and important new parameters -- ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ", called the basic ",
  "reproductive ratio",
  " of the system, and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " called the effective reproductive ratio of the system:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " = ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox["\[Gamma]\[Eta]",
            FontSize->10], 
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontSize->12], 
              StyleBox[\(\[Beta]\  + \ \[Mu]\),
                FontSize->10], 
              StyleBox[")",
                FontSize->10]}], 
            StyleBox[\((\[Gamma]\  + \ \[Mu])\),
              FontSize->10]}]], TraditionalForm]]],
  " ,    ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " = (1 - ",
  StyleBox["v)",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " =  ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontSize->12], 
              RowBox[{
                StyleBox["1",
                  FontSize->10], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox["-",
                  FontSize->12], 
                StyleBox[" ",
                  FontSize->12], 
                StyleBox["v",
                  FontSize->12]}], 
              StyleBox[")",
                FontSize->12]}], 
            StyleBox["\[Gamma]\[Eta]",
              FontSize->10]}], 
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontSize->12], 
              StyleBox[\(\[Beta]\  + \ \[Mu]\),
                FontSize->10], 
              StyleBox[")",
                FontSize->10]}], 
            StyleBox[\((\[Gamma]\  + \ \[Mu])\),
              FontSize->10]}]], TraditionalForm]]],
  "     .                                         ",
  StyleBox["(16)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Equation (15) can then be written as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(v\_crit\),
            FontSlant->"Italic"], " ", "=", "  ", "1"}], TextForm]]],
  "- 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAt times, it is useful to replace \[Eta] by an equivalent expression in \
terms of ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", so for convenience we define that expression now."
}], "Text"],

Cell[BoxData[
    \(\[Eta]exp\  := \ 
      R*\((\[Beta] + \[Mu])\)*\((\[Gamma] + \[Mu])\)/\((\((1 - 
                  v)\)*\[Gamma])\)\)], "Input"],

Cell[TextData[{
  "Also, we sometimes wish to go the other way, from ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "to \[Eta], so we define"
}], "Text"],

Cell[BoxData[
    \(Rexp := \((\((1 - 
                v)\)*\[Gamma]*\[Eta])\)/\((\((\[Beta] + \[Mu])\)*\((\[Gamma] \
+ \[Mu])\))\)\)], "Input"],

Cell[TextData[{
  "As an example, we look at the endemic equilibrium state expressed in terms \
of ",
  StyleBox["R",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(eqendmod = FullSimplify[eqend /. \[Eta] -> \[Eta]exp]\)], "Input"],

Cell[TextData[{
  "The transition at ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1 is now evident.  For ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "= 1, the two equilibria coincide, so that is a bifurcation point of the \
system.  "
}], "Text"],

Cell[TextData[{
  "\tWhen ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, the disease free state is unstable, and the endemic state has \
positive coordinates.  We expect that the endemic state is stable for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " >1, in which case the bifurcation at ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1 is an exchange of stabilities.  Let's verify this.  We begin by \
calculating the characteristic polynomial at the endemic equilibrium."
}], "Text"],

Cell[BoxData[
    \(polyend = \(-Collect[
            CharacteristicPolynomial[\((dermat /. 
                  Thread[statevec -> 
                      eqend])\), \[Lambda]], \[Lambda]]\) /. \[Eta] -> \
\[Eta]exp\)], "Input"],

Cell["We now gather the coefficients of this polynomial.", "Text"],

Cell[BoxData[
    \(coefflist = Simplify[CoefficientList[polyend, \[Lambda]]]\)], "Input"],

Cell[TextData[{
  "The coefficients given below are for the polynomial in the form c0",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^3\)]],
  "+ c1",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  " + c2\[Lambda] + c3 ."
}], "Text"],

Cell[BoxData[
    \(c0 = coefflist[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(c1 = coefflist[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(c2 = coefflist[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(c3 = coefflist[\([1]\)]\)], "Input"],

Cell[TextData[{
  "\tWe will now use the Routh-Hurwitz criterion (see for example ",
  StyleBox["Encyclopedia of Mathematics on CD-Rom",
    FontWeight->"Bold"],
  ", Kluwer, 1997, entry under Routh-Hurwitz Criterion) to establish the \
stability of the endemic equilibrium for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1.  In this case of a cubic polynomial, the Routh-Hurwitz criterion for \
stability reduces to three conditions:  c1 > 0, c3 > 0, and c1*c2 - c0*c3 > \
0.  It is easy to see that c1 is positive, and the condition ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1 guarantees that c3 is positive.  The remaining quantity that must be \
positive is"
}], "Text"],

Cell[BoxData[
    \(ctest = FullSimplify[c1*c2 - c0*c3]\)], "Input"],

Cell[TextData[{
  "To make the result clearer,  we collect by powers of ",
  StyleBox["q",
    FontSlant->"Italic"],
  " = (",
  StyleBox["R",
    FontSlant->"Italic"],
  " - 1):"
}], "Text"],

Cell[BoxData[
    \(ctestcoeff\  = \ 
      Simplify[CoefficientList[Collect[\((ctest /. R -> \((q + 1)\))\), q], 
          q]]\)], "Input"],

Cell[TextData[{
  "All the coefficients of powers of (",
  StyleBox["R",
    FontSlant->"Italic"],
  "-1) are positive, so the expression ctest is positive for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1.  Thus with the help of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and the Routh-Hurwitz criterion, we have gotten off rather easily, and we \
conclude that the endemic equilibrium is indeed stable when ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1.  An important consequence of this is that there can be no sustained \
oscillations in the form of a limit cycle.  In order to get a limit cycle \
from this configuration, we need a Hopf bifurcation, in which the endemic \
equilibrium would go unstable and throw off a stable limit cycle.  Because \
that equilibrium is stable for all values of ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, there cannot be such a bifurcation.  Even so, it is possible that \
the approach to the endemic equilibrium could be a damped oscillation.  We \
look at that possibility briefly now, by using the standard test for \
determining whether a cubic has three real roots, or one real and two complex \
roots (see e.g. ",
  StyleBox["Standard Mathematical Tables",
    FontWeight->"Bold"],
  ", CRC Press, 25th edition, 1978, p. 9).  The test is based on the \
quantities ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", and dis defined below."
}], "Text"],

Cell[BoxData[
    \(a = FullSimplify[\((1/3)\)*\((3*c2 - c1^2)\)]\)], "Input"],

Cell[BoxData[
    \(b = FullSimplify[\((1/27)\)*\((2*c1^3 - 9*c1*c2 + 27*c3)\)]\)], "Input"],

Cell["\<\
The nature of the roots is determined by the sign of the quantity \
dis given below.  If dis > 0, there will be one real and two complex \
conjugate roots.  If dis < 0, there will be three real unequal roots.  If dis \
= 0, there will be three real roots of which at least two are equal.  \
\>", 
  "Text"],

Cell[BoxData[
    \(dis = 
      Simplify[Collect[\((b^2/4\  + \ a^3/27)\) /. R -> \((q + 1)\), 
          q]]\)], "Input"],

Cell[TextData[{
  "The constant term is negative.  Hence states just above the threshhold of \
",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1 are NOT oscillatory.  For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " very large, the ",
  Cell[BoxData[
      \(TraditionalForm\`q\^4\)]],
  " term dominates, and it is also negative, so again the equilibrium is not \
oscillatory.  The coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`q\^3\)]],
  "is positive.  For the special case \[Beta] = \[Gamma] (corresponding to \
equal times for latent and infectious periods), the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(q\^4\ \)\)]],
  "vanishes identically, and there will be oscillations for sufficiently \
large ",
  StyleBox["R.  ",
    FontSlant->"Italic"],
  "It is difficult to say much more without specializing the parameters \
further.  One case of interest is that of small \[Mu], corresponding to the \
generation time scale being much longer than the disease time scales.  We \
will make approximations based on small \[Mu] several times in the work \
below."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of Equilibrium and Stability", "Subsection"],

Cell[TextData[{
  "\tThe fundamental parameter in determining the system behavior is the \
reproductive ratio ",
  StyleBox["R,",
    FontSlant->"Italic"],
  " given by equation (16).  For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1, there is a stable disease-free equilibrium, and there is no endemic \
equilibrium in that case.  If infectives are introduced, there will be no \
epidemic and the system will return to the disease-free state.  If ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "> 1, the disease-free equilibrium exists but is unstable.  If infectives \
are introduced into the disease-free state, there will be an epidemic, and \
the system will asymptotically approach the endemic state, which is stable \
for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1.  The parametric threshhold ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "= 1 may be interpreted in terms of a critical vaccination fraction, as \
given by equation (15).  That is the minimum vaccination fraction necessary \
to prevent an epidemic.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpretation of Reproductive Ratio", "Subsection"],

Cell[TextData[{
  "\tWe give here two equivalent interpretive results for the ",
  "reproductive ratio",
  " defined by equation (16).  The interpretations are based on the \
estimation of the rate of production of infectives (first interpretation), or \
the number of infectives produced by one infective (second interpretation).  \
These estimates are made for an arbitrary state, not necessarily equilibrium. \
 For the estimate based on rates, we start from equations (10) and (11).  We \
see that necessary and sufficient conditions that both ",
  StyleBox["e",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  " increase are  \[Eta]",
  StyleBox["si",
    FontSlant->"Italic"],
  "  >  (\[Gamma] + \[Mu])",
  StyleBox["e  ",
    FontSlant->"Italic"],
  ",  and  \[Gamma]",
  StyleBox["e ",
    FontSlant->"Italic"],
  " > (\[Beta] + \[Mu])",
  StyleBox["i.  ",
    FontSlant->"Italic"],
  "These may be combined to give   "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          StyleBox[
            RowBox[{"\[Gamma]\[Eta]", 
              StyleBox["s",
                FontSlant->"Italic"]}]], 
          RowBox[{
            RowBox[{
              StyleBox["(",
                FontSize->12], \(\[Beta]\  + \ \[Mu]\), ")"}], 
            \((\[Gamma]\  + \ \[Mu])\)}]], "  ", ">", "  ", 
        RowBox[{
        "1", "   ", ".", 
          "                                                                   \
                          ", 
          StyleBox[\((17)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "This is the basic condition for an epidemic for a state in which the \
fraction of susceptibles is ",
  StyleBox["s",
    FontSlant->"Italic"],
  ".  Now we give a less direct but equivalent derivation of (17), in terms \
of numbers rather than rates.  A single infective is, on the average, \
infectious for a time 1/(\[Beta] + \[Mu]).  During this time, the total \
number of encounters with other people will be \[Omega]/(\[Beta] + \[Mu]).  A \
fraction ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "of those encounters will be with susceptibles, and the probability of an \
infection for each such encounter is \[Rho].  Thus the number of exposed \
individuals produced by a single infective is \[Rho]\[Omega]",
  StyleBox["s",
    FontSlant->"Italic"],
  "/(\[Beta] + \[Mu]) = \[Eta]",
  StyleBox["s",
    FontSlant->"Italic"],
  "/(\[Beta] + \[Mu]).  Most of those exposed become infected, but not quite \
all, because there is a natural death rate for the exposed.  In most cases \
the death rate is much lower than the transition rate from exposed to \
infectious, so we may take the fraction of exposed that become infectious to \
be 1minus the fraction that die = 1 - \[Mu]/(\[Gamma] + \[Mu]) = \[Gamma]/(\
\[Gamma] + \[Mu]).  Thus the total number of infectives produced by one \
infective is given by the function ",
  StyleBox["Ri",
    FontSlant->"Italic"],
  "(",
  StyleBox["s",
    FontSlant->"Italic"],
  "), where  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["R",
                  FontSlant->"Italic"], 
                StyleBox["i",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox["(",
                FontSlant->"Plain"], 
              StyleBox["s",
                FontSlant->"Italic"], 
              StyleBox[")",
                FontSlant->"Plain"]}]}], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["   ",
            FontSlant->"Plain"], 
          RowBox[{
            FractionBox[
              StyleBox[
                RowBox[{"\[Gamma]\[Eta]", 
                  StyleBox["s",
                    FontSlant->"Italic"]}]], 
              RowBox[{
                RowBox[{
                  StyleBox["(",
                    FontSize->12], \(\[Beta]\  + \ \[Mu]\), ")"}], 
                \((\[Gamma]\  + \ \[Mu])\)}]], 
            StyleBox["   ",
              FontSize->12], 
            StyleBox["=",
              FontSize->12], 
            StyleBox["  ",
              FontSize->12], 
            RowBox[{
              SubscriptBox[
                StyleBox["R",
                  FontSlant->"Italic"], "0"], 
              StyleBox["s",
                FontSlant->"Italic"]}]}]}], 
        StyleBox["  ",
          FontSize->12], 
        StyleBox[",",
          FontSize->12], 
        StyleBox[
          RowBox[{
            
            StyleBox[
              "                                                           ",
              FontSize->12], 
            StyleBox[" ",
              FontWeight->"Bold"]}]], 
        StyleBox[\((18)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "and this is a generalization of the ",
  "reproductive ratio",
  " defined earlier by equation (16).  The rate defined in (18) depends on \
the state of the system through the fraction of susceptibles ",
  StyleBox["s",
    FontSlant->"Italic"],
  ".  Now we see that the condition (17) is just the condition that each \
infective produce more than one new infective, which is clearly the condition \
for an epidemic.  "
}], "Text"],

Cell[TextData[{
  "\tIf we apply condition (17) to the particular state of an initial \
disease-free equilibrium, in which ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = 1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ", we get"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["Ri",
            FontSlant->"Italic"], " ", 
          RowBox[{"(", 
            RowBox[{"1", "-", "  ", 
              StyleBox["v",
                FontSlant->"Italic"]}], " ", ")"}]}], 
        StyleBox[
          RowBox[{"  ", 
            StyleBox[" ",
              FontSlant->"Italic"]}]], "=", "  ", 
        RowBox[{
          FractionBox[
            RowBox[{"\[Gamma]\[Eta]", 
              RowBox[{
                StyleBox["(",
                  FontSlant->"Plain"], 
                RowBox[{
                  StyleBox["1",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], 
                  StyleBox["-",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], 
                  StyleBox["v",
                    FontSlant->"Italic"]}], ")"}]}], 
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontSize->12], \(\[Beta]\  + \ \[Mu]\), ")"}], 
              \((\[Gamma]\  + \ \[Mu])\)}]], "  ", "=", "  ", 
          RowBox[{
            StyleBox["R",
              FontSlant->"Italic"], 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], ">", "  ", 
            RowBox[{
            "1", "  ", ".", 
              "                                                               \
                   ", 
              StyleBox[\((19)\),
                FontWeight->"Bold"]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Hence the ",
  "reproductive ratio",
  " ",
  StyleBox["R",
    FontSlant->"Italic"],
  " defined earlier is just the generalized reproductive ratio (18) evaluated \
at the disease free equilibrium in which ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = 1 - ",
  StyleBox["v.  ",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\tIn the endemic equilibrium state, we would expect the ",
  "reproductive ratio",
  " to be exactly 1.  Let's verify that.  We substitute into (18) the value \
of ",
  StyleBox["s",
    FontSlant->"Italic"],
  " in the endemic state, namely "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          RowBox[{" ", 
            StyleBox[" ",
              FontSlant->"Italic"]}]], 
        RowBox[{
          StyleBox[\(s\_end\),
            FontSlant->"Italic"], "     ", "=", "   ", 
          RowBox[{
          \(\(\((\[Beta] + \[Mu])\)\ \((\[Gamma] + \[Mu])\)\)\/\(\[Gamma]\ 
                  \[Eta]\)\), "    ", ".", 
            "                                                                 \
                                   ", 
            StyleBox[\((20)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell["The result is", "Text"],

Cell[TextData[{
  "Ri",
  StyleBox["(",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`s\_end\)]],
  ")  =  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            SubscriptBox[
              StyleBox[
                RowBox[{
                  StyleBox["\[Gamma]\[Eta]",
                    FontSize->10], 
                  StyleBox["s",
                    FontSize->10,
                    FontSlant->"Italic"]}]], 
              StyleBox[\(en d\),
                FontSlant->"Italic"]], 
            RowBox[{
              RowBox[{"(", 
                StyleBox[\(\[Beta]\  + \ \[Mu]\),
                  FontSize->10], 
                StyleBox[")",
                  FontSize->10]}], 
              StyleBox[\((\[Gamma]\  + \ \[Mu])\),
                FontSize->10]}]],
          FontSlant->"Plain"], TraditionalForm]]],
  " ",
  StyleBox[
  "=  1  ,                                                                  ",
    
    FontSlant->"Plain"],
  StyleBox["(21)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["as expected. ", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Growth Rates for Epidemics", "Subtitle"],

Cell[TextData[{
  "\tIn this section, we look at the linearized behavior near the disease \
free equilibrium, with the goal of seeing how the initial epidemic growth \
rate depends on the parameters of the system.  Thus we start in the disease \
free equilibrium, and we perturb that state by adding a few exposed or \
infectives.  As we have already seen, the perturbation will decay if ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1 and will grow if ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "> 1.  Although we will look at both cases, we concentrate primarily on ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1.  "
}], "Text"],

Cell[TextData[{
  "\tAs we saw earlier, one of the three eigenvalues for perturbations to the \
disease-free state is \[Lambda] = -\[Mu].  States governed by this eigenvalue \
are those in which there are no infectives or exposed, and in which the \
perturbation is to the distribution of the population between ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["r",
    FontSlant->"Italic"],
  ".  This is basically a perturbation in the fraction vaccinated, and it \
corrects itself on the slow generational time scale.  "
}], "Text"],

Cell["\<\
\tThe other two modes are more interesting.  We derived earlier the \
equation for the eigenvalues of those modes:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
        \(\[Lambda]\^2\), " ", "+", " ", 
          \(\((\[Beta]\  + \ \[Gamma]\  + \ 2  \[Mu])\) \[Lambda]\), " ", 
          "+", " ", 
          RowBox[{"{", 
            RowBox[{
            \(\((\[Beta]\  + \ \[Mu])\) \((\[Gamma]\  + \ \[Mu])\)\), " ", 
              "-", " ", 
              RowBox[{"\[Eta]\[Gamma]", 
                RowBox[{"(", 
                  RowBox[{"1", " ", "-", " ", 
                    StyleBox["v",
                      FontSlant->"Italic"]}], ")"}]}]}], "}"}]}], "  ", "=", 
        "  ", 
        RowBox[{"0", "   ", ".", 
          StyleBox[
            RowBox[{"                                                    ", 
              StyleBox[" ",
                FontWeight->"Bold"]}]], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Bold"], 
            StyleBox["22",
              FontWeight->"Bold"], 
            StyleBox[")",
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "It is useful to replace \[Eta] in this equation by its expression in terms \
of ",
  StyleBox["R",
    FontSlant->"Italic"],
  " (inverse of equation (16)), to get"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Lambda]\^2\),
            "Text"], 
          StyleBox[" ",
            "Text"], 
          StyleBox["+",
            "Text"], 
          StyleBox[" ",
            "Text"], 
          StyleBox[\((\[Beta]\  + \ \[Gamma]\  + \ 2 \[Mu])\),
            "Text"], 
          StyleBox[" ",
            "Text"], 
          StyleBox["+",
            "Text"], 
          StyleBox[" ",
            "Text"], 
          RowBox[{
            StyleBox[\((\[Beta]\  + \ \[Mu])\),
              "Text"], 
            StyleBox[\((\[Gamma]\  + \ \[Mu])\),
              "Text"], 
            RowBox[{
              StyleBox["(",
                "Text"], 
              RowBox[{
                StyleBox["1",
                  "Text"], 
                StyleBox[" ",
                  "Text"], 
                StyleBox["-",
                  "Text"], 
                StyleBox[" ",
                  "Text"], 
                StyleBox["R",
                  "Text",
                  FontSlant->"Italic"]}], 
              StyleBox[")",
                "Text"]}]}]}], 
        StyleBox["   ",
          "Text"], 
        StyleBox["=",
          "Text"], 
        StyleBox["  ",
          "Text"], 
        RowBox[{
          StyleBox["0",
            "Text"], 
          StyleBox["   ",
            "Text"], 
          StyleBox[".",
            "Text"], 
          StyleBox[
            RowBox[{
              
              StyleBox[
                "                                                             \
  ",
                "Text"], 
              StyleBox[" ",
                FontWeight->"Bold"]}]], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Bold"], 
            StyleBox["23",
              FontWeight->"Bold"], 
            StyleBox[")",
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "This makes obvious the stability condition ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "< 1.  We introduce"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\&^\)\)]],
  " = \[Beta] + \[Mu]  ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Gamma]\&^\)\)]],
  " = \[Gamma] + \[Mu]   .                                                    \
              ",
  StyleBox["(24)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "(Although we will retain \[Mu] here, we could, because \[Mu] << \[Beta] \
and \[Gamma] , ignore the distinction between \[Beta] and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\&^\)]],
  ", and \[Gamma] and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\&^\)]],
  ".)  The two roots of the quadratic are"
}], "Text"],

Cell[TextData[{
  "\[Lambda] = -",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \((\(\[Beta]\&^\)\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Gamma]\ \)\&^\)\)]],
  ") \[PlusMinus]",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\(\@\(\(1\/4\) \((\(\[Beta]\&^\)\  + \ \(\[Gamma]\&^\))\)\^2 - \ 
              \(\[Beta]\&^\) \(\[Gamma]\&^\) \((1\  - \ R)\)\)\ \)\+\ \)\)]],
  "   .                                               ",
  StyleBox["(25)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1, both roots are negative, and they determine how rapidly the \
introduced disease will die away.  For ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "= 0, for example, the two roots are -",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\&^\)]],
  " and -",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\&^\)]],
  " , so the disease dies out on the basic time scales of the disease itself. \
 If ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\&^\ \)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Gamma]\&^\ \)\)]],
  "are not too different, then all of the eigenvalues for ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "in the range (0,1) give time scales comparable with 1/",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\&^\)]],
  " and 1/",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\&^\)]],
  " .  At ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1, one of the eigenvalues is -(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\&^\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Gamma]\&^\)\)]],
  " ) and the other is zero, and this of course is the bifurcation at which \
the disease-free and endemic states coincide.  "
}], "Text"],

Cell[TextData[{
  "\tFor ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "> 1, we know from our earlier discussion that there will be an epidemic.  \
For that case, we see from equation (25) that one root is positive and one is \
negative.  Thus for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, the disease-free equilibrium becomes a saddle point with a dimension \
two stable manifold and a dimension one unstable manifold.  For moderate ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", the growth rate is of the order of the disease time scales 1/",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\&^\)]],
  " and 1/",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\&^\)]],
  "  (and we continue to assume that these scales are comparable).  For very \
large ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", the positive eigenvalue can be approximated by"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Lambda]\_+\), " ", "=", " ", 
        RowBox[{\(\@\(\(\[Beta]\&^\) \(\[Gamma]\&^\) R\)\), " ", "-", " ", 
          RowBox[{
            StyleBox[\(1\/2\),
              FontSize->9], \((\(\[Beta]\&^\)\  + \ \(\[Gamma]\&^\)\ )\)}], 
          " ", "+", " ", 
          RowBox[{
            StyleBox["O",
              FontSlant->"Italic"], 
            RowBox[{
              RowBox[{"(", 
                StyleBox[\(R\^\(-1\)\),
                  FontSlant->"Italic"], ")"}], "      ", ".", 
              "                                                               \
         ", 
              StyleBox[\((26)\),
                FontWeight->"Bold"]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Thus for large ",
  StyleBox["R, ",
    FontSlant->"Italic"],
  "the epidemic growth rate can be larger than the basic disease time scales \
by a factor of order ",
  Cell[BoxData[
      \(TraditionalForm\`\@R\)]],
  ".  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Oscillatory Approach to Endemic Equilibrium", "Subtitle"],

Cell[TextData[{
  "\tIn this section, we study the linearized equations about the endemic \
state.  In particular, we seek an estimate of the \"period\" of the damped \
oscillations.  As shown in section 3, the characteristic polynomial at the \
endemic state has the form c0",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^3\)]],
  "+ c1",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  " + c2\[Lambda] + c3 where"
}], "Text"],

Cell[BoxData[
    \({c0, c1, c2, c3}\)], "Input"],

Cell["The characteristic polynomial is then", "Text"],

Cell[BoxData[
    \(charendpoly = 
      c3 + c2*\[Lambda] + c1*\[Lambda]\^2 + \[Lambda]\^3\)], "Input"],

Cell[TextData[{
  "\tWe can get some simple approximate results in the special case when \
\[Mu] is much smaller than both \[Gamma] and \[Beta].  This is in fact the \
typical case, because \[Mu] is of the order of 1/70 y",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["r",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ", and \[Gamma] and \[Mu] are typically around 50 y",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["r",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ", assuming that the latent and infectious periods are of the order of a \
week.  We may exploit the smallness of \[Mu] by expanding the roots of the \
the characteristic polynomial.  A little preliminary investigation shows that \
one root is of order one as \[Mu]\[Rule]0, while the other two roots are of \
order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\^\(1/2\)\)]],
  " as \[Mu]\[Rule]0.  For the order one root, the characteristic polynomial \
reduces to   "
}], "Text"],

Cell[BoxData[
    \(charendpoly1\  = charendpoly /. \[Mu] -> 0\)], "Input"],

Cell["so the order one root is approximately", "Text"],

Cell[BoxData[
    \(\(root1 = \(-\((\[Beta] + \[Gamma])\)\);\)\)], "Input"],

Cell[TextData[{
  "For the other two roots, we take the first three terms in an expansion in \
powers of \[Zeta] = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\^\(1/2\ \)\)]],
  "(we will actually only use the first two terms): "
}], "Text"],

Cell[BoxData[
    \(oscroot = d1*\[Zeta]\  + d2*\[Zeta]\^2 + d3*\[Zeta]\^3\)], "Input"],

Cell[BoxData[
    \(osclist\  = 
      Simplify[CoefficientList[\((\(charendpoly /. \[Mu] -> \[Zeta]\^2\) /. \
\[Lambda] -> oscroot)\), \[Zeta]]]\)], "Input"],

Cell["\<\
We see that the first two nonzero terms involve only d1 and d2.  We \
set those coefficients to zero and solve for d1 and d2:\
\>", "Text"],

Cell[BoxData[
    \(Solve[{osclist[\([3]\)] == 0, osclist[\([4]\)] == 0}, {d1, 
        d2}]\)], "Input"],

Cell["\<\
Combining the above results, we get the final expression for the \
two roots associated with the oscillations:  \
\>", "Text"],

Cell[TextData[{
  "\[Lambda]osc = -\[Delta] \[PlusMinus] ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "\[Omega]osc",
  StyleBox[" ",
    FontSlant->"Italic"],
  "  ,                                                                        \
    ",
  StyleBox["(27)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["where", "Text"],

Cell[BoxData[
    \(\(\[Omega]osc := \@\(\(\((R - 1)\)*\[Beta]*\[Gamma]*\[Mu]\)\/\(\[Beta] \
+ \[Gamma]\)\);\)\)], "Input"],

Cell[BoxData[
    \(\(\[Delta] := \(\[Mu]*\((\[Beta]*\[Gamma] + R*\((\[Beta]\^2 + \[Beta]*\
\[Gamma] + \[Gamma]\^2)\))\)\)\/\(2*\((\[Beta] + \[Gamma])\)\^2\);\)\)], \
"Input"],

Cell[TextData["The period constructed from \[Omega]osc is"], "Text"],

Cell[TextData[{
  StyleBox["2\[Pi]",
    FontSize->10],
  Cell[BoxData[
      FormBox[
        SqrtBox[
          StyleBox[
            RowBox[{
              FractionBox[
                StyleBox["1",
                  FontSize->12], 
                StyleBox["\[Mu]",
                  FontSize->12]], 
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    StyleBox["1",
                      FontSize->12], 
                    StyleBox["\[Beta]",
                      FontSize->12]], " ", "+", " ", 
                  FractionBox[
                    StyleBox["1",
                      FontSize->12], 
                    StyleBox["\[Gamma]",
                      FontSize->12]]}], ")"}], 
              FractionBox[
                StyleBox["1",
                  FontSize->12], 
                StyleBox[\(R\  - \ 1\),
                  FontSize->12]]}],
            FontSize->10]], TraditionalForm]],
    FontSize->10],
  "    .                                                            ",
  StyleBox["(28)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "This approximate formula for the period is given by R.M. Anderson and R.M. \
May, in ",
  StyleBox["Infectious Diseases of Humans",
    FontWeight->"Bold"],
  ", Oxford Press 1991, p. 125.  Following their presentation, we may write \
the period in terms of \[Tau] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FractionBox[
              StyleBox["1",
                FontSize->12], 
              StyleBox["\[Beta]",
                FontSize->12]], " ", "+", " ", 
            FractionBox[
              StyleBox["1",
                FontSize->12], 
              StyleBox["\[Gamma]",
                FontSize->12]]}], ")"}], TraditionalForm]]],
  " , the total time of infection (latent plus infectious periods), and ",
  StyleBox["A",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox["1",
            FontSize->12], 
          RowBox[{
            StyleBox["\[Mu]R",
              FontSize->10], 
            StyleBox[" ",
              FontSize->12]}]], TraditionalForm]]],
  " , which may be interpreted as the average age at infection (see below).  \
Then the period is 2\[Pi]",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{"A", " ", 
            RowBox[{"\[Tau]", "/", 
              RowBox[{"(", 
                RowBox[{"1", "-", 
                  StyleBox[
                    RowBox[{
                      StyleBox["A",
                        FontSlant->"Italic"], "\[Mu]"}]]}], ")"}]}]}]], 
        TraditionalForm]]],
  "\[TildeTilde] 2\[Pi]",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          StyleBox[
            RowBox[{
              StyleBox["A",
                FontSlant->"Italic"], "\[Tau]"}]]], TraditionalForm]]],
  " provided ",
  StyleBox["A",
    FontSlant->"Italic"],
  "\[Mu] << 1."
}], "Text"],

Cell[TextData[{
  "\tConsider briefly the interpretation of ",
  StyleBox["A ",
    FontSlant->"Italic"],
  "as the average age of infection.  In the endemic state, the \"",
  StyleBox["S-",
    FontSlant->"Italic"],
  "tank\" contains (1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ")/",
  StyleBox["R ",
    FontSlant->"Italic"],
  "susceptibles (this is the equilibrium value of ",
  StyleBox["s",
    FontSlant->"Italic"],
  ").  The inflow to the tank is \[Mu](1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ").  The outflow, which is split between the ",
  StyleBox["E-",
    FontSlant->"Italic"],
  "tank and the death tank, is also equal to this.  Thus the average time a \
susceptible is in the tank is "
}], "Text"],

Cell[TextData[{
  "A = ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontSize->12], 
                RowBox[{
                  StyleBox["1",
                    FontSize->12,
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSize->12], 
                  StyleBox["-",
                    FontSize->12], 
                  StyleBox[" ",
                    FontSize->12], 
                  StyleBox["v",
                    FontSize->12]}], 
                StyleBox[")",
                  FontSize->12]}], 
              StyleBox["/",
                FontSize->12], 
              StyleBox["R",
                FontSize->10]}], 
            RowBox[{
              StyleBox["\[Mu]",
                FontSize->10,
                FontSlant->"Plain"], 
              StyleBox["(",
                FontSize->10,
                FontSlant->"Plain"], 
              RowBox[{
                StyleBox["1",
                  FontSize->12,
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSize->12,
                  FontSlant->"Plain"], 
                StyleBox["-",
                  FontSize->12,
                  FontSlant->"Plain"], 
                StyleBox[
                  RowBox[{
                    StyleBox[" ",
                      FontSize->12,
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSize->12]}]], 
                StyleBox["v",
                  FontSize->12]}], 
              StyleBox[")",
                FontSlant->"Plain"]}]],
          FontSize->10], TraditionalForm]]],
  "  = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            StyleBox["1",
              FontSize->12,
              FontSlant->"Plain"], 
            StyleBox[
              RowBox[{
                StyleBox["\[Mu]",
                  FontSize->10,
                  FontSlant->"Plain"], 
                StyleBox["R",
                  FontSize->10]}]]], "  "}], TraditionalForm]]],
  "  .                                                                      ",
  
  StyleBox["(29)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "\tThe approximation of small \[Mu] has blurred a point made earlier.  \
Within this approximation, the perturbations to the endemic state are always \
oscillatory for ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "> 1.  The exact result (which can be established easily from the \
expression for dis in section 3) is that there is a small range of ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "values (",
  StyleBox["R ",
    FontSlant->"Italic"],
  "- 1",
  StyleBox[" ",
    FontSlant->"Italic"],
  "= ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(\[Mu])) for which the perturbations are not oscillatory."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Application to Measles", "Subtitle"],

Cell[CellGroupData[{

Cell["Case of No Vaccinations", "Subsection"],

Cell[TextData[{
  "\tIn this section, we look at some results for measles.  We begin with the \
case of no vaccinations.  For the time unit we use years.  We take \[Mu] = \
1/70 y",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["r",
              FontSlant->"Plain"], 
            RowBox[{"-", 
              StyleBox["1",
                FontSlant->"Plain"]}]],
          FontSlant->"Italic"], TraditionalForm]]],
  ", and we take \[Beta] = \[Gamma] = 60 y",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["r",
              FontSlant->"Plain"], 
            RowBox[{"-", 
              StyleBox["1",
                FontSlant->"Plain"]}]],
          FontSlant->"Italic"], TraditionalForm]]],
  ", corresponding to latent and infectious periods of about 6 days each.  \
For the basic ",
  "reproductive ratio",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ", we take the value given by H.W. Hethcote (\"Three Basic Epidemiological \
Models,\" in ",
  StyleBox["Applied Mathematical Ecology",
    FontWeight->"Bold"],
  ", ed. S.A. Levin, T.G. Hallam, and L.J. Gross, Springer, 1989) for the US \
in the time period 1912 - 1928, namely ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 12.3.  This corresponds to an \[Eta] value of"
}], "Text"],

Cell[BoxData[
    \(\[Eta]val\  = \[Eta]exp\  /. 
        Thread[{R, \[Mu], \[Beta], \[Gamma], v} -> {12.3, 1.0/70.0, 60.0, 
              60.0, 0.0}]\)], "Input"],

Cell["\<\
Now we send all of these values to DynPac, first looking at the \
parameter vector to remind ourselves of the order of parameters:  \
\>", 
  "Text"],

Cell[BoxData[
    \(parmvec\)], "Input"],

Cell[BoxData[
    \(\(parmval = {\[Eta]val, 60.0, 60.0, 1.0/70.0, 0.0};\)\)], "Input"],

Cell["We also set units for the time variable.", "Text"],

Cell[BoxData[
    \(\(timeunit\  = \ "\<yr\>";\)\)], "Input"],

Cell["\tThe endemic equilibrium state is", "Text"],

Cell[BoxData[
    \(eqendval = eqstateval[eqend]\)], "Input"],

Cell["Let's check the stability:", "Text"],

Cell[BoxData[
    \(classify[eqend]\)], "Input"],

Cell["\<\
For the present choice of parameters, we see that most of the \
population (around 92%) has acquired immunity by having the disease.  The \
endemic level of susceptibles is only 8%, and the endemic total of exposed \
and infectives is only a little over 0.04%.  It is interesting that the \
disease survives at such a low level.  The average age at infection is \
\>", 
  "Text"],

Cell[BoxData[
    \(A = 1/\((\[Mu]*Rexp)\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[A]\)], "Input"],

Cell["Thus the age of first infection is a little under 6 years.  ", "Text"],

Cell["\<\
\tNow let's look at the time scales for the damped oscillations \
about the endemic state.  The period of the oscillations is\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[\((2*\[Pi])\)/\((\[Omega]osc)\)] /. R -> 12.3\)], "Input"],

Cell["\<\
which is a little under three years.  The e-folding damping time is\
\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[1/\[Delta]] /. R -> 12.3\)], "Input"],

Cell["\<\
Nearly 15 years!  This is a very oscillatory system.  Let's \
calculate a solution and look at the oscillations.  We begin by resetting the \
plotting and integration options to defaults, and then choosing the \
integration parameters.\
\>", "Text"],

Cell[BoxData[
    \(\(intrest;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell["\<\
We choose the time step to be 0.005 which corresponds to a little \
under two days.  We choose the initial time to be 0.0, and we take the number \
of time steps to be 8000, which is 40 years.  We start the oscillation with \
an additional 1% of the population exposed.  \
\>", "Text"],

Cell[BoxData[
    \(h = 0.005; t0 = 0.0; nsteps = 8000; 
    init = eqendval + {0, 0.01, 0};\)], "Input"],

Cell["Now we use integrate to calculate the solution.", "Text"],

Cell[BoxData[
    \(\(ep1 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell["Now we plot the time course of the number of infectives.", "Text"],

Cell[BoxData[
    \(\(asprat\  = \ 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<\>";\)\)], "Input"],

Cell[BoxData[
    \(\(imsize = 410;\)\)], "Input"],

Cell[BoxData[
    \(\(sciflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = timeplot[ep1, 3];\)\)], "Input"],

Cell["\<\
Clearly it wouldn't take much of an external change to make this \
system periodic.  Note the nonlinear change of frequency with amplitude.  In \
the early times when the amplitude is high, the period of oscillation is \
greater.  Near the end of the 40 years, the period is consistent with the \
value of 2.86 years calculated for linearized oscillations.  Now we plot the \
number of exposed.\
\>", "Text"],

Cell[BoxData[
    \(\(graph2 = timeplot[ep1, 2];\)\)], "Input"],

Cell[TextData[{
  "Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has changed the graphs scale, so the two graphs are actually closer than \
they appear.  We compare them: "
}], "Text"],

Cell[BoxData[
    \(\(show[graph1, graph2];\)\)], "Input"],

Cell["\<\
As we would expect, the curves are essentially the same on this \
extended time scale.\
\>", "Text"],

Cell["\tFinally, we look at the number of susceptibles.", "Text"],

Cell[BoxData[
    \(\(axorg\  = \ {0, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 40.1}, {0, 0.12}};\)\)], "Input"],

Cell[BoxData[
    \(\(graph3 = timeplot[ep1, 1];\)\)], "Input"],

Cell["\<\
Before combining all three graphs, we rescale the susceptibles by \
dividing the numbers by 40.\
\>", "Text"],

Cell[BoxData[
    \(\(funclist = {s/40, e, i};\)\)], "Input"],

Cell[BoxData[
    \(\(ep1mod = transol[ep1, funclist];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 40.1}, {0, 0.003}};\)\)], "Input"],

Cell[BoxData[
    \(\(graph3 = timeplot[ep1mod, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(show[graph1, graph2, graph3];\)\)], "Input"],

Cell["\<\
The susceptibles rise at a moderate rate, and then drop very \
rapidly when the next epidemic comes.  The numbers of exposed and infected \
reach a maximum just before the number of susceptibles reaches a minimum.  \
\
\>", "Text"],

Cell["\tNow we look at the range of values occuring in this run.", "Text"],

Cell[BoxData[
    \(staterange[ep1]\)], "Input"],

Cell[TextData[{
  "We see from these numbers what the graph suggests:  the number of exposed \
and infectives drops well below the equilibrium values at certain times of \
the cycle.  As an example, let's look a little more closely at the numbers at \
time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 2.7 yr.  First we build some interpolating vectors from the solutions."
}], "Text"],

Cell[BoxData[
    \(\(solinterp[ep1, state, slope];\)\)], "Input"],

Cell[BoxData[
    \(state[2.7]\)], "Input"],

Cell["The value of the slope vector at this time is", "Text"],

Cell[BoxData[
    \(slope[2.7]\)], "Input"],

Cell["At a slightly later time:", "Text"],

Cell[BoxData[
    \(state[3]\)], "Input"],

Cell[BoxData[
    \(slope[3]\)], "Input"],

Cell["\<\
Now the infectives and exposed are on the way up again.  It is \
interesting that the disease cyclically comes so close to disappearing, but \
then bounces back.  In a closed system, this would provide an excellent \
opportunity to eradicate the disease.  In an open system, in which infected \
individuals may come from outside the population under study, epidemics will \
occur as long as there are a sufficient number of susceptibles, so that \
vaccination is the only route to eradication.  \
\>", "Text"],

Cell["\<\
\tSo far we have considered only perturbations to the endemic \
state.  Let's now look at the time course of an epidemic, starting in a \
population with no immunity.  We will put only 0.01% fraction of exposed in \
an otherwise completely susceptible population.\
\>", "Text"],

Cell[BoxData[
    \(\(init = {0.9999, 0.0001, 0.0};\)\)], "Input"],

Cell[BoxData[
    \(\(ep2 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell["Before plotting, we look at the state range.", "Text"],

Cell[BoxData[
    \(staterange[ep2]\)], "Input"],

Cell["\<\
We can see some rather amazing oscillations in those numbers.  \
First we plot the very early times.\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 0.2}, {0, 1}};\)\)], "Input"],

Cell[BoxData[
    \(\(graph2a = timeplot[ep2, {1, 2, 3}];\)\)], "Input"],

Cell["\<\
This is a fairly typical S-E-I-R epidemic curve without the effect \
of vital statistics, which is to say that this looks like any other strong \
epidemic on the short time scale.  From what we have already seen, we expect \
some serious oscillations if we look on the long scale of 40 years.  Let's \
look at the infectives.\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 40.1}, {0, 0.01}};\)\)], "Input"],

Cell[BoxData[
    \(\(graph2b = timeplot[ep2, 3];\)\)], "Input"],

Cell["\<\
Clearly we will have to run even longer than 40 years to see a real \
approach to the endemic state.  Let's look at 100 years.\
\>", "Text"],

Cell[BoxData[
    \(\(nsteps = 20000;\)\)], "Input"],

Cell[BoxData[
    \(\(ep3 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell["Now we plot the number of infectives.", "Text"],

Cell[BoxData[
    \(\(plrange = Automatic;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[ep3, 3];\)\)], "Input"],

Cell["\<\
After 100 years, we are finally homing in on the endemic \
state.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vaccination at 50%", "Subsection"],

Cell[TextData[{
  "\tWe repeat some of the above calculations under the assumption that ",
  StyleBox["v",
    FontSlant->"Italic"],
  " = 0.5, corresponding to a 50% vaccination rate.  We redefine the \
parameter values with this change (only ",
  StyleBox["v",
    FontSlant->"Italic"],
  " changes). "
}], "Text"],

Cell[BoxData[
    \(\(parmval = {\[Eta]val, 60.0, 60.0, 1.0/70.0, 0.5};\)\)], "Input"],

Cell[TextData[{
  "The present value of the ",
  "reproductive ratio",
  " is then (1-",
  StyleBox["v",
    FontSlant->"Italic"],
  ")*",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 0.5*12.3 = 6.15."
}], "Text"],

Cell["\tNow we look at the endemic equilibrium state.", "Text"],

Cell[BoxData[
    \(eqendval = eqstateval[eqend]\)], "Input"],

Cell[TextData[{
  "Because ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = (1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ")/",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " in the endemic state, it will not change with the vaccination fraction ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  We see that ",
  StyleBox["e",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "are now about half of what they were in the case of no vaccinations.  \
Approximately 92% of the population is immune -- 42% have had the disease, \
and 50% have been vaccinated.  Now let's look at the age of first infection: \
"
}], "Text"],

Cell[BoxData[
    \(eqstateval[A]\)], "Input"],

Cell["\<\
We see that the 50% vaccination has increased the age of first \
infection.  The time scales for oscillations about the endemic state are also \
of interest:\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[\((2*\[Pi])\)/\[Omega]osc] /. R -> 6.15\)], "Input"],

Cell["\<\
Thus the oscillation period has been lengthened by the vaccination. \
 Now the e-folding time for damping of oscillations:\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[1/\[Delta]] /. R -> 6.15\)], "Input"],

Cell["\<\
The damping time has essentially doubled, compared with the case of \
no vaccination.  \
\>", "Text"],

Cell["\<\
\tNow we look at the dynamics of a perturbation.  As before, we \
perturb the endemic state by adding 1% exposed.\
\>", "Text"],

Cell[BoxData[
    \(init = eqendval + {0, 0, 0.01}\)], "Input"],

Cell["\<\
We set the integration parameters, choosing 100 years as the time \
span.\
\>", "Text"],

Cell[BoxData[
    \(h\  = \ 0.005; nsteps = 20000; t0 = 0.0;\)], "Input"],

Cell[BoxData[
    \(\(epvac1 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 100.1}, {0, 0.003}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphvac1 = timeplot[epvac1, 3];\)\)], "Input"],

Cell["\<\
Comparing with the case of no vaccination, we see that the 50% \
vaccination has roughly doubled the time scale for the oscillations -- both \
the period and the decay.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vaccination at 75%", "Subsection"],

Cell[TextData[{
  "\tNow we look at the results for 75% vaccination.  We redefine the \
parameter values with ",
  StyleBox["v ",
    FontSlant->"Italic"],
  "= 0.75.  "
}], "Text"],

Cell[BoxData[
    \(\(parmval = {\[Eta]val, 60.0, 60.0, 1.0/70.0, 0.75};\)\)], "Input"],

Cell[TextData[{
  "The present value of the ",
  "reproductive ratio",
  " is then (1-",
  StyleBox["v",
    FontSlant->"Italic"],
  ")*",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 0.25*12.3 =3.075"
}], "Text"],

Cell["\tNow we look at the endemic equilibrium state.", "Text"],

Cell[BoxData[
    \(eqendval = eqstateval[eqend]\)], "Input"],

Cell[TextData[{
  "As we expect, ",
  StyleBox["s",
    FontSlant->"Italic"],
  " is unchanged.  We see that ",
  StyleBox["e",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "are now extremely small.  Again approximately 92% of the population is \
immune -- 17% have had the disease, and 75% have been vaccinated.  Now let's \
look at the age of first infection: "
}], "Text"],

Cell[BoxData[
    \(eqstateval[A]\)], "Input"],

Cell["\<\
We see that the 75% vaccination has further increased the age of \
first infection over the result for 50% vaccination.  The time scales for \
oscillations about the endemic state are also of interest:\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[\((2*\[Pi])\)/\[Omega]osc] /. R -> 3.075\)], "Input"],

Cell["\<\
Thus the oscillation period has been lengthened by the vaccination. \
 Now the e-folding time for damping of oscillations:\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[1/\[Delta]] /. R -> 3.075\)], "Input"],

Cell["Very long indeed.", "Text"],

Cell["\<\
\tNow we look at the dynamics of a perturbation.  As before, we \
perturb the endemic state by adding 1% exposed.\
\>", "Text"],

Cell[BoxData[
    \(init = eqendval + {0, 0, 0.01}\)], "Input"],

Cell["\<\
We set the integration parameters, choosing 200 years as the time \
span.\
\>", "Text"],

Cell[BoxData[
    \(h\  = \ 0.01; nsteps = 20000; t0 = 0.0;\)], "Input"],

Cell[BoxData[
    \(\(epvac2 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 200.1}, {0, 0.001}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphvac2 = timeplot[epvac2, 3];\)\)], "Input"],

Cell["\<\
We check to see whether we are close to the endemic \
equilibrium.\
\>", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
Thus there is still some time to go, as is also clear from the \
graph.\
\>", "Text"],

Cell[TextData[{
  "\tIn all cases there is a slowly damped oscillatory approach to the \
endemic equilibrium.  The damping is small, so many oscillations are required \
to reach the endemic state.  One can show that the damping factor per cycle \
-- Exp[-2\[Pi]\[Delta]/\[Omega]osc] --is essentially independent of the \
vaccination fraction ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  Thus the number of cycles required to reach the endemic state is about \
the same for every ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  However, the time per cycle increases with ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  This is to be expected, because with a constant birth rate, the \
accumulation of susceptibles occurs at a rate proportional to (1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ").  Thus as the vaccination fraction increases, the time required to build \
",
  StyleBox["s",
    FontSlant->"Italic"],
  " up to epidemic level increases.    "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Nature of Endemic Oscillations", "Subtitle"],

Cell[TextData[{
  "\tSome of the graphs in the last section resemble relaxation oscillations, \
although of course the system here is not periodic.  The interesting behavior \
is primarily a result of the two disparate time scales -- the short time \
scale of an epidemic, and the long generational time scale.  From equation \
(18), we know that an epidemic will start if the fraction of susceptibles ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "satisfies"
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["s > ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            StyleBox["1",
              FontSize->12,
              FontWeight->"Plain"], 
            StyleBox[\(R\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False}]],
          FontSize->12], TraditionalForm]]],
  StyleBox[
  "   .                                                                       \
      ",
    FontWeight->"Plain"],
  "(30)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "is the basic ",
  "reproductive ratio",
  " defined by equation (16).  After the peak of an epidemic, the fraction of \
susceptibles drops below this value (on the short time scale of the \
epidemic), and the number of infectives drops exponentially.  In a system \
without vital dynamics, the state will decay to one in which there are \
asymptotically no infectives and a fraction of susceptibles smaller than 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  This state is never reached, because, on the long generational time \
scale, new susceptibles are added.  One would expect that as soon as (30) is \
satisfied, there would be an epidemic.  In fact, because the new susceptibles \
are added so slowly (compared to the epidemic time scale), one would really \
expect a kind of quasi-static equilibrium in which ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "remains equal to 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  As the graphs in section 6 show, the truth is very different.  The \
number of susceptibles builds up to a level exceeding 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "and then at some point there is a rapid epidemic.  Why do we get these \
relaxation oscillations rather than the expected quasi-static equilibrium?  A \
clue is given by some of the state range calculations in section 6, where we \
saw that the fraction of infectives could drop as low as ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-11\)\)]],
  ".  Thus even though the epidemic starts as soon as ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "exceeds 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ", a very large amount of time is required to build up the number of \
infectives to an observable level.  Let's see if we can make some time \
estimates relevant to this process.  "
}], "Text"],

Cell["\<\
\tTo keep the discussion simple, we revert to the basic S-I-R model \
without vital dynamics.  We will use it get simple estimates relevant to the \
rapid epidemic phase.  The equations are    \
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["s",
                    FontSlant->"Plain"]}]], "dt"],
            FontSlant->"Italic"], "=", " ", 
          RowBox[{"-", 
            StyleBox[
              RowBox[{"\[Eta]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]]}]}], "   ", ",", 
        "                                                                     \
                                                 ", 
        StyleBox[\((31)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["i",
                    FontSlant->"Italic"]}]], "dt"],
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Eta]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]]}]}], " ", ",", 
        "                                                                     \
                                         ", 
        StyleBox[\((32)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"and", "                  ", 
          StyleBox[
            FractionBox[
              StyleBox["dr",
                FontSlant->"Italic"], "dt"],
            FontSlant->"Italic"]}], "=", "  ", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Beta]", 
              StyleBox["i",
                FontSlant->"Italic"]}]], "   ", ".", 
          "                                                                   \
                                                         ", 
          StyleBox[\((33)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "We should be using the SEIR model, but the simpler SIR model will suffice. \
 In looking at numerical results, we will choose \[Beta] so that the recovery \
time scale is the same as the latent plus recovery time scales.  Now we make \
some very rough estimates.  After the peak of the epidemic, the number of \
infectives will decay like ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-\[Beta]t\)\)]],
  ".  If ",
  Cell[BoxData[
      \(TraditionalForm\`i\_p\)]],
  "is the peak value, then in the post-epidemic period ",
  StyleBox["i",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") \[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`i\_p\)]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-\[Beta]t\)\)]],
  ", where ",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0 corresponds to the peak of the epidemic.  After the epidemic, the \
number of susceptibles is much lower than the critical value ",
  Cell[BoxData[
      \(TraditionalForm\`s\_crit\)]],
  "= \[Beta]/\[Eta] (the value at which a new epidemic begins and the value \
which makes the reproductive ratio unity).  If we ignore the small number of \
susceptibles existing just after an epidemic, the number of susceptibles in \
the post-epidemic period is ",
  StyleBox["s",
    FontSlant->"Italic"],
  "\[TildeTilde] \[Mu]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", where \[Mu] is the birth rate.  The time required for the reproductive \
ratio to reach unity is then ",
  Cell[BoxData[
      \(TraditionalForm\`s\_crit\)]],
  "/\[Mu]  = \[Beta]/(\[Eta]\[Mu]).  At this time, ",
  StyleBox["i",
    FontSlant->"Italic"],
  " \[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`i\_p\)]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-\[Beta]t\)\)]],
  "\[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`i\_p\)]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(-\[Beta]\^2\)/\((\[Eta]\[Mu])\)\)\)]],
  ".  The number of infectives will begin to grow again when ",
  StyleBox["s",
    FontSlant->"Italic"],
  " reaches ",
  Cell[BoxData[
      \(TraditionalForm\`s\_crit\)]],
  ".  The growth rate is \[Eta]",
  StyleBox["s",
    FontSlant->"Italic"],
  ", which we may approximate as \[Eta]",
  Cell[BoxData[
      \(TraditionalForm\`s\_crit\)]],
  "= \[Beta].  Putting all of this together, we get      "
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox["i",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" \[TildeTilde] ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`i\_p\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(-\[Beta]\^2\)/\((\[Eta]\[Mu])\)\)\)],
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(e\^\(\[Beta](t - \[Beta]/\[Eta]\[Mu])\)\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  "    ",
  StyleBox[".  ",
    FontWeight->"Plain"],
  "                                                                  (34)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell["\<\
The peak of the next epidemic occurs when the combined exponent is \
about 1, hence when\
\>", "Text"],

Cell[TextData[{
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" \[TildeTilde] ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox[\(2 \[Beta]\),
            FontSize->12,
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              StyleBox["\[Eta]",
                FontSize->12,
                FontWeight->"Plain"], "\[Mu]"}]]], TraditionalForm]]],
  StyleBox[
  "        .                                                                  \
       ",
    FontWeight->"Plain"],
  " (35)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "If we include vaccinations, \[Mu] is replaced by (1 - ",
  StyleBox["v",
    FontSlant->"Italic"],
  ")\[Mu], and the result is"
}], "Text"],

Cell[TextData[{
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" \[TildeTilde] ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox[\(2 \[Beta]\),
            FontSize->12,
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["\[Eta]",
                  FontSize->12,
                  FontWeight->"Plain"], "\[Mu]"}]], "(", 
            RowBox[{
              StyleBox["1",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False}], " ", "-", " ", 
              StyleBox["v",
                FontWeight->"Plain",
                FontSlant->"Italic"]}], 
            StyleBox[")",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  StyleBox[
  "      .                                                                    \
     ",
    FontWeight->"Plain"],
  " (36)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "We put in the values used earlier for measles to see if our estimate is \
relevant.  We have \[Eta] = 738, \[Beta] = 30 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["yr",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], \(-1\)], TraditionalForm]]],
  ", and \[Mu] = 1/70 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["yr",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], \(-1\)], TraditionalForm]]],
  ".  For no vaccinations, this gives 5.7 yr, which is not a bad estimate for \
the time between peaks in the early stages of the oscillatory approach to the \
endemic state.  For a 50% vaccination rate, we get 11.4 yr, again not a bad \
estimate.  Thus our estimates provide a qualitative basis for understanding \
these nonlinear oscillations.  A much more convincing analysis could be based \
on a two-time perturbation scheme.   "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. Effect of Small Influx of Susceptibles", "Subtitle"],

Cell[TextData[{
  "\tAs we have just seen, the strong nonlinear oscillations in the system \
are caused by an overshoot in susceptibles, made possible by the very low \
number of infectives between epidemics.  Although an epidemic starts as soon \
as the reproductive ratio exceeds unity, it takes a very long time for the \
number of infectives to become significant, and by that time the number of \
susceptibles is such that the reproductive ratio greatly exceeds unity.  This \
model is unrealistic in several respects.  In the first place, a fraction of \
infectives equal to say ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-10\)\)]],
  "in a population of a million means that for all real purposes there are no \
infectives.  The model cannot be believed if population fractions become this \
small.  That is a minor mathematical point.  The main point really is that no \
population is closed, and in general there will be a small influx of \
infectives from outside, as well as an egress of all population types.  It \
seems likely that even a modest flux of infectives would decrease or even \
prevent the overshoot oscillations we have been discussing.  One would expect \
that if the flux of infectives exceeds a certain value, the system would \
simply stay at the endemic point after any startup transients.  We can test \
this idea by adding such a flux to our equations.  In order to keep the \
population constant, we will remove recovereds at the same rate at which we \
add infectives.  We could add the infectives either to the exposed pool or \
the infective pool.  We choose to add them to the exposed pool.  Here are our \
modified equations:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(ds\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            RowBox[{"-", 
              StyleBox[
                RowBox[{"\[Eta]", 
                  StyleBox["si",
                    FontSlant->"Italic"]}]]}], "  ", "+", " ", 
            RowBox[{"\[Mu]", 
              RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", 
                  StyleBox["v",
                    FontSlant->"Italic"]}], ")"}]}], 
            StyleBox[" ",
              FontSlant->"Italic"], "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["s",
                  FontSlant->"Italic"]}]]}]}], "  ", ",", 
        "                                                                     \
                        ", 
        StyleBox[\((37)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(de\/dt\),
            FontSlant->"Italic"], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Eta]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["-",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontSlant->"Italic"], \(\[Gamma]\  + \ \[Mu]\), ")"}], 
              StyleBox["e",
                FontSlant->"Italic"]}], "  ", "+", " ", "\[Rho]"}]}], " ", 
        ",", "                                                                \
                                    ", 
        StyleBox[\((38)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(di\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Gamma]", 
                StyleBox["e",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            RowBox[{\((\[Beta]\  + \ \[Mu])\), 
              StyleBox["i",
                FontSlant->"Italic"]}]}]}], " ", ",", 
        "                                                                     \
                                             ", 
        StyleBox[\((39)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{"and", "                  ", 
            StyleBox[\(dr\/dt\),
              FontSlant->"Italic"]}], "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]], " ", "+", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["v",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            RowBox[{
            "\[Rho]", "  ", ".", 
              "                                                               \
                                        ", 
              StyleBox[\((40)\),
                FontWeight->"Bold"]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[
"Here \[Rho] is the fraction of the total population which is added to the \
exposed pool, and removed from the recovered pool,  per unit time.  We define \
these equations for DynPac, using as before only the first three equations.  \
First the state variables:"], "Text"],

Cell[BoxData[
    \(\(setstate[{s, e, i}];\)\)], "Input"],

Cell["Now the official parameters:", "Text"],

Cell[BoxData[
    \(\(setparm[{\[Eta], \[Beta], \[Gamma], \[Mu], v, \[Rho]}];\)\)], "Input"],

Cell["Finally the slope vector:", "Text"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Eta]\)*s*i + \[Mu]*\((1 - v)\) - \[Mu]*s, \[Eta]*s*
              i - \[Gamma]*e - \[Mu]*e\  + \[Rho], \[Gamma]*e - \[Beta]*
              i - \[Mu]*i};\)\)], "Input"],

Cell["\<\
\tThe new terms will change the equilibrium states.  There will no \
longer be a disease-free equilibrium, and the coordinates of the endemic \
state will change somewhat.  Let's find the endemic state.\
\>", "Text"],

Cell[BoxData[
    \(neweq\  = Simplify[findpolyeq]\)], "Input"],

Cell["\<\
This is interesting.  There are now two endemic states.  We will \
see shortly that the former disease-free state has now moved to a region of \
negative coordinates and hence is not relevant.\
\>", "Text"],

Cell[BoxData[
    \(\(neweq1 = neweq[\([1]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(neweq2 = neweq[\([2]\)];\)\)], "Input"],

Cell[TextData[
"\tWe need to look at some numbers to see how much the influx changes the \
endemic state.  We first define two sets of parameter values.  The old values \
correspond to our measles example with \[Rho] = 0.  For the time being, we \
take the vaccination fraction to be zero. "], "Text"],

Cell[BoxData[
    \(\(parmold = {738.0, 60.0, 60.0, 1.43*10\^\(-2\), 0.0, 
          0.0};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = parmold;\)\)], "Input"],

Cell["\<\
As a check, we look at the position of the equilibrium state:\
\>", 
  "Text"],

Cell[BoxData[
    \(eqstateval[neweq1]\)], "Input"],

Cell[BoxData[
    \(eqstateval[neweq2]\)], "Input"],

Cell["\<\
These are exactly the states we obtained before.  We now \
tentatively set our influx rate at 10% of the endemic value at zero influx:\
\
\>", "Text"],

Cell[BoxData[
    \(eflux = 0.1*\(eqstateval[neweq2]\)[\([2]\)]\)], "Input"],

Cell["Now the parameter values:", "Text"],

Cell[BoxData[
    \(parmnew = {738.0, 60.0, 60.0, 1.43*10\^\(-2\), 0.0, eflux}\)], "Input"],

Cell["\<\
Now we assign this vector to parmval and recalculate the \
equilibrium states.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = parmnew;\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[neweq1]\)], "Input"],

Cell[BoxData[
    \(neweq2val = eqstateval[neweq2]\)], "Input"],

Cell["\<\
The first state has negative coordinates and is therefore \
irrelevant.  The second state is only slightly changed from its earlier \
value.  We fully expect this endemic state to be stable, but let's make sure.\
\
\>", "Text"],

Cell[BoxData[
    \(classify[neweq2]\)], "Input"],

Cell["\<\
\tNow we will integrate the equations.  To compare with one of our \
earlier calculations, we will use the same initial conditions -- namely the \
endemic state plus an extra 1% exposed.\
\>", "Text"],

Cell[BoxData[
    \(h = 0.005; t0 = 0.0; nsteps = 8000; 
    init = neweq2val + {0.0, 0.01, 0.0};\)], "Input"],

Cell[BoxData[
    \(\(newep = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<\>";\)\)], "Input"],

Cell[BoxData[
    \(\(imsize = 420;\)\)], "Input"],

Cell[BoxData[
    \(\(sciflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(timeunit = "\<yr\>";\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 40.1}, {0, 0.005}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphnew1 = timeplot[newep, 3];\)\)], "Input"],

Cell["\<\
We compare this with the earlier case in which all is the same \
except the influx of exposed.\
\>", "Text"],

Cell[BoxData[
    \(\(show[graph1, graphnew1];\)\)], "Input"],

Cell["\<\
Although the oscillations are present in both cases, they are much \
less extreme in the case with an influx.  Let's increase the influx to 25% of \
previous endemic per year and see what happens.\
\>", "Text"],

Cell[BoxData[
    \(eflux = 0.25*\(eqstateval[neweq2]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(parmnew = {738.0, 60.0, 60.0, 1.43*10\^\(-2\), 0.0, eflux}\)], "Input"],

Cell[BoxData[
    \(\(parmval = parmnew;\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[neweq1]\)], "Input"],

Cell[BoxData[
    \(neweq2val = eqstateval[neweq2]\)], "Input"],

Cell[BoxData[
    \(h = 0.005; t0 = 0.0; nsteps = 8000; 
    init = neweq2val + {0.0, 0.01, 0.0};\)], "Input"],

Cell[BoxData[
    \(\(newep2 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graphnew2 = timeplot[newep2, 3];\)\)], "Input"],

Cell["\<\
We see a further reduction in the strength of the oscillations.  We \
make another run, using an influx per year equal to the previous endemic \
population.    \
\>", "Text"],

Cell[BoxData[
    \(eflux = \(eqstateval[neweq2]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(parmnew = {738.0, 60.0, 60.0, 1.43*10\^\(-2\), 0.0, eflux}\)], "Input"],

Cell[BoxData[
    \(\(parmval = parmnew;\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[neweq1]\)], "Input"],

Cell[BoxData[
    \(neweq2val = eqstateval[neweq2]\)], "Input"],

Cell[BoxData[
    \(h = 0.005; t0 = 0.0; nsteps = 8000; 
    init = neweq2val + {0.0, 0.01, 0.0};\)], "Input"],

Cell[BoxData[
    \(\(newep3 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graphnew3 = timeplot[newep3, 3];\)\)], "Input"],

Cell["\<\
The oscillations are further reduced.  We compare all of the cases:\
\
\>", "Text"],

Cell[BoxData[
    \(\(show[graph1, graphnew1, graphnew2, graphnew3];\)\)], "Input"],

Cell["\<\
Let's look at the range of state values for these solutions.  \
\>",
   "Text"],

Cell[BoxData[
    \(staterange[ep1]\)], "Input"],

Cell[BoxData[
    \(staterange[newep]\)], "Input"],

Cell[BoxData[
    \(staterange[newep2]\)], "Input"],

Cell[BoxData[
    \(staterange[newep3]\)], "Input"],

Cell["\<\
\tThe influx of exposed does decrease the oscillations, but perhaps \
not quite as much as one would expect.  We can see that after the first \
epidemic peak, the number of infectives drops to a very low value, and this \
allows an overshoot in susceptibles and hence oscillations.  This low value \
is MUCH smaller for the case with no influx than for the other cases.     \
\
\>", "Text"],

Cell["\<\
\tAs a final case, let's look at the effect of a large influx of \
exposed -- say 10 times as large per year as the previous steady state \
endemic value.\
\>", "Text"],

Cell[BoxData[
    \(eflux = 10*\(eqstateval[neweq2]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(parmnew = {738.0, 60.0, 60.0, 1.43*10\^\(-2\), 0.0, eflux}\)], "Input"],

Cell[BoxData[
    \(\(parmval = parmnew;\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[neweq1]\)], "Input"],

Cell[BoxData[
    \(neweq2val = eqstateval[neweq2]\)], "Input"],

Cell[BoxData[
    \(h = 0.005; t0 = 0.0; nsteps = 8000; 
    init = neweq2val + {0.0, 0.01, 0.0};\)], "Input"],

Cell[BoxData[
    \(\(newep4 = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graphnew4 = timeplot[newep4, 3];\)\)], "Input"],

Cell[BoxData[
    \(staterange[newep4]\)], "Input"],

Cell["\<\
Now we have finally suppressed the oscillations, but it took a \
rather large influx of exposed to do it.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000[V0801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 100, 6, 266, "Title"],
Cell[1842, 59, 38, 1, 27, "Input"],
Cell[1883, 62, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1961, 67, 35, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[2021, 71, 46, 0, 46, "Subsection"],
Cell[2070, 73, 1102, 17, 164, "Text"],
Cell[3175, 92, 519, 15, 68, "Text"],
Cell[3697, 109, 487, 23, 32, "Text"],
Cell[4187, 134, 350, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4574, 144, 72, 0, 46, "Subsection"],
Cell[4649, 146, 67, 0, 30, "Text"],
Cell[4719, 148, 956, 27, 45, "Text"],
Cell[5678, 177, 1144, 34, 45, "Text"],
Cell[6825, 213, 971, 28, 45, "Text"],
Cell[7799, 243, 837, 24, 45, "Text"],
Cell[8639, 269, 1443, 30, 180, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10119, 304, 38, 0, 46, "Subsection"],
Cell[10160, 306, 1206, 41, 100, "Text"],
Cell[11369, 349, 251, 9, 32, "Text"],
Cell[11623, 360, 1012, 16, 144, "Text"],
Cell[12638, 378, 54, 0, 30, "Text"],
Cell[12695, 380, 622, 32, 32, "Text"],
Cell[13320, 414, 21, 0, 30, "Text"],
Cell[13344, 416, 424, 20, 32, "Text"],
Cell[13771, 438, 40, 0, 30, "Text"],
Cell[13814, 440, 951, 27, 45, "Text"],
Cell[14768, 469, 989, 29, 45, "Text"],
Cell[15760, 500, 659, 18, 45, "Text"],
Cell[16422, 520, 922, 25, 45, "Text"],
Cell[17347, 547, 357, 12, 50, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17753, 565, 56, 0, 56, "Subtitle"],
Cell[17812, 567, 318, 6, 62, "Text"],
Cell[18133, 575, 57, 1, 27, "Input"],
Cell[18193, 578, 191, 8, 32, "Text"],
Cell[18387, 588, 84, 1, 27, "Input"],
Cell[18474, 591, 184, 6, 32, "Text"],
Cell[18661, 599, 195, 3, 27, "Input"],
Cell[18859, 604, 228, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19124, 613, 41, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[19190, 617, 52, 0, 46, "Subsection"],
Cell[19245, 619, 154, 3, 46, "Text"],
Cell[19402, 624, 61, 1, 27, "Input"],
Cell[19466, 627, 655, 23, 66, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20158, 655, 45, 0, 46, "Subsection"],
Cell[20206, 657, 215, 4, 46, "Text"],
Cell[20424, 663, 58, 1, 27, "Input"],
Cell[20485, 666, 55, 1, 27, "Input"],
Cell[20543, 669, 264, 6, 48, "Text"],
Cell[20810, 677, 109, 2, 27, "Input"],
Cell[20922, 681, 719, 15, 98, "Text"],
Cell[21644, 698, 233, 5, 43, "Input"],
Cell[21880, 705, 120, 2, 30, "Text"],
Cell[22003, 709, 428, 13, 32, "Text"],
Cell[22434, 724, 163, 4, 46, "Text"],
Cell[22600, 730, 285, 9, 32, "Text"],
Cell[22888, 741, 666, 10, 110, "Text"],
Cell[23557, 753, 525, 13, 46, "Text"],
Cell[24085, 768, 374, 11, 46, "Text"],
Cell[24462, 781, 1818, 64, 38, "Text"],
Cell[26283, 847, 289, 11, 30, "Text"],
Cell[26575, 860, 222, 6, 46, "Text"],
Cell[26800, 868, 149, 3, 27, "Input"],
Cell[26952, 873, 154, 5, 32, "Text"],
Cell[27109, 880, 144, 3, 27, "Input"],
Cell[27256, 885, 161, 6, 32, "Text"],
Cell[27420, 893, 86, 1, 27, "Input"],
Cell[27509, 896, 256, 9, 48, "Text"],
Cell[27768, 907, 501, 13, 66, "Text"],
Cell[28272, 922, 226, 5, 43, "Input"],
Cell[28501, 929, 66, 0, 30, "Text"],
Cell[28570, 931, 90, 1, 27, "Input"],
Cell[28663, 934, 253, 8, 30, "Text"],
Cell[28919, 944, 56, 1, 27, "Input"],
Cell[28978, 947, 56, 1, 27, "Input"],
Cell[29037, 950, 56, 1, 27, "Input"],
Cell[29096, 953, 56, 1, 27, "Input"],
Cell[29155, 956, 690, 15, 100, "Text"],
Cell[29848, 973, 68, 1, 27, "Input"],
Cell[29919, 976, 191, 8, 32, "Text"],
Cell[30113, 986, 141, 3, 43, "Input"],
Cell[30257, 991, 1484, 36, 186, "Text"],
Cell[31744, 1029, 78, 1, 27, "Input"],
Cell[31825, 1032, 92, 1, 27, "Input"],
Cell[31920, 1035, 316, 6, 62, "Text"],
Cell[32239, 1043, 123, 3, 27, "Input"],
Cell[32365, 1048, 1113, 28, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33515, 1081, 58, 0, 46, "Subsection"],
Cell[33576, 1083, 1057, 25, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34670, 1113, 58, 0, 46, "Subsection"],
Cell[34731, 1115, 973, 27, 112, "Text"],
Cell[35707, 1144, 647, 19, 44, "Text"],
Cell[36357, 1165, 1469, 33, 166, "Text"],
Cell[37829, 1200, 1868, 61, 44, "Text"],
Cell[39700, 1263, 451, 10, 64, "Text"],
Cell[40154, 1275, 247, 9, 32, "Text"],
Cell[40404, 1286, 1664, 49, 46, "Text"],
Cell[42071, 1337, 339, 13, 50, "Text"],
Cell[42413, 1352, 274, 8, 48, "Text"],
Cell[42690, 1362, 627, 17, 46, "Text"],
Cell[43320, 1381, 29, 0, 30, "Text"],
Cell[43352, 1383, 1131, 40, 37, "Text"],
Cell[44486, 1425, 29, 0, 30, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44564, 1431, 49, 0, 56, "Subtitle"],
Cell[44616, 1433, 646, 15, 82, "Text"],
Cell[45265, 1450, 553, 12, 80, "Text"],
Cell[45821, 1464, 138, 3, 30, "Text"],
Cell[45962, 1469, 1042, 29, 31, "Text"],
Cell[47007, 1500, 195, 6, 32, "Text"],
Cell[47205, 1508, 1932, 71, 31, "Text"],
Cell[49140, 1581, 142, 5, 32, "Text"],
Cell[49285, 1588, 343, 11, 33, "Text"],
Cell[49631, 1601, 348, 9, 49, "Text"],
Cell[49982, 1612, 536, 16, 59, "Text"],
Cell[50521, 1630, 1275, 41, 109, "Text"],
Cell[51799, 1673, 884, 24, 105, "Text"],
Cell[52686, 1699, 752, 19, 45, "Text"],
Cell[53441, 1720, 253, 9, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53731, 1734, 66, 0, 56, "Subtitle"],
Cell[53800, 1736, 447, 11, 62, "Text"],
Cell[54250, 1749, 49, 1, 27, "Input"],
Cell[54302, 1752, 53, 0, 30, "Text"],
Cell[54358, 1754, 104, 2, 29, "Input"],
Cell[54465, 1758, 1049, 24, 94, "Text"],
Cell[55517, 1784, 75, 1, 27, "Input"],
Cell[55595, 1787, 54, 0, 30, "Text"],
Cell[55652, 1789, 75, 1, 27, "Input"],
Cell[55730, 1792, 246, 6, 46, "Text"],
Cell[55979, 1800, 87, 1, 29, "Input"],
Cell[56069, 1803, 158, 3, 47, "Input"],
Cell[56230, 1808, 149, 3, 46, "Text"],
Cell[56382, 1813, 105, 2, 27, "Input"],
Cell[56490, 1817, 136, 3, 30, "Text"],
Cell[56629, 1822, 327, 12, 32, "Text"],
Cell[56959, 1836, 21, 0, 30, "Text"],
Cell[56983, 1838, 123, 2, 50, "Input"],
Cell[57109, 1842, 175, 3, 47, "Input"],
Cell[57287, 1847, 68, 0, 30, "Text"],
Cell[57358, 1849, 1129, 36, 44, "Text"],
Cell[58490, 1887, 1874, 61, 101, "Text"],
Cell[60367, 1950, 734, 24, 84, "Text"],
Cell[61104, 1976, 2392, 79, 39, "Text"],
Cell[63499, 2057, 646, 20, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64182, 2082, 45, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[64252, 2086, 45, 0, 46, "Subsection"],
Cell[64300, 2088, 1367, 40, 96, "Text"],
Cell[65670, 2130, 163, 3, 43, "Input"],
Cell[65836, 2135, 159, 4, 46, "Text"],
Cell[65998, 2141, 40, 1, 27, "Input"],
Cell[66041, 2144, 86, 1, 27, "Input"],
Cell[66130, 2147, 56, 0, 30, "Text"],
Cell[66189, 2149, 61, 1, 27, "Input"],
Cell[66253, 2152, 50, 0, 30, "Text"],
Cell[66306, 2154, 61, 1, 27, "Input"],
Cell[66370, 2157, 42, 0, 30, "Text"],
Cell[66415, 2159, 48, 1, 27, "Input"],
Cell[66466, 2162, 389, 7, 62, "Text"],
Cell[66858, 2171, 55, 1, 27, "Input"],
Cell[66916, 2174, 46, 1, 27, "Input"],
Cell[66965, 2177, 76, 0, 30, "Text"],
Cell[67044, 2179, 149, 3, 46, "Text"],
Cell[67196, 2184, 89, 1, 27, "Input"],
Cell[67288, 2187, 93, 3, 30, "Text"],
Cell[67384, 2192, 68, 1, 27, "Input"],
Cell[67455, 2195, 259, 5, 46, "Text"],
Cell[67717, 2202, 45, 1, 27, "Input"],
Cell[67765, 2205, 47, 1, 27, "Input"],
Cell[67815, 2208, 295, 5, 62, "Text"],
Cell[68113, 2215, 105, 2, 27, "Input"],
Cell[68221, 2219, 63, 0, 30, "Text"],
Cell[68287, 2221, 74, 1, 27, "Input"],
Cell[68364, 2224, 72, 0, 30, "Text"],
Cell[68439, 2226, 54, 1, 27, "Input"],
Cell[68496, 2229, 54, 1, 27, "Input"],
Cell[68553, 2232, 50, 1, 27, "Input"],
Cell[68606, 2235, 56, 1, 27, "Input"],
Cell[68665, 2238, 63, 1, 27, "Input"],
Cell[68731, 2241, 418, 7, 78, "Text"],
Cell[69152, 2250, 63, 1, 27, "Input"],
Cell[69218, 2253, 207, 6, 48, "Text"],
Cell[69428, 2261, 58, 1, 27, "Input"],
Cell[69489, 2264, 110, 3, 30, "Text"],
Cell[69602, 2269, 65, 0, 30, "Text"],
Cell[69670, 2271, 56, 1, 27, "Input"],
Cell[69729, 2274, 70, 1, 27, "Input"],
Cell[69802, 2277, 63, 1, 27, "Input"],
Cell[69868, 2280, 119, 3, 30, "Text"],
Cell[69990, 2285, 61, 1, 27, "Input"],
Cell[70054, 2288, 69, 1, 27, "Input"],
Cell[70126, 2291, 71, 1, 27, "Input"],
Cell[70200, 2294, 66, 1, 27, "Input"],
Cell[70269, 2297, 66, 1, 27, "Input"],
Cell[70338, 2300, 241, 5, 46, "Text"],
Cell[70582, 2307, 74, 0, 30, "Text"],
Cell[70659, 2309, 48, 1, 27, "Input"],
Cell[70710, 2312, 391, 8, 64, "Text"],
Cell[71104, 2322, 66, 1, 27, "Input"],
Cell[71173, 2325, 43, 1, 27, "Input"],
Cell[71219, 2328, 61, 0, 30, "Text"],
Cell[71283, 2330, 43, 1, 27, "Input"],
Cell[71329, 2333, 41, 0, 30, "Text"],
Cell[71373, 2335, 41, 1, 27, "Input"],
Cell[71417, 2338, 41, 1, 27, "Input"],
Cell[71461, 2341, 519, 8, 94, "Text"],
Cell[71983, 2351, 287, 5, 62, "Text"],
Cell[72273, 2358, 66, 1, 27, "Input"],
Cell[72342, 2361, 74, 1, 27, "Input"],
Cell[72419, 2364, 60, 0, 30, "Text"],
Cell[72482, 2366, 48, 1, 27, "Input"],
Cell[72533, 2369, 124, 3, 30, "Text"],
Cell[72660, 2374, 66, 1, 27, "Input"],
Cell[72729, 2377, 72, 1, 27, "Input"],
Cell[72804, 2380, 349, 6, 62, "Text"],
Cell[73156, 2388, 70, 1, 27, "Input"],
Cell[73229, 2391, 64, 1, 27, "Input"],
Cell[73296, 2394, 150, 3, 46, "Text"],
Cell[73449, 2399, 52, 1, 27, "Input"],
Cell[73504, 2402, 74, 1, 27, "Input"],
Cell[73581, 2405, 53, 0, 30, "Text"],
Cell[73637, 2407, 57, 1, 27, "Input"],
Cell[73697, 2410, 54, 1, 27, "Input"],
Cell[73754, 2413, 89, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73880, 2421, 40, 0, 46, "Subsection"],
Cell[73923, 2423, 316, 9, 50, "Text"],
Cell[74242, 2434, 86, 1, 27, "Input"],
Cell[74331, 2437, 224, 10, 32, "Text"],
Cell[74558, 2449, 63, 0, 30, "Text"],
Cell[74624, 2451, 61, 1, 27, "Input"],
Cell[74688, 2454, 721, 26, 64, "Text"],
Cell[75412, 2482, 46, 1, 27, "Input"],
Cell[75461, 2485, 181, 4, 46, "Text"],
Cell[75645, 2491, 83, 1, 27, "Input"],
Cell[75731, 2494, 146, 3, 46, "Text"],
Cell[75880, 2499, 68, 1, 27, "Input"],
Cell[75951, 2502, 111, 3, 30, "Text"],
Cell[76065, 2507, 137, 3, 46, "Text"],
Cell[76205, 2512, 63, 1, 27, "Input"],
Cell[76271, 2515, 97, 3, 30, "Text"],
Cell[76371, 2520, 73, 1, 27, "Input"],
Cell[76447, 2523, 77, 1, 27, "Input"],
Cell[76527, 2526, 72, 1, 27, "Input"],
Cell[76602, 2529, 69, 1, 27, "Input"],
Cell[76674, 2532, 192, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76903, 2541, 40, 0, 46, "Subsection"],
Cell[76946, 2543, 181, 6, 32, "Text"],
Cell[77130, 2551, 87, 1, 27, "Input"],
Cell[77220, 2554, 224, 10, 32, "Text"],
Cell[77447, 2566, 63, 0, 30, "Text"],
Cell[77513, 2568, 61, 1, 27, "Input"],
Cell[77577, 2571, 412, 13, 64, "Text"],
Cell[77992, 2586, 46, 1, 27, "Input"],
Cell[78041, 2589, 225, 4, 46, "Text"],
Cell[78269, 2595, 84, 1, 27, "Input"],
Cell[78356, 2598, 146, 3, 46, "Text"],
Cell[78505, 2603, 69, 1, 27, "Input"],
Cell[78577, 2606, 33, 0, 30, "Text"],
Cell[78613, 2608, 137, 3, 46, "Text"],
Cell[78753, 2613, 63, 1, 27, "Input"],
Cell[78819, 2616, 97, 3, 30, "Text"],
Cell[78919, 2621, 72, 1, 27, "Input"],
Cell[78994, 2624, 77, 1, 27, "Input"],
Cell[79074, 2627, 72, 1, 27, "Input"],
Cell[79149, 2630, 69, 1, 27, "Input"],
Cell[79221, 2633, 90, 3, 30, "Text"],
Cell[79314, 2638, 39, 1, 27, "Input"],
Cell[79356, 2641, 95, 3, 30, "Text"],
Cell[79454, 2646, 985, 24, 118, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[80488, 2676, 53, 0, 56, "Subtitle"],
Cell[80544, 2678, 473, 9, 80, "Text"],
Cell[81020, 2689, 749, 27, 39, "Text"],
Cell[81772, 2718, 1936, 42, 226, "Text"],
Cell[83711, 2762, 217, 4, 46, "Text"],
Cell[83931, 2768, 692, 20, 45, "Text"],
Cell[84626, 2790, 824, 24, 45, "Text"],
Cell[85453, 2816, 656, 18, 45, "Text"],
Cell[86112, 2836, 2367, 68, 183, "Text"],
Cell[88482, 2906, 832, 28, 33, "Text"],
Cell[89317, 2936, 112, 3, 30, "Text"],
Cell[89432, 2941, 698, 26, 38, "Text"],
Cell[90133, 2969, 159, 5, 32, "Text"],
Cell[90295, 2976, 1200, 40, 38, "Text"],
Cell[91498, 3018, 1251, 30, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92786, 3053, 61, 0, 56, "Subtitle"],
Cell[92850, 3055, 1684, 25, 222, "Text"],
Cell[94537, 3082, 952, 27, 45, "Text"],
Cell[95492, 3111, 1007, 29, 45, "Text"],
Cell[96502, 3142, 664, 18, 45, "Text"],
Cell[97169, 3162, 946, 26, 45, "Text"],
Cell[98118, 3190, 288, 4, 62, "Text"],
Cell[98409, 3196, 57, 1, 27, "Input"],
Cell[98469, 3199, 44, 0, 30, "Text"],
Cell[98516, 3201, 92, 1, 27, "Input"],
Cell[98611, 3204, 41, 0, 30, "Text"],
Cell[98655, 3206, 206, 3, 43, "Input"],
Cell[98864, 3211, 226, 4, 46, "Text"],
Cell[99093, 3217, 63, 1, 27, "Input"],
Cell[99159, 3220, 216, 4, 46, "Text"],
Cell[99378, 3226, 61, 1, 27, "Input"],
Cell[99442, 3229, 61, 1, 27, "Input"],
Cell[99506, 3232, 301, 4, 62, "Text"],
Cell[99810, 3238, 105, 2, 31, "Input"],
Cell[99918, 3242, 55, 1, 27, "Input"],
Cell[99976, 3245, 88, 3, 30, "Text"],
Cell[100067, 3250, 51, 1, 27, "Input"],
Cell[100121, 3253, 51, 1, 27, "Input"],
Cell[100175, 3256, 160, 4, 46, "Text"],
Cell[100338, 3262, 76, 1, 27, "Input"],
Cell[100417, 3265, 41, 0, 30, "Text"],
Cell[100461, 3267, 91, 1, 31, "Input"],
Cell[100555, 3270, 102, 3, 30, "Text"],
Cell[100660, 3275, 55, 1, 27, "Input"],
Cell[100718, 3278, 51, 1, 27, "Input"],
Cell[100772, 3281, 63, 1, 27, "Input"],
Cell[100838, 3284, 237, 5, 46, "Text"],
Cell[101078, 3291, 49, 1, 27, "Input"],
Cell[101130, 3294, 210, 4, 46, "Text"],
Cell[101343, 3300, 110, 2, 27, "Input"],
Cell[101456, 3304, 76, 1, 27, "Input"],
Cell[101535, 3307, 50, 1, 27, "Input"],
Cell[101588, 3310, 54, 1, 27, "Input"],
Cell[101645, 3313, 50, 1, 27, "Input"],
Cell[101698, 3316, 52, 1, 27, "Input"],
Cell[101753, 3319, 57, 1, 27, "Input"],
Cell[101813, 3322, 71, 1, 27, "Input"],
Cell[101887, 3325, 68, 1, 27, "Input"],
Cell[101958, 3328, 118, 3, 30, "Text"],
Cell[102079, 3333, 61, 1, 27, "Input"],
Cell[102143, 3336, 220, 4, 46, "Text"],
Cell[102366, 3342, 77, 1, 27, "Input"],
Cell[102446, 3345, 91, 1, 31, "Input"],
Cell[102540, 3348, 55, 1, 27, "Input"],
Cell[102598, 3351, 51, 1, 27, "Input"],
Cell[102652, 3354, 63, 1, 27, "Input"],
Cell[102718, 3357, 110, 2, 27, "Input"],
Cell[102831, 3361, 77, 1, 27, "Input"],
Cell[102911, 3364, 69, 1, 27, "Input"],
Cell[102983, 3367, 184, 4, 46, "Text"],
Cell[103170, 3373, 72, 1, 27, "Input"],
Cell[103245, 3376, 91, 1, 31, "Input"],
Cell[103339, 3379, 55, 1, 27, "Input"],
Cell[103397, 3382, 51, 1, 27, "Input"],
Cell[103451, 3385, 63, 1, 27, "Input"],
Cell[103517, 3388, 110, 2, 27, "Input"],
Cell[103630, 3392, 77, 1, 27, "Input"],
Cell[103710, 3395, 69, 1, 27, "Input"],
Cell[103782, 3398, 93, 3, 30, "Text"],
Cell[103878, 3403, 83, 1, 27, "Input"],
Cell[103964, 3406, 89, 3, 30, "Text"],
Cell[104056, 3411, 48, 1, 27, "Input"],
Cell[104107, 3414, 50, 1, 27, "Input"],
Cell[104160, 3417, 51, 1, 27, "Input"],
Cell[104214, 3420, 51, 1, 27, "Input"],
Cell[104268, 3423, 400, 7, 78, "Text"],
Cell[104671, 3432, 178, 4, 46, "Text"],
Cell[104852, 3438, 75, 1, 27, "Input"],
Cell[104930, 3441, 91, 1, 31, "Input"],
Cell[105024, 3444, 55, 1, 27, "Input"],
Cell[105082, 3447, 51, 1, 27, "Input"],
Cell[105136, 3450, 63, 1, 27, "Input"],
Cell[105202, 3453, 110, 2, 27, "Input"],
Cell[105315, 3457, 77, 1, 27, "Input"],
Cell[105395, 3460, 69, 1, 27, "Input"],
Cell[105467, 3463, 51, 1, 27, "Input"],
Cell[105521, 3466, 129, 3, 30, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

