(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25114,        841]*)
(*NotebookOutlinePosition[     49994,       1742]*)
(*  CellTagsIndexPosition[     49950,       1738]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
S-I-R Model of Epidemics
Part 2
Vital Dynamics Included\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["1. Introduction", "Subtitle"],

Cell[CellGroupData[{

Cell["Description of the Model", "Subsection"],

Cell[TextData[{
  "\tIn this notebook, we include births and deaths the standard S-I-R model \
for epidemics.  This model will allow us to look at events of longer \
duration, and at endemic diseases.  For the integration of the nonlinear \
differential equations, we use the package DynPac.  Although some familiarity \
with DynPac is assumed, brief descriptions of some DynPac commands are given \
as they are used.  The integrations in this notebook also can be done easily \
with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function NDSolve."
}], "Text"],

Cell[TextData[{
  "\tThe S-I-R model was introduced by W.O. Kermack and A.G. McKendrick (\"A \
Contribution to the Mathematical Theory of Epidemics,\"  Proc. Roy. Soc. \
London ",
  StyleBox["A",
    FontWeight->"Bold"],
  " ,",
  StyleBox["115",
    FontWeight->"Bold"],
  ", 700-721, 1927), and has played a major role in mathematical \
epidemiology.  In later work, Kermack and McKendrick added the effects of \
vital dynamics (Proc. Roy. Soc. London ",
  StyleBox["A,",
    FontWeight->"Bold"],
  " ",
  StyleBox["138",
    FontWeight->"Bold"],
  " 55-83, 1932, and ",
  StyleBox["141",
    FontWeight->"Bold"],
  " 94-122, 1933).  A summary of the model and its uses is given by Herbert \
W. Hethcote (",
  StyleBox["Applied Mathematical Ecology",
    FontWeight->"Bold"],
  ", ed. S. A. Levin, T.G. Hallam, and L.J. Gross, Springer-Verlag, 1989, pp. \
119-144).  In the model, a  population is divided into three groups:  the \
susceptibles S, the infectives I, and the recovered R, with numbers ",
  StyleBox["s",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " respectively.  The total population is "
}], "Text"],

Cell[TextData[{
  "\t            n ",
  StyleBox["= ",
    FontSlant->"Plain"],
  "s ",
  StyleBox["+ ",
    FontSlant->"Plain"],
  "i",
  StyleBox[" + ",
    FontSlant->"Plain"],
  "r",
  StyleBox[
  "  .                                                                        \
      ",
    FontSlant->"Plain"],
  StyleBox["(1)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["\<\
The susceptibles are those who are not infected and not immune, the \
infectives are those who are infected and can transmit the disease, and the \
recovered are those who have been infected, have recovered and are \
permanently immune.  We will include in the model the natural birth and death \
rates, although with simplifying assumptions.  We assume that all births are \
into the susceptibles.  We assume that the death rate is equal for members of \
all three classes, and we assume that the birth and death rates are equal so \
that the total population is stationary.  Finally, we assume that this is a \
non-lethal disease so that the recovered are truly recovered and not dead.  \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Equations and Parameters of the Model", "Subsection"],

Cell["\tThe basic differential equations are as follows: ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(ds\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            RowBox[{"-", 
              StyleBox[
                RowBox[{"\[Alpha]", 
                  StyleBox["si",
                    FontSlant->"Italic"]}]]}], " ", "+", " ", 
            RowBox[{"\[Mu]", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["s",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], "+", " ", 
                  StyleBox["i",
                    FontSlant->"Italic"], " ", "+", " ", 
                  StyleBox["r",
                    FontSlant->"Italic"]}], ")"}]}], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["s",
                  FontSlant->"Italic"]}]]}]}], "    ", ",", 
        "                                                                     \
         ", 
        StyleBox[\((2)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(di\/dt\),
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["si",
                  FontSlant->"Italic"]}]], "  ", "-", " ", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]], " ", "-", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["i",
                  FontSlant->"Italic"]}]]}]}], " ", ",", 
        "                                                                     \
                                  ", 
        StyleBox[\((3)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(dr\/dt\),
          FontSlant->"Italic"], "=", "  ", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Beta]", 
              StyleBox["i",
                FontSlant->"Italic"]}]], "  ", "-", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]], 
            StyleBox[".",
              FontSlant->"Italic"], 
            "                                                                 \
                                               ", 
            StyleBox[\((4)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "These equations describe the transitions of individuals from S to I to R.  \
The new parameter is the birth and death rate \[Mu].  By adding the three \
equations, we show easily that the total population ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is constant.  As before, the parameter \[Alpha] is the transmissivity  \
and the parameter \[Beta] the recovery rate.  See Part 1 of this notebook and \
especially Part 2 of the SEIR notebook for a more detailed discussion of the \
transmissivity \[Alpha].  "
}], "Text"],

Cell[TextData[{
  "\tIn equation (2), we may replace the sum ",
  StyleBox["s ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["i",
    FontSlant->"Italic"],
  " + ",
  StyleBox["r",
    FontSlant->"Italic"],
  " by the constant total population ",
  StyleBox["n",
    FontSlant->"Italic"],
  ".  Then equations (2) and (3) constitute a set of two equations for ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  ".  After they are solved, we may calculate ",
  StyleBox["r",
    FontSlant->"Italic"],
  " from equation (1).  "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Defining the Equations for DynPac", "Subtitle"],

Cell["\<\
\tIn much of what follows, we will be integrating equations (2) and \
(3) numerically.  In this section, we define the equations for DynPac.  We \
start by resetting integration and plot options.  de\
\>", "Text"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[TextData[{
  "Now we tell DynPac that the state variables are ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["s",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(setstate[{s, i}];\)\)], "Input"],

Cell[TextData[{
  "We tell DynPac that the\"official\" system parameters are the \
transmissivity \[Alpha], the recovery rate \[Beta], the birth and death rate \
\[Mu], and the total population ",
  StyleBox["n",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(setparm[{\[Alpha], \[Beta], \[Mu], n}];\)\)], "Input"],

Cell["\<\
Finally, we define the slope vector of the equations for \
DynPac.\
\>", "Text"],

Cell[BoxData[
    \(\(slopevec = {\(-\[Alpha]\)*s*i + \[Mu]*n - \[Mu]*s, \[Alpha]*s*
              i - \((\[Beta] + \[Mu])\)*i};\)\)], "Input"],

Cell["\<\
\tWe will define integration parameters later.  Our first step will \
be to look at the equilibrium states and their stability.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Equilibrium and Stability", "Subtitle"],

Cell["\<\
\tWe begin by looking for equilibrium states.  The DynPac command \
findpolyeq finds equilibrium states for systems with polynomial slope \
vectors.  \
\>", "Text"],

Cell[BoxData[
    \(eq = findpolyeq\)], "Input"],

Cell["\<\
The first state is one with no infectives, which we call eq1, and \
the second is an endemic state which we call eq2.\
\>", "Text"],

Cell[BoxData[
    \(eq1 = eq[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(eq2 = eq[\([2]\)]\)], "Input"],

Cell[TextData[{
  "\tIt is worth noting that although we can have a disease-free state with ",
  
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " both positive and ",
  StyleBox["i",
    FontSlant->"Italic"],
  " zero, it is not strictly speaking an equilibrium, because the recovered \
gradually die out and are not replaced.  Only when all of the recovered are \
gone can the population distribution be stationary."
}], "Text"],

Cell["\<\
\tLet's look at the stability of the no-infectives state.  We first \
evaluate the derivative matrix at that state.\
\>", "Text"],

Cell[BoxData[
    \(dermat1 = dermat /. Thread[statevec -> eq1]\)], "Input"],

Cell[BoxData[
    \(Eigensystem[dermat1]\)], "Input"],

Cell[TextData[
"The second eigenvalue -\[Mu] is always negative, hence the possibility of an \
epidemic hinges on the first eigenvalue.   We see that the equilibrium is \
unstable and there will be an epidemic if"], "Text"],

Cell[TextData[{
  "n",
  StyleBox["\[Alpha]",
    FontSlant->"Plain"],
  " - ",
  StyleBox["\[Beta] ",
    FontSlant->"Plain"],
  "- ",
  StyleBox[
  "\[Mu] > 0   .                                                              \
              ",
    FontSlant->"Plain"],
  StyleBox["(5)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "This is essentially our old condition that the initial ",
  "reproductive ratio",
  " must exceed 1, only the recovery rate in the earlier formula is now \
replaced by the \[Beta] + \[Mu], the sum of the recovery rate and the natural \
death rate.  If (5) is satisfied and we introduce an infective, there will be \
an epidemic.  In this case, the equilibrium is a saddle point, and the linear \
stable manifold, with eigenvalue \[Mu], is the ",
  StyleBox["s",
    FontSlant->"Italic"],
  " axis -- that is, any perturbation in population with no infectives will \
go back to the equilibrium population with an e-folding time of 1/\[Mu].  The \
linear unstable manifold points in the direction of increasing ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and decreasing ",
  StyleBox["s",
    FontSlant->"Italic"],
  ".  (See the phase plane plot for an example in section 5 below.)     "
}], "Text"],

Cell[TextData[{
  "\tThe endemic state is relevant only if the equilibrium values of ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["s",
    FontSlant->"Italic"],
  " are positive.  We see from the expression for eq2 above that this happens \
if and only if the condition (5) is satisfied.  Therefore we get the endemic \
state only when the zero infective state is unstable.  We would expect the \
endemic state to be stable in that case.  Let's see if we can show that.  We \
calculate the derivative matrix at eq2, and assign it to dermat2.    "
}], "Text"],

Cell[BoxData[
    \(dermat2 = dermat /. Thread[statevec -> eq2]\)], "Input"],

Cell["Now we introduce some simplifying notation:", "Text"],

Cell[TextData[{
  StyleBox["q",
    FontSlant->"Italic"],
  " = \[Beta] + \[Mu]  ,    ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = (",
  StyleBox["n",
    FontSlant->"Italic"],
  "\[Alpha]",
  StyleBox[" - ",
    FontSlant->"Italic"],
  "(\[Beta] ",
  StyleBox["+ ",
    FontSlant->"Italic"],
  "\[Mu] ))/(\[Beta] + \[Mu])   .                                             \
         ",
  StyleBox["(6)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["We use replacement rules to introduce these into dermat2:", "Text"],

Cell[BoxData[
    \(dermat2 = 
      Simplify[\(dermat2 /. \[Beta] -> \((q\  - \ \[Mu])\)\) /. 
          n -> \((q \((p + 1)\))\)/\[Alpha]]\)], "Input"],

Cell["Now we look at the characteristic polynomial:", "Text"],

Cell[BoxData[
    \(Collect[
      CharacteristicPolynomial[dermat2, \[Lambda]], \[Lambda]]\)], "Input"],

Cell[TextData[{
  "We see that for ",
  StyleBox["p",
    FontSlant->"Italic"],
  " > 0, the sum of the roots -",
  StyleBox["pq",
    FontSlant->"Italic"],
  "\[Mu] is negative and the product of the roots \[Mu] + ",
  StyleBox["p",
    FontSlant->"Italic"],
  "\[Mu] is positive, hence the equilibrium is strictly stable."
}], "Text"],

Cell[TextData[{
  "\tSummary of equilibrium and stability:  (1) For ",
  StyleBox["p",
    FontSlant->"Italic"],
  " < 0, the only equilibrium is the state with all susceptibles and no \
infectives or recovered.  This state is stable, and if infectives are \
introduced, the number of infectives will decrease with time -- that is, \
there will not be an epidemic.  (2) For ",
  StyleBox["p",
    FontSlant->"Italic"],
  " > 0, the equilibrium with all susceptibles and no infectives or recovered \
still exists, but it is unstable.  If any infectives are added, there is an \
epidemic and the number of infectives increases.  The asymptotic state \
reached as ",
  StyleBox["t \[Rule] \[Infinity] ",
    FontSlant->"Italic"],
  "is the endemic state with coordinates given by eq2 above.  This state is a \
stable equilibrium in which the disease persists with a constant number of \
susceptibles, infectives and recovered.  For most diseases, the time required \
for an epidemic to peak is much less than the generational time represented \
by \[Mu].  Thus when we add infectives to a population in which ",
  StyleBox["p",
    FontSlant->"Italic"],
  " > 0, we expect to see a relatively rapid peak followed by a slow approach \
to the endemic state.  We pursue these ideas next.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["4. Small \[Mu] Approximations"], "Subtitle"],

Cell[TextData[{
  "\tWe derive here some simple approximations for \[Mu] small.  We assume \
throughout this section that ",
  StyleBox["p",
    FontSlant->"Italic"],
  " > 1, so that there is an epidemic.  The positive eigenvalue calculated \
above for the initial equilibrium of no infectives is ",
  StyleBox["n",
    FontSlant->"Italic"],
  "\[Alpha] - \[Beta] - \[Mu], which is approximately ",
  StyleBox["n",
    FontSlant->"Italic"],
  "\[Alpha] - \[Beta], exactly what it is in the S-I-R model without vital \
dynamics.  For the final approach to the endemic state, the time scales are \
determined by the eigenvalues in the endemic state.  It is easy to show from \
the characteristic equation that, correct to first order in \[Mu], we get \
eigenvalues "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"-", 
          FractionBox[
            StyleBox[
              RowBox[{"\[Mu]\[Alpha]", 
                StyleBox["n",
                  FontSlant->"Italic"]}]], \(2  \[Beta]\)]}], "\[PlusMinus]", 
        " ", 
        RowBox[{
          SqrtBox[
            RowBox[{\(\[Mu]\/\[Beta]\), 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[
                    RowBox[{
                      StyleBox["n",
                        FontSlant->"Italic"], "\[Alpha]"}]], " ", "-", " ", 
                  "\[Beta]"}], ")"}]}]], "     ", ".", 
          "                                                                   \
                            ", 
          StyleBox[\((7)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[
"From the fact that \[Mu] is small, we see that both the oscillation and \
decay time scales are long, but that the decay scale is the longer of the \
two.  Now we look at a numerical example of this."], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Examples", "Subtitle"],

Cell[TextData[{
  "\tThis example is strictly fictional, but the scales are chosen to \
illustrate the basic points.  We suppose that the recovery period for the \
disease is one week, that the population is 1000, that the birth/death rate \
\[Mu] is ",
  Cell[BoxData[
      \(TraditionalForm\`5\[Times]10\^\(-2\)\)]],
  "(inverse weeks), and that \[Alpha] is 3\[Times]",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-3\)\)]],
  "(inverse weeks).  We set these parameter values for DynPac:"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {3. *10\^\(-3\), 1.0, 5. *10\^\(-2\), 1000};\)\)], "Input"],

Cell[TextData[{
  "Now we set the integration parameters -- the initial time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ", the time step ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", the initial vector initvec, and the number of time steps nsteps.  For \
the initial vector, we assume that 10 of the 1000 are infected initially."
}], "Text"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.1; initvec = {990, 10}; nsteps = 800;\)], "Input"],

Cell["\<\
Thus our time step is 0.1 weeks, and we are integrating out to 80 \
weeks.\
\>", "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell["We set the aspect ratio to 1.", "Text"],

Cell[BoxData[
    \(\(asprat = 1;\)\)], "Input"],

Cell[TextData[{
  "We set the plot range to {0,1000} in both ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 1000}, {0, 1000}};\)\)], "Input"],

Cell["\<\
We set the system name to SIR, and we ask for arrows on the phase \
diagram -- specifically one arrow at the midpoint of the integral curve.\
\>",
   "Text"],

Cell[BoxData[
    \(\(sysname\  = \ "\<SIR\>";\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell["\<\
Finally, we ask for scientific notation to be used for the \
parameter values printed in the graph label.\
\>", "Text"],

Cell[BoxData[
    \(\(decdig\  = 3;\)\)], "Input"],

Cell[BoxData[
    \(\(sciflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol1];\)\)], "Input"],

Cell["\<\
We see the rapid development of the epidemic and the slow spiral \
into the endemic state.  That state is \
\>", "Text"],

Cell[BoxData[
    \(eqstateval[eq2]\)], "Input"],

Cell["The number of recovered is ", "Text"],

Cell[BoxData[
    \(1000\  - \ 350\  - 31\)], "Input"],

Cell["\<\
We look at our last integration point to see that we have actually \
arrived at the endemic state:\
\>", "Text"],

Cell[BoxData[
    \(lasttx\)], "Input"],

Cell["\<\
We are almost at the final endemic state -- close enough for now.\
\
\>", "Text"],

Cell["\<\
\tNow let's look at a time plot of the number of infectives.  We \
first check the range in the solution.\
\>", "Text"],

Cell[BoxData[
    \(staterange[sol1]\)], "Input"],

Cell[TextData[{
  "We now set the plot range for ",
  StyleBox["i",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 70}, {0, 300}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 2];\)\)], "Input"],

Cell["\<\
We see the strong rapid peak in the epidemic, followed by decaying \
oscillations to the final endemic state.  Let's do the time plot for the \
number of susceptibles.\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 70}, {0, 1000}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["\<\
Once again the strong epidemic peak followed by an oscillatory \
approach to the endemic state.\
\>", "Text"],

Cell["\<\
\tOnce the endemic state is established, any small perturbations \
which occur will be damped oscillations, with frequency and damping rate \
determined by the eigenvalues of that state.  These eigenvalues are\
\>", 
  "Text"],

Cell[BoxData[
    \(Eigenvalues[dermatval[eq2]]\)], "Input"],

Cell["\<\
We see that the imaginary part is larger than the real part, as we \
would expect from equation (7).  The e-folding decay scale is\
\>", "Text"],

Cell[BoxData[
    \(1/0.0714286\)], "Input"],

Cell["hence 14 weeks, and the oscillation period is", "Text"],

Cell[BoxData[
    \(2*Pi/\((0.30397)\)\)], "Input"],

Cell["a little under 20 weeks.", "Text"],

Cell[TextData[{
  "\tWe now look at a second example, given by R.M Anderson and R.M May in ",
  StyleBox["Infectious Diseases of Humans",
    FontWeight->"Bold"],
  ", Oxford University Press, 1991, p. 123-124.  The model is the same as \
that discussed here.  The parameter values are (the time unit is years; our \
numbers differ somewhat from May's)"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {0.05, 10.0, 1.0/70.0, 1000.0};\)\)], "Input"],

Cell["\<\
We start with two infectives in a population of 1000, and we \
integrate for 100 years.\
\>", "Text"],

Cell[BoxData[
    \(\(maysol = integrate[{998, 2}, 0.0, 0.02, 5000];\)\)], "Input"],

Cell["We first look at the solution over a short time scale.", "Text"],

Cell[BoxData[
    \(\(sysname = "\<\>";\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 1}, {0, 1000}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeunit = "\<yr\>";\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[maysol, 1];\)\)], "Input"],

Cell["\<\
The epidemic is essentially over in four or five months.  Now we \
look at the solution over much longer times:\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 100}, {0, 1000}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[maysol, 1];\)\)], "Input"],

Cell["\<\
This rather striking curve can be described as a succession of \
epidemics, of ever-diminishing amplitude.  Eventually, these oscillations \
disappear and the system settles in to the stable endemic equilibrium.  Let's \
track it a little further in time to see this.  We use a coarser time step \
and go twice as far.\
\>", "Text"],

Cell[BoxData[
    \(\(maysol2 = integrate[{998, 2}, 0.0, 0.04, 5000];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 200}, {0, 1000}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[maysol2, 1];\)\)], "Input"],

Cell["\<\
The system requires 200 years to settle into the endemic state!   \
\
\>", "Text"],

Cell["\<\
\tThe most characteristic feature of this system is the existence \
of two very different time scales -- the short time scale of a single \
epidemic, and the long generational time scale on which susceptibles are \
replenished.  We will continue the study of the consequences of these two \
different time scales in the notebook SEIR Models Part 2.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000b60801T1T00000000000
00000000000000Q4P`00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 80, 4, 190, "Title"],
Cell[1822, 57, 38, 1, 27, "Input"],
Cell[1863, 60, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1941, 65, 35, 0, 56, "Subtitle"],

Cell[CellGroupData[{
Cell[2001, 69, 46, 0, 46, "Subsection"],
Cell[2050, 71, 577, 11, 98, "Text"],
Cell[2630, 84, 1207, 36, 134, "Text"],
Cell[3840, 122, 437, 20, 32, "Text"],
Cell[4280, 144, 715, 11, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5032, 160, 72, 0, 46, "Subsection"],
Cell[5107, 162, 67, 0, 30, "Text"],
Cell[5177, 164, 1111, 31, 45, "Text"],
Cell[6291, 197, 804, 23, 45, "Text"],
Cell[7098, 222, 725, 21, 45, "Text"],
Cell[7826, 245, 544, 10, 80, "Text"],
Cell[8373, 257, 587, 23, 50, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9009, 286, 56, 0, 56, "Subtitle"],
Cell[9068, 288, 223, 4, 46, "Text"],
Cell[9294, 294, 46, 1, 27, "Input"],
Cell[9343, 297, 47, 1, 27, "Input"],
Cell[9393, 300, 182, 8, 32, "Text"],
Cell[9578, 310, 54, 1, 27, "Input"],
Cell[9635, 313, 256, 7, 48, "Text"],
Cell[9894, 322, 76, 1, 27, "Input"],
Cell[9973, 325, 90, 3, 30, "Text"],
Cell[10066, 330, 143, 2, 27, "Input"],
Cell[10212, 334, 153, 3, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10402, 342, 48, 0, 56, "Subtitle"],
Cell[10453, 344, 174, 4, 46, "Text"],
Cell[10630, 350, 48, 1, 27, "Input"],
Cell[10681, 353, 141, 3, 30, "Text"],
Cell[10825, 358, 50, 1, 27, "Input"],
Cell[10878, 361, 50, 1, 27, "Input"],
Cell[10931, 364, 480, 14, 64, "Text"],
Cell[11414, 380, 139, 3, 30, "Text"],
Cell[11556, 385, 76, 1, 27, "Input"],
Cell[11635, 388, 53, 1, 27, "Input"],
Cell[11691, 391, 223, 3, 46, "Text"],
Cell[11917, 396, 394, 17, 32, "Text"],
Cell[12314, 415, 922, 19, 116, "Text"],
Cell[13239, 436, 580, 12, 80, "Text"],
Cell[13822, 450, 76, 1, 27, "Input"],
Cell[13901, 453, 59, 0, 30, "Text"],
Cell[13963, 455, 468, 20, 32, "Text"],
Cell[14434, 477, 73, 0, 30, "Text"],
Cell[14510, 479, 153, 3, 27, "Input"],
Cell[14666, 484, 61, 0, 30, "Text"],
Cell[14730, 486, 104, 2, 27, "Input"],
Cell[14837, 490, 336, 11, 48, "Text"],
Cell[15176, 503, 1296, 25, 166, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16509, 533, 59, 0, 56, "Subtitle"],
Cell[16571, 535, 777, 17, 100, "Text"],
Cell[17351, 554, 848, 24, 52, "Text"],
Cell[18202, 580, 226, 3, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18465, 588, 31, 0, 56, "Subtitle"],
Cell[18499, 590, 505, 11, 62, "Text"],
Cell[19007, 603, 91, 1, 31, "Input"],
Cell[19101, 606, 358, 9, 48, "Text"],
Cell[19462, 617, 86, 1, 27, "Input"],
Cell[19551, 620, 98, 3, 30, "Text"],
Cell[19652, 625, 78, 1, 27, "Input"],
Cell[19733, 628, 45, 0, 30, "Text"],
Cell[19781, 630, 48, 1, 27, "Input"],
Cell[19832, 633, 176, 8, 32, "Text"],
Cell[20011, 643, 70, 1, 27, "Input"],
Cell[20084, 646, 167, 4, 46, "Text"],
Cell[20254, 652, 61, 1, 27, "Input"],
Cell[20318, 655, 54, 1, 27, "Input"],
Cell[20375, 658, 54, 1, 27, "Input"],
Cell[20432, 661, 129, 3, 30, "Text"],
Cell[20564, 666, 50, 1, 27, "Input"],
Cell[20617, 669, 56, 1, 27, "Input"],
Cell[20676, 672, 50, 1, 27, "Input"],
Cell[20729, 675, 130, 3, 30, "Text"],
Cell[20862, 680, 48, 1, 27, "Input"],
Cell[20913, 683, 43, 0, 30, "Text"],
Cell[20959, 685, 54, 1, 27, "Input"],
Cell[21016, 688, 122, 3, 30, "Text"],
Cell[21141, 693, 39, 1, 27, "Input"],
Cell[21183, 696, 91, 3, 30, "Text"],
Cell[21277, 701, 129, 3, 30, "Text"],
Cell[21409, 706, 49, 1, 27, "Input"],
Cell[21461, 709, 111, 5, 32, "Text"],
Cell[21575, 716, 67, 1, 27, "Input"],
Cell[21645, 719, 55, 1, 27, "Input"],
Cell[21703, 722, 191, 4, 46, "Text"],
Cell[21897, 728, 68, 1, 27, "Input"],
Cell[21968, 731, 55, 1, 27, "Input"],
Cell[22026, 734, 119, 3, 30, "Text"],
Cell[22148, 739, 236, 5, 46, "Text"],
Cell[22387, 746, 60, 1, 27, "Input"],
Cell[22450, 749, 154, 3, 46, "Text"],
Cell[22607, 754, 44, 1, 27, "Input"],
Cell[22654, 757, 61, 0, 30, "Text"],
Cell[22718, 759, 51, 1, 27, "Input"],
Cell[22772, 762, 40, 0, 30, "Text"],
Cell[22815, 764, 365, 7, 64, "Text"],
Cell[23183, 773, 78, 1, 27, "Input"],
Cell[23264, 776, 111, 3, 30, "Text"],
Cell[23378, 781, 83, 1, 27, "Input"],
Cell[23464, 784, 70, 0, 30, "Text"],
Cell[23537, 786, 54, 1, 27, "Input"],
Cell[23594, 789, 67, 1, 27, "Input"],
Cell[23664, 792, 57, 1, 27, "Input"],
Cell[23724, 795, 57, 1, 27, "Input"],
Cell[23784, 798, 135, 3, 30, "Text"],
Cell[23922, 803, 69, 1, 27, "Input"],
Cell[23994, 806, 57, 1, 27, "Input"],
Cell[24054, 809, 342, 6, 62, "Text"],
Cell[24399, 817, 84, 1, 27, "Input"],
Cell[24486, 820, 69, 1, 27, "Input"],
Cell[24558, 823, 58, 1, 27, "Input"],
Cell[24619, 826, 92, 3, 30, "Text"],
Cell[24714, 831, 372, 6, 62, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

