(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43515,       1549]*)
(*NotebookOutlinePosition[     68395,       2450]*)
(*  CellTagsIndexPosition[     68351,       2446]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Within-Host Infection Dynamics
I.  No Immune Response\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["1.  Introduction", "Section"],

Cell[TextData[{
  "\tIn this notebook we consider dynamical models for the growth of \
microbial pathogens in a single host.  We follow the model given by R.M. \
Anderson in ",
  StyleBox["Emerging Infections",
    FontWeight->"Bold"],
  ", ed. R.M Krause, Academic Press, 1998, p. 23-50.  Two recent papers \
dealing with such models are \"Population Dynamics of Immune Responses to \
Persistent Viruses,\" M.A. Nowak and C.R.M. Bangham, Science ",
  StyleBox["272",
    FontWeight->"Bold"],
  ", 74-79, 1996, and \"The Within-Host Cellular Dynamics of Bloodstage \
Malaria:  Theoretical and Experimental Studies,\" C. Hetzel and R.M. \
Anderson, Parasitology ",
  StyleBox["113",
    FontWeight->"Bold"],
  ", 25-38, 1996.  The second article is closest to this notebook in that it \
does not include immune effects.  "
}], "Text"],

Cell[TextData[{
  "\tThe calculations in this notebook are carried out with DynPac, a package \
running under ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  It is available at URL: \
http://www.mathsource.com/Content/Applications/Mathematics/0209-517, or the \
latest version is availabe from Al Clark via E-mail:  \
clark@me.rochester.edu."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Formulation", "Section"],

Cell[CellGroupData[{

Cell["2.1  Balance Equations", "Subsection"],

Cell[TextData[{
  "\tAs mentioned above, we follow closely the presentation of Anderson.  The \
three state variables are the number of uninfected host cells ",
  StyleBox["H ",
    FontSlant->"Italic"],
  "(healthy cells), the number of infected host cells ",
  StyleBox["S ",
    FontSlant->"Italic"],
  "(sick cells), and the number of free pathogens ",
  StyleBox["P",
    FontSlant->"Italic"],
  ".  The basis for the model is the following set of assumptions:  (1) \
infected cells are produced by encounters between free pathogens and \
uninfected cells at a rate \[Beta]",
  StyleBox["PH ",
    FontSlant->"Italic"],
  "and infected cells die at a rate \[Alpha]",
  StyleBox["S; ",
    FontSlant->"Italic"],
  "(2) pathogens are produced by infected cells at a rate \[Rho]",
  StyleBox["S",
    FontSlant->"Italic"],
  " and die at a rate \[Delta]",
  StyleBox["P",
    FontSlant->"Italic"],
  "; (3) new uninfected host cells are produced at a constant rate \
\[CapitalGamma] and die at a rate \[Mu]",
  StyleBox["H",
    FontSlant->"Italic"],
  ".   With these assumptions, the balance equations for the three species \
become"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(dH\/dt\),
            FontSlant->"Italic"], 
          StyleBox["  ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{"\[CapitalGamma]", " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["H",
                  FontSlant->"Italic"]}]], " ", "-", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["HP",
                  FontSlant->"Italic"]}]]}]}], "    ", ","}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(dS\/dt\),
            FontSlant->"Italic"], "  ", "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["HP",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["S",
                  FontSlant->"Italic"]}]]}]}], "   ", ",", 
        "                                                                     \
                                     ", 
        StyleBox[\((1)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{"     ", 
        RowBox[{
          RowBox[{"and", "                 ", 
            StyleBox[\(dP\/dt\),
              FontSlant->"Italic"]}], "  ", "=", 
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            StyleBox[
              RowBox[{"\[Rho]", 
                StyleBox["S",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]], "   ", "."}]}]}], 
        "                            "}], TextForm]], "Text",
  TextAlignment->Center],

Cell["\<\
The list of factors and processes NOT described by these equations \
is long.  The primary processes omitted are the immune responses.  The \
primary oversimplification in the structure of the model is the lack of \
spatial variation.  We are essentially assuming that transport processes are \
not limiting in any way.  A better model would involve a compartment \
description of various body components, with a set of equations like (1) for \
each compartment, and interaction terms coupling the compartments.  There are \
other omissions, but we do not discuss them further here. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2  Defining the Equations for DynPac", "Subsection"],

Cell["\<\
\tWe have to tell DynPac the state variables, the parameters, and \
the slope functions on the right-hand sides of the equations.  We also name \
the system.  \
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{H, S, P}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[CapitalGamma], \[Mu], \[Beta], \[Alpha], \[Rho], \
\[Delta]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {\[CapitalGamma] - \[Mu]*H - \[Beta]*H*P, \[Beta]*H*
              P - \[Alpha]*S, \[Rho]*S - \[Delta]*P};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Host Pathogens\>";\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3  Basic Reproductive Parameter", "Subsection"],

Cell[TextData[{
  "\tThe most common application of equations (1) is to the situation in \
which a small number of pathogens are introduced into a previously healthy \
steady state.  In a healthy steady state, ",
  StyleBox["S",
    FontSlant->"Italic"],
  " = 0, ",
  StyleBox["P",
    FontSlant->"Italic"],
  " = 0, and ",
  StyleBox["H",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\)]],
  "= \[CapitalGamma]/\[Mu].  Now we change this state by adding a small \
number of pathogens.  The basic question is will the infection initially grow \
or die out?  We can answer this by looking at the second and third of \
equations (1) with the approximation that ",
  StyleBox["H",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\)]],
  "-- that is, the large number of healthy cells does not decrease much \
during the initial phases of the infection.  Then the relevant early time \
equations are"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(dS\/dt\),
              FontSlant->"Italic"], "  ", "=", "  ", 
            RowBox[{
              StyleBox[
                RowBox[{
                  SubscriptBox[
                    StyleBox[
                      RowBox[{"\[Beta]", 
                        StyleBox["H",
                          FontSlant->"Italic"]}]], "0"], "P"}],
                FontSlant->"Italic"], " ", "-", " ", 
              StyleBox[
                RowBox[{"\[Alpha]", 
                  StyleBox["S",
                    FontSlant->"Italic"]}]]}]}], "   ", ","}], " "}], 
      TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{"     ", 
        RowBox[{
          RowBox[{"and", "                 ", 
            StyleBox[\(dP\/dt\),
              FontSlant->"Italic"]}], "  ", "=", 
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            StyleBox[
              RowBox[{"\[Rho]", 
                StyleBox["S",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]], "   ", ".", 
              "                                                               \
                                              ", 
              StyleBox[\((2)\),
                FontWeight->"Bold"]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData["The eigenvalues \[Lambda] of this system are"], "Text"],

Cell[TextData[{
  "\[Lambda]  =  -",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "(\[Alpha] + \[Delta]) \[PlusMinus]",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
          \(\(1\/4\) \((\[Alpha]\  + \ \[Delta])\)\^2\), " ", "-", " ", 
            RowBox[{"(", 
              RowBox[{"\[Alpha]\[Delta]", " ", "-", " ", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[Beta]\[Rho]", 
                      StyleBox["H",
                        FontSlant->"Italic"]}]], "0"]}], ")"}]}]], 
        TraditionalForm]]],
  "       .                                        ",
  StyleBox["(3)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "The condition for growth is that one of the eigenvalues be positive (or \
have a positive real part), and this will be so if and only if (\[Alpha]\
\[Delta] - \[Beta]\[Rho]",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\)]],
  ") < 0, which we can write as"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["R",
              FontSlant->"Italic"], "0"], "  ", "=", "  ", 
          \(\[Beta]\[Rho]\[CapitalGamma]\/\[Mu]\[Alpha]\[Delta]\ \  > \ \ 1
            \)}], "     ", ",", 
        "                                                                     \
                       ", 
        StyleBox[\((4)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "is called the within-host basic reproductive number.  We will see in the \
next section that ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "also plays a role in determining the possible equilibria of the system. "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  Equilibrium and Stability", "Section"],

Cell["\<\
\tWe start by finding the possible equilibrium states of the \
system.\
\>", "Text"],

Cell[BoxData[
    \(eqstates = findpolyeq\)], "Input"],

Cell[TextData[{
  "The first of these is the disease-free state.  The second endemic state is \
positive and therefore relevant if and only if ",
  Cell[BoxData[
      \(TraditionalForm\`R\_\(0\ \)\)]],
  "> 1.  We name the two states."
}], "Text"],

Cell[BoxData[
    \(eqfree = eqstates[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(eqend = eqstates[\([2]\)]\)], "Input"],

Cell["\<\
Now we look at the stability of these states as determined by the \
eigenvalues of the derivative matrix.  First we get the derivative \
matrix:\
\>", "Text"],

Cell[BoxData[
    \(mat = dermat\)], "Input"],

Cell["Now we evaluate the matrix at the two equilibria.", "Text"],

Cell[BoxData[
    \(matfree = mat /. Thread[statevec -> eqfree]\)], "Input"],

Cell[BoxData[
    \(matend = mat /. Thread[statevec -> eqend]\)], "Input"],

Cell["\<\
\tWe start with eqfree by getting the characteristic polynomial of \
the derivative matrix.\
\>", "Text"],

Cell[BoxData[
    \(polyfree = 
      FullSimplify[CharacteristicPolynomial[matfree, \[Lambda]]]\)], "Input"],

Cell[TextData[
"We see that one eigenvalue is \[Lambda] = -\[Mu].  The other two eigenvalues \
are roots of"], "Text"],

Cell[BoxData[
    \(polyfree2 = polyfree/\((\[Lambda]\  + \ \[Mu])\)\)], "Input"],

Cell[BoxData[
    \(CoefficientList[\(-polyfree2\), \[Lambda]]\)], "Input"],

Cell[TextData[{
  "It is easy to show from the above coefficients that this equilibrium is \
stable if and only if ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1.  Thus the condition that the pathogens not increase is the same as \
the condition for the stability of the disease-free equilibrium (and in fact \
this is really the same calculation done in two different ways).  "
}], "Text"],

Cell[TextData[{
  "\tNow we look at the endemic state.  This state is relevant only for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1, and it is also the only candidate for an attractor when ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1, so we fully expect to find that the state is stable in that case.  We \
start by getting the coefficients of the characteristic polynomial of the \
derivative matrix at that state.  "
}], "Text"],

Cell[BoxData[
    \(listend = 
      FullSimplify[
        CoefficientList[\(-CharacteristicPolynomial[
              matend, \[Lambda]]\), \[Lambda]]]\)], "Input"],

Cell[TextData[{
  "The characteristic polynomial has the form c0",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^3\)]],
  "+ c1",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  "+c2\[Lambda] + c3, where"
}], "Text"],

Cell[BoxData[
    \(c0 = listend[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(c1 = listend[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(c2 = listend[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(c3 = listend[\([1]\)]\)], "Input"],

Cell[TextData[{
  "We will use the Routh-Hurwitz criterion for stability (see for example the \
",
  StyleBox["Encyclopedia of Mathematics on CD-ROM",
    FontWeight->"Bold"],
  ", Kluwer, 1997, entry under Routh-Hurwitz criterion).  This criterion in \
this case of a cubic with leading coefficient unity says that a necessary and \
sufficient condition for stability is that c1 > 0, c3 > 0, and c1*c2 - c3 > \
0.  Clearly c1 is always positive, and c3 is positive for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1.  We calculate c1*c2 - c3:"
}], "Text"],

Cell[BoxData[
    \(ctest = FullSimplify[c1*c2 - c3]\)], "Input"],

Cell[TextData[
"We collect the coefficients with respect to \[CapitalGamma].  If they are \
positive, then ctest is clearly positive and the equilibrium is stable."], 
  "Text"],

Cell[BoxData[
    \(FullSimplify[CoefficientList[ctest, \[CapitalGamma]]]\)], "Input"],

Cell["All the coefficients are positive, so we are done.", "Text"],

Cell[TextData[{
  "\tIn summary:  If ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1, the disease-free state is a stable equilibrium, and any pathogens \
introduced will die out.  If ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1, the disease-free state is unstable, and any pathogens introduced will \
increase in number, and the system will asymptotically approach an \
equilibrium state, which can be put into the form"
}], "Text"],

Cell[TextData[{
  "{",
  Cell[BoxData[
      \(TraditionalForm\`H\_e\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_e\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`P\_e\)]],
  "}  =  (1/\[Beta]\[Rho]){\[Alpha]\[Delta], \[Delta]\[Mu](",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " - 1), \[Rho]\[Mu](",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " - 1)}   .                                          ",
  StyleBox["(5)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.  Dynamical Examples", "Section"],

Cell["\<\
\tWe look at some examples of time-dependent solutions of these \
equations.  The examples are strictly mathematical and have no direct \
relevance to any biological problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Scaling", "Subsubsection"],

Cell["\<\
\tIn this example, we do not attempt to insert any biological \
content.  Because the emphasis is mathematical, it is helpful to scale the \
equations.  In so doing, we can reduce the number of parameters from 6 to 3.  \
We introduce the following scaled variables:\
\>", "Text"],

Cell[TextData[{
  "h ",
  StyleBox[" =  \[Mu]",
    FontSlant->"Plain"],
  "H/",
  StyleBox["\[CapitalGamma]",
    FontSlant->"Plain"],
  "  ,  ",
  StyleBox[" ",
    FontSlant->"Plain"],
  "s  ",
  StyleBox["= ",
    FontSlant->"Plain"],
  " ",
  StyleBox["\[Mu]",
    FontSlant->"Plain"],
  "S",
  StyleBox["/\[CapitalGamma]  ,   ",
    FontSlant->"Plain"],
  "p",
  StyleBox["  =  \[Beta]",
    FontSlant->"Plain"],
  "P",
  StyleBox["/\[Mu]  ,   and  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`t\&^\)]],
  "  ",
  StyleBox["=  \[Mu]",
    FontSlant->"Plain"],
  "t",
  StyleBox["   .                                     ",
    FontSlant->"Plain"],
  StyleBox["(6)",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  "  ",
  StyleBox["  ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "The final scaled equations contain three dimensionless parameters, which \
we give below, repeating the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "for convenience:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["R",
              FontSlant->"Italic"], "0"], "   ", "=", "  ", 
          \(\[Beta]\[Rho]\[CapitalGamma]\/\[Mu]\[Alpha]\[Delta]\)}], " ", 
        ",", "   ", 
        RowBox[{
          StyleBox["q",
            FontSlant->"Italic"], "  ", "=", "  ", \(\[Alpha]\/\[Mu]\)}], 
        "  ", ",", "   ", 
        RowBox[{
          StyleBox["r",
            FontSlant->"Italic"], "  ", "=", "  ", 
          RowBox[{
          \(\[Delta]\/\[Mu]\), "   ", ".", 
            "                                                                 \
                ", 
            StyleBox[\((7)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "After dropping the hat on ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", we get the scaled equations in the following form:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["h",
                    FontSlant->"Italic"]}]], "dt"],
            FontSlant->"Italic"], 
          StyleBox["  ",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{"1", " ", "-", " ", 
            StyleBox["h",
              FontSlant->"Italic"], " ", "-", 
            StyleBox[\(p h\),
              FontSlant->"Italic"]}]}], "   ", ","}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["s",
                    FontSlant->"Italic"]}]], "dt"],
            FontSlant->"Italic"], "  ", "=", 
          StyleBox[" ",
            FontSlant->"Italic"], 
          RowBox[{
            StyleBox[\(p h\),
              FontSlant->"Italic"], " ", "-", 
            StyleBox[\(q s\),
              FontSlant->"Italic"]}]}], "   ", ",", 
        "                                                                     \
                                     ", 
        StyleBox[\((8)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{"     ", 
        RowBox[{
          RowBox[{"and", "                 ", 
            StyleBox[
              FractionBox[
                StyleBox[
                  RowBox[{"d", 
                    StyleBox["p",
                      FontSlant->"Italic"]}]], "dt"],
              FontSlant->"Italic"]}], "  ", "=", 
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontSlant->"Italic"]}]], 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["qrR",
                  FontSlant->"Italic"], "0"], 
              StyleBox["s",
                FontSlant->"Italic"]}], " ", "-", 
            StyleBox[" ",
              FontSlant->"Italic"], 
            RowBox[{
              StyleBox[\(r p\),
                FontSlant->"Italic"], " ", "."}]}]}], 
        "                            "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "\tConsider the parameters briefly.  The quantities ",
  StyleBox["q",
    FontSlant->"Italic"],
  " and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " are ratios of death rates and we expect them both to be moderately large, \
because the healthy cell death rate \[Mu] will be lower than the infected \
cell death rate \[Alpha] and the pathogen death rate \[Delta].  We have \
already discussed the significance of the within-host reproductive ratio ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ", and our main purpose will be to study how the solution depends on ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the System for DynPac", "Subsubsection"],

Cell["\tWe define our scaled system for DynPac.", "Text"],

Cell[BoxData[
    \(\(setstate[{h, s, p}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{q, r, R0}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {1 - h - p*h, p*h - q*s, q*r*R0*s - r*p};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<\>";\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium and Stability", "Subsubsection"],

Cell["\<\
\tWe repeat briefly the equilbrium and stability analysis.  We \
start by finding the equilbrium states in this scaled version of the problem. \
 \
\>", "Text"],

Cell[BoxData[
    \({eqfree, eqend} = findpolyeq\)], "Input"],

Cell[TextData[{
  "\tThe scaled form of the endemic equilibrium makes it particularly \
convenient to look at some asymptotic results for the nature of the \
equilibrium state.  Two quantities of particular interest are the total \
number of cells ",
  Cell[BoxData[
      \(TraditionalForm\`C\_tot\)]],
  "= ",
  StyleBox["h",
    FontSlant->"Italic"],
  " + ",
  StyleBox["s",
    FontSlant->"Italic"],
  ", and the fraction of diseased cells ",
  Cell[BoxData[
      \(TraditionalForm\`F\_s\)]],
  " = ",
  StyleBox["s",
    FontSlant->"Italic"],
  "/(",
  StyleBox["h",
    FontSlant->"Italic"],
  " + ",
  StyleBox["s",
    FontSlant->"Italic"],
  ").  In the initial state, ",
  Cell[BoxData[
      \(TraditionalForm\`C\_tot\)]],
  "= 1 and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_s\)]],
  "= 0.  In the endemic equilibrium, we have"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["C",
              FontSlant->"Italic"], "tot"], "  ", "=", "  ", 
          FractionBox[
            RowBox[{
              SubscriptBox[
                StyleBox["R",
                  FontSlant->"Italic"], "0"], "+", " ", 
              StyleBox["q",
                FontSlant->"Italic"], " ", "-", " ", "1"}], 
            RowBox[{
              StyleBox["q",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              SubscriptBox[
                StyleBox["R",
                  FontSlant->"Italic"], "0"]}]]}], " ", ",", 
        "             ", 
        RowBox[{
          SubscriptBox[
            StyleBox["F",
              FontSlant->"Italic"], "s"], " ", "=", "  ", 
          RowBox[{
            FractionBox[
              RowBox[{
                SubscriptBox[
                  StyleBox["R",
                    FontSlant->"Italic"], "0"], " ", "-", " ", "1"}], 
              RowBox[{
                SubscriptBox[
                  StyleBox["R",
                    FontSlant->"Italic"], \(0\ \)], "+", " ", 
                StyleBox["q",
                  FontSlant->"Italic"], " ", "-", "1"}]], "      ", 
            "."}]}]}], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "The parameter ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "was discussed earlier.  The other parameter appearing, ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", is the ratio of the death rate of an infected cell to the death rate of \
an uninfected cell.  We call it the cytotoxicity ratio.  One extreme case is \
",
  StyleBox["q",
    FontSlant->"Italic"],
  " = 1, corresponding to no cytotoxicity.  In that case, the above \
expressions reduce to ",
  Cell[BoxData[
      \(TraditionalForm\`C\_tot\)]],
  "= 1 and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_s\)]],
  "= 1 - 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  Thus the number of cells remains equal to the initial number, and the \
fraction of cells that are infected varies from 0 to 1 as ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "varies from 1 to \[Infinity].  The opposite extreme for a very lethal \
infection is the limit ",
  StyleBox["q",
    FontSlant->"Italic"],
  " \[ShortRightArrow] \[Infinity] at fixed ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  In that limit, ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(tot\ \)\)]],
  Cell[BoxData[
      \(TraditionalForm\`goes\)]],
  " to 1/",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\_s\ \)\)]],
  "goes to 0.  This last result just says that infected cells die very \
quickly and so there are very few of them around when ",
  StyleBox["q",
    FontSlant->"Italic"],
  " is very large.  We may also consider the limit of large ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "at fixed ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", for which we get ",
  Cell[BoxData[
      \(TraditionalForm\`C\_tot\)]],
  " going to 1/",
  StyleBox["q",
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_s\)]],
  " going to 1.  Thus in this limit all of the cells are infected, and the \
number is reduced from the initial number by a factor of 1/",
  StyleBox["q",
    FontSlant->"Italic"],
  "  -- in effect the cell birth rate is still the same and the death rate is \
larger by ",
  StyleBox["q",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNow we look at the stability.  At each equilibrium, we get the \
characteristic polynomial in the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"c0", 
              FormBox[\(\[Lambda]\^3\),
                "TraditionalForm"]}], "+", " ", 
            RowBox[{"c1", 
              FormBox[\(\[Lambda]\^2\),
                "TraditionalForm"]}], "+", "c2\[Lambda]", " ", "+", " ", 
            "c3"}], ",", " ", \(with\ c0\  = \ 1\)}], TextForm]]],
  ".  ",
  "Then we use the Routh-Hurwitz test for stability.  ",
  "We begin with the disease-free equilbrium at {1, 0, 0}. "
}], "Text"],

Cell[BoxData[
    \(matfree = dermat /. Thread[statevec -> eqfree]\)], "Input"],

Cell[BoxData[
    \(matend = dermat /. Thread[statevec -> eqend]\)], "Input"],

Cell[BoxData[
    \(freelist = 
      CoefficientList[\(-CharacteristicPolynomial[
            matfree, \[Lambda]]\), \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(c0 = freelist[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(c1 = freelist[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(c2 = freelist[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(c3 = freelist[\([1]\)]\)], "Input"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1, c3 and c0 have opposite signs and there is then a positive real root \
for \[Lambda], and the equilibrium is unstable.  For ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1, all the coefficients are positive.  According to the Routh-Hurwitz \
criterion, the equilibrium is stable if and only if c1*c2 - c3 > 0. "
}], "Text"],

Cell[BoxData[
    \(ctest = FullSimplify[c1*c2 - c3]\)], "Input"],

Cell[TextData[{
  "This is positive for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1, hence the disease-free equilbrium is stable in that case."
}], "Text"],

Cell["\tNow we look at the endemic state.", "Text"],

Cell[BoxData[
    \(endlist = 
      CoefficientList[\(-CharacteristicPolynomial[
            matend, \[Lambda]]\), \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(c0 = endlist[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(c1 = endlist[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(c2 = endlist[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(c3 = endlist[\([1]\)]\)], "Input"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1, c0 and c3 have opposite signs, so there is a real positive root and \
the equilibrium is unstable.  For ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1, all the coefficients are positive, so the equilibrium is stable if \
and only if c1*c2 - c3 > 0.  "
}], "Text"],

Cell[BoxData[
    \(ctest = FullSimplify[c1*c2 - c3]\)], "Input"],

Cell[TextData[{
  "This is positive, which establishes the stability of the endemic case when \
",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "> 1.  These calculations simply verify what we already knew from our \
earlier analysis, although we see that the calculations are somewhat easier \
in the scaled version."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bifurcations", "Subsubsection"],

Cell[TextData[{
  "\tWe will look at several solutions, for varying values of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ".  We start by identifying the bifurcations in ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "for fixed values of ",
  StyleBox["r",
    FontSlant->"Italic"],
  " and ",
  StyleBox["q",
    FontSlant->"Italic"],
  " -- namely 2 for both.  We calculate the characteristic polynomial at each \
equilibrium as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0. \)]]
}], "Text"],

Cell[BoxData[
    \(\(dermatfree = dermat /. Thread[statevec -> eqfree];\)\)], "Input"],

Cell[BoxData[
    \(freepoly = 
      Collect[\(-CharacteristicPolynomial[
            dermatfree /. 
              Thread[{q, r} -> {2, 2}], \[Lambda]]\), \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\(dermatend = dermat /. Thread[statevec -> eqend];\)\)], "Input"],

Cell[BoxData[
    \(endpoly = 
      Collect[\(-CharacteristicPolynomial[
            dermatend /. 
              Thread[{q, r} -> {2, 2}], \[Lambda]]\), \[Lambda]]\)], "Input"],

Cell[TextData[{
  "We already know that for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1, the disease-free state is stable, and the endemic is both irrelevant \
(because of negative coordinates) and unstable.  When ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\  > \ 1\)]],
  ", the disease-free state is relevant but unstable, and the endemic state \
is both relevant and stable.  The remaining question is whether there are any \
transitions in the stable endemic state as ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "increases.  We do a spot check of the eigenvalues:"
}], "Text"],

Cell[BoxData[
    \(NSolve[\((endpoly /. R0 -> 1.2)\) == 0, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(NSolve[\((endpoly /. R0 -> 1.5)\) == 0, \[Lambda]]\)], "Input"],

Cell[TextData[{
  "Thus there is a transition from a three-dimensional node to a \
one-dimensional node and two-dimensional spiral for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " between 1.2 and 1.5.  At the transition, there will be a repeated root, \
which we now find:"
}], "Text"],

Cell[BoxData[
    \(NSolve[{endpoly == 0, 
        D[endpoly, \[Lambda]] == 0}, {R0, \[Lambda]}]\)], "Input"],

Cell[TextData[{
  "Thus the transition occurs at ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 1.41859.  We check that:"
}], "Text"],

Cell[BoxData[
    \(NSolve[\((endpoly /. R0 -> 1.418)\) == 0, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(NSolve[\((endpoly /. R0 -> 1.419)\) == 0, \[Lambda]]\)], "Input"],

Cell[TextData[{
  "\tThe bifurcations can be a little more involved if we abandon the special \
parameter relation ",
  StyleBox["q",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r",
    FontSlant->"Italic"],
  ".  We give an example by repeating the above calculations for  ",
  StyleBox["q",
    FontSlant->"Italic"],
  " = 4, ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 2."
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(endpolymod = 
      Collect[\(-CharacteristicPolynomial[
            dermatend /. 
              Thread[{q, r} -> {4, 
                    2}], \[Lambda]]\), \[Lambda]]\)\)\)], "Input"],

Cell[TextData[{
  "We look at the eigenvalues for a small, medium and large value of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(NSolve[\((endpolymod /. R0 -> 1.2)\) == 0, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(NSolve[\((endpolymod /. R0 -> 10)\) == 0, \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(NSolve[\((endpolymod /. R0 -> 20)\) == 0, \[Lambda]]\)], "Input"],

Cell[TextData[{
  "Thus we see that there are oscillations for some range of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "but not for small or large values.  If there is a transition to or from \
imaginary roots, there must be a repeated root at the bifurcation.  We look \
for those root:s.  The calculation above shows that we will find at least two \
real sets of roots.  "
}], "Text"],

Cell[BoxData[
    \(NSolve[{endpolymod == 0, 
        D[endpolymod, \[Lambda]] == 0}, {R0, \[Lambda]}]\)], "Input"],

Cell[TextData[{
  "Thus for ",
  StyleBox["q",
    FontSlant->"Italic"],
  " = 4 and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 2, there will be an oscillatory approach to endemic equilibrium for \
1.27227 < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 17.645, and three negative real eigenvalues for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "outside that range.  "
}], "Text"],

Cell[TextData[{
  "\tNow we return to the case of ",
  StyleBox["q",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 2 and look at the dynamical solutions for five values of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "-- 0.9, 1.2, 1.5,  5, and 20."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dynamics for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 0.9"
}], "Subsubsection"],

Cell[BoxData[
    \(\(parmval = {2, 2, 0.9};\)\)], "Input"],

Cell["We check the equilibrium state:", "Text"],

Cell[BoxData[
    \(eqfree\)], "Input"],

Cell[BoxData[
    \(classify[eqfree]\)], "Input"],

Cell["We check the eigenvalues at the stable equilbrium.", "Text"],

Cell[BoxData[
    \(Eigenvalues[dermatval[eqfree]]\)], "Input"],

Cell["Thus we have a stable node.", "Text"],

Cell["\<\
We choose an initial condition in which the healthy cell population \
has the steady state value of 1, and we perturb the system by adding some \
pathogens -- one pathogen for every 10 healthy cells.\
\>", "Text"],

Cell[BoxData[
    \(\(initvec = {1, 0, 0.1};\)\)], "Input"],

Cell["\<\
Now we set the integration parameters:  the time step ht, the \
number of time steps nsteps, and the initial time t0.\
\>", "Text"],

Cell[BoxData[
    \(ht = 0.02; nsteps = 1000; t0 = 0;\)], "Input"],

Cell["Now we construct the solution:", "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[initvec, t0, ht, nsteps];\)\)], "Input"],

Cell["\<\
Before plotting, we get the range of values in the solution of each \
variable.\
\>", "Text"],

Cell[BoxData[
    \(staterange[sol1]\)], "Input"],

Cell["\<\
We set some graphing parameters, and plot the three components \
separately.\
\>", "Text"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(graph1a = timeplot[sol1, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1b = timeplot[sol1, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1c = timeplot[sol1, 3];\)\)], "Input"],

Cell[TextData[{
  "\tWe can see that the pathogens decrease monotonically, and this infection \
dies out.  This is what we expect for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "< 1."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dynamics for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 1.2"
}], "Subsubsection"],

Cell[TextData[{
  "\tNow we increase ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " to 1.2 and repeat the calculation."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2, 2, 1.2};\)\)], "Input"],

Cell["We check the equilibrium states.", "Text"],

Cell[BoxData[
    \(eqstateval[eqfree]\)], "Input"],

Cell[BoxData[
    \(eqstateval[eqend]\)], "Input"],

Cell[BoxData[
    \(classify[eqfree]\)], "Input"],

Cell[BoxData[
    \(classify[eqend]\)], "Input"],

Cell["We check the eigenvalues at the stable equilbrium.", "Text"],

Cell[BoxData[
    \(N[Eigenvalues[dermatval[eqend]]]\)], "Input"],

Cell["A stable node as we expected.", "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[initvec, t0, ht, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(staterange[sol2]\)], "Input"],

Cell[BoxData[
    \(\(graph2a = timeplot[sol2, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(graph2b = timeplot[sol2, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(graph2c = timeplot[sol2, 3];\)\)], "Input"],

Cell["\<\
The pathogens begin to decrease because we start with no infected \
cells and thus no source of pathogens.  As soon as there are some infected \
cells, the pathogen level increase.  The final stable state is an endemic one \
in which the number of free pathogens is one-fifth the number of original \
healthy cells.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dynamics for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 1.5"
}], "Subsubsection"],

Cell[TextData[{
  "\tNow we increase ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  " to 1.5 and repeat the calculation."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2, 2, 1.5};\)\)], "Input"],

Cell["We check the equilibrium states.", "Text"],

Cell[BoxData[
    \(eqstateval[eqfree]\)], "Input"],

Cell[BoxData[
    \(eqstateval[eqend]\)], "Input"],

Cell[BoxData[
    \(classify[eqfree]\)], "Input"],

Cell[BoxData[
    \(classify[eqend]\)], "Input"],

Cell["We check the eigenvalues at the stable equilbrium.", "Text"],

Cell[BoxData[
    \(N[Eigenvalues[dermatval[eqend]]]\)], "Input"],

Cell["Still stable but with some oscillations.", "Text"],

Cell[BoxData[
    \(\(sol3 = integrate[initvec, t0, ht, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(staterange[sol3]\)], "Input"],

Cell[BoxData[
    \(\(graph3a = timeplot[sol3, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(graph3b = timeplot[sol3, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(graph3c = timeplot[sol3, 3];\)\)], "Input"],

Cell["\<\
The pathogens begin to decrease because we start with no infected \
cells and thus no source of pathogens.  As soon as there are some infected \
cells, the pathogen level increases.  The final stable state is an endemic \
one in which the number of free pathogens is one-fifth of the number of \
original healthy cells.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dynamics for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 5"
}], "Subsubsection"],

Cell[TextData[{
  "\tNow we increase ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "to 5 and repeat the analysis."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2, 2, 5};\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[eqfree]\)], "Input"],

Cell[BoxData[
    \(eqstateval[eqend]\)], "Input"],

Cell[BoxData[
    \(classify[eqfree]\)], "Input"],

Cell[BoxData[
    \(classify[eqend]\)], "Input"],

Cell["We check the eigenvalues.  ", "Text"],

Cell[BoxData[
    \(N[Eigenvalues[dermatval[eqend]]]\)], "Input"],

Cell["\<\
We expect some oscillations, but they will not be pronounced \
because the real part of the eigenvalues is considerably larger than the \
imaginary part.\
\>", "Text"],

Cell[BoxData[
    \(\(sol4 = integrate[initvec, t0, ht, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graph4a = timeplot[sol4, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(graph4b = timeplot[sol4, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(graph4c = timeplot[sol4, 3];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dynamics for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "= 20"
}], "Subsubsection"],

Cell[TextData[{
  "\tFor our last case, we increase ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "to 20."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2, 2, 20};\)\)], "Input"],

Cell[BoxData[
    \(eqstateval[eqfree]\)], "Input"],

Cell[BoxData[
    \(eqstateval[eqend]\)], "Input"],

Cell[BoxData[
    \(classify[eqfree]\)], "Input"],

Cell[BoxData[
    \(classify[eqend]\)], "Input"],

Cell["We check the eigenvalues.  ", "Text"],

Cell[BoxData[
    \(N[Eigenvalues[dermatval[eqend]]]\)], "Input"],

Cell[BoxData[
    \(\(sol5 = integrate[initvec, t0, ht, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graph5a = timeplot[sol5, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(graph5b = timeplot[sol5, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(graph5c = timeplot[sol5, 3];\)\)], "Input"],

Cell[TextData[{
  "\tAlthough oscillations are present, they are neither dominant nor \
persistant for the values of ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  "looked at here.  The eigenvalues tell us that."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{612, 440},
WindowMargins->{{9, Automatic}, {Automatic, 6}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 78, 3, 152, "Title"],
Cell[1820, 56, 38, 1, 27, "Input"],
Cell[1861, 59, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1939, 64, 35, 0, 50, "Section"],
Cell[1977, 66, 833, 18, 132, "Text"],
Cell[2813, 86, 367, 9, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3217, 100, 34, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[3276, 104, 44, 0, 46, "Subsection"],
Cell[3323, 106, 1149, 31, 136, "Text"],
Cell[4475, 139, 583, 18, 45, "Text"],
Cell[5061, 159, 677, 19, 45, "Text"],
Cell[5741, 180, 741, 22, 45, "Text"],
Cell[6485, 204, 607, 9, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7129, 218, 60, 0, 46, "Subsection"],
Cell[7192, 220, 183, 4, 46, "Text"],
Cell[7378, 226, 57, 1, 27, "Input"],
Cell[7438, 229, 110, 2, 27, "Input"],
Cell[7551, 233, 154, 2, 27, "Input"],
Cell[7708, 237, 68, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7813, 243, 55, 0, 46, "Subsection"],
Cell[7871, 245, 976, 27, 114, "Text"],
Cell[8850, 274, 709, 21, 45, "Text"],
Cell[9562, 297, 899, 25, 45, "Text"],
Cell[10464, 324, 70, 0, 30, "Text"],
Cell[10537, 326, 719, 22, 50, "Text"],
Cell[11259, 350, 289, 7, 46, "Text"],
Cell[11551, 359, 487, 13, 46, "Text"],
Cell[12041, 374, 317, 9, 46, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12407, 389, 48, 0, 50, "Section"],
Cell[12458, 391, 94, 3, 30, "Text"],
Cell[12555, 396, 54, 1, 27, "Input"],
Cell[12612, 399, 248, 6, 46, "Text"],
Cell[12863, 407, 59, 1, 27, "Input"],
Cell[12925, 410, 58, 1, 27, "Input"],
Cell[12986, 413, 168, 4, 46, "Text"],
Cell[13157, 419, 45, 1, 27, "Input"],
Cell[13205, 422, 65, 0, 30, "Text"],
Cell[13273, 424, 76, 1, 27, "Input"],
Cell[13352, 427, 74, 1, 27, "Input"],
Cell[13429, 430, 115, 3, 30, "Text"],
Cell[13547, 435, 109, 2, 27, "Input"],
Cell[13659, 439, 118, 2, 30, "Text"],
Cell[13780, 443, 81, 1, 27, "Input"],
Cell[13864, 446, 75, 1, 27, "Input"],
Cell[13942, 449, 404, 8, 62, "Text"],
Cell[14349, 459, 463, 10, 62, "Text"],
Cell[14815, 471, 164, 4, 43, "Input"],
Cell[14982, 477, 235, 8, 30, "Text"],
Cell[15220, 487, 54, 1, 27, "Input"],
Cell[15277, 490, 54, 1, 27, "Input"],
Cell[15334, 493, 54, 1, 27, "Input"],
Cell[15391, 496, 54, 1, 27, "Input"],
Cell[15448, 499, 570, 12, 82, "Text"],
Cell[16021, 513, 65, 1, 27, "Input"],
Cell[16089, 516, 177, 3, 46, "Text"],
Cell[16269, 521, 86, 1, 27, "Input"],
Cell[16358, 524, 66, 0, 30, "Text"],
Cell[16427, 526, 461, 11, 62, "Text"],
Cell[16891, 539, 516, 20, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17444, 564, 41, 0, 50, "Section"],
Cell[17488, 566, 198, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[17711, 574, 32, 0, 42, "Subsubsection"],
Cell[17746, 576, 289, 5, 62, "Text"],
Cell[18038, 583, 829, 40, 32, "Text"],
Cell[18870, 625, 223, 6, 46, "Text"],
Cell[19096, 633, 779, 22, 46, "Text"],
Cell[19878, 657, 158, 5, 32, "Text"],
Cell[20039, 664, 587, 18, 45, "Text"],
Cell[20629, 684, 749, 22, 45, "Text"],
Cell[21381, 708, 959, 29, 45, "Text"],
Cell[22343, 739, 669, 17, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23049, 761, 55, 0, 42, "Subsubsection"],
Cell[23107, 763, 57, 0, 30, "Text"],
Cell[23167, 765, 57, 1, 27, "Input"],
Cell[23227, 768, 57, 1, 27, "Input"],
Cell[23287, 771, 89, 1, 27, "Input"],
Cell[23379, 774, 54, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23470, 780, 50, 0, 42, "Subsubsection"],
Cell[23523, 782, 170, 4, 46, "Text"],
Cell[23696, 788, 61, 1, 27, "Input"],
Cell[23760, 791, 858, 32, 80, "Text"],
Cell[24621, 825, 1360, 40, 47, "Text"],
Cell[25984, 867, 2246, 72, 188, "Text"],
Cell[28233, 941, 656, 17, 62, "Text"],
Cell[28892, 960, 79, 1, 27, "Input"],
Cell[28974, 963, 77, 1, 27, "Input"],
Cell[29054, 966, 141, 3, 43, "Input"],
Cell[29198, 971, 55, 1, 27, "Input"],
Cell[29256, 974, 55, 1, 27, "Input"],
Cell[29314, 977, 55, 1, 27, "Input"],
Cell[29372, 980, 55, 1, 27, "Input"],
Cell[29430, 983, 421, 10, 62, "Text"],
Cell[29854, 995, 65, 1, 27, "Input"],
Cell[29922, 998, 172, 5, 30, "Text"],
Cell[30097, 1005, 51, 0, 30, "Text"],
Cell[30151, 1007, 139, 3, 43, "Input"],
Cell[30293, 1012, 54, 1, 27, "Input"],
Cell[30350, 1015, 54, 1, 27, "Input"],
Cell[30407, 1018, 54, 1, 27, "Input"],
Cell[30464, 1021, 54, 1, 27, "Input"],
Cell[30521, 1024, 362, 10, 46, "Text"],
Cell[30886, 1036, 65, 1, 27, "Input"],
Cell[30954, 1039, 337, 8, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31328, 1052, 37, 0, 42, "Subsubsection"],
Cell[31368, 1054, 532, 17, 64, "Text"],
Cell[31903, 1073, 87, 1, 27, "Input"],
Cell[31993, 1076, 179, 4, 43, "Input"],
Cell[32175, 1082, 85, 1, 27, "Input"],
Cell[32263, 1085, 177, 4, 43, "Input"],
Cell[32443, 1091, 614, 14, 78, "Text"],
Cell[33060, 1107, 83, 1, 27, "Input"],
Cell[33146, 1110, 83, 1, 27, "Input"],
Cell[33232, 1113, 298, 7, 46, "Text"],
Cell[33533, 1122, 109, 2, 27, "Input"],
Cell[33645, 1126, 145, 5, 30, "Text"],
Cell[33793, 1133, 85, 1, 27, "Input"],
Cell[33881, 1136, 85, 1, 27, "Input"],
Cell[33969, 1139, 397, 15, 50, "Text"],
Cell[34369, 1156, 215, 5, 43, "Input"],
Cell[34587, 1163, 156, 5, 30, "Text"],
Cell[34746, 1170, 86, 1, 27, "Input"],
Cell[34835, 1173, 85, 1, 27, "Input"],
Cell[34923, 1176, 85, 1, 27, "Input"],
Cell[35011, 1179, 400, 8, 62, "Text"],
Cell[35414, 1189, 115, 2, 27, "Input"],
Cell[35532, 1193, 414, 15, 48, "Text"],
Cell[35949, 1210, 308, 11, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36294, 1226, 116, 5, 42, "Subsubsection"],
Cell[36413, 1233, 59, 1, 27, "Input"],
Cell[36475, 1236, 47, 0, 30, "Text"],
Cell[36525, 1238, 39, 1, 27, "Input"],
Cell[36567, 1241, 49, 1, 27, "Input"],
Cell[36619, 1244, 66, 0, 30, "Text"],
Cell[36688, 1246, 63, 1, 27, "Input"],
Cell[36754, 1249, 43, 0, 30, "Text"],
Cell[36800, 1251, 223, 4, 46, "Text"],
Cell[37026, 1257, 59, 1, 27, "Input"],
Cell[37088, 1260, 141, 3, 30, "Text"],
Cell[37232, 1265, 66, 1, 27, "Input"],
Cell[37301, 1268, 46, 0, 30, "Text"],
Cell[37350, 1270, 79, 1, 27, "Input"],
Cell[37432, 1273, 103, 3, 30, "Text"],
Cell[37538, 1278, 49, 1, 27, "Input"],
Cell[37590, 1281, 100, 3, 30, "Text"],
Cell[37693, 1286, 50, 1, 27, "Input"],
Cell[37746, 1289, 65, 1, 27, "Input"],
Cell[37814, 1292, 65, 1, 27, "Input"],
Cell[37882, 1295, 65, 1, 27, "Input"],
Cell[37950, 1298, 208, 6, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38195, 1309, 116, 5, 42, "Subsubsection"],
Cell[38314, 1316, 142, 5, 30, "Text"],
Cell[38459, 1323, 59, 1, 27, "Input"],
Cell[38521, 1326, 48, 0, 30, "Text"],
Cell[38572, 1328, 51, 1, 27, "Input"],
Cell[38626, 1331, 50, 1, 27, "Input"],
Cell[38679, 1334, 49, 1, 27, "Input"],
Cell[38731, 1337, 48, 1, 27, "Input"],
Cell[38782, 1340, 66, 0, 30, "Text"],
Cell[38851, 1342, 65, 1, 27, "Input"],
Cell[38919, 1345, 45, 0, 30, "Text"],
Cell[38967, 1347, 79, 1, 27, "Input"],
Cell[39049, 1350, 49, 1, 27, "Input"],
Cell[39101, 1353, 65, 1, 27, "Input"],
Cell[39169, 1356, 65, 1, 27, "Input"],
Cell[39237, 1359, 65, 1, 27, "Input"],
Cell[39305, 1362, 339, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39681, 1373, 116, 5, 42, "Subsubsection"],
Cell[39800, 1380, 142, 5, 30, "Text"],
Cell[39945, 1387, 59, 1, 27, "Input"],
Cell[40007, 1390, 48, 0, 30, "Text"],
Cell[40058, 1392, 51, 1, 27, "Input"],
Cell[40112, 1395, 50, 1, 27, "Input"],
Cell[40165, 1398, 49, 1, 27, "Input"],
Cell[40217, 1401, 48, 1, 27, "Input"],
Cell[40268, 1404, 66, 0, 30, "Text"],
Cell[40337, 1406, 65, 1, 27, "Input"],
Cell[40405, 1409, 56, 0, 30, "Text"],
Cell[40464, 1411, 79, 1, 27, "Input"],
Cell[40546, 1414, 49, 1, 27, "Input"],
Cell[40598, 1417, 65, 1, 27, "Input"],
Cell[40666, 1420, 65, 1, 27, "Input"],
Cell[40734, 1423, 65, 1, 27, "Input"],
Cell[40802, 1426, 343, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41182, 1437, 114, 5, 42, "Subsubsection"],
Cell[41299, 1444, 136, 5, 30, "Text"],
Cell[41438, 1451, 57, 1, 27, "Input"],
Cell[41498, 1454, 51, 1, 27, "Input"],
Cell[41552, 1457, 50, 1, 27, "Input"],
Cell[41605, 1460, 49, 1, 27, "Input"],
Cell[41657, 1463, 48, 1, 27, "Input"],
Cell[41708, 1466, 43, 0, 30, "Text"],
Cell[41754, 1468, 65, 1, 27, "Input"],
Cell[41822, 1471, 177, 4, 46, "Text"],
Cell[42002, 1477, 79, 1, 27, "Input"],
Cell[42084, 1480, 65, 1, 27, "Input"],
Cell[42152, 1483, 65, 1, 27, "Input"],
Cell[42220, 1486, 65, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42322, 1492, 115, 5, 42, "Subsubsection"],
Cell[42440, 1499, 128, 5, 30, "Text"],
Cell[42571, 1506, 58, 1, 27, "Input"],
Cell[42632, 1509, 51, 1, 27, "Input"],
Cell[42686, 1512, 50, 1, 27, "Input"],
Cell[42739, 1515, 49, 1, 27, "Input"],
Cell[42791, 1518, 48, 1, 27, "Input"],
Cell[42842, 1521, 43, 0, 30, "Text"],
Cell[42888, 1523, 65, 1, 27, "Input"],
Cell[42956, 1526, 79, 1, 27, "Input"],
Cell[43038, 1529, 65, 1, 27, "Input"],
Cell[43106, 1532, 65, 1, 27, "Input"],
Cell[43174, 1535, 65, 1, 27, "Input"],
Cell[43242, 1538, 233, 6, 46, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

