(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    136127,       4455]*)
(*NotebookOutlinePosition[    161008,       5356]*)
(*  CellTagsIndexPosition[    160964,       5352]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Within-Host Infection Dynamics
II.  T-Cell Immune Response\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell["1.  Introduction", "Section"],

Cell[TextData[{
  "\tIn this notebook we consider dynamical models for the growth of \
microbial pathogens in a single host with an immune response in the form of \
cytotoxic T lymphocytes.  The model is the one presented in \"Population \
Dynamics of Immune Responses to Persistent Viruses,\" M.A. Nowak and C.R.M. \
Bangham, Science ",
  StyleBox["272",
    FontWeight->"Bold"],
  ", 74-79, 1996. We use their basic equations, although we introduce a \
scaling to reduce the number of independent parameters.  We also explore the \
system properties in much more mathematical detail than is given in their \
article.  Our calculations are similar to some of those given in \"Nonlinear \
Oscillations in Models of Immune Responses to Persistent Viruses,\" W.-m. \
Liu, Theoretical Population Biology ",
  StyleBox["52",
    FontWeight->"Bold"],
  ", 224-230, 1997.  "
}], "Text"],

Cell[TextData[{
  "\tThe calculations in this notebook are carried out with DynPac, a package \
running under ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  It is available at \
http://www.mathsource.com/Content/Applications/Mathematics/0209-517, or the \
latest version is availabe from Al Clark via E-mail request:  \
clark@me.rochester.edu."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Formulation", "Section"],

Cell[CellGroupData[{

Cell["2.1  Balance Equations", "Subsection"],

Cell[TextData[{
  "\tAs mentioned above, we follow closely the presentation of Nowak and \
Bangham.  The four state variables are the number of uninfected host cells ",
  StyleBox["H ",
    FontSlant->"Italic"],
  "(healthy cells), the number of infected host cells ",
  StyleBox["S ",
    FontSlant->"Italic"],
  "(sick cells), the number of free pathogens ",
  StyleBox["P, ",
    FontSlant->"Italic"],
  "and the number of cytotoxic T lymphocytes (CTL's) ",
  StyleBox["C",
    FontSlant->"Italic"],
  ".  The basis for the model is the following set of assumptions:  (1) \
infected cells are produced by encounters between free pathogens and \
uninfected cells at a rate \[Beta]",
  StyleBox["PH, ",
    FontSlant->"Italic"],
  "and infected cells die at a rate \[Alpha]",
  StyleBox["S; ",
    FontSlant->"Italic"],
  "(2) pathogens are produced by infected cells at a rate \[Rho]",
  StyleBox["S",
    FontSlant->"Italic"],
  " and die at a rate \[Delta]",
  StyleBox["P",
    FontSlant->"Italic"],
  "; (3) new uninfected cells are produced at a constant rate \[CapitalGamma] \
and die at a rate \[Mu]",
  StyleBox["H",
    FontSlant->"Italic"],
  "; (4) CTL's are produced at a rate \[Eta]",
  StyleBox["SC",
    FontSlant->"Italic"],
  " and they die at a rate \[Xi]",
  StyleBox["C",
    FontSlant->"Italic"],
  "; (5) CTL's kill infected cells at a rate \[Omega]",
  StyleBox["SC.",
    FontSlant->"Italic"],
  "   With these assumptions, the balance equations for the four entities \
are"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(dH\/dt\),
            FontSlant->"Italic"], 
          StyleBox["  ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{"\[CapitalGamma]", " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Mu]", 
                StyleBox["H",
                  FontSlant->"Italic"]}]], " ", "-", 
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["HP",
                  FontSlant->"Italic"]}]]}]}], "    ", ","}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(dS\/dt\),
            FontSlant->"Italic"], "  ", "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Beta]", 
                StyleBox["HP",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Alpha]", 
                StyleBox["S",
                  FontSlant->"Italic"]}]], " ", "-", "  ", 
            StyleBox[
              RowBox[{"\[Omega]", 
                StyleBox["SC",
                  FontSlant->"Italic"]}]]}]}], "  ", ",", 
        "                                                                     \
                     ", 
        StyleBox[\((1)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{"               ", 
        RowBox[{
          RowBox[{
            StyleBox[\(dP\/dt\),
              FontSlant->"Italic"], "  ", "=", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox[
                RowBox[{"\[Rho]", 
                  StyleBox["S",
                    FontSlant->"Italic"]}]], " ", "-", " ", 
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["P",
                    FontSlant->"Italic"]}]]}]}], "   ", ","}], 
        "                           "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"and", "           ", 
            StyleBox[\(dC\/dt\),
              FontSlant->"Italic"]}], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[Eta]", 
                StyleBox["SC",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Xi]", 
                  StyleBox["C",
                    FontSlant->"Italic"]}]], "  ", "."}]}]}], 
        "                           "}], TextForm]], "Text",
  TextAlignment->Center],

Cell["\<\
\tIn much of our discussion we will refer to the pathogens as \
viruses, although the theory applies as well to bacteria or parasites.  We \
will not discuss here the limitations of this model and its possible \
improvements.  Our main goal is to understand the mathematical properties of \
system governed by this model.  A primary complicating factor is the presence \
of 9 different parameters in the equations.  Our first step is to reduce that \
number to 5 by scaling.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2  Scaling the Equations", "Subsection"],

Cell[TextData[
"\tWe use a scaling similar to that used in the notebook HostDyn1.nb.  In \
this scaling, both the healthy and sick cell populations are scaled by the \
number of healthy cells in the disease-free equilibrium, and the basic time \
scale is defined by 1/\[Mu] where \[Mu] is the death rate of healthy cells.  \
The scaled version of each variable is denoted by the same letter but in \
lower case.  The scaled variables are  "], "Text"],

Cell[TextData[{
  "h",
  StyleBox[" = \[Mu]",
    FontSlant->"Plain"],
  "H",
  StyleBox["/\[CapitalGamma] ,   ",
    FontSlant->"Plain"],
  "s",
  StyleBox[" = \[Mu]",
    FontSlant->"Plain"],
  "S",
  StyleBox["/\[CapitalGamma] ,   ",
    FontSlant->"Plain"],
  "p",
  StyleBox[" = \[Beta]",
    FontSlant->"Plain"],
  "P",
  StyleBox["/\[Mu] ,   ",
    FontSlant->"Plain"],
  "c",
  StyleBox[" = \[Omega]",
    FontSlant->"Plain"],
  "C",
  StyleBox["/\[Mu] ,   ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`t\&^\)]],
  " = ",
  StyleBox["\[Mu]",
    FontSlant->"Plain"],
  "t",
  StyleBox["   .                                             ",
    FontSlant->"Plain"],
  StyleBox["(2)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["\<\
This scaling leads to the following set of 5 dimensionless \
parameters appearing in the equations:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["R",
            FontSlant->"Italic"], " ", "=", " ", 
          \(\[Beta]\[Rho]\[CapitalGamma]\/\[Mu]\[Alpha]\[Delta]\)}], " ", 
        ",", "   ", 
        RowBox[{
          StyleBox["q",
            FontSlant->"Italic"], " ", "=", " ", \(\[Alpha]\/\[Mu]\)}], " ", 
        ",", "  ", 
        RowBox[{
          StyleBox["r",
            FontSlant->"Italic"], " ", "=", " ", \(\[Delta]\/\[Mu]\)}], " ", 
        ",", "  ", 
        RowBox[{
          StyleBox["w",
            FontSlant->"Italic"], " ", "=", " ", \(\[Xi]\/\[Mu]\)}], " ", 
        ",", " ", 
        RowBox[{
          StyleBox["J",
            FontSlant->"Italic"], "=", " ", 
          RowBox[{
          \(\[CapitalGamma]\[Eta]\/\[Alpha]\[Xi]\), "   ", ".", 
            "                                                              ", 
            
            StyleBox[\((3)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "After dropping the hat on ",
  StyleBox["t, ",
    FontSlant->"Italic"],
  "the resulting scaled equations are"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox[
                StyleBox[
                  RowBox[{"d", 
                    StyleBox["h",
                      FontSlant->"Italic"]}]], "dt"],
              FontSlant->"Italic"], 
            StyleBox["  ",
              FontSlant->"Italic"], "=", " ", 
            RowBox[{"1", " ", "-", " ", 
              StyleBox["h",
                FontSlant->"Italic"], " ", "-", 
              StyleBox["ph",
                FontSlant->"Italic"]}]}], "   ", ","}], "   "}], TextForm]], 
  "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            FractionBox[
              StyleBox[
                RowBox[{"d", 
                  StyleBox["s",
                    FontSlant->"Italic"]}]], "dt"],
            FontSlant->"Italic"], "  ", "=", 
          StyleBox[" ",
            FontSlant->"Italic"], 
          RowBox[{
            StyleBox["ph",
              FontSlant->"Italic"], " ", "-", " ", 
            StyleBox["qs",
              FontSlant->"Italic"], " ", "-", "  ", 
            StyleBox["sc",
              FontSlant->"Italic"]}]}], " ", ",", 
        "                                                                     \
                                ", 
        StyleBox[\((4)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{"           ", 
        RowBox[{
          RowBox[{
            StyleBox[
              FractionBox[
                StyleBox[
                  RowBox[{"d", 
                    StyleBox["p",
                      FontSlant->"Italic"]}]], "dt"],
              FontSlant->"Italic"], "  ", "=", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox["qrRs",
                FontSlant->"Italic"], " ", "-", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["rp",
                FontSlant->"Italic"]}]}], " ", ","}], "                  "}], 
      TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"and", "     ", 
            StyleBox[\(dc\/dt\),
              FontSlant->"Italic"]}], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", 
          RowBox[{
            StyleBox[\(qwJ sc\),
              FontSlant->"Italic"], " ", "-", " ", 
            RowBox[{
              StyleBox["wc",
                FontSlant->"Italic"], "    ", "."}]}]}], "           "}], 
      TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "The three parameters ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["w",
    FontSlant->"Italic"],
  " are normalized death rates respectively of infected cells, pathogens, and \
T cells.  The normalization is with respect to the healthy cell death rate.  \
The parameter ",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  " is the basic reproductive parameter, and the parameter ",
  Cell[BoxData[
      FormBox["J", TraditionalForm]]],
  ", which we call the immune parameter, is a measure of the immune system \
response.  We will look in more detail at the parameters in section 3.5 after \
studying the dependence of the equilibria on them."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3  Defining the System for DynPac", "Subsection"],

Cell["\<\
\tWe define the system for DynPac, beginning with the state vector \
and the parameter vector:\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{h, s, p, c}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{q, r, R, J, w}];\)\)], "Input"],

Cell["\<\
Now we define the slope vector and we choose blank for the system \
name:\
\>", "Text"],

Cell[BoxData[
    \(\(slopevec = {1 - h - p*h, p*h - q*s - s*c, q*r*R*s - r*p, 
          q*w*J*s*c - w*c};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<\>";\)\)], "Input"],

Cell["\<\
We will set parameter values and integration parameters in section \
4 when we study the dynamics of the system.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  Equilibrium", "Section"],

Cell[CellGroupData[{

Cell["3.1  Equilibrium States", "Subsection"],

Cell["\<\
\tWe now find the equilibrium states of the system, using the \
DynPac function findpolyeq which works for polynomial slope vectors.\
\>", 
  "Text"],

Cell[BoxData[
    \(eqstates = findpolyeq\)], "Input"],

Cell["\<\
The first of these is a disease-free state.  The second is an \
endemic state with no continuing immune response.  The third is an endemic \
state with a continuing immune response.  We name the three states.\
\>", 
  "Text"],

Cell[BoxData[
    \(eqfree = eqstates[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(eqend = eqstates[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(eqendimm = eqstates[\([3]\)]\)], "Input"],

Cell[TextData[{
  "\tWe call an equilibrium state relevant if all of its coordinates are \
non-negative.  We see that eqfree is relevant for all parameter values.  We \
see that eqend is relevant for ",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  " \[GreaterEqual] 1.  After a little algebra, we see that eqendimm is \
relevant for ",
  StyleBox["JR",
    FontSlant->"Italic"],
  " > ",
  StyleBox["J",
    FontSlant->"Italic"],
  " + ",
  StyleBox["R, ",
    FontSlant->"Italic"],
  "hence for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1 and ",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  " \[GreaterEqual]  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "c"], TraditionalForm]]],
  ", where "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["R",
            FontSlant->"Italic"], "c"], "  ", "=", "  ", 
        RowBox[{
          FractionBox[
            StyleBox["J",
              FontSlant->"Italic"], 
            RowBox[{
              StyleBox["J",
                FontSlant->"Italic"], " ", "-", " ", "1"}]], "     ", ".", 
          "                                                                   \
                                               ", 
          StyleBox[\((5)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Thus for  0 < ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < 1 only eqfree is relevant.  For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1 and any value of ",
  StyleBox["J",
    FontSlant->"Italic"],
  ", eqend is relevant.  For ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1 and ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " eqendimm is also relevant.  The critical values 1 and ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " are bifurcations.  For ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\ \)\)]],
  " = 1, eqfree and eqend coincide.  For ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ", eqend and eqendimm coincide.  "
}], "Text"],

Cell[TextData[{
  "\tAt this point, we would guess that for 0 < ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < 1, eqfree is the only stable relevant equilibrium, that for 1 < ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ", eqend is the only stable relevant equilibrium, and that for  ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", eqendimm is the only stable relevant equilibrium.  We will verify this \
in the next section when we look at stability. "
}], "Text"],

Cell["\<\
\tFor some purposes, it is useful to have the equilibrium states in \
terms of the original dimensional quantities.  We obtain those now for future \
reference.\
\>", "Text"],

Cell[BoxData[
    \(\(scalevec = {\((\[CapitalGamma]/\[Mu])\)*
            h, \((\[CapitalGamma]/\[Mu])\)*s, \((\[Mu]/\[Beta])\)*
            p, \((\[Mu]/\[Omega])\)*c};\)\)], "Input"],

Cell[BoxData[
    \(\(parmdef = {\[Alpha]/\[Mu], \[Delta]/\[Mu], \((\[Beta]*\[Rho]*\
\[CapitalGamma])\)/\((\[Mu]*\[Alpha]*\[Delta])\), \
\((\[CapitalGamma]*\[Eta])\)/\((\[Alpha]*\[Xi])\), \[Xi]/\[Mu]};\)\)], "Input"],

Cell[BoxData[
    \(dimvec[eq_] := 
      FullSimplify[\(scalevec /. Thread[statevec -> eq]\) /. 
          Thread[parmvec -> parmdef]]\)], "Input"],

Cell[BoxData[
    \(dimeqfree = dimvec[eqfree]\)], "Input"],

Cell[BoxData[
    \(dimeqend = dimvec[eqend]\)], "Input"],

Cell[BoxData[
    \(dimeqendimm = dimvec[eqendimm]\)], "Input"],

Cell[TextData[
"This reveals some things which are hidden by the scaling.  For example, the \
population of infected cells in the equilibrium eqendimm depends only on \
\[Xi] and \[Eta] -- hence only on parameters of the immunological system, a \
point made by Nowak and Bangham (op.cit.).  We also see that in the endemic \
state, the pathogen population depends on both pathogen and normal cell \
parameters, whereas in the endemic state with immune response, the pathogen \
population depends only on pathogen and immunological parameters.  "], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.2  Stability of Equilibrium States for ",
  StyleBox["J > ",
    FontSlant->"Italic"],
  "1"
}], "Subsection"],

Cell[TextData[{
  "\tWe begin by calculating the derivative matrix at each of the equilibria. \
In DynPac, dermat gives the derivative matrix in terms of state variables and \
parameter symbols, and dermatval[eqstate] gives the derivative matrix at the \
point specified by eqstate.  If any parameters have been assigned numerical \
values, dermatval substitutes those values for the parameter symbols.  As we \
have not yet assigned any parameter values, all the parameters will appear as \
symbols in the formulas.  In all calculations in this section, we assume that \
",
  StyleBox["J ",
    FontSlant->"Italic"],
  " > 1.  In the next section, we will consider the case ",
  StyleBox["J <",
    FontSlant->"Italic"],
  " 1."
}], "Text"],

Cell[BoxData[
    \(matfree = dermatval[eqfree]\)], "Input"],

Cell[BoxData[
    \(matend = dermatval[eqend]\)], "Input"],

Cell[BoxData[
    \(matendimm = dermatval[eqendimm]\)], "Input"],

Cell["\<\
\tWe start with the simplest case, namely eqfree.  The \
characteristic polynomial is\
\>", "Text"],

Cell[BoxData[
    \(freepoly = 
      FullSimplify[CharacteristicPolynomial[matfree, \[Lambda]]]\)], "Input"],

Cell[TextData[{
  "Thus two of the roots are -1 and -w which are always negative.  The other \
two are roots of the quadratic equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  "+ (",
  StyleBox["r",
    FontSlant->"Italic"],
  " + ",
  StyleBox["q",
    FontSlant->"Italic"],
  ")\[Lambda] + ",
  StyleBox["qr",
    FontSlant->"Italic"],
  "(1 - ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ") = 0.  It is easy to show that both roots are real and negative for 0 < ",
  
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1.  For ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > 1, the quadratic has a positive root so the equilibrium is unstable.  "
}], "Text"],

Cell["\tNow we look at eqend.  The characteristic polynomial is", "Text"],

Cell[BoxData[
    \(endpoly = 
      FullSimplify[CharacteristicPolynomial[matend, \[Lambda]]]\)], "Input"],

Cell[TextData[{
  "The first factor gives a root \[Lambda] = ",
  StyleBox["w",
    FontSlant->"Italic"],
  "[",
  StyleBox["J(",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " -1)/",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " - 1].  It is easy to show that this root is negative for 0 < ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "and positive for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "< ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  Thus eqend is unstable for ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "< ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  We have to examine the other three roots to determine the stability for \
",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ".  These are roots of the cubic"
}], "Text"],

Cell[BoxData[
    \(modendpoly = \(-R\)*
        endpoly/\((J*\((R - 1)\)*
                w\  - \ \ R\ \((w\  + \ \[Lambda])\))\)\)], "Input"],

Cell["The coefficients are ", "Text"],

Cell[BoxData[
    \(modendpolylist = CoefficientList[\ modendpoly, \[Lambda]]\)], "Input"],

Cell[TextData[{
  "That is, this cubic has the form ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\ \)\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  "\[Lambda] + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  "where"
}], "Text"],

Cell[BoxData[
    \(c0 = modendpolylist[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(c1 = modendpolylist[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(c2 = modendpolylist[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(c3 = modendpolylist[\([1]\)]\)], "Input"],

Cell[TextData[{
  "Our objective is to determine whether all of the roots of this cubic have \
negative real parts.  To remove the ambiguity of the overall sign of the \
polynomial, we assume throughout this notebook that the coefficient of the \
highest power is positive.  Then a simple necessary but not sufficient \
condition for stability is that all of the coefficients be positive, so we \
check this first.  If the polynomial fails this test, at least one root has a \
positive real part and we are done.  If the polymomial passes, we are not \
done and must continue the investigation.  Clearly ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "0"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "1"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "2"], TraditionalForm]]],
  " are always positive, and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "3"], TraditionalForm]]],
  " is positive for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, so the polynomial passes.  To continue we use the Routh-Hurwitz \
criterion for stability (a summary of this, with some references, is given in \
the Appendix to this notebook).  For a cubic polymomial, the additional test \
which is necessary and sufficient for stability is that ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "1"], TraditionalForm]]],
  "*",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "2"], TraditionalForm]]],
  "- ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "3"], TraditionalForm]]],
  "> 0.  We calculate ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "1"], TraditionalForm]]],
  "* ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "2"], TraditionalForm]]],
  "- ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "3"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(ctest = c1*c2 - c3\)], "Input"],

Cell[TextData[{
  "We introduce a variable ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " -1, and collect the coefficients of the powers of ",
  StyleBox["m",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(FullSimplify[CoefficientList[\((ctest /. R -> 1 + m)\), m]]\)], "Input"],

Cell[TextData[{
  "These coefficients are all positive, so ctest is postive for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1.  Hence the Routh-Hurwitz criterion has shown that the roots all have \
negative real parts for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > 1.  For ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < 1, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  " is negative, so the cubic has real positive root and the equilibrium is \
unstable.  "
}], "Text"],

Cell["\<\
\tFinally we consider eqendimm.  The characteristic polynomial is  \
\
\>", "Text"],

Cell[BoxData[
    \(endimmpoly = 
      FullSimplify[CharacteristicPolynomial[matendimm, \[Lambda]]]\)], "Input"],

Cell["The coefficient list is given by", "Text"],

Cell[BoxData[
    \(endimmlist = 
      FullSimplify[CoefficientList[endimmpoly, \[Lambda]]]\)], "Input"],

Cell[TextData[{
  "We introduce the critical ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " value ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(endimmlistmod = 
      FullSimplify[\((endimmlist /. J -> Rc/\((Rc - 1)\))\)]\)], "Input"],

Cell[TextData[{
  "The coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^4\)]],
  " is 1, and the constant term is ",
  StyleBox["qrw",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ")/",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "which is negative for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ".  Hence there is a positive real root and the equilibrium is unstable for \
",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ".  Consider now the case ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ".  The polynomial has the form ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^4\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\ \)\^3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_3\) \[Lambda]\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_4\)]],
  " where "
}], "Text"],

Cell[BoxData[
    \(c0 = endimmlistmod[\([5]\)]\)], "Input"],

Cell[BoxData[
    \(c1 = endimmlistmod[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(c2 = endimmlistmod[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(c3 = endimmlistmod[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(c4 = endimmlistmod[\([1]\)]\)], "Input"],

Cell[TextData[{
  "We check the sign of each coefficient.  Obviously ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  "is positive, and it is easy to show that for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_4\)]],
  " are all positive. For ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  "we observe that the denominator is positive and that the numerator can be \
written as"
}], "Text"],

Cell[TextData[{
  StyleBox["q",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["R", "c", "2"], TraditionalForm]]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["R", "c", "2"], TraditionalForm]]],
  "+",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "c"], TraditionalForm]]],
  "- 2",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  ") + ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox["R",
                "TraditionalForm"], "-", " ", 
              FormBox[
                SubscriptBox["R", "c"],
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]]],
  " + 2 ",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["R", "c", "2"], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "c"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["R", "2"], TraditionalForm]]],
  "(",
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "c"], TraditionalForm]]],
  " - 1)  ,                                        ",
  StyleBox["(6)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "which is obviously positive.  Thus the polynomial passes the simple test, \
and we now use the Routh-Hurwitz criterion to determine the stability.  For a \
fourth degree polynomial, the additional condition necessary and sufficient \
for stability is:  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "1"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "2"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "3"], TraditionalForm]]],
  "- ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["c", "1", "2"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "4"], TraditionalForm]]],
  "- ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["c", "3", "2"], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "0"], TraditionalForm]]],
  " > 0. Before calculating this quantity, we multiply each coefficient by \
the same positive number, chosen to make the calculations somewhat easier."
}], "Text"],

Cell[BoxData[
    \(\(trans = Rc*\((R*\((\(-1\) + Rc)\) + Rc)\);\)\)], "Input"],

Cell[BoxData[
    \(d0 = c0*trans\)], "Input"],

Cell[BoxData[
    \(d1 = FullSimplify[c1*trans]\)], "Input"],

Cell[BoxData[
    \(d2 = FullSimplify[c2*trans]\)], "Input"],

Cell[BoxData[
    \(d3 = c3*trans\)], "Input"],

Cell[BoxData[
    \(d4 = c4*trans\)], "Input"],

Cell["\<\
Now we calculate the quantity that must be positive for \
stability:\
\>", "Text"],

Cell[BoxData[
    \(rhtest = FullSimplify[d1*d2*d3 - d1^2*d4 - d0*d3^2]\)], "Input"],

Cell[TextData[{
  "In order to more easily impose the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ", we introduce \[Phi] = ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(rhtestmod1 = rhtest /. R -> Rc + \[Phi]\)], "Input"],

Cell[TextData[{
  "In order to more easily impose the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "> 1, we introduce \[Epsilon] = ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "-1:"
}], "Text"],

Cell[BoxData[
    \(rhtestmod2 = rhtestmod1 /. Rc -> 1 + \[Epsilon]\)], "Input"],

Cell["We try to simplify this:", "Text"],

Cell[BoxData[
    \(rhtestfin = FullSimplify[rhtestmod2]\)], "Input"],

Cell[TextData[{
  "It is difficult to tell by inspection whether rhtestfin is positive \
definite.  We break it down further by collecting coefficients with respect \
to ",
  StyleBox["w",
    FontSlant->"Italic"],
  ".  (It is quadratic in ",
  StyleBox["w",
    FontSlant->"Italic"],
  ".)"
}], "Text"],

Cell[BoxData[
    \(\(\(wlist = CoefficientList[rhtestfin, w];\)\(\ \ \)\)\)], "Input"],

Cell["The constant term is", "Text"],

Cell[BoxData[
    \(w1 = FullSimplify[wlist[\([1]\)]]\)], "Input"],

Cell["Thus this coefficient is positive.", "Text"],

Cell[TextData[{
  "The coefficient of ",
  StyleBox["w",
    FontSlant->"Italic"],
  " is"
}], "Text"],

Cell[BoxData[
    \(w2 = FullSimplify[wlist[\([2]\)]]\)], "Input"],

Cell["\<\
This coefficient has terms of both signs and needs further \
work.\
\>", "Text"],

Cell[TextData[{
  "The coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`w\^2\)]],
  " is"
}], "Text"],

Cell[BoxData[
    \(w3 = FullSimplify[wlist[\([3]\)]]\)], "Input"],

Cell[TextData[{
  "Thus ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`w\_3\)]],
  "are positive, whereas ",
  Cell[BoxData[
      \(TraditionalForm\`w\_2\)]],
  "has some negative terms.  We break this down further, by expressing ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`w\_3\)]],
  "in terms of the parameter ",
  StyleBox["r.",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell[BoxData[
    \(\(w1rlist = CoefficientList[w1, r];\)\)], "Input"],

Cell[BoxData[
    \(w11 = w1rlist[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(w12 = FullSimplify[w1rlist[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(w13 = FullSimplify[w1rlist[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(w14 = FullSimplify[w1rlist[\([4]\)]]\)], "Input"],

Cell[BoxData[
    \(\(w2rlist = CoefficientList[w2, r];\)\)], "Input"],

Cell[BoxData[
    \(w21 = FullSimplify[w2rlist[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(w22 = FullSimplify[w2rlist[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(w23 = FullSimplify[w2rlist[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(w3rlist = CoefficientList[w3, r]\)], "Input"],

Cell[BoxData[
    \(w31 = FullSimplify[w3rlist[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(w32 = FullSimplify[w3rlist[\([2]\)]]\)], "Input"],

Cell["\<\
At this point, we have the following representation for \
rhtestfin:\
\>", "Text"],

Cell[TextData[{
  "rhtestfin  =  (",
  Cell[BoxData[
      \(TraditionalForm\`w\_12\)]],
  StyleBox["r ",
    FontSlant->"Italic"],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`w\_13\)]],
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`w\_14\)]],
  Cell[BoxData[
      \(TraditionalForm\`r\^3\)]],
  ")  +  (",
  Cell[BoxData[
      \(TraditionalForm\`w\_21\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`w\_22\)]],
  StyleBox["r",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`w\_23\)]],
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ")",
  StyleBox["w + (",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`w\_31\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`w\_32\)]],
  StyleBox["r",
    FontSlant->"Italic"],
  ") ",
  Cell[BoxData[
      \(TraditionalForm\`w\^2\)]],
  "  ,"
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "where every coefficient except ",
  Cell[BoxData[
      \(TraditionalForm\`w\_23\)]],
  "is positive.  We isolate all of the cubic terms, noting that the other \
terms in rhtestfin are all positive.  The cubic terms are"
}], "Text"],

Cell[TextData[{
  "r",
  StyleBox[" (",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox["w", 
          StyleBox["14",
            FontSlant->"Plain"]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["r", 
          StyleBox["2",
            FontSlant->"Plain"]], TraditionalForm]]],
  " +  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["w", 
          StyleBox["23",
            FontSlant->"Plain"]], TraditionalForm]]],
  "r w  ",
  StyleBox["+  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        SubscriptBox["w", 
          StyleBox["32",
            FontSlant->"Plain"]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SuperscriptBox["w", 
          StyleBox["2",
            FontSlant->"Plain"]], TraditionalForm]]],
  ")   ."
}], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[TextData[{
  "The stability question has come down to this:  if the above quadratic form \
is positive definite, then the equilibrium eqendimm is stable for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1.  We already know that ",
  Cell[BoxData[
      \(TraditionalForm\`w\_14\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`w\_32\)]],
  "are positive.  The remaining condition for the quadratic form to be \
positive definite is that 4",
  Cell[BoxData[
      \(TraditionalForm\`w\_14\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(w\_32\ \)\)]],
  "> ",
  Cell[BoxData[
      \(TraditionalForm\`w\_23\%2\)]],
  ".  We calculate this quantity:"
}], "Text"],

Cell[BoxData[
    \(lastest = FullSimplify[4*w14*w32 - w23*w23]\)], "Input"],

Cell[TextData[{
  "This is positive, so we are done and our conclusion agrees with that given \
by Liu (op.cit.).   The table below summarizes the situation for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1.  "
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["Equilibrium",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Entities",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{
                  StyleBox["Presen",
                    FontWeight->"Bold"], "t"}]]}], 
            RowBox[{
              StyleBox["0",
                FontWeight->"Bold"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Italic"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["1",
                FontWeight->"Bold"]}], 
            RowBox[{
              StyleBox["1",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Italic"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[
                SubscriptBox[
                  StyleBox["R",
                    FontWeight->"Bold",
                    FontSlant->"Italic"], "c"],
                FontWeight->"Bold"]}], 
            RowBox[{"     ", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["R",
                      FontWeight->"Bold",
                      FontSlant->"Italic"], "c"],
                  FontWeight->"Bold"], 
                StyleBox["<",
                  FontWeight->"Bold"], 
                StyleBox[" ",
                  FontWeight->"Bold"], 
                StyleBox["R",
                  FontWeight->"Bold",
                  FontSlant->"Italic"]}], 
              StyleBox["     ",
                FontWeight->"Bold"]}]},
          {"eqfree", \(healthy\ cells\), 
            StyleBox[\(relevant\n
              stable\),
              FontSlant->"Italic"], \(relevant\n
            unstable\), \(relevant\n
            unstable\)},
          {
            "eqend", \(healthy\ cells, \n\t\(infected\ cells\  &\)\ pathogens\
\), \(irrelevant\n
            unstable\), 
            StyleBox[\(relevant\n
              stable\),
              FontSlant->"Italic"], \(relevant\n
            unstable\)},
          {"eqendimm", \(healthy\ cells, \ 
            infected\ cells, \n\t\(pathogens\  &\) T\ cells\), \(irrelevant\n
            unstable\), \(irrelevant\n
            unstable\), 
            StyleBox[\(relevant\n
              stable\),
              FontSlant->"Italic"]}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Table One.  Dependence of Equilibrium States on Reproductive Ratio for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1.\n",
  StyleBox[
  "Relevant equilibria are those with positive coordinates.  Attractors are \
italicized.  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(R\_c\),
          FontWeight->"Plain"], TraditionalForm]]],
  " = ",
  StyleBox["J",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["/(",
    FontWeight->"Plain"],
  StyleBox["J",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" - 1)",
    FontWeight->"Plain"],
  StyleBox[".",
    FontWeight->"Plain",
    FontSlant->"Italic"]
}], "Text",
  TextAlignment->Center,
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.3  Stability of Equilibrium States for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " < 1"
}], "Subsection"],

Cell[TextData[{
  "\tMany of the calculations just completed for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1 can be used also for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " < 1.  In this case the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " can still be defined by ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " = ",
  StyleBox["J",
    FontSlant->"Italic"],
  "/(",
  StyleBox["J ",
    FontSlant->"Italic"],
  "- 1) but it is now negative and thus has no significance as a bifurcation \
value of ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  We begin our discussion with the equilibrium eqfree.  It is relevant \
for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  As shown in the last section, it is stable for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < 1 and unstable for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > 1.  "
}], "Text"],

Cell[TextData[{
  "\tNow consider the equilibrium eqend.  It is irrelevant for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < 1 and relevant for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > 1.  The characteristic polynomial was derived earlier and is given by"
}], "Text"],

Cell[BoxData[
    \(endpoly\)], "Input"],

Cell["The first factor gives one root, namely", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Lambda]", "  ", "=", "  ", 
          RowBox[{
            StyleBox[
              RowBox[{
                FractionBox[
                  RowBox[{
                    StyleBox[
                      RowBox[{
                        StyleBox["J",
                          FontSlant->"Italic"], "w"}]], 
                    RowBox[{"(", 
                      RowBox[{"R", 
                        StyleBox["-",
                          FontSlant->"Plain"], 
                        StyleBox[" ",
                          FontSlant->"Plain"], 
                        StyleBox["1",
                          FontSlant->"Plain"]}], 
                      StyleBox[")",
                        FontSlant->"Plain"]}]}], "R"], " ", "-", " ", "w"}],
              FontSlant->"Italic"], 
            StyleBox["   ",
              FontSlant->"Italic"], 
            StyleBox["=",
              FontSlant->"Plain"], 
            StyleBox["  ",
              FontSlant->"Plain"], 
            RowBox[{
              StyleBox["w",
                FontSlant->"Italic"], 
              FractionBox[
                RowBox[{
                  RowBox[{
                    StyleBox["R",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox["(",
                        FontSlant->"Italic"], 
                      RowBox[{
                        StyleBox["J",
                          FontSlant->"Italic"], " ", "-", " ", "1"}], 
                      ")"}]}], " ", "-", 
                  StyleBox["J",
                    FontSlant->"Italic"]}], 
                StyleBox["R",
                  FontSlant->"Italic"]]}]}]}], 
        StyleBox["       ",
          FontSlant->"Italic"], 
        StyleBox[",",
          FontSlant->"Italic"], 
        StyleBox[
          RowBox[{
            StyleBox["                                                   ",
              FontSlant->"Italic"], 
            StyleBox[" ",
              FontWeight->"Bold",
              FontSlant->"Italic"]}]], 
        StyleBox[\((7)\),
          FontWeight->"Bold",
          FontSlant->"Italic"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "and this root is always negative for ",
  StyleBox["J < 1",
    FontSlant->"Italic"],
  ".  Thus the stability is determined by the other three roots.  As we \
showed earlier, these three roots are the roots of a cubic whose coefficients \
are"
}], "Text"],

Cell[BoxData[
    \(modendpolylist\)], "Input"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " < 1, there is a positive real root and the equilibrium is unstable.  For \
",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " > 1, the Routh-Hurwitz analysis given earlier shows that the equilibrium \
is stable."
}], "Text"],

Cell[TextData[{
  "\tFinally consider the third equilibrium eqendimm.  It is not important \
here because the value of ",
  StyleBox["c",
    FontSlant->"Italic"],
  " at equilibrium is"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["J",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], 
                  StyleBox["-",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], "1"}], ")"}], 
              StyleBox["R",
                FontSlant->"Italic"]}], " ", "-", " ", 
            StyleBox["J",
              FontSlant->"Italic"]}], 
          RowBox[{
            StyleBox["J",
              FontSlant->"Italic"], 
            StyleBox[
              RowBox[{
                StyleBox[" ",
                  FontSlant->"Italic"], " "}]], "+", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            StyleBox["R",
              FontSlant->"Italic"]}]], 
        "                                                                     \
                                                  ", 
        StyleBox[\((8)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "which is always negative for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " < 1.  We look at the stability anyway.  The coefficients of the \
characteristic polynomial were calculated earlier, and they are"
}], "Text"],

Cell[BoxData[
    \(endimmlistmod\)], "Input"],

Cell[TextData[{
  "The constant term is now always negative because ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " < 0, and the cubic term has coefficient 1, so there is always one real \
positive root and the equilibrium is unstable.  We summarize these results in \
a table."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["Equilibrium",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Entities",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{
                  StyleBox["Presen",
                    FontWeight->"Bold"], "t"}]]}], 
            RowBox[{
              StyleBox["0",
                FontWeight->"Bold"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Italic"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["1",
                FontWeight->"Bold"]}], 
            RowBox[{
              StyleBox["1",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Italic"], 
              StyleBox["<",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Bold"], 
              StyleBox["\[Infinity]",
                FontWeight->"Bold"]}]},
          {"eqfree", \(healthy\ cells\), 
            StyleBox[\(relevant\n
              stable\),
              FontSlant->"Italic"], \(relevant\n
            unstable\)},
          {
            "eqend", \(healthy\ cells, \n\t\(infected\ cells\  &\)\ pathogens\
\), \(irrelevant\n
            unstable\), 
            StyleBox[\(relevant\n
              stable\),
              FontSlant->"Italic"]},
          {"eqendimm", \(healthy\ cells, \ 
            infected\ cells, \n\t\(pathogens\  &\) T\ cells\), \(irrelevant\n
            unstable\), \(irrelevant\n
            unstable\)}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True], TextForm]], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Table Two.  Dependence of Equilibrium States on Reproductive Ratio for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " < 1.\n",
  StyleBox[
  "Relevant equilibria are those with positive coordinates.  Attractors are \
italicized",
    FontWeight->"Plain"]
}], "Text",
  TextAlignment->Center,
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4 The Solutions are Bounded", "Subsection"],

Cell["\<\
\tWe show first that if the coordinates of the initial point are \
non-negative, no state variable can ever go negative.  We have the following \
results from equations (4):\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox[
                RowBox[{"(", 
                  StyleBox[
                    FractionBox[
                      StyleBox[
                        RowBox[{"d", 
                          StyleBox["h",
                            FontSlant->"Italic"]}]], "dt"],
                    FontSlant->"Italic"], 
                  StyleBox[")",
                    FontSlant->"Italic"]}], 
                RowBox[{"h", 
                  StyleBox["=",
                    FontSlant->"Plain"], 
                  StyleBox["0",
                    FontSlant->"Plain"]}]],
              FontSlant->"Italic"], "=", " ", \(1\ \  > \ 0\)}], "   ", 
          ","}], "  "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            RowBox[{"(", 
              StyleBox[
                FractionBox[
                  StyleBox[
                    RowBox[{"d", 
                      StyleBox["s",
                        FontSlant->"Italic"]}]], "dt"],
                FontSlant->"Italic"], ")"}], 
            RowBox[{
              StyleBox["s",
                FontSlant->"Italic"], "=", "0"}]], "  ", "=", 
          StyleBox[" ",
            FontSlant->"Italic"], 
          RowBox[{
            StyleBox["ph",
              FontSlant->"Italic"], " ", "\[GreaterSlantEqual]", " ", 
            "0"}]}], ",", 
        "                                                                     \
                                 ", 
        StyleBox[\((9)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[BoxData[
    FormBox[
      RowBox[{"           ", 
        RowBox[{
          RowBox[{
            SubscriptBox[
              RowBox[{"(", 
                StyleBox[
                  FractionBox[
                    StyleBox[
                      RowBox[{"d", 
                        StyleBox["p",
                          FontSlant->"Italic"]}]], "dt"],
                  FontSlant->"Italic"], " ", ")"}], 
              RowBox[{
                StyleBox["p",
                  FontSlant->"Italic"], " ", "=", " ", "0"}]], " ", "=", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Italic"]}]], 
            RowBox[{
              StyleBox["qrRs",
                FontSlant->"Italic"], " ", "\[GreaterEqual]", " ", "0"}]}], 
          " ", ","}], "             "}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"and", "    ", 
            SubscriptBox[
              RowBox[{"(", 
                StyleBox[\(dc\/dt\),
                  FontSlant->"Italic"], ")"}], 
              RowBox[{
                RowBox[{
                  StyleBox["c",
                    FontSlant->"Italic"], "=", "0"}], " "}]]}], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", 
          RowBox[{"0", 
            StyleBox[
              RowBox[{
                StyleBox["  ",
                  FontSlant->"Plain"], " "}]], "."}]}], "       "}], 
      TextForm]], "Text",
  TextAlignment->Center],

Cell["\<\
Thus the solution cannot cross any of the zero coordinate planes.  \
\
\>", "Text"],

Cell["\<\
\tNow we show the solutions are bounded.   By adding the first two \
of equations (4), we get\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(d\/dt\),
              FontSlant->"Italic"], 
            RowBox[{
              StyleBox["(",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["h",
                  FontSlant->"Italic"], " ", "+", " ", 
                StyleBox["s",
                  FontSlant->"Italic"]}], ")"}]}], "  ", "=", "  ", 
          RowBox[{
            RowBox[{"1", " ", "-", " ", 
              StyleBox["h",
                FontSlant->"Italic"], " ", "-", 
              StyleBox["qs",
                FontSlant->"Italic"], " ", "-", " ", 
              StyleBox["sc",
                FontSlant->"Italic"]}], "   ", "\[LessSlantEqual]", "  ", 
            RowBox[{"1", " ", "-", " ", 
              StyleBox["h",
                FontSlant->"Italic"], " ", "-", " ", 
              StyleBox["qs",
                FontSlant->"Italic"]}], "  ", "\[LessSlantEqual]", " ", 
            RowBox[{"1", " ", "-", " ", 
              RowBox[{
                StyleBox["k",
                  FontSlant->"Italic"], 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["h",
                      FontSlant->"Italic"], " ", "+", " ", 
                    StyleBox["s",
                      FontSlant->"Italic"]}], ")"}]}]}]}]}], "   ", ",", 
        "                                     ", 
        StyleBox[\((10)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "where ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = Min{1, ",
  StyleBox["q",
    FontSlant->"Italic"],
  "}.  This inequality has the form"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], "\[Psi]"}]], 
            StyleBox["dt",
              FontSlant->"Italic"]], "  ", "\[LessEqual]", "  ", 
          RowBox[{
            StyleBox["a",
              FontSlant->"Italic"], " ", "-", " ", 
            RowBox[{
              StyleBox["b",
                FontSlant->"Italic"], " ", "\[Psi]"}]}]}], "     ", ",", 
        "                                                                     \
                         ", 
        StyleBox[\((11)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "where ",
  StyleBox["b",
    FontSlant->"Italic"],
  " is positive.  Multiply by the integrating factor ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["e", 
          StyleBox[
            RowBox[{
              StyleBox["b",
                FontSlant->"Italic"], "t"}]]], TraditionalForm]]],
  "and integrate from 0 to ",
  StyleBox["t ",
    FontSlant->"Italic"],
  "to get "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              StyleBox["t",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontSlant->"Italic"]}]}], "  ", "\[LessSlantEqual]", " ", 
          RowBox[{
            StyleBox[\(a\/b\),
              FontSlant->"Italic"], " ", "+", " ", 
            RowBox[{\([\[Psi] \((0)\)\  - \ 1]\), 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox[\(e\^\(-bt\)\),
                FontSlant->"Italic"]}]}]}], 
        StyleBox["  ",
          FontSlant->"Italic"], 
        StyleBox[",",
          FontSlant->"Italic"], 
        StyleBox[
          "                                                                   \
        ",
          FontSlant->"Italic"], 
        StyleBox[\((12)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "showing that \[Psi] is bounded.  Thus ",
  StyleBox["h",
    FontSlant->"Italic"],
  " + ",
  StyleBox["s",
    FontSlant->"Italic"],
  " is bounded and hence both ",
  StyleBox["h",
    FontSlant->"Italic"],
  " and ",
  StyleBox["s",
    FontSlant->"Italic"],
  " are bounded.  Now we look at the third of equations (4).  If we replace ",
  
  StyleBox["s ",
    FontSlant->"Italic"],
  "in that equation by its upper bound ",
  StyleBox["M",
    FontSlant->"Italic"],
  ", we get  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["dp",
              FontSlant->"Italic"], 
            StyleBox["dt",
              FontSlant->"Italic"]], " ", "\[LessEqual]", "  ", 
          RowBox[{
            StyleBox["qrRM",
              FontSlant->"Italic"], " ", "-", " ", 
            StyleBox["rp",
              FontSlant->"Italic"]}]}], "  ", ",", 
        "                                                                     \
                         ", 
        StyleBox[\((13)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "which is of the form (11) and hence shows that ",
  StyleBox["p",
    FontSlant->"Italic"],
  " is bounded.  Finally, we add the fourth of equations (4) to ",
  StyleBox["qwJ",
    FontSlant->"Italic"],
  " times the second of equations (4) to get an equation for \[Chi] = ",
  StyleBox["qwJs",
    FontSlant->"Italic"],
  " + ",
  StyleBox["c",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], "\[Chi]"}]], 
            StyleBox["dt",
              FontSlant->"Italic"]], "  ", "=", "  ", 
          RowBox[{
            RowBox[{
              StyleBox["qwJph",
                FontSlant->"Italic"], " ", "-", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                SuperscriptBox[
                  StyleBox["q",
                    FontSlant->"Italic"], "2"], 
                StyleBox["wJs",
                  FontSlant->"Italic"]}], " ", "-", " ", 
              StyleBox["wc",
                FontSlant->"Italic"]}], "  ", "=", "  ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["qwJph",
                    FontSlant->"Italic"], " ", "+", " ", 
                  RowBox[{
                    RowBox[{
                      StyleBox["qw",
                        FontSlant->"Italic"], "[", 
                      RowBox[{
                        StyleBox["w",
                          FontSlant->"Italic"], " ", "-", " ", 
                        StyleBox["q",
                          FontSlant->"Italic"]}], "]"}], " ", 
                    StyleBox["s",
                      FontSlant->"Italic"]}]}], ")"}], " ", "-", " ", 
              RowBox[{
                StyleBox[
                  RowBox[{
                    StyleBox["w",
                      FontSlant->"Italic"], "\[Chi]"}]], "   ", ".", 
                "                   ", 
                StyleBox[\((14)\),
                  FontWeight->"Bold"]}]}]}]}], " "}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Because ",
  StyleBox["p",
    FontSlant->"Italic"],
  ", ",
  StyleBox["h",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["s",
    FontSlant->"Italic"],
  " are all bounded, the first term on the right is bounded in absolute value \
by a positive constant, and we have again the form (11) and the conclusion \
that \[Chi] is bounded, and hence that ",
  StyleBox["c",
    FontSlant->"Italic"],
  " is bounded."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5 Significance of the Parameters ", "Subsection"],

Cell[TextData[{
  "\tAs we have seen in the last two sections, the nature of the system \
depends strongly on the reproductive ratio ",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  " and the immune parameter ",
  Cell[BoxData[
      FormBox["J", TraditionalForm]]],
  ".  The reproductive ratio is a standard parameter in disease theory.  It \
can be interpreted as the number of infected cells produced by a single \
infected cell during the lifetime of the infected cell.  When ",
  Cell[BoxData[
      FormBox["R", TraditionalForm]]],
  " is greater than 1 the infection grows, and when ",
  StyleBox["R",
    FontSlant->"Italic"],
  " is less than 1 the infection does not grow.  This interpretation is \
consistent with our stability analysis, which shows that when ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1, the attractor for the system is a disease-free equilibrium, and when \
",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, the attractor is an equilibrium with pathogens present.  "
}], "Text"],

Cell[TextData[{
  "\tFrom the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " in equation (3), it is clear that it depends on basic cell and pathogen \
parameters, but not on any immune system parameters.  For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, there is a further bifurcation of possibilities depending on the \
parameter ",
  StyleBox["J, ",
    FontSlant->"Italic"],
  "which depends on both \[Eta] and \[Xi], the only two immune system \
parameters which survive the original scaling.  For ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1, there is a steady-state nonzero immune response, whereas for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " < 1 there is not.  From the definion of ",
  StyleBox["J",
    FontSlant->"Italic"],
  " in equation (3), we see that we increase the likelihood of a steady-state \
immune response by (1) lowering \[Alpha] (decreasing the death rate of the \
infected cells which are necessary to stimulate an immune respone), (2) \
lowering \[Xi] (decreasing the death rate of the T cells), (3) increasing \
\[CapitalGamma] (increasing the rate of production of healthy cells and hence \
the rate of production of infected cells), and (4) increasing \[Eta] \
(increasing the rate of production of T cells).    "
}], "Text"],

Cell[TextData[{
  "\tThe dominant parameters for determining system behavior are clearly the \
reproductive ratio ",
  StyleBox["R",
    FontSlant->"Italic"],
  " and the immune parameter ",
  StyleBox["J.  ",
    FontSlant->"Italic"],
  "The parameters ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["w",
    FontSlant->"Italic"],
  " are also important, so we discuss them too.  The parameter ",
  StyleBox["q",
    FontSlant->"Italic"],
  " is the ratio of the death rate of infected cells to the death rate of \
healthy cells.  Thus it is a measure of the cytotoxicity of the pathogen.  In \
some diseases, the infection might not kill cells at all, in which case ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "= 1.  In other cases, the pathogen may be highly lethal, in which case ",
  StyleBox["q",
    FontSlant->"Italic"],
  " will be large.  The parameter ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is the ratio of the death rate of pathogens to the death rate of healthy \
cells.  In general one would expect it to exceed one and perhaps to be large. \
 The parameter ",
  StyleBox["w",
    FontSlant->"Italic"],
  " is the ratio of the death rate of T cells to the death rate of healthy \
cells.  "
}], "Text"],

Cell[TextData[{
  "\tAs a final item in our discussion of parameters, we consider the result \
mentioned earlier that the CTL kill rate \[Omega] does not appear in the \
scaled equations (4).  This is a consequence of the last of equations (1) \
being homogeneous in the CTL population ",
  StyleBox["C",
    FontSlant->"Italic"],
  ".  If one introduces into equations (1) a new variable ",
  StyleBox["D",
    FontSlant->"Italic"],
  " = \[Omega]",
  StyleBox["C",
    FontSlant->"Italic"],
  ", then \[Omega] no longer appears in any of the equations.  We can think \
of ",
  StyleBox["D",
    FontSlant->"Italic"],
  " as the effective CTL killer population.  From the point of view of this \
model, there is no difference between the case of many CTL's with low kill \
rates or a few CTL's with high kill rates, provided that ",
  StyleBox["D ",
    FontSlant->"Italic"],
  "is the same in the two populations.  For that reason, it would probably be \
better to formulate the model in terms of ",
  StyleBox["D",
    FontSlant->"Italic"],
  " rather than ",
  StyleBox["C, ",
    FontSlant->"Italic"],
  "with the understanding that in future more complicated models, ",
  StyleBox["C",
    FontSlant->"Italic"],
  " and \[Omega] could enter independently."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.6 A Few Asymptotic Results", "Subsection"],

Cell[TextData[{
  "\tHere we look briefly at a few limiting cases.  Specifically, we look at \
the limit of the attracting equilibrium as one of the three parameters ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", ",
  StyleBox["J,",
    FontSlant->"Italic"],
  " or ",
  StyleBox["q",
    FontSlant->"Italic"],
  " becomes large.  "
}], "Text"],

Cell[CellGroupData[{

Cell["Large Reproductive Ratio", "Subsubsection"],

Cell[TextData[{
  "\tWe consider the limit as ",
  StyleBox["R",
    FontSlant->"Italic"],
  " \[ShortRightArrow]\[Infinity] at fixed values of the other parameters.  \
For ",
  StyleBox["J",
    FontSlant->"Italic"],
  " < 1, the equilibrium will be the disease free equilibrium {1, 0, 0, 0}.  \
For ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1, the equilibrium will be the endemic equilibrium, which in this limit \
becomes {0, 1/",
  StyleBox["q",
    FontSlant->"Italic"],
  ", \[Infinity], 0}.  Thus in the limit of infinitely large reproduction \
ratio, there are no healthy cells, and the number of infected cells is 1/",
  StyleBox["q",
    FontSlant->"Italic"],
  ", which is, in the original dimensional description, \[CapitalGamma]/\
\[Alpha].   This is simply the steady state population for cells with a \
constant total birth rate \[CapitalGamma] and a per capita death rate \
\[Alpha].  This is exactly what one would expect.  In this limit healthy \
cells are born at a rate \[CapitalGamma] but immediately become infected and \
therefore have a death rate \[Alpha].  The pathogen population goes to \
infinity with ",
  StyleBox["R",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large Immune Response", "Subsubsection"],

Cell[TextData[{
  "\tNow consider the limit ",
  StyleBox["J",
    FontSlant->"Italic"],
  " \[ShortRightArrow]\[Infinity] at fixed values of other parameters.  For ",
  
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1, the immune system doesn't affect the equilbrium solution, and the \
result is the disease free equilibrium {1, 0, 0, 0}.  For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1, we have the case ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ", because ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  " = ",
  StyleBox["J",
    FontSlant->"Italic"],
  "/(",
  StyleBox["J",
    FontSlant->"Italic"],
  " - 1) \[ShortRightArrow] 1 as ",
  StyleBox["J",
    FontSlant->"Italic"],
  " \[ShortRightArrow]\[Infinity].  Then the relevant equilibrium is the \
state we called eqendimm, which in this limit becomes {1, 0, 0, ",
  StyleBox["q",
    FontSlant->"Italic"],
  "(",
  StyleBox["R",
    FontSlant->"Italic"],
  " - 1)}.  This is a disease free state with no reduction in cell number, \
and there is a continuing immune response ",
  StyleBox["q",
    FontSlant->"Italic"],
  "(",
  StyleBox["R",
    FontSlant->"Italic"],
  " - 1), which in the original dimensional form is  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\/\[Omega]\)]],
  "(",
  StyleBox["R",
    FontSlant->"Italic"],
  " - 1).  This steady immune presence is thus increased by increasing the \
death rate \[Alpha] of infected cells (i.e., increasing the cytotoxicity of \
the pathogens), by decreasing the \[Omega] rate at which T cells kill \
infected cells (i.e., decreasing the efficiency of the T cells), or by \
increasing the reproductive ratio ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "of the disease (i.e., increasing the virulence of the disease).  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large Cytotoxicity", "Subsubsection"],

Cell[TextData[{
  "\tFinally we consider the case of ",
  StyleBox["q",
    FontSlant->"Italic"],
  " \[ShortRightArrow]\[Infinity] at fixed values of the other parameters.  \
This is the limit of very large cytotoxicity.  As usual, if ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1, the final equibrium state is the disease free state {1, 0, 0, 0}.  \
For ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1 but ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  ", the final state is the endemic state, which in this limit is {1/",
  StyleBox["R, 0, R",
    FontSlant->"Italic"],
  " -1, 0}.  Thus there are only healthy cells and pathogens -- no infected \
cells or immune response.  Basically the infected cells die immediately in \
this limit, and the balance between birth of healthy cells and rate of \
infection leads to the scaled steady state of 1/",
  StyleBox["R.  ",
    FontSlant->"Italic"],
  "Finally for ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`R\_c\)]],
  "(which can happen only for ",
  StyleBox["J",
    FontSlant->"Italic"],
  " > 1), the final equilibrium state is eqendimm, in which there is a \
continued immune response.  In this limit the state becomes{",
  Cell[BoxData[
      FormBox[
        FractionBox["J", 
          RowBox[{"J", " ", "+", 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox["R",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", 0, ",
  Cell[BoxData[
      \(TraditionalForm\`R\/J\)]],
  ", \[Infinity]}.  Again there are no infected cells because they die \
immediately, and the immune presence is infinite in this limit.      "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.7 Virus Load and Immune Response", "Subsection"],

Cell["\<\
\tWe use our equilibrium solutions to discuss a few points about \
the biology of the system, pertaining to virus loads and immune response.  We \
follow the discussion of these points given by Nowak and Bangham (op. cit.).  \
\
\>", "Text"],

Cell[CellGroupData[{

Cell["Reduction of Virus Load", "Subsubsection"],

Cell[TextData[{
  "\tConsider first the virus load (i.e., virus population) in steady state \
(with ",
  StyleBox["R",
    FontSlant->"Italic"],
  " > 1).  In the absence of an immune response (",
  StyleBox["J",
    FontSlant->"Italic"],
  " < ",
  StyleBox["R",
    FontSlant->"Italic"],
  "/(",
  StyleBox["R",
    FontSlant->"Italic"],
  "-1)), the equilibrium is eqend and the virus load is ",
  StyleBox["R",
    FontSlant->"Italic"],
  " - 1.  In the presence of an immune response (",
  StyleBox["J",
    FontSlant->"Italic"],
  " > ",
  StyleBox["R",
    FontSlant->"Italic"],
  "/(",
  StyleBox["R",
    FontSlant->"Italic"],
  "-1)), the equilibrium is eqendimm and the virus load is ",
  StyleBox["R",
    FontSlant->"Italic"],
  "/",
  StyleBox["J , ",
    FontSlant->"Italic"],
  "which is less than",
  StyleBox[" R",
    FontSlant->"Italic"],
  " - 1",
  StyleBox[".  ",
    FontSlant->"Italic"],
  "Thus as one would expect, the virus load is decreased by the immune \
response.  Following Nowak and Bangham, we ask under what circumstances the \
virus load will be decreased by a factor of ",
  StyleBox["f",
    FontSlant->"Italic"],
  "?  We want ",
  StyleBox["R",
    FontSlant->"Italic"],
  "/",
  StyleBox["J",
    FontSlant->"Italic"],
  " = ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["R",
    FontSlant->"Italic"],
  "-1), or ",
  StyleBox["J",
    FontSlant->"Italic"],
  " = ",
  StyleBox["R",
    FontSlant->"Italic"],
  "/f(",
  StyleBox["R",
    FontSlant->"Italic"],
  "-1).  If for example ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 10 and we want ",
  StyleBox["f",
    FontSlant->"Italic"],
  " = 0.1, then we will require that ",
  StyleBox["J",
    FontSlant->"Italic"],
  " = 100/9 = 11.111.  We translate this into a requirement on the kill rate \
by CTL's.  From the second of equations (4), we see that the death rate of \
infected cells due to pathogens is ",
  StyleBox["qs",
    FontSlant->"Italic"],
  ", and the death rate due to CTL's is ",
  StyleBox["sc",
    FontSlant->"Italic"],
  ".  Then the CTL kill rate divided by the pathogen kill rate is ",
  StyleBox["c",
    FontSlant->"Italic"],
  "/",
  StyleBox["q",
    FontSlant->"Italic"],
  ", which in the equilibrium eqendimm has the value (",
  StyleBox["RJ",
    FontSlant->"Italic"],
  " - ",
  StyleBox["R",
    FontSlant->"Italic"],
  " - ",
  StyleBox["J",
    FontSlant->"Italic"],
  ")/(",
  StyleBox["J",
    FontSlant->"Italic"],
  " + ",
  StyleBox["R",
    FontSlant->"Italic"],
  ") = 81/19 = 4.3.  Thus the CTL kill rate must be over 4 times the pathogen \
kill rate if the immune system is to reduce the virus load by a factor of 10 \
when ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 10.   ",
  StyleBox["  ",
    FontSlant->"Italic"],
  " "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rate of Immune Response and Immune Responsiveness", "Subsubsection"],

Cell[TextData[{
  "\tNow we introduce a little more precision in our terminology.  By ",
  StyleBox["immune response",
    FontSlant->"Italic"],
  ", we mean the value ",
  StyleBox["C ",
    FontSlant->"Italic"],
  "of",
  StyleBox[" ",
    FontSlant->"Italic"],
  "the CTL population in the equilibrium state eqendimm.  We denote this \
value by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "eq"], TraditionalForm]]],
  ".  It is of interest to understand how ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "eq"], TraditionalForm]]],
  " depends on the parameters \[Eta], \[Xi] and \[Omega] of the immune \
system, for fixed values of the other parameters.  In particular, the \
dependence on \[Eta], which we call the immune rate (see the last of \
equations (1)), is of interest.  From the formulas given earlier, it is not \
hard to derive the following expression for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["C", "eq"], ":"}], TraditionalForm]]],
  "  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["C",
            FontSlant->"Italic"], "eq"], "  ", "=", "  ", 
        RowBox[{
          FractionBox[
            RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["R",
                    FontSlant->"Italic"], " ", "-", " ", "1"}], ")"}]}], 
            "\[Omega]"], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                RowBox[{
                  FractionBox[
                    SuperscriptBox[
                      StyleBox["R",
                        FontSlant->"Italic"], "2"], 
                    RowBox[{
                      StyleBox["R",
                        FontSlant->"Italic"], " ", "-", " ", "1"}]], " ", 
                  FractionBox["1", 
                    RowBox[{
                      FractionBox["\[CapitalGamma]\[Eta]", "\[Alpha]\[Xi]"], 
                      " ", "+", " ", 
                      StyleBox["R",
                        FontSlant->"Italic"]}]]}]}], ")"}], "    ", ".", 
            "                                                                 \
    ", 
            StyleBox[
              RowBox[{"(", "15", ")"}],
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "We see  that ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "eq"], TraditionalForm]]],
  " is (1) a monotonically increasing function of the immune rate \[Eta] \
(producing CTL's at a greater rate leads to a larger steady state \
population), (2) a monotonically decreasing function of \[Omega] (increasing \
the kill rate of infected cells by CTL's leads to a smaller steady-state \
population), and (3) a monotonically decreasing function of \[Xi] (increasing \
the death rate of CTL's leads to a smaller steady-state population).  These \
dependences are exactly what one would expect.  Nowak and Bingham present \
examples in which ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "eq"], TraditionalForm]]],
  " does not change monotonically with \[Eta], but they do this by varying \
\[Omega] in concert with \[Eta].  "
}], "Text"],

Cell[TextData[{
  "\tIf we write equation (15) in terms of the effective killer population ",
  StyleBox["D (",
    FontSlant->"Italic"],
  "discussed in section 3.5), we get"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["D",
            FontSlant->"Italic"], "eq"], "  ", "=", "  ", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Omega]", 
                StyleBox["C",
                  FontSlant->"Italic"]}]], "eq"], "  ", "=", "  ", 
          RowBox[{"\[Alpha]", " ", 
            RowBox[{"(", 
              RowBox[{
                StyleBox["R",
                  FontSlant->"Italic"], " ", "-", " ", "1"}], ")"}], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", 
                  RowBox[{
                    FractionBox[
                      SuperscriptBox[
                        StyleBox["R",
                          FontSlant->"Italic"], "2"], 
                      RowBox[{
                        StyleBox["R",
                          FontSlant->"Italic"], " ", "-", " ", "1"}]], " ", 
                    FractionBox["1", 
                      RowBox[{
                        
                        FractionBox["\[CapitalGamma]\[Eta]", 
                          "\[Alpha]\[Xi]"], " ", "+", " ", 
                        StyleBox["R",
                          FontSlant->"Italic"]}]]}]}], ")"}], "    ", ".", 
              "                                                               \
      ", 
              StyleBox[
                RowBox[{"(", "16", ")"}],
                FontWeight->"Bold"]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "  Now we see that the effective killer population ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", "eq"], TraditionalForm]]],
  " is a monotonically increasing function of the immune rate \[Eta], and \
that there are no other immunological parameters to vary.  If we define ",
  StyleBox["D",
    FontSlant->"Italic"],
  " rather than ",
  StyleBox["C",
    FontSlant->"Italic"],
  " as the immune response (and this is probably the best definition of \
immune response), then it is ",
  StyleBox["always",
    FontSlant->"Italic"],
  " true that increasing the immune rate \[Eta] increases the immune response \
",
  StyleBox["D",
    FontSlant->"Italic"],
  ".   "
}], "Text"],

Cell[TextData[{
  "\tAnother important system response is the virus load which we have \
discussed above.  This is ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["P", "eq"], TraditionalForm]]],
  "the virus population in the equilibrium eqendimm.  In dimensional form we \
have"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["P",
            FontSlant->"Italic"], "eq"], "  ", "=", "  ", 
        RowBox[{
          FractionBox["\[Rho]\[Xi]", "\[Delta]\[Eta]"], "      ", ".", 
          "                                                                   \
                           ", 
          StyleBox[
            RowBox[{"(", "17", ")"}],
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell["\<\
By combining equations (16) and (17), we get a useful result:\
\>", 
  "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["D",
            FontSlant->"Italic"], "eq"], "  ", "=", "  ", 
        RowBox[{"\[Alpha]", " ", 
          RowBox[{"(", 
            RowBox[{
              StyleBox["R",
                FontSlant->"Italic"], " ", "-", " ", "1"}], ")"}], " ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                RowBox[{
                  FractionBox[
                    StyleBox["R",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox["R",
                        FontSlant->"Italic"], " ", "-", " ", "1"}]], " ", 
                  FractionBox["1", 
                    RowBox[{
                      RowBox[{
                        FractionBox["\[Mu]", "\[Beta]"], " ", 
                        FractionBox["1", 
                          SubscriptBox[
                            StyleBox["P",
                              FontSlant->"Italic"], "eq"]]}], " ", "+", " ", 
                      "1"}]]}]}], ")"}], "    ", ".", 
            "                                                                 \
    ", 
            StyleBox[
              RowBox[{"(", "18", ")"}],
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "This shows that the immune response ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", "eq"], TraditionalForm]]],
  " and the viral load ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["P", "eq"], TraditionalForm]]],
  " ",
  StyleBox["always",
    FontSlant->"Italic"],
  " vary in opposite directions.  Nowak and Bangham, using ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "eq"], TraditionalForm]]],
  " as the definition of immune response, state (correctly) that one can have \
similar CTL responses with different viral loads.  In terms of our notation, \
this can happen only when \[Omega] also varies.  However, the effect of the \
CTL's on the host is better measured by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", "eq"], TraditionalForm]]],
  " =  \[Omega]",
  Cell[BoxData[
      FormBox[
        SubscriptBox["C", "eq"], TraditionalForm]]],
  ", and that effect varies monotonically with and oppositely to the viral \
load."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.  Examples of Dynamical Behavior", "Section"],

Cell[CellGroupData[{

Cell["4.1 Introduction", "Subsection"],

Cell["\<\
\tA complete study of the dynamics of this five-parameter system is \
far beyond the scope of this notebook.  Instead we look at three numerical \
examples of the approach to equilibrium, choosing our parameters so that we \
have one example of each of the three equilibria.  There is no attempt here \
to connect these examples with any specific biological problem.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Approach to Disease-Free Equilibrium (eqfree)", "Subsection"],

Cell[TextData[{
  "\tAs we have seen, the disease-free equilbrium is the system attractor \
whenever the reproductive ratio ",
  StyleBox["R",
    FontSlant->"Italic"],
  " < 1.  In addition to choosing ",
  StyleBox["R, ",
    FontSlant->"Italic"],
  " we must assign values to all the parameters in parmvec: "
}], "Text"],

Cell[BoxData[
    \(parmvec\)], "Input"],

Cell[TextData[{
  "The parameter ",
  StyleBox["q",
    FontSlant->"Italic"],
  " is the ratio of \[Alpha], he death rate of infected cells ( primarily \
caused directly by the pathogens), to \[Mu], the natural death rate of \
healthy cells.  It is reasonable to suppose the ",
  StyleBox["q",
    FontSlant->"Italic"],
  " is considerably larger than 1.  We take ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "= 5.  The parameter ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is the ratio of \[Delta], the pathogen death rate, to \[Mu] the healthy \
cell death rate, and we take ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 5.  We take the reproductive ratio to be ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 0.8.  We rather arbitrarily take a value of 5 for the immune parameter \
",
  StyleBox["J",
    FontSlant->"Italic"],
  ".  Finally, ",
  StyleBox["w",
    FontSlant->"Italic"],
  " is the ratio of \[Xi], the death rate for CTL's, to \[Mu], and we take ",
  StyleBox["w",
    FontSlant->"Italic"],
  " = 1.  We give these values to DynPac by assigning them to parmval:"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {5, 5, 0.8, 5, 1};\)\)], "Input"],

Cell["\<\
\tWe start our calculations by looking at the equilibrium state and \
the eigenvalues at equilibrium.\
\>", "Text"],

Cell[BoxData[
    \(eqstateval[eqfree]\)], "Input"],

Cell[BoxData[
    \(Eigenvalues[dermatval[eqfree]]\)], "Input"],

Cell["\<\
The eigenvalues confirm the stability, and show that there are \
three time scales of order 1 and a much shorter time scale of order 1/10.  \
\
\>", "Text"],

Cell[TextData[{
  "\tThe equation for the CTL population ",
  StyleBox["C",
    FontSlant->"Italic"],
  " (last of equations (1)) is homogenous in ",
  StyleBox["C",
    FontSlant->"Italic"],
  ".  ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "This means that no CTL's will ever appear unless there are some initially. \
 Thus if we want to see what happens to the CTL population, we must set a \
non-zero initial condition for ",
  StyleBox["C",
    FontSlant->"Italic"],
  ".  This is to some extent a defect of the model, because we would expect \
some non-zero level of CTL's under any conditions.  One could introduce a \
source term in the last of equations (1), similar to the source term \
\[CapitalGamma] in the first of equations (1).  However, this would \
complicate the equations by introducing another parameter, and it is probably \
sufficient to make sure that some CTL's are present by choosing a non-zero \
initial condition."
}], "Text"],

Cell["\<\
\tNow we choose the initial conditions.  For the initial value of \
the healthy cell population, we choose the equilibrium value of 1.   We \
disturb this equilibrium by choosing values of 0.2 for infected cells, \
pathogens, and CTL's.  We assign these initial values to a vector we call \
init:\
\>", "Text"],

Cell[BoxData[
    \(\(init = {1, 0.2, 0.2, 0.2};\)\)], "Input"],

Cell["\<\
We choose an initial time t0 = 0, a time step st=0.01, and a number \
of time steps nsteps = 800:\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0; st = 0.01; nsteps = 800;\)], "Input"],

Cell["Now we integrate and name the solution sol1:", "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[init, t0, st, nsteps];\)\)], "Input"],

Cell["We check the range of the solution:", "Text"],

Cell[BoxData[
    \(staterange[sol1]\)], "Input"],

Cell["\<\
We plot the four quantities versus time, each on a separate graph.  \
We first set some plotting parameters.\
\>", "Text"],

Cell[BoxData[
    \(asprat = 0.7; axorg = {0, 0}; imsize = 420; 
    plrange = {{0, 8}, {0, 1}};\)], "Input"],

Cell[BoxData[
    \(\(graphh = timeplot[sol1, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 8}, {0, 0.22}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphs = timeplot[sol1, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 8}, {0, 0.5}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphp = timeplot[sol1, 3];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 8}, {0, 1}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphc = timeplot[sol1, 4];\)\)], "Input"],

Cell["\<\
\tWe see that the healthy cell population declines initially, \
reaching a minimum at about 1 time unit.  After this the population climbs \
back up to the equilibrium value 1, but the climb is much slower than the \
initial drop.  The population of infected cells drops rapidly and \
monotonically, with a decay time scale of less than one time unit.  Both \
pathogens and CTL's are killing these cells, hence the rapid decline.  The \
population of pathogens rises rapidly, peaks at about 0.5 time units, and \
then decays slowly.  The CTL population climbs, but not as rapidly as the \
pathogen population, and peaks at about 1 time unit, after which it decays \
slowly.  The time scale for the various slow decays is something like 5 time \
units.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4.3 Approach to Endemic State Without Immune Response (eqend)\
\>", 
  "Subsection"],

Cell[TextData[{
  "\tNow we increase the value of ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", so that the final equilibrium is the endemic state eqend, in which we \
have healthy cells, infected cells, and pathogens, but no CTL's.  We retain \
all of the parameter values of the last section except for ",
  StyleBox["R",
    FontSlant->"Italic"],
  ".  For ",
  StyleBox["J",
    FontSlant->"Italic"],
  " = 5, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "c"], TraditionalForm]]],
  "= ",
  StyleBox["J",
    FontSlant->"Italic"],
  "/(",
  StyleBox["J",
    FontSlant->"Italic"],
  "-1) = 1.25, so we choose ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 1.1."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {5, 5, 1.1, 5, 1};\)\)], "Input"],

Cell["The equilibrium state is then", "Text"],

Cell[BoxData[
    \(eqstateval[eqend]\)], "Input"],

Cell["The eigenvalues of the equilibrium state are", "Text"],

Cell[BoxData[
    \(Eigenvalues[dermatval[eqend]]\)], "Input"],

Cell["\<\
The eigenvalues confirm the stability, and show that the three time \
scales vary over a factor of 30 near equilbrium, from about 0.1 time unit to \
about 3 time units.  \
\>", "Text"],

Cell["\<\
\tNow we choose the initial conditions.  For the initial value of \
the healthy cell population, we choose the equilibrium value of 1.   We \
disturb this equilibrium by choosing values of 0.2 for infected cells, \
pathogens, and CTL's.  We assign these initial values to a vector we call \
init:\
\>", "Text"],

Cell[BoxData[
    \(\(init = {1, 0.2, 0.2, 0.2};\)\)], "Input"],

Cell["\<\
We choose an initial time t0 = 0, a time step st=0.01, and a number \
of time steps nsteps = 800:\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0; st = 0.01; nsteps = 800;\)], "Input"],

Cell["Now we integrate and name the solution sol1:", "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[init, t0, st, nsteps];\)\)], "Input"],

Cell["We check the range of the solution:", "Text"],

Cell[BoxData[
    \(staterange[sol2]\)], "Input"],

Cell["\<\
We plot the four quantities versus time, each on a separate graph.  \
We first set some plotting parameters.\
\>", "Text"],

Cell[BoxData[
    \(asprat = 0.7; axorg = {0, 0}; imsize = 420; 
    plrange = {{0, 8}, {0, 1}};\)], "Input"],

Cell[BoxData[
    \(\(graphh2 = timeplot[sol2, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 8}, {0, 0.22}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphs2 = timeplot[sol2, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 8}, {0, 0.7}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphp2 = timeplot[sol2, 3];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 8}, {0, 1.2}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphc2 = timeplot[sol2, 4];\)\)], "Input"],

Cell[TextData[{
  "\tWe see that the healthy cell population declines initially, reaching a \
minimum at a little beyond 1 time unit.  After this the population climbs \
slowly back up to the equilibrium value 0.909.  The population of infected \
cells drops rapidly and monotonically, with a decay time scale between one \
and two units.  The step-like behavior for small times is a consequence of \
the shortest time scale.  The population of pathogens rises rapidly, peaks at \
about 0.5 time units, and then decays slowly to the equilibrium value 0.1.  \
The CTL population climbs, but not as rapidly as the pathogen population, and \
peaks at about 1.5 time units, after which it decays slowly to zero.  Notice \
that both ",
  StyleBox["s",
    FontSlant->"Italic"],
  " and ",
  StyleBox["p",
    FontSlant->"Italic"],
  " seem to drop slightly below equilibrium and then slowly come back up.  It \
would be well to repeat the calculation with a smaller time step to see if \
this feature is really there."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4.4 Approach to Endemic State With Immune Response (eqendimm)\
\>", 
  "Subsection"],

Cell[TextData[{
  "\tNow we increase the value of ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", so that the final equilibrium is eqendimm, the endemic state with immune \
response, in which we have healthy cells, infected cells, pathogens, and \
CTL's.  We retain all of the parameter values of the last section except for \
",
  StyleBox["R",
    FontSlant->"Italic"],
  ".  We choose ",
  StyleBox["R",
    FontSlant->"Italic"],
  " to be well above the bifurcation value ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["R", "c"], TraditionalForm]]],
  "= ",
  StyleBox["J",
    FontSlant->"Italic"],
  "/(",
  StyleBox["J",
    FontSlant->"Italic"],
  " - 1) = 1.25, namely ",
  StyleBox["R",
    FontSlant->"Italic"],
  " = 5.  For such a large value of ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", there is a good chance we will get oscillations."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {5. , 5. , 5. , 5. , 1. };\)\)], "Input"],

Cell["The equilibrium state is then", "Text"],

Cell[BoxData[
    \(eqstateval[eqendimm]\)], "Input"],

Cell[BoxData[
    \(Eigenvalues[dermatval[eqendimm]]\)], "Input"],

Cell["\<\
The eigenvalues confirm the stability, and show that there is a \
very rapidly damped mode, a slowly damped mode, and a damped oscillatory mode \
in the solution set linearized about equilibrium.  \
\>", "Text"],

Cell["\<\
\tNow we choose the initial conditions.  For the initial value of \
the healthy cell population, we choose the equilibrium value of 1.   We \
disturb this equilibrium by choosing values of 0.2 for infected cells, \
pathogens, and CTL's.  We assign these initial values to a vector we call \
init:\
\>", "Text"],

Cell[BoxData[
    \(\(init = {1, 0.2, 0.2, 0.2};\)\)], "Input"],

Cell["\<\
We choose an initial time t0 = 0, a time step st=0.01, and a number \
of time steps nsteps =1000:\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0; st = 0.01; nsteps = 1000;\)], "Input"],

Cell["Now we integrate and name the solution sol1:", "Text"],

Cell[BoxData[
    \(\(sol3 = integrate[init, t0, st, nsteps];\)\)], "Input"],

Cell["We check the range of the solution:", "Text"],

Cell[BoxData[
    \(staterange[sol3]\)], "Input"],

Cell["\<\
We plot the four quantities versus time, each on a separate graph.  \
We first set some plotting parameters.\
\>", "Text"],

Cell[BoxData[
    \(asprat = 0.7; axorg = {0, 0}; imsize = 420; 
    plrange = {{0, 10}, {0, 1}};\)], "Input"],

Cell[BoxData[
    \(\(graphh3 = timeplot[sol3, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 10}, {0, 0.4}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphs2s = timeplot[sol3, 2];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 10}, {0, 8}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphp3 = timeplot[sol3, 3];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 10}, {0, 10}};\)\)], "Input"],

Cell[BoxData[
    \(\(graphc3 = timeplot[sol3, 4];\)\)], "Input"],

Cell["\<\
\tWe see that the healthy cell population declines initially, \
reaching a minimum at about 0.75 time units.  After this the population \
climbs fairly rapidly to a local maximum at a little over two time units, and \
continues to undergo a heavily damped oscillation with about 3 time units \
between peaks.  The population of infected cells show a rapid but very small \
initial drop, followed by a rapid climb, followed by a very rapid drop and \
then small and heavily damped oscillations.  The population of pathogens \
rises rapidly, peaks at about 0.3 time units, and then drops rapidly to a low \
value, after which it undergoes small and heavily damped oscillations.  The \
CTL population climbs, but not quite as rapidly as the pathogen population, \
and peaks at about 1 time unit, after which it undergoes heavily damped \
oscillations.  \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix.  Stability and the Routh-Hurwitz Criterion", "Section"],

Cell[TextData[{
  "\tWe consider polynomial equations of the form ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) = 0, where"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontSlant->"Italic"], \((\[Lambda])\)}], "  ", "=", "  ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "0"], 
                  SuperscriptBox["\[Lambda]", 
                    StyleBox["n",
                      FontSlant->"Italic"]]}], " ", "+", " ", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], 
                  SuperscriptBox["\[Lambda]", 
                    RowBox[{
                      StyleBox["n",
                        FontSlant->"Italic"], " ", "-", " ", "1"}]]}], " ", 
                "+", " ", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"], 
                  RowBox[{
                    SuperscriptBox["\[Lambda]", 
                      RowBox[{
                        StyleBox["n",
                          FontSlant->"Italic"], " ", "-", " ", "2"}]], " ", 
                    ".", " ", ".", " ", ".", " ", 
                    RowBox[{"+", " ", 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], 
                        RowBox[{
                          StyleBox["n",
                            FontSlant->"Italic"], " ", "-", " ", "1"}]]}]}], 
                  "\[Lambda]"}], " ", "+", " ", 
                SubscriptBox[
                  StyleBox["c",
                    FontSlant->"Italic"], "n"]}], 
              StyleBox["  ",
                FontSlant->"Italic"], "=", "  ", "0"}]}], "          ", ",", 
          "                                   ", 
          StyleBox[\((A - 1)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "under the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  "> 0.  We call ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda])  stable if all of its roots have negative real parts.  We \
summarize in this appendix some standard techniques for determining the \
stability directly from the coefficients."
}], "Text"],

Cell[TextData[{
  "\tTo begin with, suppose that ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) is stable.  Then a real root -",
  StyleBox["r",
    FontSlant->"Italic"],
  " with ",
  StyleBox["r",
    FontSlant->"Italic"],
  " > 0 will contribute a factor (\[Lambda] + ",
  StyleBox["r) ",
    FontSlant->"Italic"],
  "to ",
  StyleBox["p.",
    FontSlant->"Italic"],
  "  A pair of complex conjugate roots -",
  StyleBox["a",
    FontSlant->"Italic"],
  " \[PlusMinus]",
  StyleBox["ib ",
    FontSlant->"Italic"],
  "will contribute a factor"
}], "Text"],

Cell[TextData[{
  "(\[Lambda] + ",
  StyleBox["a",
    FontSlant->"Italic"],
  " +",
  StyleBox["ib",
    FontSlant->"Italic"],
  ") (\[Lambda] + ",
  StyleBox["a",
    FontSlant->"Italic"],
  " - ",
  StyleBox["ib",
    FontSlant->"Italic"],
  ")  =  (\[Lambda] + ",
  StyleBox["a",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\()\^2\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)]],
  "   .                                                   ",
  StyleBox["(A-2)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Thus ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) will be a product of factors with \[Lambda]'s and all positive \
numbers.  If the multiplication of the factors is carried out and the result \
multiplied by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "0"], TraditionalForm]]],
  "> 0, we must get an expression in which the coefficient of every power of \
\[Lambda] is the sum of products of positive numbers.  Hence if a polynomial \
is stable and if ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", "0"], TraditionalForm]]],
  "> 0, then every coefficient in the polynomial is positive.  This is a \
simple necessary (but not sufficient) condition for stability.  We always \
impose this coefficient test first.  If ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) fails, it is unstable.  If it passes, there is no conclusion \
and we must test further.  The further testing is done with the Routh-Hurwitz \
criterion.  In our statement of the Routh-Hurwitz criterion below, we assume \
that ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) has passed the coefficient test.\n\n\tThe Routh-Hurwitz \
criterion is summarized in many references.  For example, it is in the ",
  StyleBox["Encyclopedia of Mathematics on CD-Rom",
    FontWeight->"Bold"],
  ", Kluwer, 1997, under the entry Routh-Hurwitz Criterion.  The version we \
present here was taken from ",
  StyleBox["Methods of Analytical Dynamics",
    FontWeight->"Bold"],
  ", L. Meirovitch, McGraw-Hill, 1970, pp.222-224.  Given the polynomial \
(A-1), we form the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " x ",
  StyleBox["n",
    FontSlant->"Italic"],
  " matrix ",
  StyleBox["H",
    FontSlant->"Italic"],
  " given below."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["H",
          FontSlant->"Italic"], 
        StyleBox["  ",
          FontSlant->"Plain"], 
        StyleBox["=",
          FontSlant->"Plain"], 
        StyleBox["  ",
          FontSlant->"Plain"], 
        RowBox[{
          RowBox[{"(", GridBox[{
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], 
                  StyleBox[
                    SubscriptBox["c", 
                      StyleBox["0",
                        FontSlant->"Plain"]],
                    FontSlant->"Italic"], "0", "0", "\[CenterDot]", 
                  "\[CenterDot]", "\[CenterDot]", "0"},
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], "\[CenterDot]", 
                  "\[CenterDot]", "\[CenterDot]", "0"},
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "5"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "4"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"], "\[CenterDot]", 
                  "\[CenterDot]", "\[CenterDot]", "0"},
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "7"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "6"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "5"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "4"], "\[CenterDot]", 
                  "\[CenterDot]", "\[CenterDot]", "0"},
                {"\[CenterDot]", "\[CenterDot]", "\[CenterDot]", 
                  "\[CenterDot]", "\[CenterDot]", "\[CenterDot]", 
                  "\[CenterDot]", "\[CenterDot]"},
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], 
                    RowBox[{
                      RowBox[{"2", 
                        StyleBox["n",
                          FontSlant->"Italic"]}], "-", "1"}]], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], 
                    RowBox[{
                      RowBox[{"2", 
                        StyleBox["n",
                          FontSlant->"Italic"]}], "-", "2"}]], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], 
                    RowBox[{
                      RowBox[{"2", 
                        StyleBox["n",
                          FontSlant->"Italic"]}], "-", "3"}]], 
                  "\[CenterDot]", "\[CenterDot]", "\[CenterDot]", 
                  "\[CenterDot]", 
                  StyleBox[\(c\_n\),
                    FontSlant->"Italic"]}
                }], ")"}], "              ", ".", 
          "                                                  ", 
          StyleBox[\((A - 3)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "All elements with subscripts > ",
  StyleBox["n",
    FontSlant->"Italic"],
  " or < 0 are to be replaced by zero.  The necessary and sufficient \
condition for the stability of the polynomial is that the principal \
subdeterminants, given below, all be positive."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["D", 
            StyleBox["1",
              FontSlant->"Plain"]], "  ", 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          SubscriptBox["c", 
            StyleBox[\(1\ \ \ \ \ \ \ \ \ \ , \),
              FontSlant->"Plain"]]}], " "}], TextForm]], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["D",
              FontSlant->"Italic"], 
            StyleBox["2",
              FontSlant->"Italic"]], "  ", "=", "  ", 
          RowBox[{"\[VerticalSeparator]", "\[NegativeThinSpace]", 
            RowBox[{GridBox[{
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "1"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "0"]},
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "3"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "2"]}
                  }], "\[NegativeThinSpace]", "\[VerticalSeparator]"}]}]}], 
        "             ", ","}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["D",
                FontSlant->"Italic"], "3"], "  ", "=", "  ", 
            RowBox[{"\[VerticalSeparator]", 
              RowBox[{GridBox[{
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "1"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "0"], "0"},
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "3"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "2"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "1"]},
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "5"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "4"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "3"]}
                    }], "\[VerticalSeparator]"}]}]}], "     ", ",", 
          "                                                                   \
                 ", 
          StyleBox[\((A - 4)\),
            FontWeight->"Bold"]}], " "}], TextForm]], "Text",
  TextAlignment->Right],

Cell[". . . . . . . . . . . . . . . . . . . . . .", "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[\(D\_n\),
            FontSlant->"Italic"], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          RowBox[{"\[VerticalSeparator]", 
            RowBox[{GridBox[{
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "1"], 
                    StyleBox[
                      SubscriptBox["c", 
                        StyleBox["0",
                          FontSlant->"Plain"]],
                      FontSlant->"Italic"], "0", "0", "\[CenterDot]", 
                    "\[CenterDot]", "\[CenterDot]", "0"},
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "3"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "2"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "1"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "1"], "\[CenterDot]", 
                    "\[CenterDot]", "\[CenterDot]", "0"},
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "5"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "4"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "3"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "2"], "\[CenterDot]", 
                    "\[CenterDot]", "\[CenterDot]", "0"},
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "7"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "6"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "5"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "4"], "\[CenterDot]", 
                    "\[CenterDot]", "\[CenterDot]", "0"},
                  {"\[CenterDot]", "\[CenterDot]", "\[CenterDot]", 
                    "\[CenterDot]", "\[CenterDot]", "\[CenterDot]", 
                    "\[CenterDot]", "\[CenterDot]"},
                  {
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], 
                      RowBox[{
                        RowBox[{"2", 
                          StyleBox["n",
                            FontSlant->"Italic"]}], "-", "1"}]], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], 
                      RowBox[{
                        RowBox[{"2", 
                          StyleBox["n",
                            FontSlant->"Italic"]}], "-", "2"}]], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], 
                      RowBox[{
                        RowBox[{"2", 
                          StyleBox["n",
                            FontSlant->"Italic"]}], "-", "3"}]], 
                    "\[CenterDot]", "\[CenterDot]", "\[CenterDot]", 
                    "\[CenterDot]", 
                    StyleBox[\(c\_n\),
                      FontSlant->"Italic"]}
                  }], "\[VerticalSeparator]", "              ", "."}]}]}], 
        "                                                                   \
"}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  " \tWe illustrate the use of this for a quadratic, a cubic and a quartic.  \
We start with the quadratic ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) =  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  "\[Lambda] + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  ".  Then "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["D", 
            StyleBox["1",
              FontSlant->"Plain"]], "  ", 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          RowBox[{
            SubscriptBox["c", 
              StyleBox["1",
                FontSlant->"Plain"]], " ", 
            StyleBox[">",
              FontSlant->"Plain"], " ", 
            StyleBox["0",
              FontSlant->"Plain"]}]}], ",", " ", 
        RowBox[{
          FormBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["and",
                    FontSlant->"Plain"], 
                  StyleBox[
                    RowBox[{
                      StyleBox["  ",
                        FontSlant->"Plain"], " "}]], 
                  SubscriptBox[
                    StyleBox["D",
                      FontSlant->"Italic"], 
                    StyleBox["2",
                      FontSlant->"Italic"]]}], "  ", "=", "  ", 
                RowBox[{
                  RowBox[{"\[VerticalSeparator]", "\[NegativeThinSpace]", 
                    RowBox[{GridBox[{
                          {
                            SubscriptBox[
                              StyleBox["c",
                                FontSlant->"Italic"], "1"], 
                            SubscriptBox[
                              StyleBox["c",
                                FontSlant->"Italic"], "0"]},
                          {"0", 
                            SubscriptBox[
                              StyleBox["c",
                                FontSlant->"Italic"], "2"]}
                          }], "\[NegativeThinSpace]", 
                      "\[VerticalSeparator]"}]}], "   ", "=", "  ", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], 
                        StyleBox["1",
                          FontSlant->"Plain"]], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], 
                        StyleBox["2",
                          FontSlant->"Plain"]]}], "  ", 
                    StyleBox[">",
                      FontSlant->"Plain"], 
                    StyleBox["  ",
                      FontSlant->"Plain"], 
                    StyleBox["0",
                      FontSlant->"Plain"]}]}]}], "       ", ","}],
            "TextForm"], 
          "                                                  ", 
          StyleBox[\((A - 5)\),
            FontWeight->"Bold",
            FontSlant->"Plain"]}]}], TextForm]], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell["\<\
so in this case the conditions reduce to simply the coefficient \
test that all of the coefficients be positive.  Only for the quadratic is \
this test sufficient.\
\>", "Text"],

Cell[TextData[{
  "\tNow we consider the cubic  ",
  StyleBox["p",
    FontSlant->"Italic"],
  "(\[Lambda]) =  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  "\[Lambda] + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  ".  The three Routh-Hurwitz conditions are  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["D", 
            StyleBox["1",
              FontSlant->"Plain"]], "  ", 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          RowBox[{
            SubscriptBox["c", 
              StyleBox["1",
                FontSlant->"Plain"]], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox[">",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox["0",
              FontSlant->"Plain"]}]}], 
        StyleBox["  ",
          FontSlant->"Plain"], 
        StyleBox[",",
          FontSlant->"Plain"]}], TextForm]], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["D",
              FontSlant->"Italic"], 
            StyleBox["2",
              FontSlant->"Italic"]], "  ", "=", "  ", 
          RowBox[{
            RowBox[{"\[VerticalSeparator]", "\[NegativeThinSpace]", 
              RowBox[{GridBox[{
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "1"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "0"]},
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "3"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "2"]}
                    }], "\[NegativeThinSpace]", "\[VerticalSeparator]"}]}], 
            "  ", "=", "  ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], " ", 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"]}], " ", "-", " ", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "0"], " ", 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"]}]}], "  ", ">", " ", 
              "0"}]}]}], "       ", ","}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"and", "     ", 
              SubscriptBox[
                StyleBox["D",
                  FontSlant->"Italic"], "3"]}], "  ", "=", "  ", 
            RowBox[{
              RowBox[{"\[VerticalSeparator]", 
                RowBox[{GridBox[{
                      {
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "1"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "0"], "0"},
                      {
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "3"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "2"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "1"]},
                      {"0", "0", 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "3"]}
                      }], "\[VerticalSeparator]"}]}], "   ", "=", "   ", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"], " ", 
                  SubscriptBox[
                    StyleBox["D",
                      FontSlant->"Italic"], "2"]}], "  ", ">", " ", 
                "0"}]}]}], "  ", ",", 
          "                                                                  \
", 
          StyleBox[\((A - 6)\),
            FontWeight->"Bold"]}], " "}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "which reduces to the single condition ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  "> 0.  Thus the necessary and sufficient conditions that a cubic be stable \
are that all of the coefficients are positive and that ",
  Cell[BoxData[
      \(TraditionalForm\`D\_2\)]],
  "> 0."
}], "Text"],

Cell[TextData[{
  "\tFinally we consider the quartic polynomial  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^4\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^3\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  "\[Lambda] + ",
  Cell[BoxData[
      \(TraditionalForm\`c\_4\)]],
  ".  The four Routh-Hurwitz conditions are"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["D", 
            StyleBox["1",
              FontSlant->"Plain"]], "  ", 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["  ",
            FontSlant->"Plain"], 
          RowBox[{
            SubscriptBox["c", 
              StyleBox["1",
                FontSlant->"Plain"]], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox[">",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox["0",
              FontSlant->"Plain"]}]}], 
        StyleBox["  ",
          FontSlant->"Plain"], 
        StyleBox[",",
          FontSlant->"Plain"]}], TextForm]], "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["D",
              FontSlant->"Italic"], 
            StyleBox["2",
              FontSlant->"Italic"]], "  ", "=", "  ", 
          RowBox[{
            RowBox[{"\[VerticalSeparator]", "\[NegativeThinSpace]", 
              RowBox[{GridBox[{
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "1"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "0"]},
                    {
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "3"], 
                      SubscriptBox[
                        StyleBox["c",
                          FontSlant->"Italic"], "2"]}
                    }], "\[NegativeThinSpace]", "\[VerticalSeparator]"}]}], 
            "  ", "=", "  ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], " ", 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"]}], " ", "-", " ", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "0"], " ", 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"]}]}], "  ", ">", " ", 
              "0"}]}]}], "       ", ","}], TextForm]], "Text",
  TextAlignment->Center],

Cell[BoxData[
    FormBox[
      RowBox[{"   ", 
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["D",
                FontSlant->"Italic"], "3"], "  ", "=", "  ", 
            RowBox[{
              RowBox[{"\[VerticalSeparator]", 
                RowBox[{GridBox[{
                      {
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "1"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "0"], "0"},
                      {
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "3"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "2"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "1"]},
                      {"0", 
                        StyleBox[
                          SubscriptBox["c", 
                            StyleBox["4",
                              FontSlant->"Plain"]],
                          FontSlant->"Italic"], 
                        SubscriptBox[
                          StyleBox["c",
                            FontSlant->"Italic"], "3"]}
                      }], "\[VerticalSeparator]"}]}], "   ", "=", "  ", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "1"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "2"], " ", 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "3"]}], "-", " ", 
                  RowBox[{
                    SubsuperscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "1", "2"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "4"]}], "-", " ", 
                  RowBox[{
                    SubsuperscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "3", "2"], 
                    SubscriptBox[
                      StyleBox["c",
                        FontSlant->"Italic"], "0"]}]}], "  ", ">", " ", 
                "0"}]}]}], "  ", ",", 
          "                                                      ", 
          StyleBox[\((A - 7)\),
            FontWeight->"Bold"]}], " "}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "and   ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(4\ \)\)]],
  "=  ",
  Cell[BoxData[
      RowBox[{"\[VerticalSeparator]", 
        RowBox[{
          StyleBox[GridBox[{
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "0"], "0", "0"},
                {
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "1"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "0"]},
                {"0", 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "4"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "3"], 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "2"]},
                {"0", "0", "0", 
                  SubscriptBox[
                    StyleBox["c",
                      FontSlant->"Italic"], "4"]}
                }],
            FontFamily->"Times"], "\[VerticalSeparator]"}]}]]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_4\)]],
  Cell[BoxData[
      \(TraditionalForm\`D\_3\)]],
  " > 0  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "These reduce to the two conditions ",
  Cell[BoxData[
      \(TraditionalForm\`D\_2\)]],
  "> 0 and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_3\)]],
  "> 0.  In fact we can reduce this to the single condition ",
  Cell[BoxData[
      \(TraditionalForm\`D\_3\)]],
  "> 0 because this implies that  ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "1"], 
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "2"], " ", 
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "3"]}], ">", " ", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "3", "2"], 
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "0"]}]}]}], TextForm]]],
  ", hence that ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "1"], 
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "2"]}], " ", ">", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["c",
                  FontSlant->"Italic"], "0"], \(c\_3\)}]}]}], TextForm]]],
  ".  Thus the necessary and sufficient conditions for the quartic to be \
stable are that all the coefficients be positive and that ",
  Cell[BoxData[
      \(TraditionalForm\`D\_3\)]],
  "> 0.  "
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{612, 440},
WindowMargins->{{25, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 83, 3, 152, "Title"],
Cell[1825, 56, 38, 1, 27, "Input"],
Cell[1866, 59, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1944, 64, 35, 0, 50, "Section"],
Cell[1982, 66, 880, 17, 130, "Text"],
Cell[2865, 85, 370, 9, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3272, 99, 34, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[3331, 103, 44, 0, 46, "Subsection"],
Cell[3378, 105, 1512, 43, 152, "Text"],
Cell[4893, 150, 583, 18, 45, "Text"],
Cell[5479, 170, 808, 23, 45, "Text"],
Cell[6290, 195, 717, 21, 45, "Text"],
Cell[7010, 218, 665, 20, 45, "Text"],
Cell[7678, 240, 498, 8, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8213, 253, 48, 0, 46, "Subsection"],
Cell[8264, 255, 450, 6, 78, "Text"],
Cell[8717, 263, 818, 38, 32, "Text"],
Cell[9538, 303, 123, 3, 30, "Text"],
Cell[9664, 308, 1018, 29, 46, "Text"],
Cell[10685, 339, 142, 5, 32, "Text"],
Cell[10830, 346, 643, 20, 45, "Text"],
Cell[11476, 368, 821, 24, 45, "Text"],
Cell[12300, 394, 786, 24, 45, "Text"],
Cell[13089, 420, 509, 16, 45, "Text"],
Cell[13601, 438, 757, 21, 96, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14395, 464, 57, 0, 46, "Subsection"],
Cell[14455, 466, 118, 3, 30, "Text"],
Cell[14576, 471, 60, 1, 27, "Input"],
Cell[14639, 474, 62, 1, 27, "Input"],
Cell[14704, 477, 97, 3, 30, "Text"],
Cell[14804, 482, 122, 2, 43, "Input"],
Cell[14929, 486, 54, 1, 27, "Input"],
Cell[14986, 489, 136, 3, 30, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15171, 498, 34, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[15230, 502, 45, 0, 46, "Subsection"],
Cell[15278, 504, 159, 4, 46, "Text"],
Cell[15440, 510, 54, 1, 27, "Input"],
Cell[15497, 513, 235, 5, 46, "Text"],
Cell[15735, 520, 59, 1, 27, "Input"],
Cell[15797, 523, 58, 1, 27, "Input"],
Cell[15858, 526, 61, 1, 27, "Input"],
Cell[15922, 529, 754, 27, 64, "Text"],
Cell[16679, 558, 613, 17, 44, "Text"],
Cell[17295, 577, 882, 35, 64, "Text"],
Cell[18180, 614, 611, 18, 62, "Text"],
Cell[18794, 634, 184, 4, 46, "Text"],
Cell[18981, 640, 184, 3, 27, "Input"],
Cell[19168, 645, 216, 3, 27, "Input"],
Cell[19387, 650, 148, 3, 43, "Input"],
Cell[19538, 655, 59, 1, 27, "Input"],
Cell[19600, 658, 57, 1, 27, "Input"],
Cell[19660, 661, 63, 1, 27, "Input"],
Cell[19726, 664, 555, 7, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20318, 676, 131, 5, 46, "Subsection"],
Cell[20452, 683, 741, 15, 114, "Text"],
Cell[21196, 700, 60, 1, 27, "Input"],
Cell[21259, 703, 58, 1, 27, "Input"],
Cell[21320, 706, 64, 1, 27, "Input"],
Cell[21387, 709, 109, 3, 30, "Text"],
Cell[21499, 714, 109, 2, 27, "Input"],
Cell[21611, 718, 698, 25, 64, "Text"],
Cell[22312, 745, 73, 0, 30, "Text"],
Cell[22388, 747, 107, 2, 27, "Input"],
Cell[22498, 751, 950, 38, 64, "Text"],
Cell[23451, 791, 143, 3, 27, "Input"],
Cell[23597, 796, 37, 0, 30, "Text"],
Cell[23637, 798, 90, 1, 27, "Input"],
Cell[23730, 801, 438, 18, 30, "Text"],
Cell[24171, 821, 61, 1, 27, "Input"],
Cell[24235, 824, 61, 1, 27, "Input"],
Cell[24299, 827, 61, 1, 27, "Input"],
Cell[24363, 830, 61, 1, 27, "Input"],
Cell[24427, 833, 1920, 55, 160, "Text"],
Cell[26350, 890, 51, 1, 27, "Input"],
Cell[26404, 893, 261, 11, 32, "Text"],
Cell[26668, 906, 92, 1, 27, "Input"],
Cell[26763, 909, 510, 16, 64, "Text"],
Cell[27276, 927, 93, 3, 30, "Text"],
Cell[27372, 932, 113, 2, 43, "Input"],
Cell[27488, 936, 48, 0, 30, "Text"],
Cell[27539, 938, 105, 2, 27, "Input"],
Cell[27647, 942, 177, 8, 30, "Text"],
Cell[27827, 952, 110, 2, 27, "Input"],
Cell[27940, 956, 1368, 57, 64, "Text"],
Cell[29311, 1015, 60, 1, 27, "Input"],
Cell[29374, 1018, 60, 1, 27, "Input"],
Cell[29437, 1021, 60, 1, 27, "Input"],
Cell[29500, 1024, 60, 1, 27, "Input"],
Cell[29563, 1027, 60, 1, 27, "Input"],
Cell[29626, 1030, 659, 24, 62, "Text"],
Cell[30288, 1056, 1483, 58, 32, "Text"],
Cell[31774, 1116, 1056, 30, 78, "Text"],
Cell[32833, 1148, 79, 1, 27, "Input"],
Cell[32915, 1151, 46, 1, 27, "Input"],
Cell[32964, 1154, 60, 1, 27, "Input"],
Cell[33027, 1157, 60, 1, 27, "Input"],
Cell[33090, 1160, 46, 1, 27, "Input"],
Cell[33139, 1163, 46, 1, 27, "Input"],
Cell[33188, 1166, 92, 3, 30, "Text"],
Cell[33283, 1171, 84, 1, 27, "Input"],
Cell[33370, 1174, 335, 14, 30, "Text"],
Cell[33708, 1190, 72, 1, 27, "Input"],
Cell[33783, 1193, 230, 8, 30, "Text"],
Cell[34016, 1203, 80, 1, 27, "Input"],
Cell[34099, 1206, 40, 0, 30, "Text"],
Cell[34142, 1208, 69, 1, 27, "Input"],
Cell[34214, 1211, 304, 10, 48, "Text"],
Cell[34521, 1223, 87, 1, 27, "Input"],
Cell[34611, 1226, 36, 0, 30, "Text"],
Cell[34650, 1228, 66, 1, 27, "Input"],
Cell[34719, 1231, 50, 0, 30, "Text"],
Cell[34772, 1233, 102, 5, 32, "Text"],
Cell[34877, 1240, 66, 1, 27, "Input"],
Cell[34946, 1243, 90, 3, 30, "Text"],
Cell[35039, 1248, 111, 5, 30, "Text"],
Cell[35153, 1255, 66, 1, 27, "Input"],
Cell[35222, 1258, 556, 23, 48, "Text"],
Cell[35781, 1283, 70, 1, 27, "Input"],
Cell[35854, 1286, 55, 1, 27, "Input"],
Cell[35912, 1289, 69, 1, 27, "Input"],
Cell[35984, 1292, 69, 1, 27, "Input"],
Cell[36056, 1295, 69, 1, 27, "Input"],
Cell[36128, 1298, 70, 1, 27, "Input"],
Cell[36201, 1301, 69, 1, 27, "Input"],
Cell[36273, 1304, 69, 1, 27, "Input"],
Cell[36345, 1307, 69, 1, 27, "Input"],
Cell[36417, 1310, 65, 1, 27, "Input"],
Cell[36485, 1313, 69, 1, 27, "Input"],
Cell[36557, 1316, 69, 1, 27, "Input"],
Cell[36629, 1319, 92, 3, 30, "Text"],
Cell[36724, 1324, 944, 44, 32, "Text"],
Cell[37671, 1370, 251, 6, 46, "Text"],
Cell[37925, 1378, 885, 36, 32, "Text"],
Cell[38813, 1416, 677, 21, 64, "Text"],
Cell[39493, 1439, 76, 1, 27, "Input"],
Cell[39572, 1442, 229, 6, 48, "Text"],
Cell[39804, 1450, 3166, 94, 149, "Text"],
Cell[42973, 1546, 746, 29, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43756, 1580, 131, 5, 46, "Subsection"],
Cell[43890, 1587, 947, 34, 82, "Text"],
Cell[44840, 1623, 294, 8, 46, "Text"],
Cell[45137, 1633, 40, 1, 27, "Input"],
Cell[45180, 1636, 55, 0, 30, "Text"],
Cell[45238, 1638, 2229, 63, 45, "Text"],
Cell[47470, 1703, 275, 7, 48, "Text"],
Cell[47748, 1712, 47, 1, 27, "Input"],
Cell[47798, 1715, 306, 10, 46, "Text"],
Cell[48107, 1727, 198, 6, 48, "Text"],
Cell[48308, 1735, 1322, 39, 44, "Text"],
Cell[49633, 1776, 239, 6, 48, "Text"],
Cell[49875, 1784, 46, 1, 27, "Input"],
Cell[49924, 1787, 300, 7, 46, "Text"],
Cell[50227, 1796, 2261, 68, 145, "Text"],
Cell[52491, 1866, 334, 11, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52862, 1882, 51, 0, 46, "Subsection"],
Cell[52916, 1884, 197, 4, 46, "Text"],
Cell[53116, 1890, 831, 24, 46, "Text"],
Cell[53950, 1916, 896, 26, 46, "Text"],
Cell[54849, 1944, 884, 25, 48, "Text"],
Cell[55736, 1971, 661, 21, 46, "Text"],
Cell[56400, 1994, 93, 3, 30, "Text"],
Cell[56496, 1999, 117, 3, 30, "Text"],
Cell[56616, 2004, 1539, 41, 45, "Text"],
Cell[58158, 2047, 176, 8, 32, "Text"],
Cell[58337, 2057, 736, 21, 44, "Text"],
Cell[59076, 2080, 418, 16, 32, "Text"],
Cell[59497, 2098, 943, 28, 43, "Text"],
Cell[60443, 2128, 516, 21, 50, "Text"],
Cell[60962, 2151, 629, 18, 44, "Text"],
Cell[61594, 2171, 408, 14, 50, "Text"],
Cell[62005, 2187, 1798, 49, 44, "Text"],
Cell[63806, 2238, 445, 16, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64288, 2259, 57, 0, 46, "Subsection"],
Cell[64348, 2261, 1032, 25, 116, "Text"],
Cell[65383, 2288, 1304, 29, 166, "Text"],
Cell[66690, 2319, 1300, 38, 136, "Text"],
Cell[67993, 2359, 1274, 33, 152, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69304, 2397, 50, 0, 46, "Subsection"],
Cell[69357, 2399, 347, 12, 48, "Text"],

Cell[CellGroupData[{
Cell[69729, 2415, 49, 0, 42, "Subsubsection"],
Cell[69781, 2417, 1202, 30, 136, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71020, 2452, 46, 0, 42, "Subsubsection"],
Cell[71069, 2454, 1847, 58, 172, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72953, 2517, 43, 0, 42, "Subsubsection"],
Cell[72999, 2519, 1756, 51, 154, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[74804, 2576, 56, 0, 46, "Subsection"],
Cell[74863, 2578, 251, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[75139, 2587, 48, 0, 42, "Subsubsection"],
Cell[75190, 2589, 2807, 111, 208, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78034, 2705, 74, 0, 42, "Subsubsection"],
Cell[78111, 2707, 1033, 29, 98, "Text"],
Cell[79147, 2738, 1349, 36, 64, "Text"],
Cell[80499, 2776, 879, 18, 110, "Text"],
Cell[81381, 2796, 187, 5, 32, "Text"],
Cell[81571, 2803, 1538, 40, 64, "Text"],
Cell[83112, 2845, 708, 21, 84, "Text"],
Cell[83823, 2868, 298, 8, 46, "Text"],
Cell[84124, 2878, 485, 13, 46, "Text"],
Cell[84612, 2893, 88, 3, 30, "Text"],
Cell[84703, 2898, 1340, 35, 66, "Text"],
Cell[86046, 2935, 1013, 29, 96, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[87120, 2971, 53, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[87198, 2975, 38, 0, 46, "Subsection"],
Cell[87239, 2977, 390, 6, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87666, 2988, 71, 0, 46, "Subsection"],
Cell[87740, 2990, 323, 9, 50, "Text"],
Cell[88066, 3001, 40, 1, 27, "Input"],
Cell[88109, 3004, 1109, 33, 120, "Text"],
Cell[89221, 3039, 65, 1, 27, "Input"],
Cell[89289, 3042, 125, 3, 30, "Text"],
Cell[89417, 3047, 51, 1, 27, "Input"],
Cell[89471, 3050, 63, 1, 27, "Input"],
Cell[89537, 3053, 166, 4, 46, "Text"],
Cell[89706, 3059, 958, 22, 130, "Text"],
Cell[90667, 3083, 320, 6, 62, "Text"],
Cell[90990, 3091, 63, 1, 27, "Input"],
Cell[91056, 3094, 121, 3, 30, "Text"],
Cell[91180, 3099, 65, 1, 27, "Input"],
Cell[91248, 3102, 60, 0, 30, "Text"],
Cell[91311, 3104, 76, 1, 27, "Input"],
Cell[91390, 3107, 51, 0, 30, "Text"],
Cell[91444, 3109, 49, 1, 27, "Input"],
Cell[91496, 3112, 132, 3, 30, "Text"],
Cell[91631, 3117, 109, 2, 27, "Input"],
Cell[91743, 3121, 64, 1, 27, "Input"],
Cell[91810, 3124, 67, 1, 27, "Input"],
Cell[91880, 3127, 64, 1, 27, "Input"],
Cell[91947, 3130, 66, 1, 27, "Input"],
Cell[92016, 3133, 64, 1, 27, "Input"],
Cell[92083, 3136, 64, 1, 27, "Input"],
Cell[92150, 3139, 64, 1, 27, "Input"],
Cell[92217, 3142, 775, 12, 126, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93029, 3159, 94, 3, 46, "Subsection"],
Cell[93126, 3164, 700, 26, 66, "Text"],
Cell[93829, 3192, 65, 1, 27, "Input"],
Cell[93897, 3195, 45, 0, 30, "Text"],
Cell[93945, 3197, 50, 1, 27, "Input"],
Cell[93998, 3200, 60, 0, 30, "Text"],
Cell[94061, 3202, 62, 1, 27, "Input"],
Cell[94126, 3205, 194, 4, 46, "Text"],
Cell[94323, 3211, 320, 6, 62, "Text"],
Cell[94646, 3219, 63, 1, 27, "Input"],
Cell[94712, 3222, 121, 3, 30, "Text"],
Cell[94836, 3227, 65, 1, 27, "Input"],
Cell[94904, 3230, 60, 0, 30, "Text"],
Cell[94967, 3232, 76, 1, 27, "Input"],
Cell[95046, 3235, 51, 0, 30, "Text"],
Cell[95100, 3237, 49, 1, 27, "Input"],
Cell[95152, 3240, 132, 3, 30, "Text"],
Cell[95287, 3245, 109, 2, 27, "Input"],
Cell[95399, 3249, 65, 1, 27, "Input"],
Cell[95467, 3252, 67, 1, 27, "Input"],
Cell[95537, 3255, 65, 1, 27, "Input"],
Cell[95605, 3258, 66, 1, 27, "Input"],
Cell[95674, 3261, 65, 1, 27, "Input"],
Cell[95742, 3264, 66, 1, 27, "Input"],
Cell[95811, 3267, 65, 1, 27, "Input"],
Cell[95879, 3270, 1025, 19, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96941, 3294, 94, 3, 46, "Subsection"],
Cell[97038, 3299, 880, 30, 84, "Text"],
Cell[97921, 3331, 73, 1, 27, "Input"],
Cell[97997, 3334, 45, 0, 30, "Text"],
Cell[98045, 3336, 53, 1, 27, "Input"],
Cell[98101, 3339, 65, 1, 27, "Input"],
Cell[98169, 3342, 221, 4, 46, "Text"],
Cell[98393, 3348, 320, 6, 62, "Text"],
Cell[98716, 3356, 63, 1, 27, "Input"],
Cell[98782, 3359, 121, 3, 30, "Text"],
Cell[98906, 3364, 66, 1, 27, "Input"],
Cell[98975, 3367, 60, 0, 30, "Text"],
Cell[99038, 3369, 76, 1, 27, "Input"],
Cell[99117, 3372, 51, 0, 30, "Text"],
Cell[99171, 3374, 49, 1, 27, "Input"],
Cell[99223, 3377, 132, 3, 30, "Text"],
Cell[99358, 3382, 110, 2, 43, "Input"],
Cell[99471, 3386, 65, 1, 27, "Input"],
Cell[99539, 3389, 67, 1, 27, "Input"],
Cell[99609, 3392, 66, 1, 27, "Input"],
Cell[99678, 3395, 65, 1, 27, "Input"],
Cell[99746, 3398, 65, 1, 27, "Input"],
Cell[99814, 3401, 66, 1, 27, "Input"],
Cell[99883, 3404, 65, 1, 27, "Input"],
Cell[99951, 3407, 874, 13, 142, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[100874, 3426, 71, 0, 50, "Section"],
Cell[100948, 3428, 149, 5, 32, "Text"],
Cell[101100, 3435, 2054, 52, 31, "Text"],
Cell[103157, 3489, 363, 10, 48, "Text"],
Cell[103523, 3501, 571, 23, 50, "Text"],
Cell[104097, 3526, 565, 25, 32, "Text"],
Cell[104665, 3553, 1790, 46, 220, "Text"],
Cell[106458, 3601, 3839, 98, 107, "Text"],
Cell[110300, 3701, 295, 7, 48, "Text"],
Cell[110598, 3710, 465, 15, 31, "Text"],
Cell[111066, 3727, 1008, 27, 43, "Text"],
Cell[112077, 3756, 1660, 42, 59, "Text"],
Cell[113740, 3800, 84, 1, 30, "Text"],
Cell[113827, 3803, 4036, 98, 107, "Text"],
Cell[117866, 3903, 452, 17, 48, "Text"],
Cell[118321, 3922, 2841, 75, 45, "Text"],
Cell[121165, 3999, 187, 4, 46, "Text"],
Cell[121355, 4005, 529, 21, 32, "Text"],
Cell[121887, 4028, 820, 28, 30, "Text"],
Cell[122710, 4058, 1709, 45, 43, "Text"],
Cell[124422, 4105, 1855, 47, 59, "Text"],
Cell[126280, 4154, 480, 16, 46, "Text"],
Cell[126763, 4172, 599, 23, 46, "Text"],
Cell[127365, 4197, 820, 28, 30, "Text"],
Cell[128188, 4227, 1709, 45, 43, "Text"],
Cell[129900, 4274, 2773, 68, 59, "Text"],
Cell[132676, 4344, 1710, 52, 73, "Text"],
Cell[134389, 4398, 1710, 53, 62, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

