(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22281,        795]*)
(*NotebookOutlinePosition[     47199,       1697]*)
(*  CellTagsIndexPosition[     47155,       1693]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Logistic Equation 
With
Time Lag\
\>", "Title"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "\tThe subject of this notebook is the first-order differential equation \
known as the logistic equation.  This equation is often used as a simple \
population model when there is a maximum sustainable population because of \
limited resources.  If ",
  StyleBox["P",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") is the population as a function of time, if ",
  StyleBox["M",
    FontSlant->"Italic"],
  " is the maximum sustainable population (assumed constant), and if ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is the per capita growth rate in the absence of limited resources, then \
the equation is"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox[
            RowBox[{
              StyleBox["d",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["P",
                FontSize->10,
                FontWeight->"Plain",
                FontSlant->"Italic"]}]], 
          StyleBox["dt",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Italic"]], TraditionalForm]]],
  " = ",
  StyleBox["rP",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(1 -",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{"  ", 
          StyleBox[\(P\/M\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  StyleBox[") ",
    FontWeight->"Plain"],
  "       ",
  StyleBox[" .  ",
    FontWeight->"Plain"],
  "                                                                (1)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "The properties of the solutions of this equation are well-known.  For any \
positive initial population, there is a monotonic approach to the equilibrium \
population ",
  StyleBox["M",
    FontSlant->"Italic"],
  ", and this equilibrium is stable.  The equation is separable and the \
solution is easily obtained analytically.  By scaling, one may eliminate both \
",
  StyleBox["r",
    FontSlant->"Italic"],
  " and ",
  StyleBox["M",
    FontSlant->"Italic"],
  " from the equation.  We let     "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\&\[Wedge]\)\ \ \)\)]],
  "= ",
  StyleBox["P",
    FontSlant->"Italic"],
  "/",
  StyleBox["M",
    FontSlant->"Italic"],
  "  ,   and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\&\[Wedge]\)\)]],
  " = ",
  StyleBox["rt",
    FontSlant->"Italic"],
  "   ,                                                                      \
",
  StyleBox["(2)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["\<\
and then drop the hats for simplicity.  Equation (1) becomes \
\>", 
  "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox[
            RowBox[{
              StyleBox["d",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["P",
                FontSize->10,
                FontWeight->"Plain",
                FontSlant->"Italic"]}]], 
          StyleBox["dt",
            FontWeight->"Plain",
            FontSlant->"Italic"]], TraditionalForm]]],
  " = ",
  StyleBox["P",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(1 -",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["P",
          FontWeight->"Plain"], TraditionalForm]]],
  StyleBox[") ",
    FontWeight->"Plain"],
  "       ",
  StyleBox[" .  ",
    FontWeight->"Plain"],
  "                                                                (3)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "The solution satisfying ",
  StyleBox["P",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`P\_0\)]],
  "is given by"
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox["P",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[") = ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            StyleBox[\(P\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic"], 
            RowBox[{
              StyleBox[\(P\_0\),
                FontSize->10], " ", "+", " ", 
              RowBox[{
                RowBox[{
                  StyleBox["(",
                    FontSize->12], 
                  StyleBox[\(1\  - \ P\_0\),
                    FontSize->10], 
                  StyleBox[")",
                    FontSize->12]}], 
                SuperscriptBox[
                  StyleBox["e",
                    FontSize->12], 
                  RowBox[{"-", 
                    RowBox[{
                      StyleBox["(",
                        FontSize->9], 
                      StyleBox[
                        RowBox[{"t", " ", "-", " ", 
                          SubscriptBox["t", 
                            StyleBox["0",
                              FontWeight->"Plain",
                              FontSlant->"Plain",
                              FontTracking->"Plain",
                              FontVariations->{"Underline"->False,
                              "Outline"->False,
                              "Shadow"->False}]]}],
                        FontSize->9], ")"}]}]]}]}]],
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], TraditionalForm]]],
  "   ",
  StyleBox[" .  ",
    FontWeight->"Plain"],
  "                                                                (4)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tThe specific subject of this notebook is a modification of this problem. \
 The original equation (1) has in effect a population dependent per capita \
growth rate of magnitude ",
  StyleBox["r",
    FontSlant->"Italic"],
  "(1 - ",
  StyleBox["P",
    FontSlant->"Italic"],
  "/",
  StyleBox["M",
    FontSlant->"Italic"],
  ").  The modification consists of putting a time lag ",
  StyleBox["T",
    FontSlant->"Italic"],
  " into the ",
  StyleBox["P",
    FontSlant->"Italic"],
  " that appears in this term.  This corresponds to saying that the present \
growth rate depends on the population a time ",
  StyleBox["T",
    FontSlant->"Italic"],
  " ago.  This problem has been discussed by many authors, and May (",
  StyleBox["Stability and Complexity in Model Ecosystems",
    FontWeight->"Bold"],
  ", Robert M. May, Princeton University Press, 1974, Chapter 4) gives a \
detailed summary, including much discussion of the possible biological \
applications of such models.  For example, May notes that the logistic \
equation with lag could be a simple model for herbivores grazing on \
vegetation that takes a time ",
  StyleBox["T",
    FontSlant->"Italic"],
  " to recover.  With the time lag, equation (1) becomes     "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            StyleBox["dP",
              FontSize->10,
              FontWeight->"Plain",
              FontSlant->"Italic"], 
            StyleBox["dt",
              FontWeight->"Plain",
              FontSlant->"Italic"]],
          FontSize->10], TraditionalForm]]],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[") ",
    FontWeight->"Plain"],
  "= ",
  StyleBox["rP",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  StyleBox["[",
    FontSize->24,
    FontWeight->"Plain"],
  StyleBox["1 -",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        RowBox[{"  ", 
          StyleBox[
            FractionBox[
              RowBox[{
                StyleBox["P",
                  FontSize->10], 
                StyleBox["(",
                  FontSize->12], 
                RowBox[{
                  StyleBox["t",
                    FontSize->10,
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSize->12,
                    FontSlant->"Italic"], 
                  StyleBox["-",
                    FontSize->10], 
                  StyleBox[" ",
                    FontSize->12], 
                  StyleBox["T",
                    FontSize->10,
                    FontSlant->"Italic"]}], 
                StyleBox[")",
                  FontSize->12]}], "M"],
            FontWeight->"Plain"]}], TraditionalForm]]],
  StyleBox["]",
    FontSize->24,
    FontWeight->"Plain"],
  "       ",
  StyleBox[" .  ",
    FontWeight->"Plain"],
  "                                                                (5)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell["\<\
Again we may introduce the scaling (2), and the result, sans hats, \
is\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          StyleBox["dP",
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          StyleBox["dt",
            FontSize->10,
            FontWeight->"Plain",
            FontSlant->"Italic"]], TraditionalForm]]],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  " = ",
  StyleBox["P",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")[1 -",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["P",
          FontWeight->"Plain"], TraditionalForm]]],
  StyleBox["(",
    FontWeight->"Plain"],
  StyleBox["t",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" - \[Tau])]    ,  with \[Tau] = ",
    FontWeight->"Plain"],
  StyleBox["rT",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Plain"],
  "       ",
  StyleBox[" .  ",
    FontWeight->"Plain"],
  "                                                    (6)"
}], "Text",
  TextAlignment->Right,
  FontWeight->"Bold"],

Cell[TextData[{
  "Thus the lag logistic equation has a single parameter \[Tau], which may be \
interpreted as the ratio of the lag time to the ",
  Cell[BoxData[
      \(TraditionalForm\`r\^\(-1\)\)]],
  ", the growth rate time scale.  We would expect that if anything \
qualitatively different happens as a result of the lag, it would do so for \
\[Tau] exceeding some critical value.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining the Equations for DynPac", "Section"],

Cell["\<\
\tFor reference purposes, we will at times want the solutions to \
the unlagged logistic equation, so we define it also for DynPac.  We do that \
first:\
\>", "Text"],

Cell[BoxData[
    \(setstate[{P}]; setparm[{}]; parmval = {}; 
    slopevec = {P*\((1.0 - P)\)};\)], "Input"],

Cell[BoxData[
    \(\(savesys[Logistic];\)\)], "Input"],

Cell["Now we define the lagged system.", "Text"],

Cell[BoxData[
    \(setstate[{P}]; setparm[{}]; parmval = {}; 
    slopevec = {P*\((1.0 - Plag)\)};\)], "Input"],

Cell[BoxData[
    \(\(savesys[LagLogistic];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solutions Without Lag", "Section"],

Cell["\<\
\tThe main issue here is the dependence of the solution on the lag \
time, and the nature of the attractor as a function of the lag time.  We \
begin with the unlagged logistic equation as a reference case.\
\>", "Text"],

Cell[BoxData[
    \(\(restoresys[Logistic];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["There are two equilibrium states:", "Text"],

Cell[BoxData[
    \(eq1 = 0.0; eq2 = 1.0;\)], "Input"],

Cell["We examine the stability of each:", "Text"],

Cell[BoxData[
    \(classify[eq1]\)], "Input"],

Cell[BoxData[
    \(classify[eq2]\)], "Input"],

Cell["\<\
DynPac has told us the well-known and obvious results that the zero \
population state (eq1) is unstable (any small deviation from zero will cause \
growth), and the state of maximum sustainable population (eq2 = 1) is \
strictly stable.  As an example, we calculate and plot two solutions -- one \
with initial condition below maximum and one with initial condition above \
maximum.  We also put in a solution at the equilbrium value in red.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(sol1 = integrate[{0.05}, 0.0, 0.01, 1000];\)\)], "Input"],

Cell[BoxData[
    \(\(sol2 = integrate[{1.5}, 0.0, 0.01, 1000];\)\)], "Input"],

Cell[BoxData[
    \(\(soleq = integrate[{1}, 0.0, 0.1, 1000];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 10}, {0, 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue, Blue, Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1 = timeplot[{sol1, sol2, soleq}, 1];\)\)], "Input"],

Cell["\<\
\tFor populations far below the maximum, the logistic equation \
reduces to the Malthusian model (simple exponential growth), namely dP/dt = \
P.  Let's compare the solution of the logistic and Malthusian models.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(slopevec = {P};\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[Malthusian];\)\)], "Input"],

Cell[BoxData[
    \(\(sol4 = integrate[{0.05}, 0.0, 0.01, 1000];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red, Green, Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph2 = timeplot[{soleq, sol4, sol1}, 1];\)\)], "Input"],

Cell["\<\
We see that the Malthusian curve (green) and the logistic curve \
(blue) do indeed coincide for small values of P.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Examples of Solutions With Lag", "Section"],

Cell["\<\
\tWe now begin looking at results for the lagged equation.  We \
restore the lag system.\
\>", "Text"],

Cell[BoxData[
    \(\(restoresys[LagLogistic];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
We start with two examples:  a small lag and a large lag.  Recall \
that the lag is dimensionless in this formulation, so small and large mean \
relative to the natural growth time of the population.  We will use 0.2 and 2 \
for the values of the lag.  We will start the system out at a constant \
population of 0.5 -- one-half the maximum sustainable steady-state \
population.  We will also take our pre-lag function to be equal to 0.5 \
throughout the pre-lag time interval.\
\>", "Text"],

Cell[BoxData[
    \(\(initfunc = {0.5};\)\)], "Input"],

Cell[BoxData[
    \(\(initcond = {0.5};\)\)], "Input"],

Cell[BoxData[
    \(\(t0 = 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(\[Tau] = 0.2;\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.01;\)\)], "Input"],

Cell[BoxData[
    \(\(nlags = 50;\)\)], "Input"],

Cell[BoxData[
    \(\(lagsol1 = 
        lagintegrate[initfunc, initcond, t0, h, \[Tau], nlags];\)\)], "Input"],

Cell["Let's check the range of values of the dependent variable:", "Text"],

Cell[BoxData[
    \(staterange[lagsol1]\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 10}, {0, 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red, Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(lagraph1 = timeplot[{soleq, lagsol1}, 1];\)\)], "Input"],

Cell[TextData[
"This is not very different than the unlagged logistic.  Now let's try the \
larger value of \[Tau]."], "Text"],

Cell[BoxData[
    \(\(\[Tau] = 2.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h = 0.1;\)\)], "Input"],

Cell[BoxData[
    \(\(nlags = 5;\)\)], "Input"],

Cell[BoxData[
    \(\(lagsol2 = 
        lagintegrate[initfunc, initcond, t0, h, \[Tau], nlags];\)\)], "Input"],

Cell[BoxData[
    \(\(lagraph2 = timeplot[{soleq, lagsol2}, 1];\)\)], "Input"],

Cell["\<\
A very different result.  Now we have strong oscillatory behavior.  \
Let's extend the integration greatly in time to see what happens \
eventually.\
\>", "Text"],

Cell[BoxData[
    \(\(nlags = 50;\)\)], "Input"],

Cell[BoxData[
    \(\(lagsol3 = 
        lagintegrate[initfunc, initcond, t0, h, \[Tau], nlags];\)\)], "Input"],

Cell[BoxData[
    \(staterange[lagsol3]\)], "Input"],

Cell[BoxData[
    \(2.90181/0.0685298\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 100}, {0, 3}};\)\)], "Input"],

Cell[BoxData[
    \(\(lagraph3 = timeplot[{soleq, lagsol3}, 1];\)\)], "Input"],

Cell["\<\
This looks like a limit-cycle solution.  Let's see if we can find \
an estimate of the period.  First we find the minimum between 40 and 45:\
\>",
   "Text"],

Cell[BoxData[
    \(staterange[subsol[lagsol3, {40, 45}]]\)], "Input"],

Cell["\<\
Thus the minimum is 0.0685685 at t = 40.82.  Now we look for the \
next minimum:\
\>", "Text"],

Cell[BoxData[
    \(staterange[subsol[lagsol3, {45, 55}]]\)], "Input"],

Cell["\<\
Thus the next minimum is at t = 49.63, so we estimate the period at\
\
\>", "Text"],

Cell[BoxData[
    \(49.63 - 40.82\)], "Input"],

Cell["\<\
The ratio of the max to min in the cycle can be obtained from\
\>", 
  "Text"],

Cell[BoxData[
    \(staterange[subsol[lagsol3, {70, 100}]]\)], "Input"],

Cell["and is", "Text"],

Cell[BoxData[
    \(2.90181/0.0685298\)], "Input"],

Cell[TextData[
"These numbers for period and amplitude ratio for \[Tau] = 2 agree with those \
given in May's summary (op.cit., p. 97) of results for this equation.  "], 
  "Text"],

Cell[TextData[
"\tThis example suggests the following conclusion:  for \[Tau] sufficiently \
large, the stable equilibrium becomes unstable, and a new attractor appears \
which is a stable limit cycle.  This cycle has amplitude excursions above and \
below the equilibrium value.  In fact the minima in the cycle for \[Tau] = 2 \
are quite low, and this poses a danger of extinction if one accounts for \
random fluctuations that are surely there in a real system.  "], "Text"],

Cell[TextData[
"\tOur next and last step is to explore more thoroughly the dependence on \
\[Tau].  In particular, we would like to know the critical value that \
separates stable equilibrium from limit cycle."], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dependence of Solutions on Lag Time", "Section"],

Cell[TextData[
"\tWe now define a routine that produces a graph of the lagged solution for \
any value of \[Tau].  We will then use it to explore systematically the \
change of the solutions with \[Tau]. "], "Text"],

Cell[BoxData[
    \(lagger[\[Tau]_] := 
      Module[{laggersol}, 
        nlags = Ceiling[60/\[Tau]]; \n\t\tlaggersol = 
          lagintegrate[initfunc, initcond, t0, h, \[Tau], 
            nlags]; \n\t\tlabon = 
          SequenceForm["\<\[Tau] = \>", 
            PaddedForm[\[Tau], {4, 2}]]; \n\t\tplrange = {{0, 60}, {0, 
              5}}; \n\t\ttimeplot[{soleq, laggersol}, 1]]\)], "Input"],

Cell[TextData["Let's test this for \[Tau] = 2:"], "Text"],

Cell[BoxData[
    \(\(lagger[2];\)\)], "Input"],

Cell["\<\
Now we make a movie, and also see if we can estimate roughly the \
transition between equilibrium and limit cycle.\
\>", "Text"],

Cell[BoxData[
    \(\(Do[lagger[0.25 + 0.25*ii], {ii, 1, 9}];\)\)], "Input"],

Cell[TextData[{
  "\tThese graphs illustrate a number of interesting points.  First of all, \
the transition appears to be just beyond \[Tau] = 1.5, for which value there \
is a very slowly damped oscillation.  This is consistent with the discussion \
in May, in which the result of G.S. Jones (J. Math. Anal. Appl. ",
  StyleBox["5",
    FontWeight->"Bold"],
  ", 435, 1962) is quoted:  the transition occurs at \[Tau] = \[Pi]/2.  A \
second interesting point is the spiky nature of the solution for larger \
values of \[Tau]:  sharp narrow peaks are separated by periods of dormancy \
with very low values of P.  In a real system with irregular fluctuations, \
there would be a real danger of extinction in the intervals between peaks.  \
Note also the increase of period with \[Tau].  "
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
WindowSize->{632, 433},
WindowMargins->{{164, Automatic}, {Automatic, 20}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@Pdcl0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 57, 4, 190, "Title"],
Cell[1799, 57, 38, 1, 27, "Input"],
Cell[1840, 60, 47, 1, 27, "Input"],
Cell[1890, 63, 46, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1961, 68, 31, 0, 50, "Section"],
Cell[1995, 70, 676, 18, 82, "Text"],
Cell[2674, 90, 1017, 38, 37, "Text"],
Cell[3694, 130, 531, 15, 66, "Text"],
Cell[4228, 147, 475, 20, 35, "Text"],
Cell[4706, 169, 88, 3, 30, "Text"],
Cell[4797, 174, 956, 36, 36, "Text"],
Cell[5756, 212, 234, 11, 32, "Text"],
Cell[5993, 225, 1971, 60, 38, "Text"],
Cell[7967, 287, 1265, 33, 152, "Text"],
Cell[9235, 322, 1963, 73, 42, "Text"],
Cell[11201, 397, 95, 3, 30, "Text"],
Cell[11299, 402, 1287, 53, 35, "Text"],
Cell[12589, 457, 401, 8, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13027, 470, 52, 0, 50, "Section"],
Cell[13082, 472, 176, 4, 46, "Text"],
Cell[13261, 478, 109, 2, 27, "Input"],
Cell[13373, 482, 55, 1, 27, "Input"],
Cell[13431, 485, 48, 0, 30, "Text"],
Cell[13482, 487, 112, 2, 27, "Input"],
Cell[13597, 491, 58, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13692, 497, 40, 0, 50, "Section"],
Cell[13735, 499, 230, 4, 46, "Text"],
Cell[13968, 505, 58, 1, 27, "Input"],
Cell[14029, 508, 42, 1, 27, "Input"],
Cell[14074, 511, 49, 0, 30, "Text"],
Cell[14126, 513, 54, 1, 27, "Input"],
Cell[14183, 516, 49, 0, 30, "Text"],
Cell[14235, 518, 46, 1, 27, "Input"],
Cell[14284, 521, 46, 1, 27, "Input"],
Cell[14333, 524, 469, 8, 78, "Text"],
Cell[14805, 534, 79, 1, 27, "Input"],
Cell[14887, 537, 78, 1, 27, "Input"],
Cell[14968, 540, 76, 1, 27, "Input"],
Cell[15047, 543, 65, 1, 27, "Input"],
Cell[15115, 546, 50, 1, 27, "Input"],
Cell[15168, 549, 65, 1, 27, "Input"],
Cell[15236, 552, 79, 1, 27, "Input"],
Cell[15318, 555, 239, 5, 46, "Text"],
Cell[15560, 562, 52, 1, 27, "Input"],
Cell[15615, 565, 57, 1, 27, "Input"],
Cell[15675, 568, 79, 1, 27, "Input"],
Cell[15757, 571, 66, 1, 27, "Input"],
Cell[15826, 574, 79, 1, 27, "Input"],
Cell[15908, 577, 138, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16083, 585, 54, 0, 50, "Section"],
Cell[16140, 587, 112, 3, 30, "Text"],
Cell[16255, 592, 61, 1, 27, "Input"],
Cell[16319, 595, 42, 1, 27, "Input"],
Cell[16364, 598, 501, 8, 78, "Text"],
Cell[16868, 608, 54, 1, 27, "Input"],
Cell[16925, 611, 54, 1, 27, "Input"],
Cell[16982, 614, 46, 1, 27, "Input"],
Cell[17031, 617, 50, 1, 27, "Input"],
Cell[17084, 620, 46, 1, 27, "Input"],
Cell[17133, 623, 48, 1, 27, "Input"],
Cell[17184, 626, 111, 2, 27, "Input"],
Cell[17298, 630, 74, 0, 30, "Text"],
Cell[17375, 632, 52, 1, 27, "Input"],
Cell[17430, 635, 65, 1, 27, "Input"],
Cell[17498, 638, 59, 1, 27, "Input"],
Cell[17560, 641, 78, 1, 27, "Input"],
Cell[17641, 644, 126, 2, 30, "Text"],
Cell[17770, 648, 50, 1, 27, "Input"],
Cell[17823, 651, 45, 1, 27, "Input"],
Cell[17871, 654, 47, 1, 27, "Input"],
Cell[17921, 657, 111, 2, 27, "Input"],
Cell[18035, 661, 78, 1, 27, "Input"],
Cell[18116, 664, 172, 4, 46, "Text"],
Cell[18291, 670, 48, 1, 27, "Input"],
Cell[18342, 673, 111, 2, 27, "Input"],
Cell[18456, 677, 52, 1, 27, "Input"],
Cell[18511, 680, 50, 1, 27, "Input"],
Cell[18564, 683, 66, 1, 27, "Input"],
Cell[18633, 686, 78, 1, 27, "Input"],
Cell[18714, 689, 167, 4, 46, "Text"],
Cell[18884, 695, 70, 1, 27, "Input"],
Cell[18957, 698, 104, 3, 30, "Text"],
Cell[19064, 703, 70, 1, 27, "Input"],
Cell[19137, 706, 93, 3, 30, "Text"],
Cell[19233, 711, 46, 1, 27, "Input"],
Cell[19282, 714, 88, 3, 30, "Text"],
Cell[19373, 719, 71, 1, 27, "Input"],
Cell[19447, 722, 22, 0, 30, "Text"],
Cell[19472, 724, 50, 1, 27, "Input"],
Cell[19525, 727, 180, 3, 46, "Text"],
Cell[19708, 732, 477, 6, 78, "Text"],
Cell[20188, 740, 220, 3, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20445, 748, 54, 0, 50, "Section"],
Cell[20502, 750, 215, 3, 46, "Text"],
Cell[20720, 755, 399, 8, 107, "Input"],
Cell[21122, 765, 57, 0, 30, "Text"],
Cell[21182, 767, 47, 1, 27, "Input"],
Cell[21232, 770, 138, 3, 30, "Text"],
Cell[21373, 775, 76, 1, 27, "Input"],
Cell[21452, 778, 801, 13, 112, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

