(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    117079,       3252]*)
(*NotebookOutlinePosition[    142034,       4155]*)
(*  CellTagsIndexPosition[    141990,       4151]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Single Species Population Models", "Title"],

Cell[CellGroupData[{

Cell["I.  Introduction", "Section"],

Cell[TextData[{
  "\tMany of the issues that arise in theoretical population biology are \
already present in two special cases:  single species models, and models of \
two interacting species.  In this notebook, we look at the basics of single \
species models.  Almost all of the material presented here is well-known and \
the goal is pedagogical.  We do not consider here such complications as age \
structure or time lags, nor do we consider in detail the problem of relating \
a model to real data.  The most helpful references for what we do here are \
Chapter 1 of ",
  StyleBox["Mathematical Biology",
    FontWeight->"Bold"],
  " by J.D. Murray, 2nd edition, Springer, 1993, Chapter 4 of ",
  StyleBox["Stability and Complexity in Model Ecosystems",
    FontWeight->"Bold"],
  ", R.M. May, 2nd edition, Princeton University Press, 1974, and Chapter 5 \
of ",
  StyleBox["Ecological Dynamics",
    FontWeight->"Bold"],
  ", W.S.C. Gurney and R.M. Nisbet, Oxford University Press, 1998.  All of \
the calculations are done in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and some make use of a package called DynPac which runs under ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and which is available from the author. "
}], "Text"],

Cell["\<\
\tWe conclude this introduction with a brief outline of the \
remainder of this notebook.  In section II, we look at the standard \
Malthusian and logistic models, along with some examples.  In section III, we \
look more generally at the forms of birth and death rates, and we see how the \
Malthusian and logistic models fit into this more general framework.  It is \
here that the curse/blessing of population modelling becomes apparent:  \
instead of an underlying set of basic equations, as one has for example in \
fluid mechanics or other branches of physics, there are an uncountable \
infinity of models with more or less the right properties.  A comparison of \
theoretical predictions with hard-won data provides necessary constraints on \
a given model, but this is in general is not sufficient to determine a model \
uniquely.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["II.  Malthusian and Logistic Models", "Section"],

Cell[CellGroupData[{

Cell["2.1  Malthusian Model", "Subsubsection"],

Cell[TextData[{
  "\tIn 1798, the English clergyman, professor, and political economist \
Thomas R. Malthus published anonymously a pamphlet entitled ",
  StyleBox[
  "An Essay on the Principle of Population as It Affects the Future \
Improvement of Society, with Remarks on the Speculations of Mr. Godwin, M. \
Condorcet, and Other Writers",
    FontWeight->"Bold"],
  ". ( A number of inexpensive modern reprints are available -- for example, \
the one edited by Geoffrey Gilbert and published by Oxford University Press \
in 1993.)     This pamphlet was meant to counter some of the rosier utopian \
views of that time on the perfectability of human society.  Malthus' counter \
argument was that population growth would eventually produce widespread \
poverty or worse.  In his words (p. 61 of the edition cited above):   "
}], "Text"],

Cell["\<\
\t\"Must it not then be acknowledged by an attentive examiner of \
the histories of mankind, that in every age and in every state in which man \
has existed, or does now exist,
\tThat the increase of population is necessarily limited by the means of \
subsistence.
\tThat population does invariably increase when the means of subsistence \
increase.  And,
\tThat the superior power of population is represssed, and the actual \
population kept equal to the means of subsistence, by misery and vice.\"\t\
\
\>", "Text"],

Cell["These were not popular words in 1798 nor are they now.", "Text"],

Cell[GraphicsData["PICT", "\<\
LP8000000<T0PP0A0_l<0?on0000B00004P000000000b@220000002Q0O805SQ2
BDd000000000b@22Ag:9L6R_HVX00@0:000000390880V8240000003908800000
000000180000B0000000200100P00000000000000000000X0000o`00oooooooo
007no_kno_h00_gmoOgmo@03o?clo?cl00Ckno_kno/01O[jn_[jnP06nOWinOWi
00Ohn?Shn?P02?OgmoOgm`09m_Kfm_Kf00[emOGemOD02oCdm?Cdm00<lo?clo?c
00gbl_;bl_803_7alO7al@0?l?3`l?3`013_kno_knl04Nk^k^k^kP0BkNg]kNg]
01?/k>c/k>`05>_[jn_[j`0Ej^[Zj^[Z01KYjNWYjNT05nSXj>SXj00HinOWinOW
01WVi^KVi^H06^GUiNGUi@0Ki>CTi>CT01cShn?Shn<07N;Rh^;RhP0NhN7QhN7Q
01oPh>3Ph>008=oOgmoOg`0Qg]kNg]kN02;MgMgMgMd08mcLg=cLg00Tfm_Kfm_K
02GJf][Jf]X09]WIfMWIf@0Wf=SHf=SH02SGemOGemL0:MKFe]KFeP0ZeMGEeMGE
02_De=CDe=@0;=?Cdm?Cd`0]d];Bd];B02kAdM7AdM40;m3@d=3@d00`clo?clo?
037>c/k>c/h0</g=cLg=c@0cc<c<c<c<03C;bl_;bl/0=L[:b/[:bP0fbLW9bLW9
03O8b<S8b<P0><O7alO7a`0ia/K6a/K603[5aLG5aLD0>lC4a<C4a00l`l?3`l?3
03g2`/;2`/80?/71`L71`@0o`<30`<30042o_kno_kl0@Kjn_[jn_P12_Kfm_Kfm
04>l_;bl_;`0A;^k^k^k^`15^[Zj^[Zj04Ji^KVi^KT0AkRh^;Rh^018]kNg]kNg
04Vf][Jf][H0B[Fe]KFe]@1;];Bd];Bd04bc/k>c/k<0CK:b/[:b/P1>/K6a/K6a
04n`/;2`/;00D:n_[jn_[`1A[Zj^[Zj^05:][Jf][Jd0Djb/[:b/[01DZj^[Zj^[
05FZZZZZZZX0EZVYZJVYZ@1GZ:RXZ:RX05RWYjNWYjL0FJJVYZJVYP1JYJFUYJFU
05^TY:BTY:@0G:>SXj>SX`1MXZ:RXZ:R05jQXJ6QXJ40Gj2PX:2PX01PWinOWinO
066NWYjNWYh0HYfMWIfMW@1SW9bLW9bL06BKVi^KVi/0IIZJVYZJVP1VVIVIVIVI
06NHV9RHV9P0J9NGUiNGU`1YUYJFUYJF06ZEUIFEUID0JiBDU9BDU01/Ti>CTi>C
06fBTY:BTY80KY6ATI6AT@1_T92@T92@072?Shn?Shl0LHj>SXj>SP1bSHf=SHf=
07><S8b<S8`0M8^;Rh^;R`1eRXZ:RXZ:07J9RHV9RHT0MhR8R8R8R01hQhN7QhN7
07V6QXJ6QXH0NXF5QHF5Q@1kQ8B4Q8B407b3Ph>3Ph<0OH:2PX:2PP1nPH61PH61
07n0P820P800P7moOgmoO`21OWinOWin089mOGemOGd0PgalO7alO024Ng]kNg]k
08EjNWYjNWX0QWUiNGUiN@27N7QhN7Qh08QgMgMgMgL0RGIfMWIfMP2:MGEeMGEe
08]dM7AdM7@0S7=cLg=cL`2=LW9bLW9b08iaLG5aLG40Sg1`L71`L02@Kfm_Kfm_
095^KVi^KVh0TVe]KFe]K@2CK6a/K6a/09A[Jf][Jf/0UFYZJVYZJP2FJFUYJFUY
09MXJ6QXJ6P0V6MWIfMWI`2IIVIVIVIV09YUIFEUIFD0VfATI6ATI02LHf=SHf=S
09eRHV9RHV80WV5QHF5QH@2OH61PH61P0:1OGemOGel0XEiNGUiNGP2RGEeMGEeM
0:=LG5aLG5`0Y5]KFe]KF`2UFUYJFUYJ0:IIFEUIFET0YeQHF5QHF02XEeMGEeMG
0:UFEUIFEUH0ZUEEEEEEE@2[E5ADE5AD0:aCDe=CDe<0[E9BDU9BDP2^DE5ADE5A
0:m@D51@D500/4m?Cdm?C`2aCTi>CTi>0;9=CDe=CDd0/da<C4a<C02dBd];Bd];
0;E:BTY:BTX0]TU9BDU9B@2gB4Q8B4Q80;Q7AdM7AdL0^DI6ATI6AP2jADE5ADE5
0;]4A4A4A4@0_4=3@d=3@`2m@T92@T920;i1@D51@D40_d10@410@030?clo?clo
0<4n?Shn?Sh0`Sdm?Cdm?@33?3`l?3`l0<@k>c/k>c/0aCXj>SXj>P36>CTi>CTi
0<Lh>3Ph>3P0b3Lg=cLg=`39=SHf=SHf0<Xe=CDe=CD0bc@d=3@d=03<<c<c<c<c
0<db<S8b<S80cS4a<C4a<@3?<30`<30`0=0_;bl_;bl0dBh^;Rh^;P3B;Bd];Bd]
0=</;2`/;2`0e2/[:b/[:`3E:RXZ:RXZ0=HY:BTY:BT0ebPX:2PX:03H9bLW9bLW
0=TV9RHV9RH0fRDU9BDU9@3K92@T92@T0=`S8b<S8b<0gB8R8R8R8P3N8B4Q8B4Q
0=lP820P8200h1lO7alO7`3Q7QhN7QhN0>8M7AdM7Ad0ha`L71`L703T6a/K6a/K
0>DJ6QXJ6QX0iQTI6ATI6@3W61PH61PH0>PG5aLG5aL0jAHF5QHF5P3Z5ADE5ADE
0>/D51@D51@0k1<C4a<C4`3]4Q8B4Q8B0>hA4A4A4A40ka0@410@403`3`l?3`l?
0?4>3Ph>3Ph0lPd=3@d=3@3c30`<30`<0?@;2`/;2`/0m@X:2PX:2P3f2@T92@T9
0?L820P820P0n0L71`L71`3i1PH61PH60?X51@D51@D0n`@410@4103l0`<30`<3
0?d20P820P80oP410@410@3o0000000000000039088000000<T0PP00QPhB51<A
4Q<D5A8A4a8B4ACn4fdB51@E4a<B4Q@B51<D51<G4a@C5Q@E5a@E5ALF51HF51LE
8R@O5APH5aPH8aLF5Q/P7APD5QTI51HJ61HG61HF4a@D4a<A4a<D51<B4a8C4a@G
4a@E51LH5ALD4a8B4APD4Q<C51XG5aPK61XH70<I6000Q@`D4Q<D51<B4A4B518A
oQ<?4QDD4aDD4a<B4Q<B4aDC4?hFoaGo5_hG?1DA91P?5QH=62@F6B@Y51TK6bX?
<1@a;BHO6ALK7AdJ6QTG5A@D5aLA4a@B4a8@5a<A4A8D4a<D4a@C4QKn5?lCoa89
4a@B4Q@C4A8B4OhD11TG6QXI0aPG00241a8D4a<@518AoQ?o4T0C50lC4Q@C51<B
61<A4Q8C518C5AHB53PD5aLH5aHG4A0g>STV5ATI5aPF6A8Y4S0?:A0[Hb`C81XK
51T?8QdJ5OhD31LF4a@C518D4A8B51Cn4`lB4a@B4aDB51HC518B4A4BoQ7o4ohD
1QHD5AHH6QSo6?l0Q00Bo1<>4A8A4Q8C4Q4B4a8E514BoQ<14Q?n53XC4Q@D5Q@H
51LG5QLH61TVATHP;C4]8ATBEbDC:c/K;chZ8R1:4B8G714c;RlV7aXD5QDC5ATC
5Q<B4ohBoa@;4a8C5Q<D4Q<F5a@BoQ<C7a<B4a4A4Q4B4Q@G51XE5aLJ6QL36AX0
08?o4QLC51<C4Q<C518B4a4C4Q@F4a<D51<D4a?m5?lE>1@F5aHF51PI4RDe9Ra7
;adk<1`i5ALlHa8YBBdk<a0PJS8e@2h[@T915AT`6AXM41HH6RXJ5a@F4ohD1a<B
51<I4aDDoQ<@4Q<C5A8D4a<B4A4B4A8A5AOl508F5aP361/0088K4Q4D4a<B4a4A
4a4@4Q4B51@E5Q@C51@C5A@D5OhF?1DD5QLF51/D4CTh?1DR8aU;5UL[MR8H;9lX
ES1GJRU3O5Hl>3]DC2lB4AdH4aPM3C8:6aTG9ADC51DF51Wk5?hC2a@B4Q<B4a@C
4A<B4ohA2a8D51DF51<D5AHE5`<F6P00Q?lC1a@B4Q<C4Q@DoQ8<4a4A4Q@C51@F
4a8C4ohE>aHG5QLG5QXJ4Cn9Mi>;R1XR4TLW>Tef=4]DTTh?NcD[NTQ?42/T>SlB
52@V9RL]:2e<<4<i;3@X7QhB4ohD2Q<D4a@C5QHE4aDEoA?o4OhB0A<BoQ@:4aPA
5AHE51HE61P361/008D451<E5A?n4P/D5AHE4a8C4APC4a;n54HF51DL5a@G6ALH
5aHH6D5TK5eCJc<m@2@HOBiBM49UH7ACAeUBWD93<ADg85<oEDQF=c8`<AhfABHR
7a<L7CI4>a4G71HI6?hDoaH851HD51<C4Q8AoA8;4a@E4a@C51DD5QHDoQP06P<J
6`00Q08I51Cm4olB21<E4a8@4A8C4odD1AXF5QDK4ohFB1LI6R8O;gIAGG1V?1hc
AQ/NIQeFP69:TEl[G6N=GVP/@D4lCd`V7bl_:d8fBA@G9RHR6adL7QdC>2lD5QLK
6Q@C5A@F51<A5A?n51@B51@C5Q@F51<H4a@E5QHE5QPG61P361/007oo5?dCoA80
5?dC1a8C5A@C4Q@GoQKn54/G5QLG4bi3Ff]gBR8mDC0d64XKISAdH7USS6E@MHaM
L3TnNXmiPEdg8RPF:2Pn=40G5BXI;1dK61dK6B/Y6ALJ4S8D5aHG5AHF5a@DoA<B
4QDE4aDD51<D5ADH5QDG61HG5P<H6P00QQTD4Q@C4Q8C4Q@C4Q8C4a@A51@F5A<E
5aHF6?hFBADG62H^GD]4=2a:H0`bEh@jIDfAGViZH99JMXRjAIiIPZIJ9C0W72Tf
8AT@71TR6c8V92LC:2X]6A<i=BdV:bDM6ADG61PG5QLFoQ@>4a8C51@E4a<D5AHD
5aHEoQH35aHG60<I6000PohC418C4a8@4A<B4Q@D4a<B51@CoAA>5AHG5QLH6a`e
@gAVMWUT9BU`7SfSJV]bNY24M:2MLf28Gj9QSI5=OXQmRW9EL7TmJT`T82M?<Q`T
8bdN5AhN5ETID38i724]5aHE5QPH5_dD518C5A<E51<A5Q@C5QDD5QHH5aPB6P<H
5`00Q14D4a<B4Q<C4A4C51<C4Q<B51Gm500BoQAF4QLF6AHk@d8dEC`VA5LhAgER
cTR:WVfjOhZBGdo@GG2OT8ELYh1PAalY:R8f?dM5LUm662e3:ah;9d/@:2`VJ2<K
:dDL?R<J5QHJ61HB5ADF5ADF5A@DoAKo50PJ51HF71HG5aX361X008@34A<D4_hA
oQ?o4VXC51@@51@C5QHD51HF5b<J6QTB;DI2M7IYAd8WIFaWGimaQXbcUi?2HF=m
JXRIVFAgMXI?=TM=;3@Q:Q4/2BmC>S@Q8T/W?58GD@Q3;4=9;ahj72/R6A/J6QLI
61HG5A@G5AHD5QHG4aXF5?dF11LF5aPH0aTK00202a8A4a<B4a8C4Q@C4_TDoaEY
5QDF5aLH5214Ie1fH69ZNVnCU99cQZQZO;2e`fmgPVeBRhb:L:6HID]XHjjGFeEQ
?Shd9RY1?Ta81C4Q6SMT;clQFRE;=Q/M?4<j4RDX7B0K61HG5QPF5aLK4aHG5QDD
5QTH5QHG5QTO5_lJo`26Oa<B4aDC4a8C4aHE5AXD51<B5AHD5QLE5aHF61dAH920
If9OKTe@OXYbThfMRkBoV8BRTX:IQH=_L7f1PV1JQi1HDe`M9BQ:=Ddb;AHX;AYR
@T`C8d=h3b5C95hO>4@g52hV6AHN9Q<J61TE5aDG5aHF7aLF5a@G71PG5QLF61`F
0alL00263A4B4QPA4aHC4aHD5ALFoQA^5ALF71LF61TI7BHgLHE:CE:3Qfn8QlN`
QfkR^gj_ah2UM:2EMGEMHW6:FF^DOF61OT<G:RPL82PX?44W5RlXIGa<>amZC1@o
7DHO:1==420K7QTCG30O5QXF4QLH51LG6ALI61HG51LG6ALF5aXH0aTH00243a@C
51@F5aPG61LH5aLJ61Km65HJ6aPH6QXR:Wb3HfFRLGmeXgYbYIbidjVAS]7<^Y6:
X91kIge[KIQ[TI5`T6E7NUHO9Qh_;20Y8S5F>4IVAgHkI1mmMB5CDU0`7R]46bXB
6C13ABLM7Q;n6_hHoa[o60XG5QHH5aPE6A@J5@<L6P00QPHE4a@H5aXKoQYe6aXJ
6aTJ6a/J6QdN6a/M8S@oR4R5X7JKMJf@Q7Bl[[S2[]G2_;:bf<28WGN6N75hMZBB
IH5cMUm064lk<Ql/;4XU<C<X:fV:FbEmHDE?91dF6da>:20h7UPe<45H;28Y:b<U
7AXJ5b0L6QXH6QTK71/J6adQ70<T8`00Q@PE51@H5aTK6QWm6W8K6Q/L7A`K7AdK
7AdGHFePXhJ6Tl30WGJ2/k7:aLK=MMOD//J/U/>MWYQmOj:DaDV1W9bRN6EV7S<a
:RXf<Se7=38k:Qe_IEe>KSHa@3XK629`;RTkARULB50M:SL^:BHM6aXM71XK6ATJ
7AdR6A`I8ahM0bDP0024oa@85QTH6Q/J61TIo1YR6A/J81dM6ahD:d1OLZAQQham
OL^MSjN7ai60]I5hQhb?L;?JRg9]CZ1bZE^QYhZ1MfaTF34d<2Lb;BXoDT54Cg1:
@E5>Rf9M9RXg:bHH9fLbK3MCMbYH52dlAS`h7C4T7Q/KoQ[o7@LL8b0J6b0U6`<T
8P00Q@0DoQKo5``H5A@F5aHH5aLH4QLHoQYK6B8LL9>6ZZ;2WH?S[Fj?Pi78PXNB
U8^;UY6_X[f2EW]XchRBML6NLfe[OgYcA4HV;1`W8RPT>DiGA1b5A4Qa=cQ<>2`N
6BaL>4MOSEmCC4A_7bdWACMH;AT[6aKn604E6OhJ1ALJ5Q/K6OlJo`253a<D5QLE
5QHE5AHG5QLF5aSm5e/J61==S7n:OIFl_9O:MIBAVhebbWQdQX^TLi6;/ZaYKK^;
TenQZ7^1Jgb;QVQTFfQ:A2Tk;dPM92U9>D<E>7QZDHTYR2T/:AhQ<f]KITnYBC/Q
@BDTCbE]:S8Y5?hH31LF5aLF5aTH6QTJ61L36aT008H34aHE5_hGN1HH5QLH61LL
5QPG6ATL5cF1Ki30Y<_6ZZEkWX]nPgYc/;mXOF]`Whb5OG5jP8MOSYaPE4iNLGES
A69[GD`o=1Xb9dDg?TPP9EMbA351CFi69B@O?c=8>5b7;fjW=ChR6Q`m8T`^BA`Q
:1/G61LF5Q`H5aPH5aLE61L36QT008@05OhFoQOn5_lGoaYU6ALH5aXK5BBCRH>_
a;9m^;ZVXVZ7KgecQ;jRLh9lF61aGfaWHYQ[WJ=NMfIRLF6?J7]XBfYjB3HE4ah>
;Da@LBHnB7/eAd=6LBX>BPiG?85IV6:=MRTV<R4T:bHn?DXE61TN5QLFoQL85QLF
5QPG6APH0aXH002401Cl5WTG5QLF5aLJ61PJ61HH6B8SJiFmIkK0_hV:SgnDM6Pj
B82P^8F6Oj5]KGMeNGAVK6ANHemb[X>1M7I^GEE<BU0m:Q/L71DT7S9A=3e6EedM
BV]>54Y6>TE5Pf@aU8D^CQ<P:RLn<dhb9QhF:bLM5AHG61DE5QHH6APH6@<G6P00
QOlGoaI_5aPH51HG5QHL5aPG5aPH5bUkU7Fh_Zb1V;:JPG2XKBQ<=J9mN75AT7QX
STf1KVEZI6Y`EW]KLIRNX7MaHU=:>RLi@A/K71dP>CLZD40k?4Y7<T=DHQj7@UlY
be=ZKf@h=APC:2@C<DL`8QlD6R@H6_dGoaGo60<I5aTJ0adL0025AaDH5aDH5aPD
5AHF61HE5QPG6Q/X9YRe]kBachJERhA;WXQKAd:UPFMJCWLiFUY@KEmVJGE^F5e`
NI]RMW5XMXm^C4M4<1XI7_dJ<b<Q;V8H>B<R?4U0@eA9>UUc<Iil?7]RDS4Y=C8N
710I9A<X6Q@g51XF518F4a@G61PG61P371X008Ko5P/H5aPG5Q@G5APG61Kn5fhH
6a5jOINM/[FoUhadHZa[HCLRLW1eKW=c>f9NJTE6EWY@FEloFfF5HI6NR8e5DRl/
62lZ8alL71PK624]8TX/5R0X;c0a=3PW>RINICm`A6]@Md1;A3`G9R/V8ATM6a9K
8AdF5QXF5QPX:Q0J61P36Q/008D151On5P8H5A[n5flF61LG5QLK5RMn[Hg2VI6M
Sgm>UI8SR22REXaGCF4jHFDfGE`j=4a7C4IALdAcSWaXWHNKOZ4eAbTZ824O7BhD
;A`P7T`W7bdF92PX92DY9bXa?R=;=5e[Nd1TDd8aDcXd8QTJ6`Y?5bLG5a8K5AHH
oAX05`<J6@00Q@0FoACo5olEBALF5aPF61PJ6QLbNJ?0Z8k?R89LGK@jRTDkSF]N
O4YLJeYZFEeP=d=@:CAVCU9C?dIOR5mGDcDm=Sm:<alO<B4Y=Q@Q=Q@o81lLoQhY
72@/8QhZ720U9Q8h?XY7IhALKTiDFDh@62DA?R0X61PF5A@G5aPG61LG0aPJ0026
DA@F5A@D5QHE5QPE5QLG6ATH6PR4WJ?>Y<60_8Pl[G`UQba_NFMRHf55ESe/HChd
DT56=bA3<690CdIN@Ea6JVI492dH?F/D:2`MGBP^<14Y7Aon7R<M71hU72<Q73HW
:B/^JDQZOV=2HS]W@Y8/5b/;HBlS6ATF5AGn5`<L5aPJ0aPJ0024MA<E51@F5aHE
5a`G5QLF6QTI7@^6MIfE_/JeNY5dP8A[Q76;MGERGFISJF]UN54hDeXi:4/d@c<o
;X4i@D4^=44aF68Y<2e56R/K<R`W:CDK7A/J6Q/K6QdI9aPL7A`N;dP_DeabJT>5
@C]c=Xhk424LFR@]:1gl5`@F5aTK7`<F6P00P@8D4AGn5P<G5ALDnaMU5Qd[PX^e
`<JbRgZ3HW^LDib4S6f7J6ABFFiKIUa<=Sh]A40V;aI;Ach]>BP_C2/h>BHhD3Db
?bdS8T`V71lH6aXF6AXL6aLK6aPJ71TN6b@RDeMjCDNKKeYLJDBV41DS850a?2@L
o1P46QPI61X36QP008@14aSn5OlFMAPG5aHH5aPJ5aTQ:j5n_X2Y_kb6DYFQ^f]U
O9QZNgQPIUAAOh=A?Clh<3HQ:cT_830S=bM=>3Hi@b<W74@T:BXY:28P8QTK6A`J
61XO6Q/J8aXR7Q/L7R<R<SHi>D::Pd5KC59hWbHZ6ELl<AhV6alJ6AXJ7Acn6_lJ
o`251QPC51@G5QGn604L5ohJJQTH;Wb;^[n5Uh[>Q;M]W:B6OEMjRgJHO6J;I7M;
:e92;BlZ>BTR8S<a;3927C</;aTc6RlC:b8P8RTI6adI6aXK6ATJ61TG81XK7A`K
7AhJ8BLgP7IlH5m9CV4oUUX^;cHU@c@V7Q@I6Q<HoAX16aH36Q/008;o50@E51HG
5o/HLQHL6QAPb6fkYJR2^gRGNj2]T8A/Q6mOQXJnRgEED4eC=2i:8bX^92HT5B<]
:2HU9b@I8bDY7A`R81TN7R0J71XH6QLF5QPI5aPK61P`7ATJ6aPU91m1@4m0=3=3
7WiOAB54=C4LHQ0L6QXG5aXJ6APJ71Wo6_l0QDTD4aDC51LH5QLH5alK61/H3Z9b
bl6AUhnSQMel^GBF]5n5EFf5N5iFNCU?@BE4<Q`c;APh9BXY9B0M7AHT7ahP81hJ
5a/N7A`J6_hG1aPI61LF6QPGoQXP61`K5QXI61dK8QdD3B<^:4Q`Hfe7=C8V<a]e
7APK6QPGoQ[o6@4J6?lJo`2421<F6Q8F61LH5ohHoaYZ618nZY:[Mif4`[RWN;6;
O8>fS7m_Fdm]LF9e>TD]<2<f>RT_=RXU8b@T<1`J:1TO6A/J7AXK:1/J7AXH5aPE
5QPJ5aPJ5aPE6Q/J61XI6adJ7BLV6Bl_=3]7FDeb?BEg;RdFT3e55Q`H6AOl6P4K
6P<L6P00QRlI5AHF71LF61LG61LF6b<eEJ67]JW5W;6A`[nPZINBPgbOW7QaGFMc
B50a=CXe;bOn:THW9A/L8Q`O7AlL81XJ7R0E6Q`K6QXK6QPG61HI6QLF6QLF61XJ
61TF5aXL6Qd^9C8f=D58PBa@FS]f@BU3I0d8AQPJ61PI7?hJ0Q/M6`<M6`00QTLD
5AHF5aLI5aHG61LJ7STc>KR7RK;@XLj8UYIgVH26QJMgOeiaNVAI9bdjAba1<B`F
9b8V;24X9QhI6adN8adL71/N61XJ61Sn6S0L51PI6ALG6AXH61hJ6ATG6QHK6QdN
9B`_8cTbBVPnJh=fDUD_4Qh]:B8M6QXI6QXLoQ/070<K6P00Q?lDoaLl5QPG5aHI
61PJ62<ZJ:NH^Y[3a<9oNibaN8AfLgZ6VGZ3IGeEH3Q5<4@h7C<Y>2TT8QPL7Q/J
61TK7A/J6?`G>APF5adI5aHH5QDG5aPF61PG61XI6QTG5aPI71Pb9d5JJe>DTZeF
:5l/5D=>D34K6QTO5QXJ5a/H6A/361T0087n5O`G<1HH5aPM71PDLG:bVjV]/JnU
X9Z<U6a@Id1ANWmLJUm6:C@/=bi9<BdP<BXT9adI7A_m6_lHoaLn4aHI61HE51@F
51DD5Q@D5aLI51DJ5aHG6QTG61LH6AXQ>S0`CD1DJfY=?ePg>blb<AXQ71HH6QHF
5aTG61XI0aPJ0025oaE05QLF5aPG6APH6Q`K=CeSW:FnV=5h^m>5WiZj[g5IOXQn
HFUSAF]>>cM9=RX_8D0W;A@X7BdO71XK61TI5QPH5aSn5olD0a<G51Kn50XF5aHG
51HJ6QPJ6_hH8QLK71XI7RA<GDUfEUaWG5Qe;A</9ade5RHA8aLG4aHG61PIoa[o
08?n5OlDoaKo5c<H6AXN8R=5JkAm[;^`dIFS^Z2CQjjiUjZPNFIBIg<oBS`Q:CDg
;bdY9b8e9APM8AHK7AXFoAL861HE5Q@F4aHGoA@/5AHG5AHF5ALH5aPD5QLG5QXK
81PN52HP9BL/BeUSJTYjG28kB2LQ7QdT61HFoQL161T36aX008EA51HE51DG5aHG
61LJ7QTj?82^W<6?[:niSj=bQIBGRIinPeaoHTiAC4<k?4<c=2dG9R`V9R<F71dP
6AXH5QLF61HG5ADF51HD61HD4a@D4AHD5?dF:ALD5ALF5ALF61XL8QlO7QlQ:D@i
=fIWIC4_71@H9AHQ7BPJ61HE5QTH6P<I6P00QTLE5QHE5QDH61HI5aPCCR/SOi2B
`KB/X/VkT9FGVXZ;HWmXPW=gPdI>?b/h9C0h92lU:RlP7aLM7Q/G7aXH71PJ61LD
5QLF5QCn5PdG51TD5A@E5QhG5QLF7?hH8aLF6AXI7AlR6APQ8c9X>e]lN99bG4Q/
?R<H8AHG61LK5QTH5`<I6000Q?lFoQE<5aPF61XH6Q/ZHUZ1Ujj:cK:WX/?9bI^b
X8n2b8AWR7mcME9>D3]4>bT`:BT^9bLN7ahP7Q/M6aXF5QPG5QHD51DE5QHG5aHF
5A@G5ACn5P0GoQH961LH5API6BHL6_hM6AlC;bE3QFZDW928O6<K71/N6AXJ5QLF
6ATJoa[o08Co5SLG5QDH5aHG6AHK71DIKXFZXkNM`K:o^Z6I_]N<UiaCHhmeDG]S
BEE8A3`U?CL`;2H[>R<Q9R8/6?hJ3ALF5aLF5QDD5Q@H5QLFoAL15QCn5B/F5AHE
61DG5aHF61XI7AhM6A/N8Q/`>ba7?TPmIS0m8RPM6a/J5QPI6AXK6_lKo`26>APE
5Q@G5aPG61LJ6Q/W;3BLVY6:_jnUY;BR^GZAIXb6LFe^HheZFV1;@U<_@BdY;2L_
:2<S8QhM7B?n6RHM5aTG61LF5Q@F5Q@D5aHG5AHC5QLF51HD5QLG5QLH5adJ6Q/E
6RGn7APS93I36S@`SF0`>R@[91XK6QLJ61PG6APO0a/J00260ALFoQ@a5ATH6QLJ
6AdKNH>C]9G7VZc=]/nd]<ajRfn@Pf=[Mg5ZAEI<@d@e6S4d:34/;B4Q7Qkn6TDK
6AXH61/J5adD5QLG5QDF5aDD5QHH5aLF5a@D5aLF5aPJ5aXI71/J6QhM9R@W=R/d
>CI>I7Ug@4`/8bDQ9QdJ5aTH5aDK0adK0026B1@E5QHD5QPH6QPK6Q`/8bYhR:^Y
Tijdd;Aj_YB/OJB0FYQgLV1VFgMHFT@X>dDZ638X6BLX81hJ6aXK6Q`K6Q/J61XJ
5aLH5aGn63<F61LH5QLF5a<H6QLG6QLJ61TK6b0J6QTN8A`I;bdR?CU4I5JSZ81O
?BDT7A`K6AXH6a/T0aXM002501Cn5@4D5ohJMQ/M6AdJJ7B0`9Ze[;RZ[LFkaic8
UXYdIFVMK7iVG4MC@TXe;TL_BCHY71lX8QhL71/M6QhP61dJ6QPI6ALJ6aLH6QTH
6QXI5aLD5aLJ71XO71TI71/N6QLM7AhV920[:3U4=Rl^C5]MBEaS?ClZ8B4K6Q/I
6a/Moago08H25AHGoQKo674G6QdR6QPP4gn_b;ZG^j:S]Z?;]9=VM6akZFa]KXi>
Gf98@dA3<B/a<2`U8Q`N7b<J6B0J6aLI7aTH5aPI5a@O6QHJ6aLH6QLF61<G61/H
61/N7A/J6alM7RDK9b0S8bT];CP_5D5DHF]jKWUBA1<Q9Q_n6P8H6QX38A`008Hh
51HH5ADG6QTG61TN7R@l7i6U^/^`/=20egIkOVi^LiZ7KFEmHXPmGCMO<3PR;3I4
8b/T:RHH7QdKoQX:71TH6Q/I6AlH5aSn6PHK:Q@G6aXIoQL[5Q/J5QlK6Q/M7B<N
7APO8QdE:BTc;DdU;TY3DgMjU6U?@C4T8A<M7ATG6AX371/008ID5AHI71HG6ATD
61XN82D_D[c1WLc9^ZZPNXZ=VfjFVUIdLXYTGVnBDfTgEB`_;c4_<BTW:QlK7AlM
7A/J6APJ6adH61lG5QTJ6AXJ6aPJ6a/G61PF5ohJ9a`K6Q/J7QlI7ALP81hI8bT/
<c0]<4//:EZ@Xe5@>B0T8C@T;1DG6Qd36aX008Io5ALF5aHI6QTG61XL6a@L@Z:Q
bJ?9YjbOc75`PFj0Ih5cMEb6GfIIIEiI>T8e;C0Y:BLF8bTL71hT7ahK6aLI6a`H
6AdJ6ALG6QPK6QTH6b8H5aHG5aXI7QLJ6a`J91TK72<R:B@N:R`l9C@K=UD`<UYL
I/2=D3I4:S<X81HG6Ah36QL008Io5aHG5APH5alH61/T6aTg=YW@^:R/^ZS1P8R3
PiF=NFmWKfihFheFFd5A@D@l?C@[:2TX92@N<2<R6R<M6QPI6Q/K6Q/I6QXI6QDK
6QPI6aXH61XH6QhM6QPJ7B/L;24P7QdT:QIB;1hg=R/b;S`j;VQY>fYSKf<[<1dH
6aTI7Ah37AX008Cn5T8E5aPN6Q/J6BhX<EV6`JNnakS>cho2SI2MRIQYN9EaKW9X
GW=9JW4kCchk=bHS:R4V92PL720N91hP61PG6QPH5aPKoQXf61/I6QXK6aXI61XK
8A`M724L6RXM71dJ4BPTCDh_;34Q=Rh^>3e>Af9ZMDh`9BXR5QLH6Q/J6olKo`25
oaCo5SLE6ATH6QPF84@dIF>aOmJhW;jo`:ioLGFJLGmoEDb8Lg5mHG=METPo>cDd
8B@T8BLR7b0M7a/I8?hJ@1PJ61PJ6QHH61XG5aPF6QXK6aXG6Q`K6A/I7R4K7a`M
6Q/P7B8W5R@i7Ca6<cXe<TE=?SXj55<Z7AXH5QLD5aXIoa[o08@45Q@H5QOn6S8I
6QXN<4MZLhmd`JZ/]i6o_8:HRiJFJFeYJdUnJg9eK7IADRm0:R8M7R8N7adI7R<P
6Q[m6d0J6AXJ61TJ5aPI5aPJ6QPF6aXI5aXY7a/K7AhL6aXI5a`K6AdK8R`Y6bPZ
8T8h>T5ED65;M4@i9ahF61LH5aPH6OlHo`26EAHG61<G6Q/J6Q@P6BHSAfn=ZH6h
WjoGPj>1SI67GXI?VHIoPFA_K7aBE4I7:RdY9blO7QdR61lM7A/N61XK6QTH61/J
5aPI6QLL61PK6QTI61HF6QdMoQhV6Q/N7Q/I7AhM6A`P8SHY>APf8RDk@baUDV]<
@cP]6ALD61PG5aTI0aTJ0026=Q@E5AHG6QXH61TK72<P:5N3aL6aYIRkTXB=KgMi
PViINgQeM6UlI6mAB4<a<RLS828`8Q`P7Qon7@HS6a`R7QdLoQX561XI6QPGoQ[o
62PJ5aLF7ATK71/J6Q/L9R@L72PJ7QhX:2XX;cla:Rm4>e=KM:/OAC4J7?hH11TG
5aPH0aXH0025oaA55QTG6QPH6QTI6b9>KIaKYJFaKin^^jmjJWacBUJcChIeIfeX
PHE>7Ua2:SD/6B`X928N92HP8AdR72<M8RLI7QdR61/I6_hH<1hI5aHJ61TI61TJ
61LH6aTJ6a`J6AXJ71hR9B@]<1d]540i;VLjIe5kCaHb6AhM61Wn5`0JoaSo08Dn
51<F5aPH6ALG61TK7QmbCXK;Q:NgOjnP]KEoRYjDSDVDNWb4Le:7HdmN?C8f;ahf
;b@/7RPg;BDI8bDO728ZoB8l81`K6QXH6R0X6ATH6aPJ5QXJ6ATG6APH6aPJ6ALH
6QXK9bL/:SH]9S0n<3i<ND5?G5=E>c<X7QLF5QLH6`<I6P00QOlD@aLF5ALG5QPG
6QPU=69bTLB/VJW6OGN6T8Z[Khf8LGV6H6jBLfI[DTXl;R<[;bHk?D/k;c9793La
=bPM92PR9R0R8R4MoQ/>5blD61XO6aLH6aTM61/HoAXS51/K6QPJ6ahR92<]AS0]
;Ta1GTi6F59D>65W=2TO5aDE5aLI0aXH002541HD5aLF5aPH5aLH7cPGB4^3oJE;
V8]iX7N9SiN=TW1iO9alIXUbJ5<j?Ri9>cAKBeI9E48i;TPo?ddn>R8W9Ch/8b@O
81dM71TR7QTM6R8J6b@S8B0N7A/L7AXJ6aPG6OhL6b8V;c@W<C0a?CTf=YaC@5A2
<a`O7aXH5QPG61P36aX008El51LF5QLH5aPN6APU;4=MN7^`ZKb/YF[0PhR0QW^@
MIEdKFB<AHN=F5M5AT58GE`i?c/c=cHj>TmQADQDBc=77cPc:BTW91`L7QdT<a8P
7QhI7ah_8R8N7B8R71`T8b0V8blc92@V:BM7=2TZ9cUHCTYJ?3D/824N8APG4AGn
60<J6000Q@4F5OhGMAPG61/M7A`F765]WY6hNZNEIh^?RH25OgaUSFZ;O7RLOH1D
DC/iCU9B@C51;b<o8TDb>2aG?5XnL4/o;T0c92PT8Q<R7BHI5QPT7Q/S6bHR8aTV
:2TJ<R97?2l_@Ad]:1dV<b]39C`U74iCH3AY;Q0I6AdK6AOn604F5olFo`26MQLF
5aDF5QDU71`M828kCfj=]k^BVHIKWgRJRVJ8KGYgLgR3N7QQOFMI@d5NEdM==2@a
;bdV<cHb>Di<BfE0HDAOC44l=24U82P/91/J82PN8R4S:A`_;30^<c`k?BHcBdL`
;C4]<C57<SX]=cHUE4YWCSi=9Q@IoQX55QLJ6APF0aPF00260aHG61Sn5gPJ6ATK
8b`lMF6OSZUlU:9oMYIc/XZ0MGJ:Qg>6Q8>=GeE?C3`e>T95=2hc<2dZ;BPZ<3Q0
CF5lLX9CE4QB@CPG>c8/9Q/N8b/Y9Q<R=CXb?C/mBcm3E2]:>4Ti<2PZ;bi0Ecdf
8U55EVESN64R92@i9QXJ5aPG61HD0aHE0026AADF5QLH6QPE6AXJ7RdaO7V5O[:<
UiEhQI>FFWn=N568MWemNV1oLXE:DFE>C4Y2:CLb=BL]>2Lc>S@oD5I9EGY]OVQV
>eCn?3H/:QhK;3LY:B0[F391H3e@A3i3ASd^71lX;RPX>S<jFT4P<BQD>69QEeMi
8RHI6QhP5QHH5aLF0aLE0026Oa@F5a<G5aTG61hJ7A/QY85m/IfUZYA/UfbHP7AN
PGj3S8aoU7MnLVUFAU]4DfdY@bX_;b`Z92XR>c]PJUahNfF2O8B1Ie4g<AhX7QTM
:2@V<R<h?3E8CTa>@d/Z>cLW;2HV6bTY:S<e>5@M=Dl]BD]WJWhA<4LR7b0N4QDF
5aPH0aPG0025oaAL5aHF6APG61HJ5aF;Sh=lTHBaXj[?IXQgVgQfYG^1RXb7PH65
JfI`CE]KDc<d;CX`92/P8S4f=C8`?TU3LVQfPGaZM7I>@CDT8alK<RhQ>BE;MFbV
DU<k>3Pf;B`VoBPL:BX]CSMFA38h>ca>GV9_A6Li52`T8B<G5Q`H6AP35aP008Io
5AHH61LH5QHI61TLL7MhF5J1`[RBHmM_LY1ETGaNO8Q`QW9dKFIHM6YVC3Y>BCi3
=SA6>RDh?2Pe=30V=DI7<5N@QkUETVlj?b4V8Q`V9dDn@g5hNG0_=SXa>RPL8R/Y
7CTa:RHdCeL`C3le93YCG59R>2A>Fbd_>ADH5aPG6AH35Q`008Ei5aTH5a@H61LJ
6QTKPFV2QGEFOX_6^6RhRf9NIG9oRfZJMW^3Q8=[R79ZGe58JVECDTMQHT]KBDMN
NE=bNV@h>S1ZHX>PPfm1<c/X91DR:BEVHheZAcdb=b0X92LR;Ah/:RHX<RX`:3m/
BTI<@TEAGhln@4l:4Q@T:Q_n608C5QOo5ol0Q@0EoAQj6APJ6Q/L;ZB8NZiRJFBC
X=[4OH]eLGYbN85iIXV:KX9iVI=aEE]CKFmlR::gTY[0VJ^MVGeQ:CImKe4Z<fV/
LXF>Ge0_8b@M=B=1FFBM@f0^;bdP61P/;b4W;a/]<3@h=34[C6E:>RiECW1[M3PG
<TTU62`I61TH5QHG0a`G0026oaLS6ALP6QXG7a/C=g^5T[6<LW=dQ8bA[He^Tgf@
HWifKUiUVg5hoWeFJdJTSHbSZY:LU::Jd7;4[;nX?BLIMVmP@5>1VYijLCTe92/S
820fJ5e9=c@b?CQ<JCPh934Y=C@];Sdd;c8/Adi]<C]8AWYVJW8c=A/S91lJ6QPJ
5QLH0aLH00251ALF5QLH6OdJMADXIiNAYhIcB7JSSGB9N9=hR65WGWA[JU5_FG5k
Jhf3W;6MD8nNNEF?Z/?;UDfc9@]dQ1<WGg9]C9N5Rgi8MShX;2XW8c]oIS1WDEQh
I6j?V9OQY9]ZO65D=B<mDDM>Df<YDdQNBU^7VSA1;AHB7`lG8AXG61T35aH008Io
5AHE5aLH6AXK7A@jUjBM/IQiHee]WHJ8QhYHDFQUKg5/JEYPHfA`Q829SiAOV:1N
IV20QHRoc<i[CA<HNWDn8c6KGG=iOi9TMT@T;2XZ<7eRAUIXG3h`:F6gUmb>[;_D
_;BTT6Tl?4YGDd0mGChSE79SMG11;QhS:0m;<ATE61L361D008H45QDG61Kn6GLH
6A@SRi2TU8Z=Ei63KG]ZOWEJS41kR7]/Ee]QQ5J0TH^QNV^3XXJ8M5]`fVj?M69l
?R8SJ2hl;aDoQfYW[7ULC3X_92PX83IEFg546C]_TIIIR7C?dP2l`D:EPYEaE5IH
HTDn:Sh/AUY[FgQPGD4[2dD`L`dH5aH35aH008Ko5P8H6QOn6?lJMAPSPXRMT7Mm
DVJUTiejMWEOH6=iIWAYDV14FUeeNG=lIEJJPW9^I:1LSj:HLY/n;ReNC`hX:QTS
J6aeJHR1HC`Q9RHU74UIODLG7hHB4hA@ReQo/lFbX0h:KhR3SEm8Gc`f=1e@DDN0
M6>6K6Q1EB/H9QPF5aH361H008Ko5TPL6API5aPI61LLPHfGLEUeRH6:MWmRK4]i
>cmbKG5KQ79MESIiG8M_NWmcOJ]77c`o?6a^Dd8O9d0k?3/e8de6FhQQHGnEI3dY
oR8a:3Y>J2LW6c/]5:IPF:9VVYAmGVA9W:]^UWaJKA@K7T=BKVhRDfI=HUm0B2hB
6QTF61P35aP008;n5_dGoaYf6AXORYQoVEaURXnQVge/CdIE<E1?NEeYTUU?@H]]
BGV8QIedR6fBREQ7<R<H8a//<cH[<BTY9cM=JF]eRHR=A2/Y9b8R8b5I>bXY8aPT
9c98K:>6Y:a_@RQTRUInR6`a71<T:2idGf1XAS0i@D`^91<H61LG5Q?o5ol0QP<H
5APHoQMb6QPJ6AUeOiF?AgQT]G6IVeAV?5MJ@hinNgAhPFQRNGa^J8IkK9IcIFYM
I4aRHc@V:2/X;2P/;28W=VEGPH=VT9=29CH[7APY:E0Z;BlX8R<T91XG5UAOGca7
KgA@?4m;H1TV<RDL>cJ3DUU]:bd_9QHN5ohH0QLI5P<G6000Q@4G5OdHNAXF6QTJ
3dR6LGaPC7f/WkMgTTF0If9LIGF;OG=KLemKCfaECTUlUFe`HDXjF4@/=RDV9BPS
:Ql[9RDOJeaCNG>FMDlh6b0T:2@W>S0/9BPV92dF7B4S71TY;S8l7BM1>V]8CSD]
<RhmGf]FE590<2HT8R<K61PJ5aPF0a`H00240AHEoAM36QPJ6Q/CCX^RR6Q?S;jH
U89XNXj0CCmZK5VKKhA?EeI;@S]7NS^9SUF0AgDh=cX]:1hY8RH`:CXJ7TaA:VMX
VHQlJS_n9P/T8C0S=B`Q8bXQ7akn92<P:RHO;bM<@dME@c@X7RL_?4mU>G1hDbLa
>1h];aXK6aTJ61Oo6?l0Q_lDoaMk61XH61lK6aPkTHBQKg:3X9f6QjN6GDATGfY[
Mgn7MFEaB552>5PfAf^3K7YGC5@a=b0Y=B`Z:BPV:C4kB6YROfeIRjUE:b/U7RDV
:BHl;2DV@RDT9RTo;28R8bPb>R`iAclg6B0R<24l>UiJ>fE<=B@[;B@R6QLH5QLE
5P<G6000QWlF5AHG5QLF61/J5QdPPH5XQgmj_:nd]79dHU9;?UYCKfN9HFeCFC9B
GT0^<EEZGe]FLE4e?BP/;2P_:BP/;3E:?eEMFVV4_F]0>28M8b0U=TPQ:RDH=blb
=RDe8SXb:BLo9d=3Gb`k;bT[:CDoBgYLFVi88DX/7alL6APF61HF7P<G6@00QOlF
oaL261LHoQYe71hGTgmmK6N__:>8SHN<HU@aJEIGN:n8LVm^GE0k@cXkC2A@FS4o
D6MS>bDe<bP]<B`]93/n:eQCGE^2RhU[<aTL8RXY;Ta1;B8T9S`h?48e<a`Y:Rd`
@2i1HVi::S0n<CHnEUYLFUQ8=d/m5QdK5aLE5a@F5OlFo`25Oa@G71LJ5aXF61TJ
6Q=fTWQUd9_3Z/^N/WN3HEMF@H65IW]IRG=CCS@l@BTj?SY5@4dfCU@Y?S=;<B`a
82I29ci7C5MXG8FVOf<n<b@Q:RT]?E@]:2PU:bPa@cDQ9bTL;R92<2m8C54h>2H^
<d4lF5ia?5X]<RXN6APF5AHF4AHDoaKo08Ig51DD51PG61XJ61/K4GN=JjagYjna
^9n`NHiH=TA/AiI[MUe/Ng0fEdXmEC`h;b`h<B8l@497?Rl]9bX^:Ada?C=<BGAE
Ih2<IS@Q8Q/R:3@f?c4X9ALW:2`b>30/;BXW<dHB=d1A8T4Q=DP]CDMAAEI=ACLU
71dGoQH45A<C4Q835QX008404ohFoASm6W0AP6>AJHNj^HV/RZR;PGRHQ7AGVh9a
KV]`HFMXACI3>bXb=CHf<bXl<2/`;2`Z:RPZ:CA;>5=dDY1cKXaj=bXW81DDB3/d
@Q/`8b@X8BTX;b`/?b`W<bPU63D`<216;3hUJ6MGO1da:B0M6QHB5AXF5OhC0a@F
0023o1Ij6ALM5aPJ6aE1XhmiMYBba:aoX8mbLe]`M81oQGn0DViYFdmC>D/]@cLh
>SD^;cdW9CHZ;bXZ934_=C]:Cg1:E75lOGeI9blQ8aYG>Cd[:B8Z51hN:2Xc8cHR
:1h`8RD[8BH]>c/j@DDk=EUG;S0D61TH4aHD4a@C4Q<B0aPD0026oaOo5W/G6QPJ
5aPH6QLjVWm[PZk9//ZWX9nFIY>1MgQNQWIOI6A[De8mDd91<3Di9D4m:2HX92@X
9BPT:B`^?Sa4BTMYIH=aR7i1@2PT8Be<@SPS;BTT7APN9b4[<B/[62lZ8R`I<B/[
>E4`CTM?F4Xf?cl_9QXJ5a@C51<E41<C0a8C0026OaLF5aHG6ATJ61PJ6QPJS9Ua
NgVo][f8[6>8WXEoRX]PP7YTJEm>ED59BTLb@3PTC3H_:B@[7b4T9R<_:1/c=Ce@
IFUnK7>LNVINAB/N7c0lA24X=2Xd81hJ7R4R;bhR9AL@;BhW?3Xd>bm3>D=:CDa@
9a/Q7QXH5A<C5A8E51<C0a8G0024oQIi71LJ6QTI61XJ61E1Oj1IOJV/ZYRkd6j8
RTeaJh=TMWUbKdmcAdi;GDY4;DLg=bX]=B<V:2<Y:RP`<B/k>d19K6m_QEiUHU8l
>alP?3Hd7ch[9B0L7RXM8RPX9b@[:bLZ6b@a<CA@=3AD=TaTEC@e@PhK61PC4Q@C
4aCn4`<C4P00QGlF5aHF5aXK61XK6aXK8AQPOhUGGhA/SifKYfQNMWEP<WZ8[TMJ
HG5DC50lBdY7B40g;2HZ:BhZ:2//<CP`:cI<I6=YLXiNQ5=^DD4_5b@X:S0b;SLl
:R0R824V62DW;2DX<B`T;3@U=BmC@dM<M5QB?R/K<1lJ6A@F51@H4Q4B4_lCo`26
0QPI6OhG0aPI61Sn6f/H9268Rh=[GVUlSK:6PeZY@TYXOF23L51^AGQHFEa]EUh]
;4dW;bdc:RTZ;c4j>RXX?TIECF=XNebDKF]:@BlH6R/o72`Z:S/]9R0H9B8Q;2TX
<0lh:S@[;cA6>d0f?D/nME]T8b/J6alF4aCn4`<A4Q<D0a<E00250aXH61cn5g0H
6QXK6Q`H8QUFZYf=ViFJSGM^RK5MGeMAM8FAH6edN6YNG690DUQ]@c4_ARTd;S/_
;cDd=45=@UEAFeaKIfESPe0hAR<R:bhH>R<cAcTb;CTW;2HO8R<Z6d0O?C0]>chj
=T]@<eU5NH=0AcXc5aXE4_dC0a8C51<34aD008Ef5aHI5QTH61XK6A/Q81lR7aFE
RIj6PKn2U9^OK6mZJE=k?7j6NW=hL6UKB6i;DeH_DSTY@3i3=1/k9S4c@bi/DTEZ
AeaYNWMLEDY1:1dW:40T?CTg@S@a;b`Z<QlO8Q`c;2Pa<3Hi=T0d=b`jD8]lLELO
<d8X5aCn4olBoaCo4`<A4`00P`DG5QPJ5aSm6_lKKQhM828C<XZ3QXfaK:EbNX2F
H6YeE4b<SF9ZEEETIFM<EDU_F4P]BQde<C@/<C4T@cm9V79/F4YfL6AZQUPW<2XF
:b@a9aHa<398:2@X9R@]72H[:2Y5<BUG@b]@>B4hACY_IehgFblX7QLC4aDD4odB
01So4ol0QWPI5aPH6QXI6AXK6adN7AhP8QlnUGeSSYj;_Gj<XV]cKUUcUXZCHFmA
KGMIHEaKB3aT?dE0@BXf9cA0>S0mF:F@M4ALG51:SfMJ>DD/4bl/:2@U9R0l@4E3
:bXX6b4/72<A72dc;Chh;SHo=T5<=UEIGbPQ7ADC4aTDoQ<3518A4P<A4`00Q0XI
5aXJ5adK6QTK7OdKL1lQ9aJ4PVAJG7ZP[Z>?LG]hGg5bRWmWOVMWIGAhCXMWEeLj
?cY89T0c?457;4^2X9QeEEm0EE5CAf0M@BLM>B`X8B/L;bmC6cL`:cHZ92<Y=AXo
CSXZBSi69THoBDiH1R<_61DA51@B5Q<C4Q<B518Boa;o08II5aPH6QXM6Q/J6adM
6a/L7alS6e2aQgIcEGnk[j>?V5R3Ohj9VfaWQcIVI6A]Ff5MH4`l<chkC4LeEU5U
I;j<RiAEBf=;Cgi^F3m7;10]92dW9b/b?Sie?34VoRTR<2PT5C50>U@o>D4e;44f
DEXg<2XB6QLD51<B4a@C3a8C4Q<34Q4008Cm6@PK6QLP6QTN71gn7VlG:b4FDI2?
SJ>7WJV:TY2QQXfNNHnBHf5[JW5?PVY>F4]X5Tm8?cdUCTAJJG38]XMgP7AoEdUS
D4`j92hP:RdW:2HS=S`YFdLc:bPZ;2/I<2/i>T`j:c/e945:HV5;=T0j7Q/G4a<B
4Q<F518B4a@B0a8C0026M1PI6QXK7QHI7b4N7AlO8R4X9b`X72AEK8W:Q9ZOVI5m
LGJ9NJ1SQFYeCU=SHeMRG68mFcdk;D/lCT=_LHF1/7V2LhNWTWUcK4l`=BTJ;2T]
<C0/AD@O:3]F>BLb<c4Y:bhf:CPf7C@`CDUC>6i6924[4QPG5?hC01Cn4`<A4Q8D
0a8C0025oQ[o7GHX7QdQ8ahQ8RPU9RHZ8BTL:RA0K8fOQk1j[/6<_WbFU768N59S
EWaWFFAPIdI>=T5<<Ta?LV]aP;2gT7FI]eR7V92=GC=7:20Y:b`Y?DMNBSHm@D4W
:RXQ=c@dC3U1<S@a=3m;LE]QFT4T;A`I61LD51DG5QHC4_hC01@34aP008Io5a`O
91dY7b8T92PR8RLX:BTX<5JRSh6AZ6C>ZJbPRJ2:Qi:U^Fm_N6]^P5IUMVaWHU=>
<U15<eUJGVUgP:^4[<fT`:NVR8R;RTlc<Aha<AmQ`80j9RdV>D8[<BPg>CM8>S@f
>alk;DU9Le9BE3Df@CLU6aLI7APJ6QhG5AHE5aL36QD008Ko6WdO82TR7B@V:QlV
9RT];2Y4P<jjYL>LM8FY]iW3R<FS_j6^aGYhM5e_NTQTCVA=McUa?EE8C5=/GfQL
Nh2E]7>U//;5aWj9Wg]2?b4_8TfT>C@O?RT[6CH/;2lfBSXN<bLg=C/g=6=YLFhd
>T8lA2@H6QPG5QPG6QTM5APH5QH34aH008Ko6W4O8B8N7R8V91hZ92/Y83c9X;^b
//iOH6b2^ZVN`jfFUkJWXJ28OhA[MEY[Ifj?E55O>d<k=TeKGEe^NHb4Oi:B`ZNC
XX26TZmbCde8<X8i81ll8C<[9b`V93LY>bPj@c0_=CY3EWQNUcm>;3DX61`I7ASn
5olH1Q`G51HG5aH35aH008Io81dO8BHK7b8U9BHO>bDbM=n/W;C7cXiPS7Z3S;NE
U]FdbK31ZJ>LLGeRL4a>L5YYIT/l=Tm@He=FEREMM7NEHK6XP<>1fZMlOl^=LWIY
NB/R<3<]<C`/9RXc:20g=3TW?3Dk;T13OWm^DETo;c0X7a@F5Q@D5A8C5A<B4A<B
5A<35A@008Io6R@M8QlV8R8]9RHQ;c:g]jS5`K]mg71mVGV8Q]jg`[:P/[>j^YEm
T7]^Eg1AD6]1Db]@>4MOBEQJN55ZFGR1XXj@X;bU/[f>P8f[V8mG:R/Y;bHj<2<Z
8BHh8BPa<2m9:Bd^?CmHMhU4=Blk:C8G6QPB51@B4a8A4a<A4A<B4a<34Q@008I`
6bDR8AlU92XM;cQ;EIo<Y/jhR];?ZgE_XIijRgZUZib_^<RoP9b2Q8E[IT=VEW9^
F4a6BUE/FeaFCd]:HfR=LXb=PiB7`Lo>X<J8QSHU=B8/:cDV9C/`9bPb<cD_>3@[
>3hS>4DkTXA]F3T`9C0V71Wn500BoQ<74A8A4Q8C4A834Q<008Ii;QTT8CDV:2@Y
>B^8]jjcd97@aZ>hTXYgP7j9P8o1aj6e`;2caj>DV71cNf1RIV=;LeUC@eYOFEmS
GWV5AeY[RgVQOhnIMZFBTXm/DE4_@blZ9cTd@R8d<Alk924]BcDm<CM2:cIUNVha
EATa:BHK6aLE51<D4aPC51?n4_lA01835a8008Ag72lU828W9blX6h;<akZnVm>b
Z<FN/7idIVnQQ8IjWlFMW:no]ZM`VWmkQU1QMf1HE6DdBUILHEYhJ6Q6L767Aj5`
TGaUYgQVBe0g>EPj>C/i?c5>>3Hb<2l`<CXg@Ci2<cdi?2QHPf1N:cl[:C8S6ALE
4aTE51<CoQCn4_lC0a8A0025NAhP;BHP:AeC<R3:`K:`[/?5Wlc2d8MWOXU`_YbB
L9nPV;Rn[:biPh=iV6EPIWQ]BE1PEE1@JFZB>8F3FFUOKgJ1PgiNIfU3;40l?2hj
C2@^@ce4@c<m>2/j9cXd<C/i=c`^@dLc@D^0;U4n9blP41LF4a@E51<B4a@BoQ<2
4A8Boa;o08Ec7S4X92@/<bP]Il>V`/f>ahRb_l:h[f=ePG6cUH^YGIZ0/W^RXjJ3
T8f4Jg9NKUmTCDQ9=4U7MVR2Q6V>FF5mNg=mCW5_Hbde:CPf:S]5@d==>5=FBEDi
Ca`c=DPNB3`i;CX_A5dMODll@C4S6AXH5a@D5AGn50PF5A<D4a@C4a7o4_l0QG0Q
72Xl<c`aC3f3_I[;NL;:hJO1cJVfME^CPI2`P8BVSVNGTiFMPYekDGI]Ee9UN31<
DCM?AC1OXW^IQi6?V9:?RVjDS7]fI2T_<SX^:UQRFVIKCU=6C3D^@R4f=dHk>C];
EC]?>69EAPlE4aLH6QLH5odF2Q@K5a@C4a8D4Q@D0a4C0025JcPX9QPfBRdXO;fZ
XkS7^Y[:djS8b/29Nh:;I[JTWFIRX;F0[K>RP8:QL8^:DG9REf0e@D10CbZ5b:V]
U<nD]M2_ciN9PgeS?UHgSg]]KG>5NIB7QhU5Ac<a7b/_=d4WAEI<<SU=EHhV4aXH
5odH3aLH5aHF4aDG51HC51<B5A@34Q<008=Y;BTMEb4Z=CCRWLn[c[RoV:FdV[K=
TW]bM9a[Vi=X^FK0O85_Y]5YLWmoGV]:FgeWAd/n@Bh]>41[KgUmEEIhHH5dYJ6o
VHUdLEAkR8:JWWfAXiJPPheM;cPa73<d:4<m<U9<F5IHLA0L6ohJoASn5`8E5QKn
50DE51<B4a@351<008AX?a]=9CLo<g:U`:fh/ZNXY[:lb/CMRWUmOg2@K[jLRI5Z
[fjDRhVBO722RW5SEeMHEdPl>R]9<4]8AGYdXGYiHfU]@TI?S9fBQZVbUEX/8R8m
:C@j>6iUK1`_;C0d<3]=KUID;6=YE`TJoA/<61dH5aLH71DG5QLF4_dC0AHD0a8C
0024N28i8cQA>3ZS_Knlc;O1d<^Te<:Y]8^2Z8>3VW:/X9>3Ng63LXZEOXU>OhE[
QDMIF5I9>3`e;T53BS^5LeAiUYEhKgA;;RhWBd1C:SDb=C0Y=C/l=dHfNW9:>2/Z
=3Q3?D1AEFAeRZ0Y4AhM6aXK61LG61PG5AHD51Gm508B51?o4_l0QWm>=2Hd?Cma
eJbc^:bfbjc2aKS;`/G>QhNML:aoNKjJIUa_`XR8[:5eMUeAJf9GK5m_Ae=1>S@l
?U1;FfU[OFb;QGB0AC`V<A`];R`V9b4j=Slk>2M7;ahlE4H`9bhk?EQ@@VIZRkB[
hcLB7adK6AXK5aPF61HD51DF4aDE51@E4`<D4`00QGX_<cdlA2n1^LVb`LK:[=G2
`/_:`/;:R7Z2NXVQH9JGRhUQIYInY8Z8OeemJ4iLC5]QHTI3;Cm3ADQ6FH9_Eh>4
LUb5EBXe<T51;clk7blg?d4m?3hk>RlQ?T=0AS<l@eY]ETMY^Lba^Kdg61XJ71/J
61PG5QDD5QDD4aCn4olD0aHD0025Kc<aBbe2GK2b`Z;?UlB>akK5XlO2e[nlKGUP
PGg=LKR3P8]eK8R1/960M5aVIF1dFF]GBDXmATA5>dQ4IfMIM4iUJ4bBD4Xm@d@i
B1dm<4`W<Se6>ShY<34`IRi1?CE<DePmPlFTXLNgXnT=71dN6a[m60/F51LE5ALD
4aDD5QD35A@008Io<3X^>4fRYKZhcY6b`LbRcL3?aj35dK:jR8:<Sh1gU:F9J7UR
X9>FP7mPL69MG5ThDDmL@DPcAdQ7FCilM6QMIe]LCEDnEd]<C4do<bhY<3Hf<1dc
A2db>TDc@b/l?dU;BeB?_XW@`Uf[ZKPP9R4O7AXJ61TE<aDH5QLF5Q@G5bD35aH0
08Ag<S/aGec@[LbR];C2`J?>`<[8aL;:aLbMRgegXJR@H<Z[OiR6G:J1VVidQE=4
DfE7DF5BFe5@NU0gCDQACE]LDeUMEUHm95USHSTj=SL`<BlZ9bTY>RU09CM3DClo
?D=4JY]Jh=F][Mk@/Z2_3b8N6aTF7ALG6APHoQOm5P0H0aHE0026OcaB?S9m`;jX
eZ:hbknod<G5b;g:ckg;/WMoMHV=]h=`X8U`MX=PSYYZQVmJFC]5GeI5DFY5C3mD
@D8cG5mGEdUIDT1_@61lE6Ta>T0d;Blb82T/;3T_ASQ4?c/b@CYLCfnDHJC5[<F4
PMNG/lTF71hK6QLH6QPH5QLH5QHG5aPC0aHE0026Lc=0?gc8UkBd`L6hY:_=[[[5
e;?8Y;KO]lA]QFVYVjYIT[=hOG9TTKB?P8YTDD99EUiL>f9AATPiCTU>CTU>AGaZ
FEILKEQ=CS91>C/[>3LT;C8k<CdYA3<[93@kA4U8GFf3D<G@_lo8[J7HZ[d<820J
6RDIoQP85aHH5aPG5aPC0aLF0026OclaF5b4dlNTYM2`^<bMcl;;a<G:amBAaLB^
M9S9XjbQM7FPO:9]B/fGMgQPFFEBEeaTLE]WB4i]DTA8?54iAdiFEeI@LdMLF5EC
BSM0D38ZAB0`944l:4To=Sa3EBUHJ9ac;i>oaYo;d:Bb`hZ152HJ71XK5aPJ5aPJ
61DH71LK0aHB0026Od=0K8>SS[k=dkWLY/jnW=Vial[2_l;BalYXPf5YeI2LLG2/
QWbKSD>m/X5DHdeBGeQDLD9;@5Lb>DM7BDE3Aba@>f0iB4LZ=cloDCLk9CHZ<b4a
=S@i>RTe>3ECF5EUP8j=:I7NYM_5eiW<TJVM2R4M71XL6QXO61DI5A`H5QLH0aPD
0025LTljN<O7[/RH`Kc8b;[8WJK2^lG2_:c<`<OGQ8md/kJUd7F9TXnDSgY/`H=k
DhhoKTjA?e5GKEECBe5<=d5D9eYH=S`c;BhW9RdL:Ri=?CHc9S<f;c4d=THQ?TUE
FdImR4Yb<E;<_<_4U]S5blZ<HAHJ7Agn6_hK1QHH61LE9AP37QL008IoDd20Z9R]
ciO>YkR6c[JjXkjWbkFngJ3@aLNSNgn6b95mV5b;X7jEOgbBf:iKJ4QVJ79XA5IX
>W5GL5<i>c`_A4M=AS@e<2PT<2DX:RLc<CPd93939Ri<?5U0F6]AEh]8EVDb>[Nl
`/Fba<bLXYk5=aPR7Q/L8APP6aXK6ALH61H381H008IoFboNW/Zb_<Vj_[_E_kc;
d[W;aLO8`=75b:S2XhnGXj>nVXI[T/^]P8]cY[MhHhE_I8a/QFeJFT9>CTI?@b];
Ad@c>chd=blX92T/:R`QAS0_9BLgDdQ6<cYRPF=oLU18ATlV@MNlc;b^_<O9amU/
]PXR81dL6AhI:AHW5QPG7AX351P008IoI9>@cZZnbJCA/]6Y^;RoaMG8_kn_a<;2
a<FofUJ?T=R;ZhUcLM1lYJ1/Ml2eKGUfPFbTPW9GF61KF4`c?S=?B4I3@c`k=34[
;b``9CE1=blYBcL]>dQ:BTmUTE23BDELHR/ke[jl_;9kalG5NZnXXD0I8QhV:3@N
7QTI61TJ5aD361H008EoDV2V[M6g_mBj]8o2_Zk1`/:P_<o1_k31Yko1]9BBN[BH
RjF2LGkBM9V7OGS=VH1/Lf:5VFagEXmULU98B453B4=8=Ci=<CH/:2<g>2l^=CDg
;3i0>4m7?5:INWTZ@SiL4eWb`K:VdZoDbj7>aMO2TZ`>5RTR7a8Y61d]5QPF6Qgo
6Ol0QWl`UK:ZYjW1_LRl^<^l/[Rjd:jodZ7A_k_5`[o6Q7b@VZ2XS<nBG:^_YKAk
^SF7^f1hOWNUNY1YH71^G4a3>4]:>3Y1@Blf<S0Z<3De>cI1=2Tj;DUj94=ZVfmh
9CUIBAAch[o0fKn/dL35_lRFZfk6_RHK928P920N6aXR61XI60<D6`00QWmbcLBh
ajG;bJno[ZS;_:_;Z:k>_/:W_;c2`[[;aJF7QZfGNWo3TgFVWHBcJ<91QYm`NhNC
YgR?LeIcJEI;B4PfD5Y5=4`[Ac<e=2/e>3<c=d5?AE5:BI20O4<Z;fLa4>GLZ:oF
^lG5bl?Dal;?_=>h]XXS:RHQ71hT7AXI7aHI6@<X4000QWnB[;RWdZb[Z/SKaKJ`
e9S8ckbo^/;8/;o:aLBZ]:G4Q:R0SgbW/gMmX;B?WWOS:i;@FW25cW>9P822Fd]C
F5=EEDe9=T<n=CI89d0i?3h^=CI4F6QNEHb@<2E0IaLWi<^mclG>b<GHZ=Rn_ZW=
_kc1]I9c5bHV7AlK7Qhd718h6@<F8@00QWn=g<Ro^[O2bkJZW=O4[mNj/:c5alG2
`ZkF]l;2ZLjgMh^<];EcTJN@TD2eWIN?]4MEj9m]blN2RH68LV1OFTYFKd][H3e;
>Cle>TDoB21D@FHe?5YDOCdS8TE>57;8X<7;ck_CaKFo_lF]UkRl_kQl[<:[31lY
8R8U520R81PR60<I7@00QWnUS=;2b<jJ_;jg^/7:ZlZfhKRl_L;5eL:;flFmblG6
XhUjWWO:QZf<GIFc^9VM[g=>9GZU]Kk0Y6YhEW]AGea9C5eMFV1=?DQIB493<5]4
AeULCTiH=APaAC`GIlk<WkjReL[0^LBZ[]Vmb[nl`]2Z^Z68TATb:24J<1<N91/`
<@<I7@00QWn/ZkNnXjRnd;?C/:>`_j?8[Y6jd<7:aKCFaL7;aLo4a9n;Q7Z5/jbG
WV9gWMZJZMF;<2</Ph;CPW5MQfEYIgICP6N6DV8hDe5HF59@B3TmCU9:GeHW7b`_
7c9mX<Jo`M6jalG5e<ZodkGC`=2ka<VbcKI`f0<[9bTc3CDH6B0Q5`<M9@00QWnd
^<n5bLGFSgS9YJnbYKC:Nl:Jdl;5`L^m_L;5`[2l[GnJYk>5TiZ5[WN5LYG1X8c]
F2lf@eN<cHJBOFMeK6Q`HfYTNCmoLgIYEDEADFY6Dd=jCA//;2<SAI>0WlRo]LFo
]<^m`/:k_MfSb<:V_:VkMlK1R7XX;BTO>1HC;1`R:@<b4P00QWo6blB^c[bQb<_>
aL2Vek72dIo@^<W5aKg2b<G7ak32clRiIJZ@N9[6X9J9Ih2UPYfgeB4f<TYDLI>J
Rh9lH6U/UFV5LF=UF5aZFUI:EUMOOV8o;2XX9DYXQgEY`k_7bl[:aMBc`/Fk`WNX
clCIckRkRkJnaYm28RA36B544b@O4`<S9@00QWoDHlo;Tl^/blO5ch>dZKo@b<fT
ghWBd/NlgM>PcL;5^;K7PgZRPI2h[HF]PfY]X>J_`78V@dI7B6YhPGb5J6QcL6IY
P7YSMVah@UaJG5=fDR8[:B4cAfY4?5i[dLC2`[W8b<C5`n2]gko8eLZlb:SFV<>_
Rhf[4cd[81LO6alH=`<W3@00QWnPdkg;^:_:V<6dam6fbmj8UkRofY_<aK[?/<SA
Z/_6ik7?fiic[KF9OhfINXF3O82bPkA09blR;RQIVW1eOhilKiB7Ig=dHWm=KWa^
LX5B:R/T9C]GEC]<CX:9ckZ_cl;:blS;e;OEfL77Zl^1^<bo^JbkfKnk:B@R<C`X
7R8Y50<AE@00QWo6al;2bY_8aLS7`/j_c[gCX/_C^<N@cIcB^=;:`/SKa/G5`/JQ
U7fUSjVVPimhOgmfX;bI7UJ1WLc2[kR^ZWUjLF5jXFM_L7AoNG>?MAlV7CQI>eA@
8TMOP>BlcLBfb/:nX<BS`MB^aKS7_l_A`JWNPGUjg7[IVa<n<aLV<b<V:P<T:P00
QWnDd/:ja<^K^YO9a:3:ZKbWfJNVd>>?clC2b/Ribl2kaL;>_LGHJI:?GX>FRIJI
OHQiUHWcN<6Sa9ZY^[:S]:bJ]I:dRF]oTHJQYVE2:C8l>48kAb@e<eQYPI>7_kg7
b<SBalo;b=CB`=C7ZJg2_:bkem:Y/ZR2_UPd:RTX4RTZ;0<Q:P00QWnRZl6l_:G:
/=VZb<SB/<VlambhVik4XmRiaLRo[<oD_ZW2aJg2ei6HSJiX^gR:Ji:8Ni;4S]O5
X:^WYJFYYKb@WH2`_I^EN75C@STi@Ci3?4hf:cPnA5AlOJWD]N:kclS>^M?3c=O8
_LZhb[:b^:c:Si>Y`XjlX9Ld8DXMG48P6`<Y>@00QWo:dKo4_lZ/b;gB_L6]b<>X
bgKL//>bLK;?b:7A`[g:a;;2gL35bmk<ThFnTXnJR8Z9OU^?RGZUbISHTifjQX:B
bW:?U7BKGd=9=dE;>BEB;bdT:4HfBFm?HMRfcFcFb;cE[LG5b<?D^/G>_[^A_=Bk
dgJ/aLNbZHUa9Ri58QPZ:P<W8`00QWnoWl72`[gI_[32`Jg9c7_<PmjSV=?7XM6T
c;3;ckC2]Ko5c<SDZL;7ai=[QgfFOHV=SiRUPY:IQ7NMNhF_PKjDQXNUFFihBST[
?Rhg:d`T:BXg>cYUKBQ6Vl?;b=C3b<G<]=K4bkC@VM35cJW8a<RX]l??W:kCTGnY
<DM793M<8P<aC`00Q_nlOKnmaKg5`[o@_9fl_l[5^=3AKLfn];[=b[g2_Lo1bl;3
c/??alGDaMVjRHnCMhVJ[Y>2`Y>9Q8NjLZ1gJTQBE4HdA34a8BPe9d<e;bTT:c<c
C4m3;DM[V/Zdc/[>e[nDdk_?]n;3d<S5^[JCbL;=`JY`e;oBU;:Y>d@PA2TJ;`<e
<000QWo;_kkKXmO2`[bHckoBaLjobiVPgg>b]]:ad<S>_l[0dl?Mb<35_LRlb/S;
`6IcXIJ5J::7U9J:OhV:Ih2KUH52DT]6A3Xe@TU=?38Z7RPW>4hX>ChU>U9Q_[_=
]ZC@XLo8b<Zm^k3;`lS:cIfnK/ZmdKS1_mODJMFA`b`k:U@m>`=88@00QQf:^[c2
_9fl`]:_bl:]b<:gb=JcS=:hbl[<Wm2oY=?naEjkb<G:/Mk0a<k>d[ahQEedO6F4
J:Z8XhV1THQCR7b<FeMNAd=M?2Td;2DQ:2/UDC@T=RHhBDF:cM:malgE_MC4aLS5
`MC3c=^d`]Mgdkc9[L1`bhjCakRoQ6E8AB0g<`<M;000QWnB^[32el^lcl;G/=Bn
_kbVMM[2e;bbWL_4_mBmb=_7aL;5dl38aLSDP]ODYkSDOeihM7YFGdmgPi22Nj>E
LgMEE5aAAd53=BXX9R8X;CDo9b4c;STnB5VOZ[njb9c1al3:b<S5b<k3cl[F_Y[O
`[3AMkBHUlG7//RgPI4U;dQ59P=:>`00QWo6a=>fa9nQbJ?Ee:Z2`M2n/[3=Y/;D
Z=>TdXk>];_M]/7DaKO:aLG:dLS5TMg2`lb4LeeTFDaI@d5UI6>7J7R9M5I;>c@d
:28R:Bde?C0Q:S@_:CE<=XZS/<_7_lfFcL:na<jnc<S8`YC4f;aIekjoZG;/UMC4
d7W9eWaOBB/T<0=4=P00QWnl_knka;:/a<_2Z=OAfZ2o_<^RcZN[^j?JaKoF`/C<
b<G5a=Jkb==Ph/kM_lS;Z;?GYe1>>UM4EE9OG5=2FDM9?515>c@Y;2/_;c@[82PZ
:R`X:3A4A7;Db<G8^/;5`LN]e<kIek[;`/RTfZ2g_mCBbXR6gLnCilG@/Z3:7T8d
=P<h:`00QWnbaKboalBo`/;:WJWC^L^Sd<^EblGD^:MmcL:l`=g7b;S5ckc8e[[7
Xk[5[<SN_;R_cl>HD6mJA4]FFd=PJU5CJCm8<bhU<2]2?BHW9RL[:B`/>bHbPlG5
dLN__<G5b=Jkck?0c=2h`MFob=^9c/^RV=SZE>Jf^<RTb:jDC2eH>0<c>P00QWoD
KlW7`/_2dK:aej:l_l;D]jgD]iVQal9ab/SNaLG7b<G7[LcC]ZO=_kGE`]?4^koJ
ZK:bVV>GHTe<Kei:G4MM@5AA;48o>bXT92LX8cP/:bl_<390SKVSZl72XN34aKn/
Tl[0g:;8b<necJfhc<OBfkRHZ;oEOM:adZ_9OVdD=0<iG@00QWngc[[>YJg<_j^n
/L;4bl][]JfMaM6Q_koJOk3;[[nTaL;2]ZbQ`M35`/O:^LG>]L;D_kZOj4IEHFAK
G55CD4i8CdA:@S@S:BHP:RHX:R/b;2d[6U1[I6_5b:k1_mG5_KgIa<77ij_IVk71
[=>lZMgIagWBc8bP`jS:]]BM`1Hi>@<eA`00Q_n^OLV7dK2FdL;2`JCCRK;?]/F@
g7kOaL:gbj_8_lO;c/G5`]V2_<[8Zl;2aL_0al70_jWD]7aTIFUDLeMHA3]A;38V
:bPV8QlX8RDV;d0_;2XX8V>7G;fn^YZh`JWBbl3:_=ZJ^/ZJe<O5c=2YVLbjcmVE
`mRPe7gQYH^NbgM2G0=B?`00QWnj_<Fhc;jh/]J<fInVdj?5b/76^9>Xb<^NY]>`
a<;;e;S?/LOCe<OKb<G2aLG7aLoD_ko8b6f9H4a>@Sdl=RHa;B`/:2PV9R@T9RXm
<c/X;R@TAfA:GmC@YLNo`]:Ra<[1c/G4_/Nodkg>Y<C1]k?5c/GIT9JjT/ZIi7ZS
^HQ8CP=A:@00QV6K`[nYbJOCXLGRVM2bWlb^/J^N`mK1eI[JOMZ`_kbY]Kk0f;31
aLG4b<:dg67?_lS0[/;=V:e_Abll;CH`;b/X:2XX:2@Q9B<X9C@_@a`V9bLTEUQF
@<K;W:;5aL_<[=Fe_Ok56/O5ejJh[<;8b=[>b;W5ak;<YmbVakJhUKEVA0<VM000
QWn/a<nZ`LZkdl^da[o?]8C>V]o:Y;:^/]VY^VCG^[nle<o;_m;B_=30dKk2/lno
Y=k?b<O5dmZKA5Q1<c@^<BXZ:2TX9bHS9R//<Bd_:B/V7S<hAG94E[g<_Z[;`Zg4
]Mfgb<S5eJW>_ljfa=>Xg=Vob<;5][S<f[:Z[=:</K:VG@<EH@00QWo9a;3<^;RN
a/Fl[LjKd=6@f8Z_WIf<fG7?PMSC/lnSe/RZe<k6ajW;Xk[Fb<jm_lS2[[C>b9Z/
N4Q3>c<Y>BD[:RHV:BPO9c4b;2`_;b`X9bdlBT/eDlRYdkjWV/^o`Lo7f<nlb<;P
Q/C?_jg4bjgCVl;>ek31OGVj]9jbe[FB=P>B9000QWo5_;K3W;ZgVjVoXkRYX<SE
XmRoTNBG[XkNZF_2fkng`]jbb;KM_l_>e<;0b[O5b/S1aMVld:fnSFm1@D<n@3Td
8bPY8bHS;RH/;BdQ;b/Q>SE4IRd_JF_CYkRj[ljoeK7Lc;S=b[ZNcL[8_L;2/]_5
^/GEcXJf/]>YcZ6fT[K7O@<nF@00QWnl_m2Gd[bS^/nod<71dJ[FbjSM]VgZR:bR
dYenejVjX=C>emRkd[_7ckW1aLG8a=C5ajS7a<O<X5]QNTaIGS@e=bPa;BHY;2`Y
;Bl`=BLZDT5F;S57G7J;b]REP:>/eM;3`n>8f/3I/lOD_>>l`ZWCa=:Igl]fg:Vo
WlW6_[S1Q0=@?@00QWo1`/G7Zl7</LC:TK:l_lRldJeSf;e//lgATX6iPl>`j8N[
c=O<c/SJb<?DaK_?aKO:`=;8d/c8bY=fMF9MFU1fB4UD=R/b:c``93/g9dTo?Se;
9DIKAFijgJ72VKjR`/Rl_<o;aL3>`Zbmcj3Dh[[JggkFemE_e;[Ic;RjG]^>_P<S
R@00QWn^_<Rh/kb_`KGEPM?BV/o:aM73[/gLU9Zld[F2fW>N^=^dgKKBa<C8^mjn
b=;>aL3>ajGA/mkE]/EnH8iGJ8U7BE4k>2ha934o:bd^=S`k?e8h;TH[F6ETe:O@
]:j]alcGcl?2`/GL_<kCNlc3e<Zben>cc/SPI>B4/ZCUcMAnd0=Y>P00QWnn_=FI
//[7aLbb`J:dfik4b:3<e9_8_l7CMNJb[/fb/XOEb<[5cHG<`/CDd[S8b<kIaJo0
bjVZgXOUFVaaMFm`PDAC?c`c<3@g=CXj?40iBSPZARTZHYb?`mBY/ZnRelKJ`=C5
_L;4aLG?elS5c<75c<S4c]Z0hYV__KB7bXnm/P=RQ`00QBk2XYbacZG;`[n/`jVF
XKjkcko2eYnO^/C<kfnJ/82_bL^EcL:mam;8aL:Y`=_3bog8C=WHeL[I_koAQGNY
KgiMB511>2ld>ce0AcM6>39F<c11:BImQHJ^U[Zb/ZKFc/FTaLS5^L_5^l^W/:WQ
/LSMW]GARknRY>Ia]<WOZYW10fIm0026Okjj/lJoa;o2_kc9QlJYK/o4a<nPd=BC
e5bnSgag^;N:d/no^/bda=W>`=[3fl6]_LS>c/S2/kKKaLbhYTm5=2LY92Hb=3L`
<38f@C<e:DLU<C0O<W6GSe1o]kJd/K;2aLG2b/o5aL3BelS5YJg;_LS>a=Jo^;:a
jWCY/kYjbGG00kA<0026;kbf_k_2cIO5_jRlcKbhf9b`[Zk?X9KGZkZkZlUc^i^=
Lj6b]/74clk8_JS:`lG2aOk8C<^Tbm>ob[[4eGXa<blY:B/V:cP[;BXV9RX/=3@o
<BU6JGEP;de0PY?4^;cA/lO5^LFcgkbfh<K>^[k:`L[7UKbNfY:RaYbkU=RbT<jO
0lea0025;l;5Y<j?e[o:b=B/cKnl/LNfcj2ogkbV[[jhdfG/YL>n`<S<bYnZd;35
cmGJ`l[BaOg8BknnclC;W];2gChV:BTX:BHW9BHV9bHW9B@Y72dc?2Pb7U=1=U@g
HlO6]lS4_LS0iJS8e;3Icl;:f/O5^<[;aL6QcJ2XZKCGZ<>^d[`3dZT008Io_;_5
`/Zc_/OD/<nd_kc;Tm::X=ZXfK:hK;g3TZnN`7NFaJ>oeKo2al^T]<S;]lZg`<G>
dl:[dl?>eL3@/YTX;CDZ:R4X9RHQ92TX9b<W9bdN:38T:STo>d9;?72[/Y[1]N35
X=Zob<;8`ZG2elcK`/GHalG@_MgIKJ36][;;/<L3/:L008Io/[o2`[SLcikDd;;<
dYK?`/k:f:;DZKk@V8[MekQN[=Y`ZhK5`L:l_mC5b/2m`/[Bdl;:]/k5c/k7ck??
]l1X?FIWIS@X9bDQ92dZ:RPX:S/_9R/_;bi7@EM9<Wbha=;2_;KG_LOKb;W7`/S2
e;C:]<;Hf/3?bGJleMF0gl;PN<H3]=d008I4_;o4]]F@bln@_m6Zc/78SjRg^mf0
_KRMc8eWKj_7I;7AQKO2ZXZkZlG>c/S5^;g5`Yc4`/35b<S:e;[:cZ6`FAQ7IE8Z
oRPg92L`=2PZ9B`kDc4_9bLU;3M8=FR9]ZW;^/O1b=Znb<FfYmFS]/o5aKK4_kfl
W>C:`]Nde<IPYMD3KM4008Iob;nl_<O=aJO5cIO<bj;C`Zc5^97PP]BE^W[1bH>4
Y/:EaZ1Kc9RE_=K8b<?Jh;Jm_LC2_L_>c]6/_i_H`mW=_C57BalY:B``<CLi=b/Z
:R`S>2di:RH[=E13@UUd[M7?_M>daLo3a=K8_l:ka<G3gK;>glZVbk[?bF^>/][G
TGP3e//008Io[;RU_[ncek[5b]G8em:gd/:neHK>`/n=i=A/_:BiVGcIRU7WN]SA
a;g0d/[5Y=o?d/c8aKS8`YZoalS4b=>Sg84/?Bdj@SY5EdM:?bT`>S8n>bm<A20Z
9d/e@EUfPjboa:W6ak[EbigN`L;8]<S>c[g8dlS2c9OAQ/nPQiOHWml3OZ8008Io
_<^Z[;c7aLVT`/k?U;7>Zm72]/FhXnBbQYk7T:oXLk=UiLiJe[69b[[@aKOCb/Ro
_MW<b<3?b<O:aLS8fLo7b=9;AU8h>d60MEaCAdDR9SHb=2DaA2PY8Se1ACaYJ[c2
cZVE_mN_aLGH`[o7`/k<b;jgf/cEb/NTgkQ]dj2=[;83dM@008Hc_;o4bkC7akj5
_<[5a<;4_kO;b;JfdhSL]J6C_LA9cl66MJ?BLLC?WlFj/L;8b<^C/]SJc?k80L[5
o/Q3bZS2b:JfG3<c=1]IIf=[ECPl<30_?BdY>BXW93=E@Sf0NH?6]MK2blO8em?K
/ZS5]/S:`<;2`<FUa:;HbEgK_mndY=43cjP008Io_;o5b/jl`[[C^lO1aM6Wcmo5
akS6Z/Ud`9VjJL??NJjMcY5TejJ[c;K;^<;5b/3HHj6fclO<b[[5c/o8^m2gb]JY
aRTj<bQ7KFUeA65HA2XZ;B`Z=bLV8S5;?DZBKEJQdjW?]n6ic/c0ZKRQ_mF`aL[5
a=n[cknkcg74aIRld:L3ek8008IV`K[7`[cMb/;2Y/;7_LF[e6cHaI74b9gBS]>l
kfn9Thf9Lnc7R9o;V=VbN/[:aLGBe<bic/cK`9c?eK;5c/S>`<3>`e<d;c0/DU];
KUU@JU4X;B/Z<bTU8B`g?S=aKF34b<G8h:K?_ok81^JeclS7aKonb0_5c/nX/ZR?
eHoOZ;83]94008Io^[^o[L_8_Kg:c/G5_kbDfK]XcN^?bKZdQJc>HNV9S6kIQWOH
TkijXmBOc<O;`<73g<G8c=^ggL;4Z>2nf<jfb=;?b=db:c0VCfQTHSY>?T/o=2`b
;BlW:2do>baLQ7:]d/G8`kk5gLS4f9g;`=Jfc^34_<SCc/SE]8o=`9bd/^03V/T0
08Iod<G1cJc5`L[8b[7:aLoEOmGD_W_TNkCIbgReiU;:dj9c`[n=Hi2Sbl>_S<be
c/S8`kW:`L30cmN[a<c8c<k7X<G8]K]oBbPdB5=1BdQBHDL`CC8Y:B`X:BY3?SA@
RG=`^;[8fLFd`<S0`;bXb[k2`mVjclj_bhG7fGRkK^RaSWX3XL/008Io`/GD`/;8
b<k4aLG8`[W9[]1[d<g:c;:6aN9aQNahNJkaDJ2o]Z^M[9BngHc8`/k<cl7;^M??
/kW>]mc<f;_5a<G>d/;?PBPm@da1:Si4F2ln;SDg;c0T:B/h:cLlPY9R_/RjfLc5
b<k<c/[1YKK7aLS5c>7:ZlJYQNb_jIK2/mP3e;d008Io_kg7]LG8c/k5b=K8`=^S
bl^a_<nhd;Rm/F3_^dc;_E^1jZ>6Q<;>Y=ImKL66/<_8b;g2bYbl_l^_bkK4cl38
_KK8c/S8c54T<d4kCTDY=EXj=30e;3lL:S4Z<3/dI5FIR<_D_/k8aKkHc<o1b;k:
_L73i7[GfKnh_8No_kSAb/P3HmL008Io_l;1_l^lb/32dIkJe7bj_YW?Y/Nmdi^J
`YIX_[BH^kn2Q;[0`XnJ[Y_8[7C>/Lc8b<O2_9K?_l^WalG:aK_MaKK1`LZbc?=K
?3lb>T/g?dA1?3Y4CC/e>24]<3a:OgieMMK:aKo:]Lk<`koC]<G?`<[N^lcE[jK5
WZkD]Z;3D:`3eLd008Io[lb8b<G:aLFe`MBT`]G2_kk5clS5`/B_RJFCaH_Z@HGF
QW2h^Z2[`8R2_KESZk;8e;SG_lGAX<o4aLNh]mFlg/GC^<[>`[g8g65Y@clm>Ca;
>c/l>SmEIB8]7ChlQX2EF:W2b=ZocmW:`mnS_lOCd;W2_ik<^=:f];S7NjUeg;/3
bgD008Ioc/;>aLG2al[>QmJ^alSD_kRSV=K@cG79d:[7`[m`mFG:_j]GT8b[NY6^
IL>jXZNfa<F9alS2c:ZbbKKBd/?:`;?C`[g2^MNl]:2fOC=5CBPd;C@]BcHk>FPY
:B9KN8:>I<S@b<c5aLNCamnEeZblX/^ef;KDP[kCONAWfXk6SYD3e6@008Iobkg5
`/^jZ<;5`L;>`[g7cIgFcJEgc<Vh^j6;];bLWlY@fH_9RIZPcIJ:fF6i^]Rf^;o:
Zkbl][S:WMW>b<31ckk8aL;2`LjS_[jSeRdf?44S;CPd=S8j:ddk:bLUKi:MUF[E
`/_1al;5`<ZoaLjWd;Jjf:Nle;JTfGfg/[Jf_]L3P]P008IoaLS5_/[;^/_5akZU
c[^lTMRJ_=:/Ojg:K]K<ahc<aX7LXHBKeij3WkFdZKfM]/g9ZKjf]lZl_;jU^l:i
b/_2`[C8cl72e<S2c=6KT9<V>STo;B@_<C4_A4Tn=2XK79ifW6cJ^[[4^jO;c[S8
_lFb]:JoaK;=KlkFWk6YU/NMGYD3alh008ITb:cD[/Bj_/[0aL[=_k[E`[WCa9[A
_]Emd/>KY=]a[;UTbLkAG/bjN/;DeGB`YFV3V/jlakJb/LV/X<Rob<72`/O8c/NK
`/G>Z<bJeKd^>CPb:Rl/;BPZ>b=5=BHX4hR1P6gI_kon`P2mo/8CZijVY=g2f:VL
V]B][Lb:ZMg3b/h3[m@008Iob;bj`KnoclG7`Lj`_;bY/M72bmGD`ZWQE[VgZYbf
c:^bX;BjUTNWegN@V[9MUN2Y_IBb[LbbdlG8[L:o^872akg5a<[2b[oHWKblaYeA
;C<e<3@/;c@Z;cY7@BHV82RIMFB8aL_5dJG<akKDeM?<S>6Sbl;@`/el`jSUSZbS
/[l3cKl008H1a;on_7Zo_Knm`/F``/k:`L:n]6gIbjfXhj^ca<J@diO<[kfQQkQj
T>F0`8K;a6W0MLRfT:O4_lO7^mS8aM2o`[C:b;_Cc=ZidKS;dKBk<T8h=2/[:2d/
;bLk=B@Q91IiMGZ5TL_?^L6n`]??P/bZ[KS5/L:j_<^7b;C6OZ7DR>83ILH008H0
cojlNko7d:G8b]C2bk=f/m:@ejb0c/j^Xk^h[;cCTi60WJ>W[G30Q637akMnZk:4
^[C4RIJY^;c1/Z[>aL:nbl[8b<[5b<c8c/o8`[;7Q10j=2<^9RPY:BX`>bdR71m8
I8mXKJW5cZ_;/]?5h;nfd:;1Y]Bo_Z^n^:nj[Z]A_[83/;H008IoQ<KA_l;2b[k5
`/2o`[jhbL3SI]KQ/VgN`ZO6bm1OiK:Mbjj;^/EJ^<e@c:gIGLbO`Hbh`;[2`JNf
c=JjeL[2Y<k@`/Fed/c>alS3`[bdfA<W>T0S:BTR928Z:3TO8B<IHiI_A<Fl[MfQ
e/Fe[[o5ThoMc/Qm^jc:e8?:/Jjj]ZL3SHT008E4P;fK`[nJd<GC[=VidjG:_]6Y
]<S1a:S:YMf8N]NoV/bAeJabXjW<JXcaELIVeKnY[jYRj87?akna]L[:]/;@bLFH
_<_Do/<gdkWJb=6RVClQ<2lb;B@[8RPX:B/T8b8T<HAQLJ3E_m2/Z;o>_lG?_/Vl
diZScj^nS=bUdgoFB=ko[ol0QWmo/lZoa=C5a:Bh`[no/knjckO;am:Df/VKO>;B
[lSAXKb_]=:eYgGDOXfTYKf9/HnBS>5Kf=72aLk?^=2R_k:P_;R]a/G5eLS3b=^c
dln`IALU;c0d;2T[9RTW:B/V920IGF]RBMbb_lC;`=F[alfY/]^ifJO;Y>>]gY2a
`7k]V0>oe`00QWmUN9gDZ[3@]/FK_lfhWln`e9f]]/GRQ<bb[kjLala]jhRCXg=b
U]NFciY_L]C4RWjoXjSMU;Bhb<:n_lG7c/;5_lfhPl;5Zl_8f[k:b=;1fbHY6R`a
<BTV92DW:2<W7RLGGV25HZW7^ko5c/S=a:_4VLF__l^oc:FlJlV0XmRmI@?0N@00
0?l\>"], "Graphics",
  TextAlignment->Center,
  ImageSize->{131, 202.5},
  ImageMargins->{{185, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Thomas R. Malthus
(1766 - 1834)\
\>", "Text",
  TextAlignment->Center,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tWe start our quantitative discussion with the simple and justly famous \
model based on Malthus' ideas (said by Murray op.cit., p. 2,  to have been \
suggested even earlier by Euler).  We denote the time-dependent population by \
",
  StyleBox["N",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ").  The basic assumptions of the model are a constant birth rate per \
capita ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", and a constant death rate per capita ",
  StyleBox["d",
    FontSlant->"Italic"],
  ".  The effect of immigration is ignored.  Then the differential equation \
governing ",
  StyleBox["N",
    FontSlant->"Italic"],
  " is  "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[
            StyleBox["dN",
              FontSlant->"Italic"], 
            StyleBox["dt",
              FontSlant->"Italic"]], " ", "=", " ", 
          StyleBox[\(bN - dN\),
            FontSlant->"Italic"]}], 
        StyleBox["   ",
          FontSlant->"Italic"], 
        StyleBox[",",
          FontSlant->"Italic"], 
        StyleBox[
          "                                                                   \
                             ",
          FontSlant->"Italic"], 
        StyleBox[\((1)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell["which we solve to get", "Text"],

Cell[TextData[{
  "N",
  StyleBox["(",
    FontSlant->"Plain"],
  "t",
  StyleBox[") = ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\((b - d)\) \((t - t\_0)\)\)\)]],
  "   ,                                                                       \
 ",
  StyleBox["(2)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  " is the population at the initial time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ".  Equation (2) is the mathematical form of Malthus' insight:  if the \
birth rate exceeds the death rate, then the population will grow \
exponentially without limit; if the death rate exceeds the birth rate, the \
species will disappear.  Thus Malthus has given every population two equally \
grim paths.  For most species at most times, ",
  StyleBox["b ",
    FontSlant->"Italic"],
  "exceeds ",
  StyleBox["d",
    FontSlant->"Italic"],
  ", so that the population will grow  -- without limit according to the \
model, but in reality to some limit determined by constraints not included in \
the model.  Most such constraints that one can think of -- war, famine, \
pestilence -- are dramatic and unpleasant.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2  The Logistic Model", "Subsubsection"],

Cell[TextData[{
  "\tNote the singular \"Principle\" in the title of Malthus' book.  \
Exponential growth is indeed an important consequence of ",
  StyleBox["b ",
    FontSlant->"Italic"],
  "> ",
  StyleBox["d",
    FontSlant->"Italic"],
  ", but there are other principles in population biology and other possible \
outcomes.  P.F. Verhulst in 1838 was one of the first to incorporate a limit \
to growth in the original model, rather than having all such limits \
implicitly awaiting a catastrophic collision with the solution of the \
Malthusian model.  The equation Verhulst proposed, called the logistic \
equation, has remained useful to this day.  It is based on the idea that a \
given species in a given environment has a maximum sustainable population.  \
This is certainly consistent with Malthus' ideas, but it remained for \
Verhulst to incorporate this concept into the population equation.  Let's \
call this maximum sustainable population ",
  StyleBox["K.  ",
    FontSlant->"Italic"],
  "Then Verhulst argued that the net per capita growth rate -- birth rate \
minus death rate -- must decrease as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " approaches ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", and go negative when ",
  StyleBox["N",
    FontSlant->"Italic"],
  " exceeds ",
  StyleBox["K.  ",
    FontSlant->"Italic"],
  "The simplest function which does this is ",
  StyleBox["r",
    FontSlant->"Italic"],
  "(1 - ",
  StyleBox["N",
    FontSlant->"Italic"],
  "/",
  StyleBox["K",
    FontSlant->"Italic"],
  "), where ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is a positive constant.  With this assumption for the net per capita \
growth rate, we get the logistic equation:       "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          StyleBox["dN",
            FontSlant->"Italic"], 
          RowBox[{
            StyleBox["dt",
              FontSlant->"Italic"], " "}]], " ", "=", " ", 
        RowBox[{
          StyleBox["rN",
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                RowBox[{
                  StyleBox["N",
                    FontSlant->"Italic"], "/", 
                  StyleBox["K",
                    FontSlant->"Italic"]}]}], ")"}], "       ", ".", 
            "                                                                 \
                               ", 
            StyleBox[\((3)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "When ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[LessLess] ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", equation (3) reduces to Malthus' equation (1) with ",
  StyleBox["r = b ",
    FontSlant->"Italic"],
  "- ",
  StyleBox["d",
    FontSlant->"Italic"],
  ".  Thus solutions of the logistic equation exhibit exponential growth if \
they start at values far below the maximum.  As ",
  StyleBox["N",
    FontSlant->"Italic"],
  " approaches ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dN",
    FontSlant->"Italic"],
  "/",
  StyleBox["dt",
    FontSlant->"Italic"],
  " will approach zero, and we expect the population to level off \
asymptotically to the value ",
  StyleBox["K",
    FontSlant->"Italic"],
  ".  The same argument applies if the population happens to start above ",
  StyleBox["K",
    FontSlant->"Italic"],
  ":  it will decrease and again approach ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", this time from above.  These statements can be verified from the \
solution, which is easily obtained for this separable equation: "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"  ", 
        RowBox[{
          RowBox[{
            StyleBox[\(N \((t)\)\),
              FontSlant->"Italic"], "=", " ", 
            FractionBox[
              StyleBox[\(\(N\_0\) K\),
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox[\(N\_0\),
                  FontSlant->"Italic"], " ", "+", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["K",
                        FontSlant->"Italic"], " ", "-", 
                      StyleBox[" ",
                        FontSlant->"Italic"], 
                      StyleBox[\(N\_0\),
                        FontSlant->"Italic"]}], 
                    StyleBox[")",
                      FontSlant->"Italic"]}], 
                  SuperscriptBox[
                    StyleBox["e",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox[\(-r\),
                        FontSlant->"Italic"], 
                      RowBox[{
                        StyleBox["(",
                          FontSlant->"Italic"], 
                        RowBox[{
                          StyleBox["t",
                            FontSlant->"Italic"], 
                          StyleBox["-",
                            FontSlant->"Italic"], 
                          StyleBox[\(t\_0\),
                            FontSlant->"Italic"]}], 
                        StyleBox[")",
                          FontSlant->"Italic"]}]}]]}]}]]}], "  ", ",", 
          "                                                                   \
                        ", 
          StyleBox[\((4)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  " is the population at the initial time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ".  It is not hard to show that for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  " \[LessLess] ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", and for times not too large (so that ",
  StyleBox["K",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-\(r(t - t\_0)\)\)\)]],
  "\[GreaterGreater] ",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  "), the solution (4) reduces to the Malthus solution (2).  "
}], "Text"],

Cell[TextData[{
  "\tThe logistic model has two equilibrium solutions:  ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = 0 and ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = ",
  StyleBox["K",
    FontSlant->"Italic"],
  ".  It is fairly clear from the formula (4) for the solution that the first \
of these is unstable and the second is stable.  We can also establish that by \
a stability analysis.   Let ",
  StyleBox["F",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") be the right-hand side of equation (3).  Then"
}], "Text"],

Cell[TextData[{
  "F'",
  StyleBox["(",
    FontSlant->"Plain"],
  "N",
  StyleBox[") = ",
    FontSlant->"Plain"],
  "r",
  StyleBox["(1 -",
    FontSlant->"Plain"],
  " 2N",
  StyleBox["/",
    FontSlant->"Plain"],
  "K)     .                                                                   \
  ",
  StyleBox["(5)",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "The stability is determined by the sign of ",
  StyleBox["F'",
    FontSlant->"Italic"],
  " at the equilibrium point.  We have ",
  StyleBox["F'",
    FontSlant->"Italic"],
  "(0) = ",
  StyleBox["r",
    FontSlant->"Italic"],
  " > 0 and ",
  StyleBox["F'",
    FontSlant->"Italic"],
  "(",
  StyleBox["K",
    FontSlant->"Italic"],
  ") = -",
  StyleBox["r",
    FontSlant->"Italic"],
  " < 0, so ",
  StyleBox["N ",
    FontSlant->"Italic"],
  "= 0 is unstable and ",
  StyleBox["N = K",
    FontSlant->"Italic"],
  " is stable, as we expected."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3  Comparison of Malthusian and Logistic Models", "Subsubsection"],

Cell[TextData[{
  "\tWe start with a simple mathematical example, just to see what the \
solutions look like for the Malthusian and logistic models.  We define the \
solutions for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " first. "
}], "Text"],

Cell[BoxData[
    \(Mal[t_] := N0*Exp[r*\((t - t0)\)]\)], "Input"],

Cell[BoxData[
    \(Logistic[
        t_] := \((N0*
            K)\)/\((N0 + \((K - N0)\)*Exp[\(-r\)*\((t - t0)\)])\)\)], "Input"],

Cell[TextData[{
  "We measure ",
  StyleBox["N",
    FontSlant->"Italic"],
  " and ",
  StyleBox["K",
    FontSlant->"Italic"],
  " in millions, and ",
  StyleBox["r",
    FontSlant->"Italic"],
  " in inverse years.  We arbitrarily assign the values below."
}], "Text"],

Cell[BoxData[
    \(N0 = 0.05; K = 1.0; r = 0.025; t0 = 0.0;\)], "Input"],

Cell[TextData[{
  "Now we plot our populations for 300 years, using red for the Malthusian \
curve, blue for the logistic curve, and green for the logistic asymptotic \
maximum ",
  StyleBox["K",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(graph1 = 
        Plot[{Mal[t], Logistic[t], K}, {t, 0, 300}, 
          AxesLabel -> {"\<yr\>", "\<Millions\>"}, PlotRange -> {0, 1.5}, 
          PlotStyle -> {RGBColor[1, 0, 0], RGBColor[0, 0, 1], 
              RGBColor[0, 1, 0]}];\)\)], "Input"],

Cell[TextData[{
  "This shows most of the features we discussed earlier.  For small times, \
the Malthusian and logistic curves coincide.  After about 50 years, the \
curves separate as the constraint effects in the logistic model become \
appreciable.  As still more time elapses, the logistic curve approaches the \
asymptote from below.  It is evident from the graph that the curvature of the \
logistic solution changes sign.  One may show easily that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(d\^2\), 
          RowBox[{"N", "/", 
            SuperscriptBox[
              StyleBox["dt",
                FontSlant->"Italic"], "2"]}]}], TraditionalForm]]],
  "= 0 at ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = ",
  StyleBox["K",
    FontSlant->"Italic"],
  "/2, so that the sign change occurs at half-maximum population.  "
}], "Text"],

Cell[TextData[{
  "\tThe graph above seems to support the view that Malthusian models head \
rapidly toward catastrophe, whereas logistic models smoothly approach a \
steady-state.  It is important to understand, however, that the steady-state \
in a logistic model may well be the horrific mix of famine, war and \
pestilence envisioned by Malthus.  The difference in the two models is that \
the logistic equation portrays an event which is only implicit in the \
Malthusian model.  Whether the state ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = ",
  StyleBox["K",
    FontSlant->"Italic"],
  " is a Malthusian hell, a utopia, or something in between, depends entirely \
on the social and economic factors that determine ",
  StyleBox["K",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4  The Logistic Model and the US Population", "Subsubsection"],

Cell[TextData[{
  "\tAn important question which we have ignored so far is the validation of \
a population model.  The applicability of the model can be determined only by \
comparison with data.  As an example, let's attempt to fit the US census data \
to the logistic model.  We take the data from ",
  StyleBox["The World Almanac Book of Facts",
    FontWeight->"Bold"],
  ", Funk and Wagnalls, 1993, as presented in the CD ",
  StyleBox["Microsoft",
    FontWeight->"Bold"],
  " ",
  StyleBox["Bookshelf '94",
    FontWeight->"Bold"],
  ".  We round the data to the nearest 1000 and use millions for units.  The \
data is entered in a list of pairs, with the year being the first member of \
each pair and the population the second.  We call the list censlist.  "
}], "Text"],

Cell[BoxData[
    \(\(censlist = {{1790, 3.929}, {1800, 5.308}, {1810, 7.240}, {1820, 
            9.638}, {1830, 12.861}, {1840, 17.063}, {1850, 23.192}, {1860, 
            31.443}, {1870, 38.558}, {1880, 50.189}, {1890, 62.980}, {1900, 
            76.212}, {1910, 92.228}, {1920, 106.021}, {1930, 123.203}, {1940, 
            132.165}, {1950, 151.326}, {1960, 179.323}, {1970, 
            203.302}, {1980, 226.542}, {1990, 248.710}};\)\)], "Input"],

Cell[TextData[{
  "To test the model, we will use the data from 1790 through 1920 to find the \
parameters ",
  StyleBox["r",
    FontSlant->"Italic"],
  " and ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", and then we will see how well the data beyond 1920 is fit by the \
solution with those parameter values. "
}], "Text"],

Cell[TextData[{
  "\tWhile it would be possible to do a full nonlinear regression to \
determine both ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", that is a more elaborate procedure than the problem warrants.  Instead \
we note from the last data point that we expect ",
  StyleBox["K",
    FontSlant->"Italic"],
  " to be larger than 248.710, so that the early data points, for which ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[LessLess] 248.710",
  StyleBox[",",
    FontSlant->"Italic"],
  " should be in the Malthusian range of the process.  This suggests that we \
fit the early data to the Malthusian solution to determine ",
  StyleBox["r",
    FontSlant->"Italic"],
  ".  After that we will seek ",
  StyleBox["K.  ",
    FontSlant->"Italic"]
}], "Text"],

Cell["\<\
\tBy taking the logarithm of the Malthusian solution (2), we \
get\
\>", "Text"],

Cell[TextData[{
  "log(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") - log(",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  ") = ",
  StyleBox["r",
    FontSlant->"Italic"],
  "(",
  StyleBox["t - ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(t\_0)\)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["  .                                                        ",
    FontSize->13,
    FontSlant->"Italic"],
  StyleBox["(6)",
    FontSize->13,
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "We can estimate ",
  StyleBox["r",
    FontSlant->"Italic"],
  " by doing a linear regression on log(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") - log",
  Cell[BoxData[
      \(TraditionalForm\`\((N\_0\)\)]],
  ") versus (",
  StyleBox["t ",
    FontSlant->"Italic"],
  "- ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ").  We transform the data list so that each element in the list has the \
form {",
  StyleBox["t",
    FontSlant->"Italic"],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ", log(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") - log(",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  ")}, and we call the transformed list logcenslist:"
}], "Text"],

Cell[BoxData[
    \(\(logcenslist = 
        Module[{logger, firs, 
            delta}, \n\t\tlogger[{t_, N_}] := {t, Log[N]}; \n\t\tfirs = 
            logger[censlist[\([1]\)]]; \n\t\tdelta[lis_] := 
            lis - firs; \n\t\tMap[delta, 
            Map[logger, censlist]]];\)\)], "Input"],

Cell[TextData[{
  "Now we define a function which fits the first ",
  StyleBox["n",
    FontSlant->"Italic"],
  " data points, and then returns the value of ",
  StyleBox["r.",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(regress[
        n_] := \(CoefficientList[Fit[Take[logcenslist, n], {t}, t], 
          t]\)[\([2]\)]\)], "Input"],

Cell[TextData[{
  "We use this function to make a short table of values of ",
  StyleBox["r",
    FontSlant->"Italic"],
  " for values of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " from 2 to 10."
}], "Text"],

Cell[BoxData[
    \(Table[{i, regress[i]}, {i, 2, 10}]\)], "Input"],

Cell[TextData[{
  "We see that there is not a large change in ",
  StyleBox["r",
    FontSlant->"Italic"],
  " as the fitting base is enlarged.  If the logistic model is a correct \
description of the US population, then it is the earliest times at which the \
data will most closely resemble a Malthusian population.  Thus we will take a \
value of ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "= 0.03, corresponding to the time interval 1790 to about 1820 or 1830.  We \
will use this value of ",
  StyleBox["r",
    FontSlant->"Italic"],
  " and then fit the data from 1790 to 1920 to the logistic law, thereby \
determining a value for ",
  StyleBox["K",
    FontSlant->"Italic"],
  ".  We start by setting the values of ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", the initial population ",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  ", and the initial time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(r = 0.03; N0 = 3.929; t0 = 1790;\)], "Input"],

Cell[TextData[{
  "\tIn finding ",
  StyleBox["K ",
    FontSlant->"Italic"],
  "from the data, we again opt for something simpler than a nonlinear \
regression.  This time we use a graphical trial and error approach.  We guess \
a value of ",
  StyleBox["K",
    FontSlant->"Italic"],
  ", and then plot both the logistic function and the census data on the same \
graph, from 1790 to 1920.  We first construct the plot of the data, and then \
we define a routine which plots the logistic curve and the data together."
}], "Text"],

Cell[BoxData[
    \(\(datgraph = 
        ListPlot[censlist, PlotRange -> {{1788, 1923}, {0, 120}}, 
          AxesLabel -> {"\<year\>", "\<N (millions)\>"}, 
          PlotLabel -> "\<US Population\>", AxesOrigin -> {1790, 0}, 
          PlotStyle -> {PointSize[0.02]}];\)\)], "Input"],

Cell[BoxData[
    \(compare[maxpop_] := 
      Module[{logiplot}, K = maxpop; 
        logiplot = 
          Plot[Logistic[t], {t, 1790, 1922}, PlotRange -> {0, 120}, 
            AxesLabel -> {"\<year\>", "\<N (millions)\>"}, \n\t\t\t\t\
PlotLabel -> "\<US Population\>", AxesOrigin -> {1790, 0}, 
            DisplayFunction -> Identity]; 
        Show[{logiplot, datgraph}, DisplayFunction -> $DisplayFunction, 
          PlotRange -> {{1788, 1923}, {0, 120}}]]\)], "Input"],

Cell[TextData[{
  "Now we try a comparison with ",
  StyleBox["K",
    FontSlant->"Italic"],
  " = 170."
}], "Text"],

Cell[BoxData[
    \(\(compare[170];\)\)], "Input"],

Cell["\<\
The theoretical curve lies below the data, so we try a larger \
maximum population.\
\>", "Text"],

Cell[BoxData[
    \(\(compare[200];\)\)], "Input"],

Cell["Still a little low.  Once more:", "Text"],

Cell[BoxData[
    \(\(compare[230];\)\)], "Input"],

Cell["One more time.", "Text"],

Cell[BoxData[
    \(\(compare[240];\)\)], "Input"],

Cell[TextData[{
  "\tImagine that the year is 1920, and you have just completed the above \
calculation.  The fit of the logistic curve to the data is good for ",
  StyleBox["K",
    FontSlant->"Italic"],
  " = 240.  On the basis of this calculation, you might claim that the \
logistic model describes the US population, and that the asymptotic maximum \
population we are approaching is 240 million.  If you did make this claim, \
you would be very wrong.  For the year 1990, this model predicts"
}], "Text"],

Cell[BoxData[
    \(Logistic[1990]\)], "Input"],

Cell[TextData[{
  "The actual population in 1990 was 249 million.  The point here is an \
important one.  The only thing we have accomplished in our 1920 calculation \
was a curve fit to the data.  To use that curve fit for 1990 is an \
unwarranted and dangerous extrapolation.  Only if we have some fundamental \
reason for ",
  StyleBox["believing",
    FontSlant->"Italic"],
  " the logistic model would we attempt to use it to predict the future.  But \
we have no such reason.  In fact, a model with only two constant parameters \
is unlikely to describe accurately an event as complex as the growth of the \
US population over a span of 200 years.  "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["III.  More General Models", "Section"],

Cell[CellGroupData[{

Cell["3.1  General Properties of Birth and Death Rates", "Subsubsection"],

Cell[TextData[{
  "\tIn our discussion of the Malthusian model, we started by considering \
separately the per capita birth rate ",
  StyleBox["b",
    FontSlant->"Italic"],
  " and the per capita death rate ",
  StyleBox["d",
    FontSlant->"Italic"],
  ".  Each of these processes produces a term in the right-hand side of \
equation (1).  When we turned to the logistic equation, however, our \
discussion blurred this distinction.  We simply took the net (births minus \
deaths) per capita rate to be ",
  StyleBox["r",
    FontSlant->"Italic"],
  "(1 - ",
  StyleBox["N",
    FontSlant->"Italic"],
  "/",
  StyleBox["K",
    FontSlant->"Italic"],
  ").  If one asks what are the birth and death rates in the logistic model, \
there is not a unique answer.  Let's take a more systematic approach here, \
and begin by listing the properties we expect the birth and death rates to \
have.  We denote the per capita birth rate by the function ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  "), and the per capita death rate by the function ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ").  In reality these functions also may depend explicitly on time, but we \
ignore that possibility for now.  The population model, in terms of these \
functions (and in the absence of immigration) is    "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(dN\/dt\),
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], "=", "  ", 
        RowBox[{
          RowBox[{
            StyleBox["{",
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["(",
                    FontWeight->"Plain"], 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["-",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["d",
                  FontWeight->"Plain",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["(",
                    FontWeight->"Plain"], 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}]}], 
            StyleBox["}",
              FontWeight->"Plain"]}], 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic"], 
            StyleBox["     ",
              FontWeight->"Plain"], 
            StyleBox[".",
              FontWeight->"Plain"], 
            
            StyleBox[
              "                                                               \
                               ",
              FontWeight->"Plain"], 
            StyleBox[\((7)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "\tLet's begin with the per capita birth rate.  We assume that ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") is continuous and in addition has the following three properties:  (1) ",
  
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") \[GreaterEqual] 0 and ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(0) > 0;  (2) ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`N\_1\)]],
  ") \[GreaterEqual] ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`N\_2\)]],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_1\)]],
  "< ",
  Cell[BoxData[
      \(TraditionalForm\`N\_2\)]],
  "; and (3) ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") \[ShortRightArrow] 0 as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[ShortRightArrow] \[Infinity].  Property (1) is just the obvious \
requirement that the birth rate be non-negative, with the added stipulation \
that the rate is actually positive for very small populations.  Property (2) \
says that the birth rate is a non-increasing function of population.  This \
will surely be true for ",
  StyleBox["N",
    FontSlant->"Italic"],
  " sufficiently large, and we make the simplifying assumption here that it \
is true for all ",
  StyleBox["N",
    FontSlant->"Italic"],
  ".   Property (3) requires that the birth rate go to zero as the population \
becomes arbitrarily large.  It is hard to quarrel with properties (1) and \
(3), but it is not hard to imagine a reasonable situation in which property \
(2) is violated.  For example, a population which is too small may have fewer \
mating encounters per capita than a larger population, and hence the per \
capita birth rate would actually increase with increasing ",
  StyleBox["N",
    FontSlant->"Italic"],
  ", at least for certain range of ",
  StyleBox["N",
    FontSlant->"Italic"],
  ".  Nevertheless in the interests of simplicity, we will impose the three \
properties as stated on our choices of ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ").      "
}], "Text"],

Cell[TextData[{
  "\tNow we consider the per capita death rate.  We assume that ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") is continuous and in addition has the following three properties:  (1) ",
  
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") > 0;  (2) ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`N\_1\)]],
  ") \[LessEqual] ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`N\_2\)]],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_1\)]],
  "< ",
  Cell[BoxData[
      \(TraditionalForm\`N\_2\)]],
  "; (3) ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") \[Rule] \[Infinity] as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[Rule] \[Infinity].  Property (1) is the obvious condition that the \
death rate be positive for all levels of population.  Property (2) says that \
the death rate is an increasing function of population.   This will surely be \
true for sufficiently large ",
  StyleBox["N",
    FontSlant->"Italic"],
  ", and we make the simplifying assumption here that it is true for all ",
  StyleBox["N",
    FontSlant->"Italic"],
  ".  Property (3) says that the death rate becomes arbitrarily large as the \
population becomes arbitrarily large.  This is a bit of an \
oversimplification.  In the absence of food or in the presence of a \
catastrophe the death rate will be very large but finite.  The difference is \
irrelevant for the fate of the population, and the introduction of a large \
but finite asymptotic death rate would just add one more parameter to the \
problem with no real gain in insight.      "
}], "Text"],

Cell[TextData[{
  "\tThe purpose of the mathematical assumptions we have just made is not \
profound.  It is simply to limit the huge range of possibilites for \
population models.  To illustrate the possibilities consistent with these \
assumptions, we list below five choices which satisfy them.  All quantities \
with zero or asterisk subscripts are positive constants.  In Model C, ",
  StyleBox["p",
    FontSlant->"Italic"],
  " > 1."
}], "Text"],

Cell[TextData[{
  "\t\tModel A:\t",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " for ",
  StyleBox["N \[LessEqual] ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = (",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")/",
  StyleBox["N",
    FontSlant->"Italic"],
  " for ",
  StyleBox["N",
    FontSlant->"Italic"],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ",\n\t\t\t\t",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  " for ",
  StyleBox["N \[LessEqual] ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ", ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = (",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  StyleBox["N",
    FontSlant->"Italic"],
  ")/",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " for ",
  StyleBox["N",
    FontSlant->"Italic"],
  " > ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t\tModel B:\t",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\([\(N\_*\)\)\)]],
  "/(",
  StyleBox["N",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")] ,\n\t\t\t\t",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "[(",
  StyleBox["N",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")/",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  "] ."
}], "Text"],

Cell[TextData[{
  "\t\tModel C:\t",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`\([\(N\_*\)\)\)]],
  "/(",
  StyleBox["N",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")",
  Cell[BoxData[
      \(TraditionalForm\`\(]\^p\)\)]],
  ",\n\t\t\t\t",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "[(",
  StyleBox["N",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(/ N\)\_*\)]\)\^p\)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\t\tModel D:\t",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  Cell[BoxData[
      \(TraditionalForm\`exp\)]],
  "(-",
  StyleBox["N",
    FontSlant->"Italic"],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ") ,\n\t\t\t\t",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "exp(",
  StyleBox["N",
    FontSlant->"Italic"],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ") ."
}], "Text"],

Cell[TextData[{
  "\t\tModel E:\t",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "sech(",
  StyleBox["N",
    FontSlant->"Italic"],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")  ,\n\t\t\t\t",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "cosh(",
  StyleBox["N",
    FontSlant->"Italic"],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ")  ."
}], "Text"],

Cell["In the next section, we will explore Model B in detail.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2  An Example (Model B)", "Subsubsection"],

Cell[TextData[{
  "\tLet's look first at the birth rate in Model B.  We have ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  ", and ",
  StyleBox["b ",
    FontSlant->"Italic"],
  "decreases monotonically from that value to zero as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " increases.  For ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ", ",
  StyleBox["b = ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  ", so we see that the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " is a measure of the population size at which resource limitations have an \
appreciable effect on the birth rate.  Thus ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  "has a significance somewhat like that of ",
  StyleBox["K",
    FontSlant->"Italic"],
  " in the logistic model, although it is more a scale than a maximum."
}], "Text"],

Cell[TextData[{
  "\tSimilar considerations apply to the death rate ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ").  We have ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(0) = ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  ", with ",
  StyleBox["d",
    FontSlant->"Italic"],
  " increasing monotonically from that value as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " increases.  For ",
  StyleBox["N",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ", ",
  StyleBox["d",
    FontSlant->"Italic"],
  " = 2",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  ", and as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[Rule] \[Infinity] , ",
  StyleBox["d ",
    FontSlant->"Italic"],
  "becomes far larger than ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ".  Thus ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " is a measure of the population level at which resource limitations have \
begun to cause a significant increase in the death rate.  In this model, the \
population scale for resource limitations, namely ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ", is the same for the birth rate and the death rate.  In general, these \
two scales could be different, but for simplicity we take them to be the \
same."
}], "Text"],

Cell[TextData[{
  "\tA few comments on the other models are in order here.  Model A is a pure \
Malthusian model for ",
  StyleBox["N",
    FontSlant->"Italic"],
  " < ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ", but looks like Model B for ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[GreaterGreater]",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ".    Model C is very much like Model B, except that the transition between \
plenty and want is sharper because of the exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  " > 1.  Model D is algebraic in variation for small ",
  StyleBox["N",
    FontSlant->"Italic"],
  ", but exponential for larger ",
  StyleBox["N",
    FontSlant->"Italic"],
  ".  Model E is very similar to Model D."
}], "Text"],

Cell["\tThe basic differential equation for Model B is", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[
          StyleBox["dN",
            FontSlant->"Italic"], 
          StyleBox["dt",
            FontSlant->"Italic"]], "=", " ", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox[\(b\_0\),
                  FontSlant->"Italic"], 
                FractionBox[
                  StyleBox[\(N\_*\),
                    FontSlant->"Italic"], 
                  RowBox[{
                    StyleBox["N",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "+", 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[\(N\_*\),
                      FontSlant->"Italic"]}]]}], " ", "-", 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox[\(d\_0\),
                  FontSlant->"Italic"], 
                FractionBox[
                  RowBox[{
                    StyleBox["N",
                      FontSlant->"Italic"], " ", "+", 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[\(N\_*\),
                      FontSlant->"Italic"]}], 
                  StyleBox[\(N\_*\),
                    FontSlant->"Italic"]]}]}], "}"}], 
          RowBox[{
            StyleBox["N",
              FontSlant->"Italic"], 
            StyleBox["        ",
              FontSlant->"Italic"], 
            StyleBox[".",
              FontSlant->"Italic"], 
            
            StyleBox[
              "                                                               \
 ",
              FontSlant->"Italic"], 
            StyleBox[\((8)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell["\<\
We can reduce the number of parameters by some simple scaling.  We \
introduce\
\>", "Text"],

Cell[TextData[{
  "n ",
  StyleBox["= ",
    FontSlant->"Plain"],
  "N",
  StyleBox["/",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " ,  ",
  StyleBox["\[Lambda] = ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  StyleBox[",  and  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`t\&^\)]],
  StyleBox["  = ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "t   .                                                         ",
  StyleBox["(9)",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox[" ",
    FontSlant->"Plain"]
}], "Text",
  TextAlignment->Right,
  FontSlant->"Italic"],

Cell[TextData[{
  "Then the differential equation becomes (after dropping the hat on the ",
  StyleBox["t",
    FontSlant->"Italic"],
  ")"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(dn\/dt\),
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], "=", "  ", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              FractionBox["1", 
                RowBox[{
                  StyleBox["n",
                    FontSlant->"Italic"], " ", "+", " ", "1"}]], " ", "-", 
              " ", 
              FractionBox[
                RowBox[{
                  StyleBox["n",
                    FontSlant->"Italic"], " ", "+", " ", "1"}], 
                "\[Lambda]"]}], "}"}], 
          RowBox[{
            StyleBox["n",
              FontSlant->"Italic"], "      ", ".", 
            "                                                                 \
                   ", 
            StyleBox[\((10)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[
"Now there is only a single parameter \[Lambda], which is equal to the ratio \
of the per capita birth rate to the per capita death rate in limit N \
\[Rule]0, when resources are not limiting.  Thus \[Lambda], which we call the \
fecundity ratio, is a number more characteristic of the species than the \
situation.  For now we make the reasonable assumption that \[Lambda] > 1, \
since otherwise a small initial population could never grow."], "Text"],

Cell[TextData[{
  "\tWe begin our analysis of equation (10) by looking at the equilibrium \
states. There are two with non-negative values of ",
  StyleBox["n",
    FontSlant->"Italic"],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ n\_1\)\)]],
  "= 0, and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\)]],
  " - 1.  The stability of each is determined by the sign of the slope \
function."
}], "Text"],

Cell[BoxData[
    \(\(rhsB = \((1/\((n + 1)\) - \((n + 1)\)/\[Lambda])\)*n;\)\)], "Input"],

Cell[BoxData[
    \(\(n1 = 0;\)\)], "Input"],

Cell[BoxData[
    \(\(n2 = \@\[Lambda]\  - \ 1;\)\)], "Input"],

Cell[BoxData[
    \(D[rhsB, n] /. n -> n1\)], "Input"],

Cell["which is positive, and", "Text"],

Cell[BoxData[
    \(D[rhsB, n] /. n -> n2\)], "Input"],

Cell[TextData[{
  "which is negative.  Thus the equilibrium at ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  "= 0 is unstable (a seed population will grow), and the equilbrium at ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\)]],
  " - 1 is stable.   "
}], "Text"],

Cell[TextData[{
  "\tAlthough equation (8), being separable, is easily solved, the resulting \
form of the solution is not convenient.  (The main use of the analytical \
solution is in obtaining simple and explicit asymptotic results for large \
time behavior.)  Therefore we will solve the equation numerically in order to \
see what the solution looks like.  We do the integration with DynPac, which \
must be loaded at this point.  (This is done by opening and evaluating the \
notebook Dynsys.nb.)  The command sysid below simply records the version of ",
  
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the version of DynPac, and the date."
}], "Text"],

Cell[BoxData[
    \(sysid\)], "Input"],

Cell[TextData[{
  "Now we define the system for DynPac by specifying the state vector {",
  StyleBox["n",
    FontSlant->"Italic"],
  "}, the parameter vector {\[Lambda]}, the slope vector (rhsB as defined \
above), and the optional system name Model B."
}], "Text"],

Cell[BoxData[
    \(\(setstate[{n}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[Lambda]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {rhsB};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Model B\>";\)\)], "Input"],

Cell[TextData[{
  "\tWe somewhat arbitrarily take \[Lambda] = 4, and look at a solution when \
the initial population is small (corresponding to ",
  StyleBox["N",
    FontSlant->"Italic"],
  "\[LessLess]",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ").  We take an initial value n0 = 0.01. "
}], "Text"],

Cell[BoxData[
    \(parmval = {4}; n0 = {0.01};\)], "Input"],

Cell["\<\
We take the initial time to be t0 = 0, and the time step to be h = \
0.02, with the number of timesteps nsteps = 1000.\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0; h = 0.02; nsteps = 1000;\)], "Input"],

Cell["\<\
Now we construct the solution and then plot it, after adjusting the \
aspect ratio for the plot.\
\>", "Text"],

Cell[BoxData[
    \(\(solB1 = integrate[n0, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(graphsolB1 = timeplot[solB1, 1];\)\)], "Input"],

Cell[TextData[{
  "\tThe equilibrium population in this case is ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\)]],
  " - 1 = 1, and we see that we are about 80% there after 10 time units (10/",
  
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " dimensional time units).  "
}], "Text"],

Cell[TextData[
"\tLet's study how the solution depends on the parameter \[Lambda].  We do \
this by defining a function which will produce a combination of time plots \
for several solutions, each at a different value of \[Lambda].  The argument \
parmlist is a list of the parameter values -- in this case the  \[Lambda] \
values -- for which the solution is to be obtained."], "Text"],

Cell[BoxData[
    \(\(\(multigraph[parmlist_, n0_, t0_, h_, 
        nsteps_]\)\(:=\)\(Module[{ansgraph, lenparm, i, temsol, temgraph, 
          temlab}, ansgraph = {}; lenparm = Length[parmlist]; 
        display = False; \n\t\ttemlab = labon; \n\t\tlabon = \ 
          SequenceForm[parmvec, "\< = \>", parmlist]; \n\t\tDo[
          parmval = 
            parmvec /. \n\t\t\t\t\tThread[
                parmvec -> parmlist[\([i]\)]]; \n\t\t\ttemsol = 
            integrate[n0, t0, h, nsteps]; \n\t\t\ttemgraph = 
            timeplot[temsol, 1]; \n\t\t\tansgraph = 
            Append[ansgraph, temgraph], {i, 1, lenparm}]; \n\t\tdisplay = \ 
          True; show[ansgraph]; 
        labon = temlab]\)\(\n\)\(\t\t\t\)\(\n\)\(\t\t\t\)\)\)], "Input"],

Cell[TextData[
"We construct the graph for four different values of \[Lambda], and we ask \
for four different colors for the curves."], "Text"],

Cell[BoxData[
    \(\(setcolor[{Blue, Green, Orange, Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(multigraph[{{2}, {4}, {8}, {16}}, n0, t0, h, nsteps];\)\)], "Input"],

Cell[TextData[{
  "\tWe see that in this scaling, the equilibrium state is reached in about \
the same time for every \[Lambda] , even though the equilibrium population, ",
  
  Cell[BoxData[
      \(TraditionalForm\`\@\[Lambda]\)]],
  " - 1, depends on \[Lambda] .  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3  Another Example (Model C)", "Subsubsection"],

Cell["\<\
\tNow we consider the generalization of Model B embodied in Model \
C.  We again scale the variables with the scaling given in equation (9).  \
Then the basic differential equation becomes\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(dn\/dt\),
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], "=", "  ", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              FractionBox["1", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["n",
                        FontSlant->"Italic"], " ", "+", " ", "1"}], ")"}], 
                  StyleBox["p",
                    FontSlant->"Italic"]]], " ", "-", " ", 
              FractionBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["n",
                        FontSlant->"Italic"], " ", "+", " ", "1"}], ")"}], 
                  StyleBox["p",
                    FontSlant->"Italic"]], "\[Lambda]"]}], "}"}], " ", 
          RowBox[{
            StyleBox["n",
              FontSlant->"Italic"], 
            StyleBox["      ",
              FontSlant->"Italic"], 
            StyleBox[".",
              FontSlant->"Italic"], 
            "                                                                 \
              ", 
            StyleBox[\((11)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "In this formulation, the only parameters are the exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  " and the fecundity ratio \[Lambda] = ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "/",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  ".  As before we assume that \[Lambda] > 1."
}], "Text"],

Cell["\<\
\tWe begin by looking at the non-negative equilbrium states, which \
are\
\>", "Text"],

Cell[BoxData[
    \(n1 = 0; n2 = \[Lambda]\^\(1/\((2\ p)\)\)\  - \ 1;\)], "Input"],

Cell["The slope function is", "Text"],

Cell[BoxData[
    \(\(rhsC = 
        n*\((1/\((n + 1)\)^p\ \  - \ \((n + 1)\)^p/\[Lambda])\);\)\)], "Input"],

Cell["\<\
The stability of each equilibrium is determined by the sign of the \
derivative of the slope function:\
\>", "Text"],

Cell[BoxData[
    \(D[rhsC, n] /. n -> n1\)], "Input"],

Cell["\<\
This is positive, so the zero population state is unstable, \
indicating that a small seed population will grow.\
\>", "Text"],

Cell[BoxData[
    \(FullSimplify[PowerExpand[D[rhsC, n] /. n -> n2]]\)], "Input"],

Cell["This is negative, indicating stability at n2.  ", "Text"],

Cell["\<\
\tEquation (11) is separable, but the solution is messy.  We can \
get what we need more easily from numerical solutions and plots.  We begin by \
defining the system for DynPac.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{n}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[Lambda], p}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {rhsC};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Model C\>";\)\)], "Input"],

Cell[TextData[{
  "We begin our calculations with \[Lambda] = 4, the first case that we did \
for Model B, but this time for the exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = 2."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {4, 2};\)\)], "Input"],

Cell["\<\
We set the initial time t0, the initial population n0, the time \
step h, and number of time steps nsteps:\
\>", "Text"],

Cell[BoxData[
    \(t0 = 0.0; n0 = {0.01}; h = 0.02; nsteps = 1000;\)], "Input"],

Cell["Now we construct the solution and plot it.", "Text"],

Cell[BoxData[
    \(\(solC1 = integrate[n0, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input"],

Cell[BoxData[
    \(\(graphsolC1 = timeplot[solC1, 1];\)\)], "Input"],

Cell[TextData[{
  "Now we compare this with the Model B result, in which the exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = 1."
}], "Text"],

Cell[BoxData[
    \(\(labon = "\<Models B & C\>";\)\)], "Input"],

Cell[BoxData[
    \(\(show[graphsolB1, graphsolC1];\)\)], "Input"],

Cell[BoxData[
    \(\(labon = True;\)\)], "Input"],

Cell["\<\
The equilibria are different, but the approach occurs on \
approximately the same time scale.\
\>", "Text"],

Cell[TextData[
"\tLet's look at a graph showing the variation with four different values of \
\[Lambda] for this case of exponent = 2."], "Text"],

Cell[BoxData[
    \(\(setcolor[{Blue, Green, Orange, Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(multigraph[{{2, 2}, {4, 2}, {8, 2}, {16, 2}}, n0, t0, h, 
        nsteps];\)\)], "Input"],

Cell[TextData[
"Qualitatively this is quite similar to the earlier case of Model B.  We make \
one last attempt at comparison by choosing a value of \[Lambda] in Model C \
which will give us the same equilibrium population as does \[Lambda] = 4 in \
Model B.  Thus we choose \[Lambda] = 16."], "Text"],

Cell[BoxData[
    \(\(parmval = {16, 2};\)\)], "Input"],

Cell[BoxData[
    \(\(solC2 = integrate[n0, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(graphsolC2 = timeplot[solC2, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(labon = "\<Models B & C With Same Equilibrium\>";\)\)], "Input"],

Cell[BoxData[
    \(\(show[graphsolB1, graphsolC2];\)\)], "Input"],

Cell[BoxData[
    \(\(labon = \ True;\)\)], "Input"],

Cell["\<\
As we would have predicted, the transition is a little sharper and \
quicker with the larger exponent, although the solutions are not very \
different. \
\>", "Text"],

Cell[TextData[{
  "\tAs a final parametric study with this model, let's vary the exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  ".  We will also vary \[Lambda] in such a way that the equilibrium state is \
the same (namely ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 1) in every case."
}], "Text"],

Cell[BoxData[
    \(\(parmlist = {{4, 1}, {8, 1.5}, {16, 2}, {32, 2.5}, {64, 
            3}};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{PrussianBlue, SpringGreen, YellowGreen, Firebrick, 
          DeepMadderLake}];\)\)], "Input"],

Cell[BoxData[
    \(\(imsize = 410;\)\)], "Input"],

Cell[BoxData[
    \(\(multigraph[parmlist, n0, t0, h, nsteps];\)\)], "Input"],

Cell[TextData[{
  "\tThe lesson from this graph is sobering -- namely that systems with very \
different values of \[Lambda] can look essentially alike.  By letting the \
exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  " vary, we can make such systems have the same equilibrium state and \
approximately the same time course in the approach to equilibrium. Thus many \
different plausible models can fit the same data.  We will explore this point \
a little more in the next section.   "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.4  Fitting Models to Data", "Subsubsection"],

Cell[TextData[{
  "\tThe problem of fitting real models to real data is far beyond the scope \
of this notebook.  A recent reference on this subject is ",
  StyleBox["The Ecological Detective",
    FontWeight->"Bold"],
  ", R. Hilborn and M. Mangel, Princeton University Press, 1997.  Our purpose \
here is simply to make clear the embarrassment of riches in the set of \
available models.  Whereas the primary form of raw data is a time series of \
population values, we assume (rather optimistically) that this data has been \
processed to yield experimental values of the small time (Malthusian) growth \
rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  " , the fecundity ratio ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " , and the equilibrium population ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\&\[Wedge]\)\)]],
  ".  In each case, we may choose the parameters of the theoretical models to \
match these.  The algebra is straightforward, and the results are given in \
the list below."
}], "Text"],

Cell[TextData[{
  "\tModel A:\t",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  " /(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\()\^\(1/2\)\)\)]],
  "  ."
}], "Text",
  TextAlignment->Left],

Cell[TextData[{
  "\tModel B:\t",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  " /(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\&\[Wedge]\)\)]],
  "/[(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\()\^\(1/2\)\)\)]],
  " - 1]  ."
}], "Text",
  TextAlignment->Left],

Cell[TextData[{
  "\tModel C:\t",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  " /(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\()\^\(1/\((2  p)\)\)\)\)]],
  "  ."
}], "Text",
  TextAlignment->Left],

Cell[TextData[{
  "\tModel D:\t",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  " /(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " = 2",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&\[Wedge]\)\_e\)]],
  "/log(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  ")  ."
}], "Text",
  TextAlignment->Left],

Cell[TextData[{
  "\tModel E:\t",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  " /(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_0\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  "/(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  " - 1) ,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&\[Wedge]\)\_e\)]],
  "/cos",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["h",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  "[(",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\()\^\(1/2\)\)\)]],
  "]  ."
}], "Text",
  TextAlignment->Left],

Cell[TextData[{
  "Thus all of the models can fit a data set described entirely in terms of ",
  
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\&\[Wedge]\)\)]],
  ".  In the case of Model C, the exponent ",
  StyleBox["p",
    FontSlant->"Italic"],
  " is undetermined, so that there is a one-parameter family which fits the \
data.   "
}], "Text"],

Cell[TextData[{
  "\tDo the curves look alike for the different models?  Let's give a sample \
answer to that question by plotting the solutions for the different models, \
all with the same values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&\[Wedge]\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\&\[Wedge]\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\&\[Wedge]\)\)]],
  ".  We use units of millions for population and years for time, and \
arbitrarily choose "
}], "Text"],

Cell[BoxData[
    \(lamhat = 10.0; rhat = 0.030; Ne = 100.0;\)], "Input"],

Cell["Then the initial birth and death rates are", "Text"],

Cell[BoxData[
    \(b0 = \((lamhat*rhat)\)/\((lamhat - 1)\)\)], "Input"],

Cell[BoxData[
    \(d0 = rhat/\((lamhat - 1)\)\)], "Input"],

Cell[TextData[{
  "The scale population ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  "will be different in each model.  Now we define the slope functions for \
the five models:"
}], "Text"],

Cell[BoxData[
    \(fA[n_] := 
      If[\((n < nstar)\), \((b0 - 
            d0)\), \((\((b0*nstar)\)/n\  - \ \((d0*n)\)/nstar)\)]\)], "Input"],

Cell[BoxData[
    \(\(slopeA = {n*fA[n]};\)\)], "Input"],

Cell[BoxData[
    \(\(slopeB = {n*b0*\((nstar/\((n + nstar)\))\) - 
            n*d0*\((\((n + nstar)\)/nstar)\)};\)\)], "Input"],

Cell[BoxData[
    \(\(slopeC = {n*b0*\((nstar/\((n + nstar)\))\)^p - 
            n*d0*\((\((n + nstar)\)/nstar)\)^p};\)\)], "Input"],

Cell[BoxData[
    \(\(slopeD = {n*b0*Exp[\(-n\)/nstar] - n*d0*Exp[n/nstar]};\)\)], "Input"],

Cell[BoxData[
    \(\(slopeE = {n*b0*Sech[n/nstar] - n*d0*Cosh[n/nstar]};\)\)], "Input"],

Cell["Now we define the nstar values:", "Text"],

Cell[BoxData[
    \(nstarA = Ne/Sqrt[lamhat]\)], "Input"],

Cell[BoxData[
    \(nstarB = Ne/\((Sqrt[lamhat] - 1)\)\)], "Input"],

Cell[BoxData[
    \(nstarC = Ne/\((lamhat^\((1/\((2*p)\))\) - 1)\)\)], "Input"],

Cell[BoxData[
    \(nstarD = 2*Ne/Log[lamhat]\)], "Input"],

Cell[BoxData[
    \(nstarE = Ne/ArcCosh[Sqrt[lamhat]]\)], "Input"],

Cell[TextData[{
  "\tWe will use DynPac to integrate each system, and we will plot the \
results for 500 years.  In the case of Model C, we will do this for ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = 2.  We take an initial population of 5 million.  We take a time step of \
0.5, an initial time of 0, and a number of time steps = 1000: "
}], "Text"],

Cell[BoxData[
    \(init = {5.0}; h = 0.5; nsteps = 1000; t0 = 0.0;\)], "Input"],

Cell["We now define the system for DynPac, starting with Model A.", "Text"],

Cell[BoxData[
    \(\(setstate[{n}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{nstar}];\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {nstarA};\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = slopeA;\)\)], "Input"],

Cell[BoxData[
    \(\(Asol = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell["\<\
Now we calculate in turn the solution for each of the other models. \
 At each change, we redefine the slope vector and the value of nstar.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(slopevec = slopeB;\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {nstarB};\)\)], "Input"],

Cell[BoxData[
    \(\(Bsol = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = slopeC;\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {nstarC};\)\)], "Input"],

Cell[BoxData[
    \(\(p = 2;\)\)], "Input"],

Cell[BoxData[
    \(\(Csol = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = slopeD;\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {nstarD};\)\)], "Input"],

Cell[BoxData[
    \(\(Dsol = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = slopeE;\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {nstarE};\)\)], "Input"],

Cell[BoxData[
    \(\(Esol = integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell["Now we plot them all on the same graph:", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Blue, Green, Orange, Yellow}];\)\)], "Input"],

Cell[BoxData[
    \(\(labon = "\<Model Comparison\>";\)\)], "Input"],

Cell[BoxData[
    \(\(biggraph = timeplot[{Asol, Bsol, Csol, Dsol, Esol}, 1];\)\)], "Input"],

Cell[TextData[{
  "\tAt early times, the systems all look alike, because we have imposed the \
same early time growth rate on each.  At large times, they all approach the \
same equilibrium as imposed on each.  All of the systems have the same \
fecundity ratio, again imposed.  They differ in the time course.  The \
hyperbolic Model E is the fastest to approach equilibrium.  The next fastest \
is Model A, the hybrid which looks exactly Malthusian until ",
  StyleBox["N",
    FontSlant->"Italic"],
  " has reached ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_*\)\)]],
  ".  The longest passage to equilibrium is achieved by Model B."
}], "Text"],

Cell["\<\
\tBecause we have not tackled the difficult problem of fitting real \
data to our models (other than the earlier example with the US census data), \
we are not really entitled to philosophize on that problem.  Nevertheless, \
the plethora of models with similar behavior at least suggests that one of \
the problems in population modelling is to rise above mere curve fitting.  \
After all, our goal is to use modelling to say something meaningful about the \
behavior of a real population.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5  The Logistic Model In This Context", "Subsubsection"],

Cell["\<\
\tThe logistic equation (given in equation (3) and also below for \
convenience) is arguably the simplest one-species population model which \
incorporates the effect of finite resources.  However, it is not based on a \
specific separate models for birth and death rates, and it is of interest to \
see examples of birth and death rates which lead to the logistic equation.  \
\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[\(dN\/dt\),
          FontSlant->"Italic"], 
        StyleBox[" ",
          FontSlant->"Italic"], "=", " ", 
        RowBox[{
          StyleBox["rN",
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                StyleBox[\(N\/K\),
                  FontSlant->"Italic"]}], ")"}], "   ", ".", 
            "                                                                 \
                              ", 
            StyleBox[\((13)\),
              FontWeight->"Bold"]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "One possibility (which violates our rules of section 3.1) is a constant \
per capita birth rate ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "and a per capita death rate ",
  StyleBox["rN",
    FontSlant->"Italic"],
  "/",
  StyleBox["K",
    FontSlant->"Italic"],
  ".  This is clearly artificial, because the birth rate should eventually \
drop for a large population, and the death rate should not go to zero as ",
  StyleBox["N",
    FontSlant->"Italic"],
  " \[Rule] 0.  Let's see if we can find a better basis for the logistic \
equation.  After a little exploration, one can find the formulas below, which \
satisfy the rules of section 3.1 and which combine to give the logistic \
equation.  This is a one-parameter family of functions, with the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  " being any number > ",
  StyleBox["r",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["b",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["(",
                  FontSlant->"Italic"], 
                StyleBox["N",
                  FontSlant->"Italic"], 
                StyleBox[")",
                  FontSlant->"Plain"]}]}], 
            StyleBox["  ",
              FontSlant->"Italic"], "=", " ", 
            FractionBox[
              RowBox[{"K", 
                SuperscriptBox[
                  RowBox[{"(", 
                    StyleBox[\(b\_0\),
                      FontSlant->"Italic"], ")"}], "2"]}], 
              RowBox[{
                StyleBox[\(Kb\_0\),
                  FontSlant->"Italic"], "+", " ", 
                StyleBox[\(r N\),
                  FontSlant->"Italic"]}]]}], "  ", ",", 
          "                                                                   \
                                         ", "\n", "     ", 
          RowBox[{
            RowBox[{"and", "    ", 
              StyleBox["d",
                FontSlant->"Italic"], 
              RowBox[{"(", 
                StyleBox["N",
                  FontSlant->"Italic"], ")"}]}], " ", "=", " ", 
            RowBox[{
              RowBox[{
                StyleBox["r",
                  FontSlant->"Italic"], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["N",
                        FontSlant->"Italic"], "/", 
                      StyleBox["K",
                        FontSlant->"Italic"]}], " ", "-", " ", "1"}], 
                  ")"}]}], " ", "+", "  ", 
              RowBox[{
                FractionBox[
                  RowBox[{"K", 
                    SuperscriptBox[
                      RowBox[{"(", 
                        StyleBox[\(b\_0\),
                          FontSlant->"Italic"], ")"}], "2"]}], 
                  RowBox[{
                    StyleBox[\(Kb\_0\),
                      FontSlant->"Italic"], "+", " ", 
                    StyleBox[\(r N\),
                      FontSlant->"Italic"]}]], "   ", ".", 
                "                                                             \
  ", 
                StyleBox[\((14)\),
                  FontWeight->"Bold"]}]}]}]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "There are an infinity of other such pairs ",
  StyleBox["b",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["d",
    FontSlant->"Italic"],
  "(",
  StyleBox["N",
    FontSlant->"Italic"],
  ") which combine to give the logistic equation.  Although the logistic \
equation is perhaps the simplest equation, the birth and death rates of Model \
B are simpler than those in equation (14).  "
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Printout",
WindowSize->{615, 610},
WindowMargins->{{18, Automatic}, {Automatic, -1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 49, 0, 152, "Title"],

Cell[CellGroupData[{
Cell[1813, 55, 35, 0, 50, "Section"],
Cell[1851, 57, 1269, 26, 168, "Text"],
Cell[3123, 85, 865, 13, 142, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4025, 103, 54, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[4104, 107, 46, 0, 42, "Subsubsection"],
Cell[4153, 109, 839, 14, 164, "Text"],
Cell[4995, 125, 528, 11, 110, "Text"],
Cell[5526, 138, 70, 0, 30, "Text"],
Cell[5599, 140, 39692, 613, 212, 39571, 609, "GraphicsData", "PICT", \
"Graphics"],
Cell[45294, 755, 102, 5, 50, "Text"],
Cell[45399, 762, 712, 22, 100, "Text"],
Cell[46114, 786, 672, 21, 44, "Text"],
Cell[46789, 809, 37, 0, 30, "Text"],
Cell[46829, 811, 454, 18, 32, "Text"],
Cell[47286, 831, 906, 21, 128, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48229, 857, 48, 0, 42, "Subsubsection"],
Cell[48280, 859, 1739, 47, 214, "Text"],
Cell[50022, 908, 830, 24, 44, "Text"],
Cell[50855, 934, 1113, 38, 120, "Text"],
Cell[51971, 974, 1802, 46, 47, "Text"],
Cell[53776, 1022, 634, 22, 66, "Text"],
Cell[54413, 1046, 570, 19, 66, "Text"],
Cell[54986, 1067, 426, 20, 32, "Text"],
Cell[55415, 1089, 580, 26, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56032, 1120, 74, 0, 42, "Subsubsection"],
Cell[56109, 1122, 259, 7, 48, "Text"],
Cell[56371, 1131, 66, 1, 27, "Input"],
Cell[56440, 1134, 130, 3, 27, "Input"],
Cell[56573, 1139, 269, 11, 32, "Text"],
Cell[56845, 1152, 73, 1, 27, "Input"],
Cell[56921, 1155, 239, 7, 48, "Text"],
Cell[57163, 1164, 272, 5, 75, "Input"],
Cell[57438, 1171, 857, 21, 112, "Text"],
Cell[58298, 1194, 791, 18, 130, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59126, 1217, 70, 0, 42, "Subsubsection"],
Cell[59199, 1219, 780, 16, 132, "Text"],
Cell[59982, 1237, 454, 6, 123, "Input"],
Cell[60439, 1245, 328, 10, 64, "Text"],
Cell[60770, 1257, 827, 25, 100, "Text"],
Cell[61600, 1284, 90, 3, 30, "Text"],
Cell[61693, 1289, 548, 24, 32, "Text"],
Cell[62244, 1315, 724, 30, 66, "Text"],
Cell[62971, 1347, 295, 6, 91, "Input"],
Cell[63269, 1355, 213, 7, 32, "Text"],
Cell[63485, 1364, 134, 3, 43, "Input"],
Cell[63622, 1369, 213, 8, 32, "Text"],
Cell[63838, 1379, 67, 1, 27, "Input"],
Cell[63908, 1382, 952, 28, 120, "Text"],
Cell[64863, 1412, 65, 1, 27, "Input"],
Cell[64931, 1415, 531, 12, 98, "Text"],
Cell[65465, 1429, 286, 5, 91, "Input"],
Cell[65754, 1436, 477, 9, 171, "Input"],
Cell[66234, 1447, 116, 5, 32, "Text"],
Cell[66353, 1454, 50, 1, 27, "Input"],
Cell[66406, 1457, 107, 3, 30, "Text"],
Cell[66516, 1462, 50, 1, 27, "Input"],
Cell[66569, 1465, 47, 0, 30, "Text"],
Cell[66619, 1467, 50, 1, 27, "Input"],
Cell[66672, 1470, 30, 0, 30, "Text"],
Cell[66705, 1472, 50, 1, 27, "Input"],
Cell[66758, 1475, 510, 9, 96, "Text"],
Cell[67271, 1486, 47, 1, 27, "Input"],
Cell[67321, 1489, 668, 12, 112, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[68038, 1507, 44, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[68107, 1511, 73, 0, 42, "Subsubsection"],
Cell[68183, 1513, 1404, 38, 182, "Text"],
Cell[69590, 1553, 1961, 59, 45, "Text"],
Cell[71554, 1614, 2288, 74, 236, "Text"],
Cell[73845, 1690, 1807, 57, 184, "Text"],
Cell[75655, 1749, 452, 9, 80, "Text"],
Cell[76110, 1760, 1385, 70, 50, "Text"],
Cell[77498, 1832, 730, 37, 50, "Text"],
Cell[78231, 1871, 801, 40, 50, "Text"],
Cell[79035, 1913, 654, 34, 50, "Text"],
Cell[79692, 1949, 610, 32, 50, "Text"],
Cell[80305, 1983, 71, 0, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80413, 1988, 50, 0, 42, "Subsubsection"],
Cell[80466, 1990, 1069, 37, 102, "Text"],
Cell[81538, 2029, 1391, 51, 114, "Text"],
Cell[82932, 2082, 788, 25, 100, "Text"],
Cell[83723, 2109, 64, 0, 30, "Text"],
Cell[83790, 2111, 1885, 55, 46, "Text"],
Cell[85678, 2168, 102, 3, 30, "Text"],
Cell[85783, 2173, 767, 33, 32, "Text"],
Cell[86553, 2208, 151, 5, 32, "Text"],
Cell[86707, 2215, 921, 27, 45, "Text"],
Cell[87631, 2244, 467, 6, 94, "Text"],
Cell[88101, 2252, 479, 16, 65, "Text"],
Cell[88583, 2270, 90, 1, 27, "Input"],
Cell[88676, 2273, 44, 1, 27, "Input"],
Cell[88723, 2276, 62, 1, 31, "Input"],
Cell[88788, 2279, 54, 1, 27, "Input"],
Cell[88845, 2282, 38, 0, 30, "Text"],
Cell[88886, 2284, 54, 1, 27, "Input"],
Cell[88943, 2287, 445, 17, 51, "Text"],
Cell[89391, 2306, 669, 12, 128, "Text"],
Cell[90063, 2320, 38, 1, 27, "Input"],
Cell[90104, 2323, 266, 6, 48, "Text"],
Cell[90373, 2331, 51, 1, 27, "Input"],
Cell[90427, 2334, 58, 1, 27, "Input"],
Cell[90488, 2337, 55, 1, 27, "Input"],
Cell[90546, 2340, 61, 1, 27, "Input"],
Cell[90610, 2343, 318, 9, 48, "Text"],
Cell[90931, 2354, 60, 1, 27, "Input"],
Cell[90994, 2357, 142, 3, 46, "Text"],
Cell[91139, 2362, 65, 1, 27, "Input"],
Cell[91207, 2365, 120, 3, 30, "Text"],
Cell[91330, 2370, 74, 1, 27, "Input"],
Cell[91407, 2373, 50, 1, 27, "Input"],
Cell[91460, 2376, 69, 1, 27, "Input"],
Cell[91532, 2379, 352, 12, 49, "Text"],
Cell[91887, 2393, 386, 5, 78, "Text"],
Cell[92276, 2400, 753, 13, 283, "Input"],
Cell[93032, 2415, 144, 2, 46, "Text"],
Cell[93179, 2419, 74, 1, 27, "Input"],
Cell[93256, 2422, 90, 1, 27, "Input"],
Cell[93349, 2425, 280, 7, 49, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93666, 2437, 55, 0, 42, "Subsubsection"],
Cell[93724, 2439, 212, 4, 46, "Text"],
Cell[93939, 2445, 1323, 37, 47, "Text"],
Cell[95265, 2484, 332, 11, 48, "Text"],
Cell[95600, 2497, 96, 3, 30, "Text"],
Cell[95699, 2502, 82, 1, 29, "Input"],
Cell[95784, 2505, 37, 0, 30, "Text"],
Cell[95824, 2507, 109, 2, 27, "Input"],
Cell[95936, 2511, 126, 3, 30, "Text"],
Cell[96065, 2516, 54, 1, 27, "Input"],
Cell[96122, 2519, 136, 3, 46, "Text"],
Cell[96261, 2524, 81, 1, 27, "Input"],
Cell[96345, 2527, 63, 0, 30, "Text"],
Cell[96411, 2529, 202, 4, 46, "Text"],
Cell[96616, 2535, 51, 1, 27, "Input"],
Cell[96670, 2538, 61, 1, 27, "Input"],
Cell[96734, 2541, 55, 1, 27, "Input"],
Cell[96792, 2544, 61, 1, 27, "Input"],
Cell[96856, 2547, 204, 6, 48, "Text"],
Cell[97063, 2555, 54, 1, 27, "Input"],
Cell[97120, 2558, 130, 3, 46, "Text"],
Cell[97253, 2563, 80, 1, 27, "Input"],
Cell[97336, 2566, 58, 0, 30, "Text"],
Cell[97397, 2568, 74, 1, 27, "Input"],
Cell[97474, 2571, 50, 1, 27, "Input"],
Cell[97527, 2574, 55, 1, 27, "Input"],
Cell[97585, 2577, 69, 1, 27, "Input"],
Cell[97657, 2580, 152, 5, 32, "Text"],
Cell[97812, 2587, 64, 1, 27, "Input"],
Cell[97879, 2590, 66, 1, 27, "Input"],
Cell[97948, 2593, 50, 1, 27, "Input"],
Cell[98001, 2596, 117, 3, 30, "Text"],
Cell[98121, 2601, 145, 2, 46, "Text"],
Cell[98269, 2605, 74, 1, 27, "Input"],
Cell[98346, 2608, 111, 2, 43, "Input"],
Cell[98460, 2612, 301, 4, 62, "Text"],
Cell[98764, 2618, 55, 1, 27, "Input"],
Cell[98822, 2621, 74, 1, 27, "Input"],
Cell[98899, 2624, 53, 1, 27, "Input"],
Cell[98955, 2627, 69, 1, 27, "Input"],
Cell[99027, 2630, 86, 1, 27, "Input"],
Cell[99116, 2633, 66, 1, 27, "Input"],
Cell[99185, 2636, 52, 1, 27, "Input"],
Cell[99240, 2639, 176, 4, 46, "Text"],
Cell[99419, 2645, 313, 9, 50, "Text"],
Cell[99735, 2656, 109, 2, 27, "Input"],
Cell[99847, 2660, 126, 2, 43, "Input"],
Cell[99976, 2664, 50, 1, 27, "Input"],
Cell[100029, 2667, 77, 1, 27, "Input"],
Cell[100109, 2670, 507, 10, 96, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100653, 2685, 52, 0, 42, "Subsubsection"],
Cell[100708, 2687, 1071, 22, 154, "Text"],
Cell[101782, 2711, 853, 35, 35, "Text"],
Cell[102638, 2748, 859, 35, 35, "Text"],
Cell[103500, 2785, 863, 35, 35, "Text"],
Cell[104366, 2822, 794, 33, 35, "Text"],
Cell[105163, 2857, 1002, 41, 35, "Text"],
Cell[106168, 2900, 506, 16, 69, "Text"],
Cell[106677, 2918, 529, 14, 72, "Text"],
Cell[107209, 2934, 73, 1, 27, "Input"],
Cell[107285, 2937, 58, 0, 30, "Text"],
Cell[107346, 2939, 72, 1, 27, "Input"],
Cell[107421, 2942, 59, 1, 27, "Input"],
Cell[107483, 2945, 204, 6, 46, "Text"],
Cell[107690, 2953, 144, 3, 43, "Input"],
Cell[107837, 2958, 56, 1, 27, "Input"],
Cell[107896, 2961, 129, 2, 43, "Input"],
Cell[108028, 2965, 133, 2, 43, "Input"],
Cell[108164, 2969, 91, 1, 27, "Input"],
Cell[108258, 2972, 88, 1, 27, "Input"],
Cell[108349, 2975, 47, 0, 30, "Text"],
Cell[108399, 2977, 57, 1, 27, "Input"],
Cell[108459, 2980, 67, 1, 27, "Input"],
Cell[108529, 2983, 79, 1, 27, "Input"],
Cell[108611, 2986, 58, 1, 27, "Input"],
Cell[108672, 2989, 66, 1, 27, "Input"],
Cell[108741, 2992, 357, 7, 64, "Text"],
Cell[109101, 3001, 80, 1, 27, "Input"],
Cell[109184, 3004, 75, 0, 30, "Text"],
Cell[109262, 3006, 51, 1, 27, "Input"],
Cell[109316, 3009, 54, 1, 27, "Input"],
Cell[109373, 3012, 56, 1, 27, "Input"],
Cell[109432, 3015, 55, 1, 27, "Input"],
Cell[109490, 3018, 75, 1, 27, "Input"],
Cell[109568, 3021, 166, 4, 46, "Text"],
Cell[109737, 3027, 55, 1, 27, "Input"],
Cell[109795, 3030, 56, 1, 27, "Input"],
Cell[109854, 3033, 75, 1, 27, "Input"],
Cell[109932, 3036, 55, 1, 27, "Input"],
Cell[109990, 3039, 56, 1, 27, "Input"],
Cell[110049, 3042, 43, 1, 27, "Input"],
Cell[110095, 3045, 75, 1, 27, "Input"],
Cell[110173, 3048, 55, 1, 27, "Input"],
Cell[110231, 3051, 56, 1, 27, "Input"],
Cell[110290, 3054, 75, 1, 27, "Input"],
Cell[110368, 3057, 55, 1, 27, "Input"],
Cell[110426, 3060, 56, 1, 27, "Input"],
Cell[110485, 3063, 75, 1, 27, "Input"],
Cell[110563, 3066, 55, 0, 30, "Text"],
Cell[110621, 3068, 82, 1, 27, "Input"],
Cell[110706, 3071, 68, 1, 27, "Input"],
Cell[110777, 3074, 92, 1, 27, "Input"],
Cell[110872, 3077, 653, 13, 112, "Text"],
Cell[111528, 3092, 516, 8, 94, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112081, 3105, 64, 0, 42, "Subsubsection"],
Cell[112148, 3107, 402, 7, 78, "Text"],
Cell[112553, 3116, 660, 19, 45, "Text"],
Cell[113216, 3137, 925, 25, 118, "Text"],
Cell[114144, 3164, 2422, 65, 84, "Text"],
Cell[116569, 3231, 470, 16, 64, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

