(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12530,        529]*)
(*NotebookOutlinePosition[     37413,       1430]*)
(*  CellTagsIndexPosition[     37369,       1426]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Applications List\
\>", "Title"],

Cell["\<\
\tThere are many applications notebooks accompanying this package.  \
There is considerable overlap between the tutorials and the applications, but \
the applications tend to be more focused on a single task or concept.  \
\>", 
  "Text",
  Evaluatable->False,
  PageBreakBelow->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Basic Dynamical Systems", "Section"],

Cell[CellGroupData[{

Cell["DampedLinearOsc.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe damped undriven linear oscillator is used as an introduction \
to the phase plane view of a system.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DuffingUndamped.nb", "Subsubsection",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe undamped Duffing equation with both linear and cubic force terms is \
used as an introduction to nonlinear conservative systems.  Both the hard \
spring and soft spring cases are considered.",
  StyleBox["\t",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equil2DCat.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook gives a catalogue of phase portraits for a number \
of different equilibria in autonomous linear systems of two equations.  All \
of the major types of equilibria are illustrated.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lineig.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThis is not actually a DynPac application.  It is a notebook showing how \
to solve linear autonomous systems using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to carry out the eigenvector analysis.  It deals with all cases:  \
distinct real roots, distinct complex roots, and repeated real and complex \
roots."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["LorenzIntro.nb", "Subsubsection",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[
  "This very brief look at the Lorenz equations focusses on the sensitive \
dependence on initial conditions that occurs in chaotic motions.",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["PendulumIntro.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook illustrates how the response of the damped driven \
pendulum can depend strongly on the amplitude of the forcing.  In particular, \
the examples show that periodic and chaotic responses are not that far apart \
in parameter space.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Periodic.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook gives several examples of systems with periodic \
solutions.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced Dynamical Systems", "Section"],

Cell[CellGroupData[{

Cell["Bifurcation Notebooks", "Subsection"],

Cell[CellGroupData[{

Cell["Hopfsub.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a subcritical Hopf bifurcation.\
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hopfsup.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a supercritical Hopf \
bifurcation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinBif.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a bifurcation sequence in a \
linear system.  The bifurcation is from saddle to node to spiral.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LocalGlobal.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie which shows the transition between \
a local and global view of a saddle point in a nonlinear system.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MultPort.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this notebook, a phase portrait is constructed for a system \
with five equilibria.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Orbstab.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook contrasts Liapunov and orbital stability, and \
constructs several examples.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OrbitTrap.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook illustrates the use of orbit trapping and the \
Bendixson test to find a periodic solution for a nonlinear planar system.  \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pitchsub.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a subcritical pitchfork \
bifurcation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pitchsup.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a supercritical pitchfork \
bifurcation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SadNod.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a saddle-node \
bifurcation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transcrit.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces a movie of a transcritical \
bifurcation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VanderPol.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook contains an extensive study of the van der Pol \
oscillator with emphasis on the dependence of the orbits on the damping \
parameter.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Biological Models", "Section"],

Cell[CellGroupData[{

Cell["Population Models", "Subsection"],

Cell[CellGroupData[{

Cell["LogisticLag.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook analyzes the logistic equation with a time lag.  As \
the time lag increases through a certain critical value, the attractor of the \
system changes from a stable equilibrium to a limit cycle.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PredatorPreyPt1.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA detailed and specific predator prey model is used to illustrate \
the dependence of equilibrium on a system parameter.  In this part, the \
stable equilibrium is tracked as a parameter is changed, and it goes from \
node to spiral to a Hopf bifurcation. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["PredatorPreyPt2.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[
  "This is a continuation of the predator prey model, into the limit cycle \
regime.  Among other things, this model provides an example of an increased \
food supply for the prey being deleterious for the system.",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Single Species Models.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAn elementary look at the Malthusian, logistic, and other models \
of single-species populations.  \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Epidemic  Models", "Subsection"],

Cell[CellGroupData[{

Cell["SIRModelPart1.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook is an introduction to the S-I-R model of epidemics. \
 The three subclasses of the population are the susceptibles, the infectives \
and the recovered.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SIRModelPart2.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this notebook, births and deaths are added to the basic S-I-R \
model.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SEIRModelPart1.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook is an introduction to the basic S-E-I-R model of \
epidemics.  The subclasses in the population are the susceptibles, the \
exposed, the infectives and the recovered.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SIRModelPart2.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this notebook, births and deaths are added to the basic \
S-E-I-R model.  Also, the effect of a steady influx of new susceptibles is \
considered.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SIRRecTime.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA modified version of the SIR model is considered in which the \
recovery time is fixed and uniform.  This leads to a set of differential \
equations with lag terms.  The results from this model are compared with \
results from the standard SIR model.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["In-Host Disease Dynamics", "Subsection"],

Cell[CellGroupData[{

Cell["HostDyn1.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA simple model of infection dynamics is considered.  The state \
variables are the populations of healthy cells, infected cells, andbacteria \
or viruses.  In this first part, no immune responses are considered.\
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HostDyn2.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe infection model of part 1 is extended to include cytotoxic \
T-lymphocytes.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Section"],

Cell[CellGroupData[{

Cell["SpiralArt.nb", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis notebook produces decorative colored spirals from orbits of \
a damped free linear oscillator.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{Automatic, 182}, {Automatic, 38}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 60, 3, 152, "Title"],
Cell[1802, 56, 321, 8, 48, "Text",
  Evaluatable->False,
  PageBreakBelow->False],

Cell[CellGroupData[{
Cell[2148, 68, 42, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[2215, 72, 91, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[2309, 76, 129, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2475, 84, 120, 3, 42, "Subsubsection",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[2598, 89, 348, 9, 48, "Text",
  Evaluatable->False,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[2983, 103, 86, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[3072, 107, 267, 6, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3376, 118, 82, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[3461, 122, 408, 10, 66, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3906, 137, 117, 3, 42, "Subsubsection",
  Evaluatable->False,
  PageBreakWithin->Automatic],
Cell[4026, 142, 293, 9, 48, "Text",
  Evaluatable->False,
  PageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[4356, 156, 89, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[4448, 160, 318, 7, 65, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4803, 172, 84, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[4890, 176, 100, 3, 31, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5039, 185, 45, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[5109, 189, 43, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[5177, 193, 83, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5263, 197, 93, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5393, 205, 83, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5479, 209, 95, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5611, 217, 82, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5696, 221, 155, 3, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5888, 229, 87, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5978, 233, 158, 3, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6173, 241, 84, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[6260, 245, 112, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6409, 253, 83, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[6495, 257, 116, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6648, 265, 85, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[6736, 269, 213, 6, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[6986, 280, 84, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[7073, 284, 98, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7208, 292, 84, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[7295, 296, 100, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7432, 304, 82, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[7517, 308, 88, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7642, 316, 85, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[7730, 320, 90, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7857, 328, 85, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[7945, 332, 173, 4, 48, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8179, 343, 36, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[8240, 347, 39, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[8304, 351, 87, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[8394, 355, 232, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8663, 364, 91, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[8757, 368, 330, 7, 65, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[9124, 380, 91, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[9218, 384, 336, 9, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[9591, 398, 97, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[9691, 402, 125, 3, 31, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9865, 411, 38, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[9928, 415, 89, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[10020, 419, 191, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10248, 428, 89, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[10340, 432, 99, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10476, 440, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[10569, 444, 208, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10814, 453, 89, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[10906, 457, 175, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11118, 466, 86, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[11207, 470, 277, 5, 65, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11533, 481, 46, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[11604, 485, 84, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[11691, 489, 239, 5, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11967, 499, 84, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[12054, 503, 105, 3, 31, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12220, 513, 32, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[12277, 517, 85, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[12365, 521, 125, 3, 31, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

