(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22777,        724]*)
(*NotebookOutlinePosition[     47870,       1631]*)
(*  CellTagsIndexPosition[     47826,       1627]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Log of Changes Since Version 10.2\
\>", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 2"
}], "Section"],

Cell[CellGroupData[{

Cell["Version 10.21", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAll iteration indices have now been declared as local variables \
within the module.  It was an oversight that this was not done \
originally.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tMinor modifications were made to the ReadMe statement and its \
name was changed to StartHere.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.22", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA new plot control variable has been introduced -- plrange3D.  \
This controls the plotting window for 3D graphs, and plrange is now used only \
for 2D graphs.  This prevents the annoying errors that occur when one \
switches from 2D to 3D without remembering to change plrange.  This change \
required minor changes in Tutorials 6, 7, 9, 10, and 12.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tSome minor changes were made in the descriptive portions of Part \
1 and Tutorial 1.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.23", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA new plotting parameter dirpt has been defined.  The value of \
dirpt (an integer) controls the number of points in the direction field, \
which is dirpt by dirpt.  The default value is 20.  The command plotreset \
resets dirpt to the default, as well as resetting the previously defined 12 \
plot parameters to default values.  A very slight change was made in Tutorial \
8.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3"
}], "Section"],

Cell[CellGroupData[{

Cell["Version 10.24", "Subsection"],

Cell[TextData[{
  "\tThis is the first version run under ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.  Some minor formatting changes were made in the text, but no code \
was changed."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.25", "Subsection"],

Cell[TextData[{
  "\tBecause of a bug in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0, certain characters (namely \"(  )  {  }  [  ]\") in PlotLabels or \
AxesLabels will not print correctly unless $FormatType is set to OutputForm.  \
In Version 10.25, this is setting is made automatically when the notebooks \
are loaded.  Wolfram has fixed this bug in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.1, so you can delete this line from Dynsys.nb if you are running \
3.0.1.    "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.26", "Subsection"],

Cell["\<\
\tSome minor changes were made to allow some control of the \
position of the plot label, in order to avoid collision of the plot label and \
the y-axis label.  The technique is illustrated in a new version of Tutorial \
4.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.27", "Subsection"],

Cell["\<\
\tThe basic code, which previously existed in two notebooks, was \
combined into a single notebook.  The tutorial list and function index now \
exist as separate notebooks rather than as appendices to the notebook with \
the basic code.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.28", "Subsection"],

Cell[TextData[{
  "\tA small change was made in the auxiliary routine graphconaux3D to \
compensate for changes induced by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.  Without this change, 3D graph animations produce the solution \
curves in white rather than black."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.29", "Subsection"],

Cell["\<\
\tNew graph control variables have been added.  The variable \
colorvec is used for specifying color in plots.  It is a list of arguments \
for RGBColor.   A variable dashvec has been added to control dashing in \
two-dimensional plots.  It is a list of arguments (dashing patterns) for the \
option Dashing.   A new variable for controlling the background darkness in \
animations has been added.  It is graylev, and it ranges from 0 (black) to 1 \
(white).  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.30", "Subsection"],

Cell["\<\
\tNew variables to control plot labels have been added.  These \
allow the user to specify the total number of digits and the number of digits \
to the right of the decimal point in plot labels.   With these variables, one \
can prevent \"label jumping\" in animations.  Illustrated in Tutorials 14 and \
15.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.31", "Subsection"],

Cell["\tA minor bug in dashing was fixed.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.32", "Subsection"],

Cell["\<\
\tPlot labels can now be anything the user specifies, as an \
alternative to the default of showing the system name and the parameter \
values.  Illustrated in Tutorial 15.  \
\>", "Text"],

Cell["\<\
\tArrows may be added to orbits in two-dimensional phase plane \
plots.  Illustrated in Tutorials 1, 4, 8 and 15.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.33", "Subsection"],

Cell["\<\
\tThe arrow routines were greatly improved.  Arrows can now be \
placed at positions that are specified fractions of the arc-length of the \
orbit.  Illustrated in Tutorials 1, 4, 8 and 15.  \
\>", "Text"],

Cell["\<\
\tRange checking has been modified slightly so that no points \
outside the specified range are kept in the solution list.  In the old \
version, one or both end-points in the solution list were outside the \
prescribed range.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.34", "Subsection"],

Cell["\<\
\tTwo simple transformation rules for systems have been added.  To \
reverse time, execute reversetime.  Illustrated in Tutorial 1.  To translate \
the origin to a new position vec, type transorg[vec].  Illustrated in \
Tutorial 3.  \
\>", "Text"],

Cell["\<\
\tThere has been a slight modification of range checking.  When \
range check halts the integration because of a point out-of-bounds, the \
coordinates of the point are stored in the variable named outbound.  \
\>", 
  "Text"],

Cell["\<\
\tSymbols used in statevec and parmvec remain protected even when \
they are no longer part of the present system.  This allows savesys and \
restoresys to be used safely.  However, it can also cause an accumulation of \
protected variables that might be need for other purposes.  To free up all \
old unused variables, typd unprold.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.35", "Subsection"],

Cell[TextData[{
  "\tThe ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package Graphics`Colors` is now used as the basis for color \
specification.  All of the colors in that package are now available for use.  \
Because there is a change in the way colors are specified, there may be some \
minor incompatibilities with earlier notebooks.  In the present version, the \
color red for examples is specified as RGBColor[1,0,0].  In earlier versions \
it was specified as {1,0,0}.  Illustrated in Tutorial 12."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.36", "Subsection"],

Cell["\<\
\tThe modifications in version 10.34 on variable protection have \
been greatly simplified here.  Variables appearing in the current state and \
parameter vectors are protected as before.  Also any such variables in a \
system which has been saved by a savesys command are protected for the \
reminder of the session.  This allows free switching back and forth between \
saved systems without any danger of corruption of the symbols appearing in \
statevec and parmvec.  All of this is transparent to the user.\
\>", "Text"],

Cell["\<\
\tThe routine direction field dirfield has been modified to produce \
direction fields in color.  It uses the current setting of colorvec.  \
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.37", "Subsection"],

Cell[TextData[{
  "\tA new graphics control variable has been added -- imsize.  Imsize \
controls the width of graphs.  The value is in printer's points.  The default \
is 380, which is larger than the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " default of 288.  Illustrated in Tutorials 1, 7 and 15."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.38", "Subsection"],

Cell["\<\
\tA bug in the arrow routine was fixed.  In the old versions a zero \
arclength solution (equilibrium solution) would cause a division by zero in \
the arrow making routine.\
\>", "Text"],

Cell["\<\
\tThe argument nsteps in integrate may now be a non-integer.  The \
routine will round it to an integer.  This prevents a crash when a \
non-integer value is specified inadvertently.\
\>", "Text"],

Cell["\<\
\tFour patterns for dashing have been defined by name.  Illustrated \
in Tutorial 12.\
\>", "Text"],

Cell["\<\
\tA bug in savesys was fixed.  In older versions, attempting to \
save a system under a name previously used in a save gave an error.  Now the \
second save simply overwrites the first.\
\>", "Text"],

Cell["\<\
\tChanges have been made in the basic integration routine \
integrate[initvec,t0,h,nsteps].  In the new version, any of the four \
arguments may be expressions in the parameters of the system.  Before \
integrate is executed, each argument is operated on by the replacement \
parmvec -> parmval.  This can be useful in bifurcation sequences, where, for \
example, one may need very different time steps for different parameter \
values.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.39", "Subsection"],

Cell["\<\
\tThe parameter symbol vector parmvec is now protected.  This \
prevents the careless error of assigning parameter values to parmvec instead \
of the proper assignment to parmval.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.40", "Subsection"],

Cell["\<\
\tA minor bug was corrected, so that arrows no longer will appear \
on time plots, even if arrowflag is True.  They will appear only on \
two-dimensional phase plots.

\tParameters in graph labels can now be printed in scientific notation by \
setting sciflag = True.  Illustrated in Tutorials 5 and 15.
\t
\tIf there are no parameters, the graph label now omits any reference to \
them.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.41", "Subsection"],

Cell["\<\
\tThe opportunity to specify units for state variables and \
parameters is now included.  They are presently used for graph labels, but \
may be used in other ways in the future.  Illustrated in Tutorial 15.\
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.42", "Subsection"],

Cell["\<\
\tA function transol has been defined which makes it easy to apply \
functional transformations to already computed solutions.  Illustrated in \
Tutorial 15.\
\>", "Text"],

Cell["\<\
\tMore control has been provided over axes labels.  A new flag, \
axlabon, gives the default axis labels when True, no axis labels when False, \
and when axlabon = \"user specified labels\", the user-specified labels are \
used.  Illustrated in Tutorial 15.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.43", "Subsection"],

Cell["\<\
\tAn additional interpolating function has been defined.  The \
function solinterp[sol,stname,slpname] constructs interpolating vectors for \
the state vector (returned to stname) and the slope vector returned to \
slpname) for the solution sol.  Illustrated in Tutorial 1.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.44", "Subsection"],

Cell["\<\
\tFive routines for automating the production of phase portraits in \
2D have been added.  The routines are saddleportrait, saddleportraitman, \
centerportrait, spiralportrait, and nodeportrait.  Each routine takes two \
arguments -- the location of the equilibrium point and the plotting window.  \
Illustrated in Tutorial 4.   \
\>", "Text"],

Cell["\<\
\tTutorial 0 -- Introduction to DynPac -- has been added.  It is \
designed to be a first look at the package, and contains only very basic \
commands, with very little exploration of options.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.45", "Subsection"],

Cell["\<\
\tA routine has been added to estimate an appropriate time step for \
autonomous systems.  The time step is returned by sugtimestep[window].  The \
argument window is a box region in which the equation will be studied.  The \
time step is estimated from the rms values of the slope components over the \
region specified by window.  Illustrated in Tutorials 1 and 2.  \
\>", "Text"],

Cell["\<\
\tThe portrait routines portrait, portrait3D, bifurc, bifurc3D, and \
limbifurc have been enhanced.  All of these routines take as argument an \
initial time, a time step, and a number of time steps.  All of these \
arguments may now be either single expressions or lists of expressions, with \
the length of the list being the same as the list of initial conditions.  If \
an argument is a list, the list values are used in succession as the \
integrations are performed.  Any expression in any argument may contain \
parameter symbols.  These will be replaced by current parameter values before \
an integration is performed.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.46", "Subsection"],

Cell["\<\
\tA routine has been added to integrate systems of differential \
equations with lag terms.  One lag time is allowed, and any of the dependent \
variables may appear in lagged form in the slope vector.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.47", "Subsection"],

Cell["\<\
\tThe show command has been modified.  It now uses the value of \
labon for the plot label, rather than using the label from the last graph in \
the argument graph list.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.48", "Subsection"],

Cell["\<\
\tSome minor changes are made in using units.  Specifically, \
functions are defined to clear previously assigned units to state variables, \
parameters and the time variable.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.49", "Subsection"],

Cell["\<\
\tA very minor change was made in the parameter-defining function \
setparm.  Now the function also assigns the literal parameter symbols to the \
value vector parmval.  This prevents errors which can occur if certain \
routines are called with parmval = empty vector.   \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.50", "Subsection"],

Cell[TextData[{
  "\tA bug which gave error messages during loading, with some but not all \
versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", was fixed.  This bug was bizarre even by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " standards.  It has to do with a basic If statement.  The standard form is \
If[cond,t,f], which will execute t if cond is true and f if cond is false.  A \
variation is If[cond, , f], which will do nothing if cond is true and will \
execute f if cond is false.  ",
  StyleBox["This form of If statement works with some versions of ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" 3.0.1 and not with others.  ",
    FontWeight->"Bold"],
  "It works on my version, so I did not detect the bug until I received \
reports from other users of the package.  In version 10.50, all such \
constructions have been replaced by ones which will work with all versions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.51", "Subsection"],

Cell["\<\
\tA very minor addition has been made for convenience.  The \
functions eigval[state] and eigsys[state] have been added.  Eigval returns \
the eigenvalues of the derivative matrix at state, and eigsys returns both \
the eigenvalues and eigenvectors at state.  The same results may be \
accomplished by Eigenvalue[dermatval[state]] and \
Eigensystem[dermatval[state]].  \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4"
}], "Section"],

Cell[CellGroupData[{

Cell["Version 10.52", "Subsection"],

Cell[TextData[{
  "\tThis version is the first to be tested with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.  Every notebook was opened, executed, and saved in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0.  No incompatibilities were found.  A bug in the routines portrait \
and portrait3D was fixed.  This bug showed up whenever the step sizes were \
specified as functions of the parameter.  For example, the bug showed up in \
Tutorial 10, where the routine bifurc was used, a routine which calls \
portrait."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.53", "Subsection"],

Cell["\<\
\tThe phase portrait routines phaseseq, phaseseq3D, bifurc, \
bifurc3D, limbifurc and limbifurc3D all have been modified slightly.  They \
now allow an optional final argument which, when used, is the name of a \
reference graph to be superimposed on all graphs of the sequence.  Two new \
functions have been added for modifying computed solutions.  The function \
timeshift[sol,\[Tau]] increments every time coordinate in sol by \[Tau].  The \
function stateshift[sol,vec] increments every state vector in sol by vec.  \
Two new plotting functions have been added.  The function dots[list] plots \
dots at the coordinates specified by the coordinate pairs in list.  The 3D \
version is dots3D.  CheckAborts have been added to some of the phase portrait \
routines.  If you hold down the abort key sequence, this will allow you to \
abort the entire portrait rather than having to abort each individual \
integration.   \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.54", "Subsection"],

Cell[TextData[{
  "\tA function polartrans[x,y,r,\[Theta]] has been added, which makes the \
change of variables ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r",
    FontSlant->"Italic"],
  "cos(\[Theta]) and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " = ",
  StyleBox["r",
    FontSlant->"Italic"],
  "sin(\[Theta]), and returns the components of the slope function for ",
  Cell[BoxData[
      \(TraditionalForm\`r\& . \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\& . \)]],
  " .  The inverse of this, frompolartrans[r,\[Theta],x,y], returns the slope \
vector in rectangular form for a system which has been defined in polar form. \
 The functions firstx, firstt, and firsttx have been added.  They are \
analogous to lastx, lastt, and lasttx, except that they extract the first \
element (earliest in time) of a solution rather than the last.  They are \
useful when continuing integrations that are being run backwards in time. A \
graphics option frameon has been added.  When it is set to true, a frame is \
drawn around 2D graphs.  The frame labels are controlled by framelabon.  A \
number of new applications in dynamical systems have been added.  They are \
listed in the notebook AppList.nb.   "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.55", "Subsection"],

Cell["\<\
\tAll phase plotting routines such as phaseplot, portrait, \
phaseseq, bifurc and others have been modified so that one of the quantities \
plotted can be the time, which is assigned variable number 0.  Thus \
timeplot[sol,1] and phaseplot[sol,0,1] produce the same graph.  A graphics \
option backcolor has been added.  The color assigned to it is used as \
background color on plots.   \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.56", "Subsection"],

Cell["\<\
\tIterated maps have been added to the package.  There are many new \
functions for iteration, for cobweb plots and for bifurcation diagrams.  The \
usage is explained in detail in section 21 of the main notebook \
(dynsys10.56.nb), and all of the new functions appear in FunctionIndex.nb.  \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version 10.57", "Subsection"],

Cell["\<\
\tA few minor cosmetic changes have been made to the graphics \
functions for iterated maps.  These functions now use most of the graphics \
options which control phaseplot, phaseplot 3D, and timeplot.  Some bugs in \
bifurc, bifurc3D, limbifurc, and limbifurc3D were fixed.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{-4, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 124, 5, 190, "Title",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1888, 60, 89, 4, 50, "Section"],

Cell[CellGroupData[{
Cell[2002, 68, 83, 2, 46, "Subsection",
  Evaluatable->False],
Cell[2088, 72, 216, 6, 46, "Text",
  Evaluatable->False],
Cell[2307, 80, 168, 5, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2512, 90, 83, 2, 46, "Subsection",
  Evaluatable->False],
Cell[2598, 94, 424, 8, 78, "Text",
  Evaluatable->False],
Cell[3025, 104, 158, 5, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3220, 114, 83, 2, 46, "Subsection",
  Evaluatable->False],
Cell[3306, 118, 450, 9, 78, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3805, 133, 89, 4, 50, "Section"],

Cell[CellGroupData[{
Cell[3919, 141, 35, 0, 46, "Subsection"],
Cell[3957, 143, 214, 6, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4208, 154, 35, 0, 46, "Subsection"],
Cell[4246, 156, 526, 12, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4809, 173, 35, 0, 46, "Subsection"],
Cell[4847, 175, 247, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5131, 185, 35, 0, 46, "Subsection"],
Cell[5169, 187, 260, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5466, 197, 35, 0, 46, "Subsection"],
Cell[5504, 199, 299, 7, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5840, 211, 35, 0, 46, "Subsection"],
Cell[5878, 213, 484, 8, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6399, 226, 35, 0, 46, "Subsection"],
Cell[6437, 228, 332, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6806, 239, 35, 0, 46, "Subsection"],
Cell[6844, 241, 51, 0, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6932, 246, 35, 0, 46, "Subsection"],
Cell[6970, 248, 198, 4, 46, "Text"],
Cell[7171, 254, 137, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7345, 262, 35, 0, 46, "Subsection"],
Cell[7383, 264, 215, 4, 46, "Text"],
Cell[7601, 270, 250, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7888, 280, 35, 0, 46, "Subsection"],
Cell[7926, 282, 257, 5, 46, "Text"],
Cell[8186, 289, 236, 5, 46, "Text"],
Cell[8425, 296, 357, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8819, 307, 35, 0, 46, "Subsection"],
Cell[8857, 309, 533, 10, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9427, 324, 35, 0, 46, "Subsection"],
Cell[9465, 326, 534, 8, 94, "Text"],
Cell[10002, 336, 167, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10206, 345, 35, 0, 46, "Subsection"],
Cell[10244, 347, 337, 7, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10618, 359, 35, 0, 46, "Subsection"],
Cell[10656, 361, 197, 4, 46, "Text"],
Cell[10856, 367, 206, 4, 46, "Text"],
Cell[11065, 373, 109, 3, 30, "Text"],
Cell[11177, 378, 209, 4, 46, "Text"],
Cell[11389, 384, 460, 8, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11886, 397, 35, 0, 46, "Subsection"],
Cell[11924, 399, 203, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12164, 408, 35, 0, 46, "Subsection"],
Cell[12202, 410, 413, 10, 126, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12652, 425, 35, 0, 46, "Subsection"],
Cell[12690, 427, 234, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12961, 437, 35, 0, 46, "Subsection"],
Cell[12999, 439, 181, 4, 46, "Text"],
Cell[13183, 445, 281, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13501, 455, 35, 0, 46, "Subsection"],
Cell[13539, 457, 299, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13875, 467, 35, 0, 46, "Subsection"],
Cell[13913, 469, 353, 6, 62, "Text"],
Cell[14269, 477, 216, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14522, 486, 35, 0, 46, "Subsection"],
Cell[14560, 488, 392, 6, 78, "Text"],
Cell[14955, 496, 651, 10, 110, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15643, 511, 35, 0, 46, "Subsection"],
Cell[15681, 513, 225, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15943, 522, 35, 0, 46, "Subsection"],
Cell[15981, 524, 193, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16211, 533, 35, 0, 46, "Subsection"],
Cell[16249, 535, 199, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16485, 544, 35, 0, 46, "Subsection"],
Cell[16523, 546, 295, 5, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16855, 556, 35, 0, 46, "Subsection"],
Cell[16893, 558, 1002, 22, 134, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17932, 585, 35, 0, 46, "Subsection"],
Cell[17970, 587, 393, 7, 78, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18412, 600, 89, 4, 50, "Section"],

Cell[CellGroupData[{
Cell[18526, 608, 35, 0, 46, "Subsection"],
Cell[18564, 610, 559, 12, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19160, 627, 35, 0, 46, "Subsection"],
Cell[19198, 629, 945, 14, 142, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20180, 648, 35, 0, 46, "Subsection"],
Cell[20218, 650, 1267, 30, 146, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21522, 685, 35, 0, 46, "Subsection"],
Cell[21560, 687, 412, 7, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22009, 699, 35, 0, 46, "Subsection"],
Cell[22047, 701, 317, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22401, 712, 35, 0, 46, "Subsection"],
Cell[22439, 714, 298, 5, 62, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

