(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    230484,       6335]*)
(*NotebookOutlinePosition[    255820,       7252]*)
(*  CellTagsIndexPosition[    255745,       7246]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["\[Copyright] ",
    FontFamily->"Symbol"],
  StyleBox["Alfred Clark, Jr.,",
    FontSize->10],
  StyleBox[" ",
    FontFamily->"Symbol"],
  StyleBox["1996, 2000",
    FontFamily->"Symbol",
    FontSize->10]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
dynsysver = \"10.57\";
\
\>", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
DynPac:
A DYNAMICAL  SYSTEMS PACKAGE
FOR MATHEMATICA  4\
\>", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["AL CLARK\nDEPARTMENT OF MECHANICAL ENGINEERING\n\
UNIVERSITY OF ROCHESTER\nROCHESTER NY 14627\n\nJUNE 23, 1995\n\nVERSION 10.57 \
REVISION\n FEBRUARY 21, 2000\n",
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold"]], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["1.  INTRODUCTION"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThis package grew out of my attempts to do two things:  learn more about \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and prepare examples and handouts for my graduate course in nonlinear \
differential equations.  The package has all the shortcomings you might \
expect from those origins.  The algorithms are not robust in many cases, much \
of the code was hastily written, and it often looks like the FORTRAN I have \
been writing for the last 30 years.  On the plus side, I would say that the \
package does create a uniform environment in which to find and display the \
solutions of systems of ordinary differential equations.  It also provides \
partial automation of such processes as linear stability analysis, orbit \
trapping, limit cycle construction, Poincar\[EAcute] maps, and phase portrait \
construction.  \n     \n\tThe primary function of this package is to \
facilitate the construction of pictures of solutions of differential \
equations within the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " environment. My hope is that it will be useful to you in your study of \
dynamical systems."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["ACKNOWLEDGMENTS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tI thank my students in ME 406, whose questions have kept me searching \
for better ways to construct examples.  I thank my colleague Colin \
McKinstrie, whose polite requests for extra features led to many \
enhancements.  Special thanks to Patricia Andre Clark of the Rochester \
Institute of Technology, for frequent and essential help with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n2.  OVERVIEW"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis overview describes how to use the principal routines in this \
package.  A description of the accompanying tutorial notebooks is given in \
the notebook TutorList.nb..  Collectively these tutorials illustrate the use \
of every user function in this package.  An alphabetical index of the \
principal routines is given in the notebook FunctionIndex.nb.  The detailed \
code, along with annotation and comments, appears in the sections following \
this one.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["INTEGRATION TECHNIQUES"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThis program solves the initial-value problem for systems of first-order \
ordinary differential equations.  In setting up the integration, you may \
choose the initial time, t0, the number of time steps, nsteps, and the step \
size, h.  (These are not reserved names -- you may use any names you like.)  \
You have your choice of four variations on the method of integration.  You \
make the choice by your settings of three flags.  If you set fastflag = True, \
then the system will call the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " routine NDSolve to perform the integration.  Within this option, there \
are two choices.  If you set maxstepflag = True, NDSolve will be constrained \
to a maximum step size h.  If you set maxstepflag = False, NDSolve will be \
free to make its own choice of step sizes.  In this last case, the parameter \
h and number of steps, nsteps, would be used only to calculate the final time \
as t0 + h*nsteps.  This option is generally the fastest available here, but \
be warned that NDSolve can use prodigious amounts of memory.  If you get near \
your memory limit, NDSolve may become slower than the other options described \
below.  Another limitation of using NDSolve, is that there is no \
range-checking as you integrate."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf you set fastflag = False, then the system will use the fourth \
order Runge-Kutta method with a fixed step size h.  There are also two \
choices within this option, and they differ in whether or not there is range \
checking.  If you set rangeflag = False, the integration routine does no \
range checking.  This makes the integration about 50% faster, but it can \
produce overflows with unbounded systems.  If you set rangeflag = True, the \
system still uses fourth order Runge-Kutta, but checks the values of the \
dependent variables at each time step.  If any value falls outside the range \
which you have set, the integration is terminated, and no points outside the \
range are put in the solution list.  The out-of-bound point that caused the \
integration to stop is stored in the variable outbound.  The prescribed range \
is stored in the variable ranger, with format\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ranger = {{a1,b1},{a2,b2},... {aj,bj}...}  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
Here the permitted range for the ith state vector component is the \
closed interval [ai,bi].  \t\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe user interface, as described below, is exactly the same for \
all these modes of integration, with the only difference being the flag \
settings already discussed.  The default settings are fastflag = False, \
maxstepflag = False, and rangeflag = False.  To return to those default \
settings at any time, type intreset.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["SPECIFYING A SYSTEM"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe consider first how to specify a particular system.  The system \
and the entire computing environment for the system are built around four \
vectors with fixed names.  The first, called statevec, gives the names you \
have chosen for the dependent variables in the differential equations.  To \
assign a list of variables to this vector, we use the function setstate.  For \
example, in a third order system we could assign {x,y,z} to statevec by\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}].", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"After this is executed, the vector statevec will have the value {x,y,z}."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe second vector, parmvec, contains all of the parameters of the \
system.  For the Lorenz equations, for example, the conventional parameters \
are sigma, r, and b.  To assign these parameter names to parmvec, we use the \
function setparm: \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["setparm[{\[Sigma],r,b}] .                   "], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"After this is executed, the vector parmvec will have the value \
{\[Sigma],r,b}.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe third vector, called slopevec, gives the right-hand sides of \
the differential equations, in terms of the dependent variables and any \
parameters in the system.  For example, for the Lorenz equations with \
standard notation, we define the slope vector by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[" slopevec = {\[Sigma]*(y-x),r*x-y-x*z,x*y-b*z}   ."], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"The differential equations defined by these three statements are "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"dx/dt = \[Sigma]*(y-x) ,  dy/dt = r*x-y-x*z ,  dz/dt = x*y-b*z  ."], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tThe fourth defining vector for the system is parmval, which \
carries the specific parameter values for a given integration.  For \
example,\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,28.0,8/3} ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"assigns \[Sigma] = 10.0, r = 28.0, and b = 8/3 (a set of parameter values \
which gives a chaotic solution of the Lorenz equations).  If you have any \
expression containing the parameter symbols in parmvec and you wish to \
evaluate that expression using the current parameter values in parmval, just \
execute "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["evalparm[exp].", "Text",
  TextAlignment->Center],

Cell[TextData[
"\tSometimes, one wants to set numerical values for some of the parameters \
but leave the others unspecified.  For example, we might want to track an \
equilibrium point or eigenvalues as a function of one of the parameters.  In \
the above example, if we wanted to set \[Sigma] = 10.0 and b = 8/3 with r \
left unspecified, we do this by setting"], "Text"],

Cell["parmval ={10.0, r, 8/3} .", "Text",
  TextAlignment->Center],

Cell["\<\
Of course for an integration, all parameters must have numerical \
values.  \
\>", "Text"],

Cell["\<\
\tAlthough it is possible to have parameters in the slope function \
which do not appear in parmvec, it is not recommended.  Some of the \
bifurcation routines require that the parameters being varied appear in \
parmvec.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn general, the definition of a system as described above is \
straightforward.  A potential source of trouble is the direct assignment of \
values to any of the symbols in statevec and parmvec.  In principle this \
isn't necessary because nothing requires you to assign values to the state \
variables, and you are required to use parmval to pass values to the \
parameters in parmvec.  In practice, it is not possible because the setting \
routines setstate and setparm do two things in addition to setting the values \
of the vectors:  they clear any values previously assigned to the symbols \
appearing in the vectors, and they protect these symbols so no values can be \
assigned to them later.  This is why we use these routines rather than \
assignment statements such as statevec = {x,y,z} and parmvec = {sigma,r,b} \
(which are also valid, but do not provide protection against accidental \
assignment of values to the symbols in the two vectors).  As soon as you \
define a new state vector by setstate and a new parameter vector by setparm, \
the symbols in the old state vector and old parameter vector are unprotected, \
so that they may be used.  The one exception is when you save your system \
definition, as we describe now.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tOn those occasions when you wish to work with more than one \
system in the same session, you can make use of savesys and restoresys.  To \
save the current four vectors defining the state under the name oldsys (you \
may use any name you like), type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["savesys[oldsys]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"To restore oldsys and make it the current system, type"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["restoresys[oldsys]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
The symbols appearing in the state vector and in the parameter \
vector of a saved system remain protected throughout the session.  This \
prevents assignment to state and parameter symbols which could be needed \
later if a restore is executed.\
\>", "Text"],

Cell["\<\
\tAs a second example, we consider a non-autonomous system -- \
namely the damped, driven pendulum.  The state vector is assigned by \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["setstate[{\[Theta], \[Omega]}]   ,"], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"and the slope vector, in a standard dimensionless form, is "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"slopevec = {\[Omega],-c*\[Omega]-Sin[\[Theta]]+f*Cos[w*t]}  ."], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"The time t appears explicitly in the cosine driving term.  While you are \
free to use any names for your state variables, you MUST use the symbol t for \
the independent variable.  The parameter vector for this system is set by"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setparm[{c,f,w}]    ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"where c is a dimensionless damping constant, f is the dimensionless driver \
amplitude, and w the dimensionless driver frequency.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tYou may assign optionally a name to the system: ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysname = \"Pendulum\"", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
assigns the name Pendulum.  This name will be displayed in the \
title of any graph that you produce.  The default name is \"System\".  Any \
previously assigned name is replaced with this default whenever setstate is \
executed.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTwo simple transformations of systems have been defined.  To \
reverse the time in the current system, type\
\>", "Text"],

Cell["reversetime  .", "Text",
  TextAlignment->Center],

Cell["\<\
To translate the origin of the system to a new position named say \
orgvec, type\
\>", "Text"],

Cell["transorg[orgvec]  .", "Text",
  TextAlignment->Center],

Cell["\<\
\tSometimes it is useful with two-dimensional systems to transform \
to polar coordinates.  The function below gives the slope vector after such a \
transformation, but does not alter the original system.  The function is  \
\
\>", "Text"],

Cell["polartrans[x, y, r, \[Theta]]  .", "Text",
  TextAlignment->Center],

Cell[TextData[{
  "Here x and y are the names of any two state variables which are to play \
the role of traditional x and y respectively.  The arguments r and \[Theta] \
are the new radial and angular polar coordinates respectively (any names may \
be used).  The function polartrans applies the transformation argx =r*Cos[\
\[Theta]] and argy = r*Sin[\[Theta]], and then returns the slope vector for \
{",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(r\& . \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\& . \)]],
  " }.  A function to go the other way is"
}], "Text"],

Cell["frompolartrans[r,\[Theta],x,y].", "Text",
  TextAlignment->Center],

Cell["\<\
This function takes a system in polar form and returns the slope \
vector for the rectangular form.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["CONSTRUCTING SOLUTIONS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tOnce statevec, parmvec, slopevec and parmval have been specified, \
the system is integrated by invoking the function integrate.  For \
example,\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["answer = integrate[initialvec,t0,h,nsteps]", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
assigns the solution (a list) to the variable answer.  The \
arguments of integrate are (1) intialvec, the vector of initial conditions, \
(2) t0, the initial time, (3) h, the time step size, and (4) nsteps, the \
number of time steps to be taken.  The list assigned to answer is a list of \
lists, each element of which has the form {t,x1,x2,x3,..xn}, where t is time, \
and the xi's are the components of the state vector at time t.  No matter \
which of the integration choices is used, the increment in the solution list \
between successive times is the step size h.  Normally nsteps is an integer.  \
If you choose a value other than an integer, it will be rounded to the \
nearest integer by the integrate routine.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tYou can get some help in your initial choice of time step for \
autonomous systems by typing\
\>", "Text"],

Cell["sugtimestep[window]   .", "Text",
  TextAlignment->Center],

Cell["\<\
Here window is a box region in which you will be working.  An \
example of a two-dimensional window is\
\>", "Text"],

Cell["window = {{-1,1},{0,3}}  .", "Text",
  TextAlignment->Center],

Cell["\<\
This routine will return a suggested time step.  It works by \
calculating rms values over the window of the slope vector components, and \
then estimating an appropriate time step from those numbers and from the size \
of the window.  The basic principle is that the window should be at least 100 \
time steps across in every dimensions, based on the average slope.  Although \
the suggested time step will give you a start, it often will be necessary to \
modify -- sometimes smaller and sometimes larger.\
\>", "Text"],

Cell["\<\
\tAll four of the arguments of integrate may depend on the \
parameters of the system.  Before integrate is executed, all arguments are \
subjected to a replacement operation with parmvec -> parmval.  This is \
particularly useful in bifurcation studies, where one may want different \
initial conditions for different parameters, or a different number of time \
steps for different parameters. \
\>", "Text"],

Cell["\<\
\tThe last calculated element in the solution list is assigned to \
the variable lasttx, the value of the state vector at this final time is \
assigned to the variable lastx, and the final time is assigned to lastt.  \
These variables make it simple to continue an integration.  If you want to \
continue the integration most recently performed and assign the continuation \
to moreanswer, type  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["moreanswer = integrate[lastx,lastt,h,nsteps]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tIntegrations may be carried out backward in time by simply \
setting h equal to a negative value.  In either case -- backward or forward \
in time -- the answer list always begins with the point corresponding to the \
algebraically smallest time, and lastx, lastt, and lasttx always refer to the \
last point calculated.  If you want an integration automatically to go both \
backward and forward, you set a flag named bothdirflag to true:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["bothdirflag = True  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
As long as this setting is in effect, all integrations will go \
nsteps in both directions from the initial point.  The default setting for \
this flag is False.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["LAG EQUATIONS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIt is also possible to integrate equations which have lagged \
values of the dependent variables in the slope function.  The routine which \
does this is\
\>", "Text"],

Cell["lagintegrate[initfunc,initcond,t0,h,T,nlags]   .", "Text",
  TextAlignment->Center],

Cell["\<\
The use of this and the nature of the arguments is best illustrated \
by an example.  Suppose we wish to integrate the equations given below.\
\>", 
  "Text"],

Cell[BoxData[
    \(TextForm
    \`\(dx\/dt\) \((t)\)\  = \ x \((t)\)*y \((t - T)\) - a*y \((t)\), \ \ 
    and\ \ \(dy\/dt\) \((t)\)\  = \ y \((t)\) - y \(\((t - T)\)\ \  . \)\)], 
  "Text",
  TextAlignment->Center],

Cell["\<\
In these equations, the lag time is T and a is a parameter.  To \
define this system for DynPac, we execute\
\>", "Text"],

Cell["\<\
setstate[{x,y}],  setparm[{a}],  and slopevec={x*ylag - a*y, y - \
ylag}.  \
\>", "Text",
  TextAlignment->Center],

Cell[TextData[
"Thus any lagged quantity appears in the slope vector with the name augmented \
by \"lag.\"  Suppose we want to integrate this set starting at t0 = 2 with \
initial conditions x = 3 and y = 4.  Suppose also the lag time is T = 4, and \
suppose we want to use a spacing of h = 0.05.  This is not yet enough \
information, because the lag term in the equation requires us to know y \
beginning at time t0 - T = -2.  Thus we must specify the values of y for the \
time range t0 - T \[LessEqual] t \[LessEqual] t0.  Let us suppose that during \
this time y(t) = Exp[-t].  The general code assumes that all variables appear \
in lagged form, so we must also specify a starting function for x, even \
though the values will not be used.  We can take it to be the initial value 3 \
for example.  Then we set initfunc = {3, Exp[-t]}.  Note that discontinuites \
are allowable in the sense that initcond does not have to be equal to \
initfunc[t0].  One could of course dispense with initcond by allowing \
initfunc to be a discontinuous function, but NDSolve has some major bugs when \
there are discontinuous coefficients, so this is not advisable.    "], "Text"],

Cell["\<\
\tThe solution returned by lagintegrate is of exactly the same form \
as a solution returned by integrate, so that any routine that takes a \
solution as an argument (graphing commands for example) will work with the \
solutions of lagintegrate.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["SCANNING AND MODIFYING SOLUTIONS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe describe here the routines that have been defined for scanning \
or modifying solutions.  The first such routine, joinsol, joins two \
solutions.  This routine is used to join an integration with a continued \
integration.  Thus if answer is the result of an integration, and moreanswer \
is the result of continuing the integration by using lastx and lastt for \
starting values, then we create a single solution (called totalanswer) from \
these by typing\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["totalanswer = joinsol[answer, moreanswer]   .           ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"The two solutions so joined must overlap -- that is, the last point of the \
earlier solution must agree with the first point of the later solution."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBesides joinsol, there are several other functions for modifying \
solutions already calculated.  The function stripsol removes a particular \
state variable from your solution list.  For example, to remove the kth state \
variable from a solution named answer and re-assign the modified solution to \
newanswer, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["newanswer = stripsol[answer,k]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"If you want to strip out the time coordinate from the solution list, execute \
stripsol with k = 0.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAnother solution-modifying function is modsol.  This function \
lets you replace the values of any state variable by its values modulo a \
specified interval.  This is helpful in dealing with systems like the \
pendulum, for which values of the angular state  modulo 2 Pi represent the \
same physical state. To replace the values of the kth state variable in the \
solution named answer by values modulo the interval [a,b), and assign the \
result to newanswer, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["newanswer = modsol[answer,k,a,b]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tTo create a solution list which is a subset of an original list, \
use \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["shortanswer = subsol[answer,{tmin,tmax}]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
This creates from answer a new list, shortanswer, which has in it \
only the data points with times in the closed interval [tmin,tmax].\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo make a functional transformation of a solution, use the \
function transol[sol,funclist].  The first argument of transol is the \
solution to be modified.  The second argument is a list of expressions in the \
state variables and time which are to be calculated at each solution point.  \
For example, suppose the statevector is {x,y}, and the parameter vector is \
{a,b},  and we have integrated the equations to get a solution named oursol.  \
Each element in the solution list has the form {t,x,y}.  Now suppose we would \
like to tabulate values of a*Sin[x], Exp[-y], and x + b*y.  We do this by \
first defining the list of transformations:  \
\>", "Text"],

Cell["funclist = {a*Sin[x], Exp[-y], x + b*y}  .", "Text",
  TextAlignment->Center],

Cell["\<\
Then to apply this to our original solution and assign the result \
to transoursol, we type\
\>", "Text"],

Cell["transoursol = transol[oursol, funclist]  .", "Text",
  TextAlignment->Center],

Cell["\<\
The list transoursol will now have the form {t, a*Sin[x], Exp[-y], \
x + b*y}, with all quantities being reduced to numbers, and we can use this \
list in any of the standard plotting routines.  For the special case of \
simple translations, the following functions have been defined: \
\>", "Text"],

Cell["\<\
timeshift[sol,\[Tau]] and stateshift[sol,vec]  .\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
In both cases, sol is the solution to be modified.  The function \
timeshift shifts each value of the time coordinate by \[Tau].  The function \
stateshift shifts the statevector at each point by the vector vec.  \
\>", \
"Text"],

Cell["\<\
\tThere are two routines for scanning the range of a solution.  The \
time range is obtained from trange.  Thus\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["trange[answer]", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
returns a list {tmin,tmax}, where tmin is the smallest time \
appearing in answer and tmax is the largest.  To find the minimum and maximum \
values of each component of the state vector in a solution named answer, type\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["staterange[answer]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["This will return a list of the form ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
{{x1,{xmin1,tmin1},{xmax1,tmax1}},..., \
{xn,{xminn,tminn},{xmaxn,tmaxn}},...}  ,\
\>", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
where the first elements of each sublist will be the name of that \
component of the state vector, and the min's and max's will be the numerical \
values of the minimums and maximums over the solution list, with the t's \
being the times at which they occur.                \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tTo find the arclength of a solution named answer, type", "Text"],

Cell["arclen[answerl]   .", "Text",
  TextAlignment->Center],

Cell["\<\
\tTo replace a solution list with a smooth interpolating function \
of time, use the routine buildinterp.  For example, to replace a solution \
list for the Lorenz equations named lorsol by a smooth vector with components \
X[t], Y[t], Z[t], type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["{X,Y,Z} = buildinterp[lorsol]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
After executing this, you can evaluate any component of the state \
vector for any t in the list range by typing X[t], Y[t] or Z[t].  You cannot \
use the original state variable names for your interpolation function names, \
because they are protected from assignments.  A second interpolating routine \
gives vector results for both the state vector and the slope vector.  If you \
type  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["solinterp[sol,stname,slpname]", "Text",
  TextAlignment->Center],

Cell["\<\
then executing stname[t] will return the state vector at time t, \
and executing slpname[t] will return the slope vector at time t.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["PERIODIC SOLUTIONS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf a system is known to have a limit cycle, and if you want to \
produce the pure limit cycle without the startup transient, then you can \
integrate twice:  once to get on the cycle, and then, using lastx and lastt, \
once again to produce the pure cycle.  The routine limcyc does this for you \
automatically.  Typing\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["answer2 = limcyc[initialvec,t0,h,nsteps]", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"will produce the list for the pure limit cycle and store it in the variable \
answer2.  Here initialvec is any reasonable starting point, not in general on \
the limit cycle.  The routine takes nsteps from initialvec, then starts the \
integration again with initial values lastx and lastt taken from the first \
integration.  Hence nsteps must be large enough to (1) put you on the cycle, \
and (2) to take you completely around the cycle.  Some experimentation may be \
required to find a suitable value of nsteps."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo find the period of any periodic solution for an autonomous \
sytem, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["period[answer2]   . ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
Although this routine usually works, it can be fooled by certain \
circumstances, such as a periodic solution very near a period doubling \
bifurcation.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["PLOTTING SOLUTIONS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA number of routines have been defined for plotting solutions.  \
For example,  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph1 = timeplot[answer,i]", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
produces a graph named graph1 which is a plot of the ith component \
of the solution versus time.  To plot more than one component on the same \
graph, you may use a list of components for the second argument.  For \
example, \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["multigraph1 = timeplot[answer,{2,3}] ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"plots the second and third components versus time on one graph."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe can produce a two-dimensional phase plot, named graph2, of the \
ith versus jth component by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph2 = phaseplot[answer,i,j]  ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"where i is plotted on the horizontal and j is plotted on the vertical.  For \
convenience, the function phaser has been defined for the special case i = 1, \
j = 2.  Thus"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph3 = phaser[answer]     ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  "gives the same thing as phaseplot[answer,1,2].  Another way of getting \
time plots is to execute phaseplot[answer,0,j].  Because the zeroth \
coordinate is taken to be ",
  StyleBox["t, ",
    FontSlant->"Italic"],
  "this will give the same thing as timeplot[answer,j]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo plot dots at specific points (for example equilibrium points) \
you can use the command dots[list].  Here list is a list of coordinate pairs \
to be plotted.  The 3D version of this is dots3D[list], where list is now a \
list of coordinate triples.  Both dots and dots3D use all of the graphics \
options.  The size of the dots plotted is controlled by ptsize, which \
specifies dot diameter relative to the graph size.\
\>", "Text"],

Cell["\<\
\tIf you wish to add arrows to a two-dimensional phase plot, set \
arrowflag = True.  Arrowheads pointing in the direction of increasing time \
will be added to the plot.  The vector arrowvec is used to specify the number \
and placement of arrows.  Arrowvec must contain positive numbers in the range \
[0,1], in increasing order.  We explain the action of arrowvec in terms of an \
example.  If arrowvec = {0, 1/3, 2/3}, then arrows will be added at positions \
which correspond to zero arclength from the start, 1/3 of the total arclength \
from the start, and 2/3 of the arclength from the start.  If you use 1 in the \
list, an arrow is placed at the endpoint of the path.  \
\>", "Text"],

Cell["\<\
\tAll of the above plotting routines can plot several solutions \
simultaneously.  The argument, named answer above, can be a list of solutions \
rather than a single solution.  Such a list must be enclosed in curly \
brackets.  For example, to simultaneously plot answer1, answer2, and answer3 \
in a phaseplot named graphmulti, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graphmulti = phaseplot[{answer1,answer2,answer3},1,2]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"In plotting a single solution named answer, you may enter the argument \
either as answer or {answer}."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf you wish to plot only part of a solution, you can use the \
function subsol defined above.  For example, if a solution named answer has \
been calculated for t from 0 to 5, and you wish to plot the ith component \
versus time for time running from 2 to 4, and name the graph graphpart, \
type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graphpart = timeplot[subsol[answer,{2,4}],i]    .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tWe can also produce direction fields for two-dimensional systems. \
 A direction field plot named graph4 is produced by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph4 = dirfield    .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  "This routine uses the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics package PlotField.  The range of coordinate values used for the \
direction field is taken from the variable plrange.  Thus before calling \
dirfield, you should set plrange.  For example, plrange = {{-1,1},{-2,2}} \
produces a direction field ranging from -1 to 1 in the horizontal, -2 to 2 in \
the vertical.  (For more on plrange and related variables, see the section \
below on Controlling Plot Appearance.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA three dimensional phase plot, named graph5, for components i, \
j, and k of the state vector is produced by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph5 = phaseplot3D[answer,i,j,k]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"As with phaseplot, this routine will also accept a list of solutions for the \
first argument.  The special case when i=1, j=2, and k=3 may be executed by \
typing  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph6 = phaser3D[answer]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tTo produce a three dimensional phase plot rotated theta degrees \
about the z-axis and assign it to graph7, type   \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph7 = rotphaseplot3D[answer,i,j,k,theta]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tYou can produce a sequence of rotated three-dimensional phase \
plots, suitable for animation, by the single command\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["animate[answer,i,j,k,ng]    ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
where ng is the number of graphs at equal angular displacements \
about the z-axis of 360/ng degrees.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["CONTROLLING PLOT APPEARANCE"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe variables controlling plot appearance are (1) pointcon, a \
setting for PlotJoined, (2) colorvec, a list of RGB colors,  (3) dashvec, a \
list of arguments for Dashing in two-dimensional plots,  (4) asprat, a \
setting for AspectRatio, (5) viewpt, a setting for ViewPoint, (6) boxrat, a \
setting for BoxRatios, (7) ptsize, an argument for PointSize, (8) \
poincptsize, an argument for PointSize used in Poincar\[EAcute] maps, (9) \
dirpt, which determines the number of grid points in a direction field plot, \
(10) lnthick, an argument for Thickness, (11) plrange, a setting for \
PlotRange for two-dimensional plots, (12) plrange3D, a setting for PlotRange \
for three-dimensional plots, (13) axon, a setting for Axes, (14) frameon, a \
setting for Frame, (15) axorg, a setting for AxesOrigin, (16) axlabon, a \
logical setting for AxesLabel, (17) framelabon, a logical setting for \
FrameLabel, (18) labon, a logical setting for PlotLabel, (19) labshift, a \
positioning variable for PlotLabel, (20) graylev, which sets the background \
level for animations, (21) display, which turns graph display on and off, \
(22) arrowflag, which controls whether arrows are shown on two-dimensional \
phase plots,  (23) arrowvec, which controls the number and placement of the \
arrows, (24) imsize, a setting for ImageSize which controls the size of the \
graph in the notebook, and backcolor, a setting for Background, which \
controls the background color of a graph.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe variable pointcon is set to True (the default) to get a connected \
graph, and set to False for a plot of points only.  Set arrowflag to True to \
get arrows at time increments of arrowinc on two-dimensional phase plots.  \
The first arrow will be placed a number of timesteps equal to arrowoffset \
from the initial time.  If you want to change the shape of the arrowhead, you \
can change the default options stored in the variable arropt.  (In so doing, \
don't count on any useful help from the obscure write-up in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages book).  The variable asprat controls the aspect ratio of \
two-dimensional plots created by timeplot, phaseplot, and dirfield.  The \
default value used here is Automatic, which means that equal x and y \
increments receive equal screen increments.  If you set asprat equal to a \
numerical value r, then the resulting graph will have a height r times its \
width.  If axon is set to True (the default), axes are plotted on your graph. \
 On those occasions when the axes interfere with the graph, you can turn them \
off by setting axon to False.  If frameon is set to True, a box will be drawn \
around a 2D graph.  The default is False.  The variable axorg gives the \
position of the origin in a two-dimensional plot.  The values are either a \
list of two numbers, or Automatic, which is the default.  The flag axlabon \
controls the axis labels.  If axlabon is set to True, then the axes are \
labeled with the variable names and, if they were supplied, units.  If \
axlabon is False, no axis lables are printed.  If axlabon is set to a valid \
AxesLabel setting, that setting will be used.  Exactly the same options apply \
to the quantity framelabon, which controls the frame labels when frameon has \
been chosen to be true. The variable imsize is a value for the option \
ImageSize, in printer's points.  It controls the width of the graph when \
displayed.  The default in regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is 288.  As a boon to those of us who have reached the bifocal age, the \
default here is 340.  The variable backcolor contains the background color to \
be used in plots.  It is assigned a value by the command setback[color].  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThere are several variables for controlling plot labels.  The logical \
variable labon is set to True (the default) to produce a plot label giving \
the name of the system and the parameter values.  Sometimes the plot label \
overlays the y-axis label, a situation which doesn't bother ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " but may bother you.  You can turn off the plot label by setting labon to \
False.  Alternatively, you may \"spread\"  the label by setting labshift = n. \
 This will insert n spaces between the system name on the left and the \
parameters on the right.  The default is n = 0 which gives a single space \
between the name and the parameters in the label.  The numerical values of \
the parameters printed in the labels may be printed in several ways.  To \
prevent label \"jumping\" during animations, it is necessary to control the \
digits of the numbers in the plot labels.  These have been set to default \
values of totdig = 4, the total number of digits, and decdig = 2, the number \
of digits to the right of the decimal point.  You may set these variables to \
any value that is convenient.  The output in this case is by the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function PaddedForm.  In systems with very large or small parameters, \
this is inconvenient.  To use scientific notation for the numbers in the \
graph label, set sciflag = True.  Then scientific notation will be used with \
the number of digits to the right of the decimal equal to decdig.  To define \
your own plot label rather than using the default of system name and \
parameter values, just set labon = \"your label\" .  This will be used as the \
label until you set labon to something different."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tYou may also add units to the axes labels or the plot labels.  Suppose \
for example the state vector is {x,y,z}, and you wish to assign units of \
\"m\" to x, no units to y, and \"",
  Cell[BoxData[
      \(TraditionalForm\`s\^\(-1\)\)]],
  "\" to z.  Do this by typing"
}], "Text"],

Cell[TextData[{
  "stateunits = {\"m\",\"\",\"",
  Cell[BoxData[
      \(TraditionalForm\`s\^\(-1\)\)]],
  "\"}     ."
}], "Text",
  TextAlignment->Center],

Cell["You may also assign a unit to the time variable:", "Text"],

Cell["timeunit = \"hr\"   .", "Text",
  TextAlignment->Center],

Cell["\<\
Finally, you can assign units to the parameters also.  Suppose the \
parameter vector is {a, b}, and suppose that a has units of kg, and b has no \
units.  You can make this assignment by typing\
\>", "Text"],

Cell["parmunits = {\"kg\",\"\"}   .", "Text",
  TextAlignment->Center],

Cell["\<\
As long as these unit definitions are in effect, the graphs will be \
labeled with the units as well as the parameters and state variables.  Unit \
assignments may be cleared with the functions parmunitsclear, \
stateunitsclear, and timeunitclear.  To clear all of these at once, execute \
unitsclear.\
\>", "Text"],

Cell["\<\
\tConsider now color for plotted curves.  This is controlled by the \
vector colorvec, which contains a list of RGB colors.  If colorvec contains a \
single color, that color is used for all plots.  If it contains more than one \
color, the colors are used cyclically in a sequence of plots.  The default \
value of colorvec is {{RGBColor[0,0,0]}}, which causes everything to be \
plotted in black.  Because colors may be assigned by name, an equivalent \
default is {{Black}}.  To assign a value to colorvec, use the function \
setcolor (this also initializes a pointer for the cyclic colors).  Thus to \
get all curves in red, type \
\>", "Text"],

Cell["\<\
setcolor[{Red}]  , or equivalently, setcolor[{RGBColor[1,0,0]}]  \
.\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
To get a sequence of curves in red, green and then blue, type\
\>", 
  "Text"],

Cell["setcolor[{Red, Green, Blue}]  .", "Text",
  TextAlignment->Center],

Cell[TextData[{
  "The color definitions by name are from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package Graphics`Colors` which is loaded automatically at startup.  \
Because this package defines several hundred colors by name, the direct \
numerical specification of colors will rarely be needed.  A list of all \
available colors may be obtained by typing AllColors or allcolors."
}], "Text"],

Cell[TextData[{
  "\tThe situation for dashing is entirely analogous.  Dashing for \
two-dimensional plots is controlled by the vector dashrvec, which contains a \
list of patterns to be used as arguments for the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " option Dashing.  If dashvec contains a single pattern, that pattern is \
used for all plots.  If it contains more than one pattern, the patterns are \
used cyclically in a sequence of plots.  The default value of dashvec is \
{{}}, which causes everything to be plotted in with a solid line.  To assign \
a value to dashvec, use the function setdash (this also initializes a pointer \
for cyclic dashing).  Thus to get all curves in a pattern {0.05} (equal \
length of lines and gaps, with both being a fraction 0.05 of the graph \
width), type "
}], "Text"],

Cell["setdash[{{0.05}}]  .", "Text",
  TextAlignment->Center],

Cell["\<\
To get a sequence of curves in patterns {0.05}, {0.05,0.02}, and \
{0.05,0.02,0.02,0.05} type\
\>", "Text"],

Cell["setdash[{{0.05},{0.05,0.02},{0.05,0.02,0.02,0.05}}  .", "Text",
  TextAlignment->Center],

Cell["\<\
For convenience, five dashing options have been defined by name:  \
dashlong for long dashes, dashort for short dashes, dashalt for alternate \
long and short, dotted for dotted, and solid for solid curves.  \
\>", "Text"],

Cell["\<\
\tThree variables which affect the three dimensional plots produced \
by phaseplot3D and animate are viewpt, boxrat and graylev.  The variable \
viewpt is a list of three numbers which defines the viewpoint position of the \
plot, with coordinates defined relative to the box coordinates.  Viewpoints \
far away (i.e., large numbers in the list) reduce the effects of perspective. \
 The default used here, {13,-24,20}, is such a viewpoint.  The variable \
boxrat is a list of three numbers which define the ratios of the box sides.  \
The default used here is Automatic, which means that the box is scaled by the \
actual data being plotted.  Sometimes this results in a very skinny box, a \
situation which can be fixed by setting boxrat to a trio of not-too-different \
numbers.  The variable graylev controls the darkness of the gray background \
for animate.  It ranges from 0 (black) to 1 (white).  The default is 0.49.  \
Values below 0.50 produce a white box frame, values above a black box frame.  \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe variables ptsize, poincptsize and lnthick control the \
thickness of graphic elements.  The variable ptsize specifies the size of \
graphed points relative to the size of the graph.  The default here is 0.005. \
 The variable poincptsize specifies the size of dots in a Poincar\[EAcute] \
map.  The default is 0.008.  The variable lnthick specifies the line \
thickness as a fraction of the graph size.  The default is 0.002.\
\>", "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe variable dirpt (an integer) controls the number of grid \
points in a direction field plot, that number being dirpt x dirpt.  The \
default value is 20.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe variable plrange is the setting for PlotRange.  The default \
is All, which plots all points.  An alternative is Automatic, which doesn't \
plot outliers.  You can also set plrange to a numerical range for the \
variables plotted.  In a two-dimensional plot, for example, the setting \
\>",
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-1,3},{0,5}}", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
would produce a plotting window running from -1 to 3 in the \
horizontal and 0 to 5 in the vertical.  For three-dimensional plots, the \
variable controlling range is plrange3D.  The default setting is All, which \
plots all points.  An alternative is Automatic, which plots all but outliers. \
 You can also set plrange3D to a numerical range for the three variables \
plotted:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange3D = {{-2,2},{-4,4},{-5,5}}  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tThere are times when one wishes to construct a graphical object \
without displaying the graph.  To do this, set the variable display to False. \
 The default setting is True, which causes graphs constructed to be shown on \
the screen.  Graphs which are produced with the setting False, carry with \
them the non-display option, and a Show command will not display them unless \
the Show command explicitly contains the option DisplayFunction -> \
$DisplayFunction.  As a convenience, we have defined the commands \
show[graphlist] and show3D[graphlist] which will show all graphs in the list, \
no matter what display option was in effect when they were created.  The \
argument graphlist should be entered exactly as it would be for a Show \
command, without curly brackets around the list, although it will also work \
with the curly brackets.  The other default options used with show are the \
current settings of asprat, axon, and plrange.  Default options used with \
show3D are axon, boxrat, plrange, and viewpt.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tSometimes we wish to plot a function -- for example, a forcing function \
in a driven system -- on the same time graph with the solution.  We can use \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Plot command to do this.  As a convenience, we have defined a variation \
named plot, which works like Plot but which automatically takes as options \
the current settings of asprat, axon, axorg, plrange, and display."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe command plotreset will set all of the graphics control \
variables to their default values.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["CONSTRUCTING PHASE PORTRAITS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe use the term phase portrait informally here to mean a plot of \
several solutions on one graph.  Because both phaseplot and phaseplot3D will \
accept lists of solutions for arguments, one can produce such plots simply by \
carrying out several integrations and then plotting them on the same graph \
with a single execution of phaseplot or phaseplot3D.  Here we describe \
several routines which automate some tasks of this type.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo produce automatically a phase plot with curves from several \
different initial conditions, there is the function portrait.  A phase \
portrait named portgraph is produced by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["portgraph = portrait[intlist,t0,h,nsteps,i,j].", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
Here intlist is a list of initial conditions.  For each of t0, h, \
and nsteps, there are two choices.  If the argument is a number, that number \
is used for all the integrations in intlist.  If the variable is a list, with \
the same number of entries as there are initial conditions in intlist, then \
the elements of the list are used in succession as the integrations are \
performed.  Any of the entries appearing in any of the first four arguments \
of portrait may also contain expressions in the parameters of the system.  \
Before integration, the parameter symbols are replaced by their present \
values.   There is also a three-dimensional version of this routine:\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph3d = portrait3D[intlist,t0,h,nsteps,i,j,k]", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
produces a sequence of three-dimensional plots of components i,j,k. \
 The allowed formats for the arguments are exactly the same as for portrait. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis automation has been carried one step further with the \
function bifurc, which produces a sequence of phase portraits for a sequence \
of parameter values.  The syntax is\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["bifurc[intlist,t0,h,nsteps,i,j,parmlist,refgraph]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
The new argument, parmlist, is a list of parameter values.  That \
is, each element in parmlist is a value of the vector parmval.  The argument \
refgraph is optional  When used, it should be the name of a graph which will \
be superimposed on each graph produced by bifurc.  The graph can be a \
\"constant\" graph constructed earlier, or it can be a function of the system \
parameters which returns a graph.  If you have no such reference graph, \
simply omit the argument.  There is also a three-dimensional version of this:\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["bifurc3D[intlist,t0,h,nsteps,i,j,k,parmlist,refgraph]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
The arguments intlist, t0, h, and nsteps in bifurc and bifurc3D \
have the same allowed formats as for portrait.\
\>", "Text"],

Cell["\<\
\tA variation of this for limit cycles is called limbifurc.  To \
produce a sequence of limit cycles corresponding to different parameter \
choices, use\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["limbifurc[initialvec,t0,h,nsteps,parmlist,refgraph]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
Here initialvec is any reasonable point somewhat near the limit \
cycle.  It is important that nsteps be large enough to allow the limit cycle \
to be reached starting from initialvec.  The quantities t0, h, and nsteps are \
as for portrait.  The list parmlist is a list of parameter values to be used \
in the sequence.  As before, refgraph is an optional argument, which when \
used is the name of a graph to be superimposed on all of the graphs produced \
by limbifurc.  The three-dimensional version of this is limbifurc3D.\
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  " \tSome software packages for differential equations feature a \
\"point-and-click\" mode in which the solutions are graphed as they are \
constructed.  Considerable insight can be obtained from watching such \
constructions.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", one generally has to compute first and then plot.  However, it is quite \
easy to simulate such point-and-click constructions by producing a \
time-sequence of graphs which can be animated.  The routine defined here \
produces a sequence of phase plots at equal time intervals.  The usage is"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["phaseseq[initlist,t0,h,nstepic,npics,i,j,refgraph]  ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
where initlist is a list of initial conditions, t0 is the initial \
time, h is the time step, nstepic is the number of time steps in a single \
plot, npics is the number of plots desired, and i and j are the components \
plotted.  Again the argument refgraph, which is optional, is the name of any \
reference graph which you want to superimpose on all the graphs of your \
sequence.  To produce a three-dimensional sequence, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
phaseseq3D[initlist,t0,h,nstepic,npics,i,j,k,refgraph]  .      \
\
\>", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"When these sequences are animated, you see the orbits being constructed, \
and, because the graphs are at equal time intervals, you get some idea of \
orbital velocities.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tFive routines have been defined to automate the construction of \
simple phase portraits near equilibrium points in two dimensions.  Each \
routine takes two arguments:  the coordinates of the equilibrium point, and \
the plotting window.  All of the routines choose a time step by calculating \
the rms values of the slope components over the plotting window.  Those \
values are then taken as \"typical,\"  and the time step is chosen so that \
there are at least 100 time steps across the minimum width of the plotting \
window.   For example, near a saddle point in two dimensions, we may get a \
graph of the stable and unstable manifolds plus four nearby integral curves \
by typing\
\>", "Text"],

Cell["saddleportrait[eq,window]  .", "Text",
  TextAlignment->Center],

Cell["To get the just the stable and unstable manifolds type", "Text"],

Cell["saddleportraitman[eq,window]  .", "Text",
  TextAlignment->Center],

Cell["\<\
Here window is in the format of plrange, and gives the plotting \
window for the graph.  The other three routines work in the same way (in fact \
they differ only in the way the initial conditions are chosen).  \
spiralportrait[eq,window] produces four integrals connecting with the spiral \
equilibrium point, nodeportrait[eq,window] produces the fast and slow \
eigenvectors and four additional integral curves, and \
centerportrait[eq,window] produces three periodioc orbits surrounding the \
equilibrium point.  For best results with these five routines, it is \
essential to put the equilibrium point at or near the center of the plotting \
window.   As is usually the case in computing, we trade here robustness for \
automation.  Although it is possible to change the parameters in these \
routines if they are not working well in a particular case, it is probably \
better simply to abandon them in favor of \"hand-construction\" with \
integrate, which offers full control over the integration parameters.  \
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["POINCAR\[CapitalEAcute] MAPS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA special plot of interest in the search for periodic solutions \
is the Poincar\[EAcute] map.  Such maps are defined here both for \
periodically driven systems and for autonomous systems.  Consider first the \
driven systems.  The map is executed in two steps.  The first step is  \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["answer = drpoincsol[initvec,t0,tau,numper]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"The function drpoincsol produces a solution list suitable for a Poincar\
\[EAcute] map.  The arguments are the initial vector, initvec, the initial \
time t0, the strobing time interval, tau (normally the period of the driver), \
and the number of tau-periods to be calculated, numper.  The number of \
integration point per period is taken as the value of the variable \
poincpointper.  The value must be a multiple of 24 (including 24), and the \
default is 48.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAfter drpoincsol is executed, you can produce the \
Poincar\[EAcute] map with the function drpoincmap:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["drpoincmap[answer,phase,i,j]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"Here i and j are the components to be plotted.  The argument phase is the \
phase of the cycle (relative to t0) at which you want the solution to be \
sampled.  You have 24 choices for phase:  0(15)345 degrees.  If you use any \
other number for phase (positive or negative), drpoincmap will reduce it \
modulo [0,360), and then round it to the nearest 15 degree point.  The \
function drpoincmap3D works in exactly the same way, except that it gives a \
three-dimensional plot of components i,j,k.    "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf you want a list of the points plotted in the Poincar\[EAcute] \
map, use the function drpoinclist[answer,cycphase], where answer has been \
produced by drpoincsol, and cycphase is the phase at which you want the \
points.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf you want to continue a given map for more periods, just type\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["moreanswer = drpoincsol[lastx,lastt,tau,numper]   ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"where now numper is the number of additional periods desired.  You can plot \
this separately, or you can join your solutions and plot them together:"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["biganswer = joinsol[answer,moreanswer]   ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["bigmap = drpoincmap[biganswer,phase,i,j]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tFor autonomous systems, the problem is somewhat different, \
because we seek intersections of orbits with a given surface, and these \
events do not in general occur at equal time intervals.  In the \
implementation here, the only intersection surfaces considered are planes.  \
The plane of intersection, called the Poincar\[EAcute] plane, is required to \
have the name poincplane.  It is specified as follows:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincplane = {a,b}  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"Here a is a vector of length n (system dimension) and b is a scalar.  This \
specifies the plane with equation Dot[a,x] + b = 0, where x is the state \
vector.  For example, the Poincar\[EAcute] plane     x - y + 2z = 1 is \
specified by {1,-1,2,-1}.  The starting point for constructing the Poincar\
\[EAcute] map is to carry out an integration in the usual way.  For example, \
we suppose that the solution named answer has been obtained by executing \
integrate.  Then we execute the function poinclist:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincans = poinclist[answer]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"This function will assign to poincans a solution list which contains the \
times and coordinates for the crossing of poincplane (determined by linear \
interpolation from nearest points on either side of poincplane).  If you want \
to distinguish between positive crossings (in the direction of a) and \
negative crossings (in the direction of -a), you may use poincminus and \
poincplus to subdivide poincans:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincansplus = poincplus[poincans]  ,", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["poincansminus = poincminus[poincans]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"These functions use the slope vector to sort out positive and negative \
crossings.     "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBecause the lists produced by these functions are simply solution \
lists (although not at equally spaced time intervals), you may use any of the \
plotting routines to look at them.  To make this a little easier, we have \
defined poincmap and poincmap3D, which are essentially versions of phaseplot \
and phaseplot3D, but which automatically plot unconnected points of a \
suitable size.  For example, to produce a Poincar\[EAcute] map from poincans \
for components i and j of the state vector, type \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincmap[poincans,i,j] .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"To produce a three-dimensional Poincar\[EAcute] map from poincans for \
components i,j, and k, type "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincmap3D[poincans,i,j,k]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tFor the special case of a system of dimension three, there is an \
additional Poincar\[EAcute] map called poincmapopt3D.  This is essentially \
poincmap3D with a special viewpoint, chosen along the negative of the normal \
to the Poincar\[EAcute] plane.  The usage is \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincmapopt3D[poincans]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["FINDING EQUILBRIUM STATES"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIn autonomous systems, the equilibrium states (the roots of the slope \
vector) play a major role in the analysis of the system.  The most powerful \
root-finding technique in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is the command FindRoot.  It is generally the method of choice, \
particularly with difficult roots.  For simpler cases, we have defined \
several easy-to-use routines here.  The first two are simply applications of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve and NSolve commands, and are limited to systems with polynomial \
slope vectors.  The command"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["findpolyeq", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
will, when it works, give exact algebraic expressions for the \
equilibrium points in terms of the system parameters.  Suppose we have named \
one of these equilibrium points eqpoint.  To evaluate eqpoint in terms of the \
current values of parmvec in parmval, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["eqstateval[eqpoint]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tTo find numerical values using the current parameter values, type\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["nfindpolyeq   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
A third routine, which gives numerical results for general slope \
functions, has been based on the Newton-Raphson technique.  It requires one \
initial guess, and is executed by \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["nfindeq[initguess]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"You can refine your root by applying nfindeq again, using your first root as \
an initial value.  For any of the above routines, you can evaluate the slope \
vector at your root by executing"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["residual[root]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["LINEAR STABILITY ANALYSIS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe linear stability analyis of an equilibrium state of an \
autonomous system is based on the eigenvalues and eigenvectors of the \
derivative matrix at the equilibrium point.  To make this analysis more \
convenient, we define here routines dermat and dermatval[eqstate].  The \
routine dermat takes the current settings of statevec and slopevec, and \
creates the derivative matrix in terms of the symbols of statevec and \
parmvec.  The routine dermatval[eqstate] gives the numerical derivative \
matrix at the point eqstate, with the current setting of parmval.  The \
argument eqstate can be a pure list of numbers, or it can also include \
parameter symbols, in which case the parameter values in eqstate will be \
taken from the current setting of parmval.  If for example we have found an \
equilibrium at the point {1,-2,4}, we may find the eigenvalues at this point \
by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[{1,-2,4}]      .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
As a convenience, we have defined eigval to do this without \
reference to dermatval:\
\>", "Text"],

Cell["eigval[eqstate]", "Text",
  TextAlignment->Center],

Cell["\<\
returns the eigenvalues of the system at the point eqstate (whether \
it is an equilibrium or not), and \
\>", "Text"],

Cell["eigsys[eqstate]", "Text",
  TextAlignment->Center],

Cell["\<\
returns the eigenvectors and eigenvalues at the point eqstate.\
\>",
   "Text"],

Cell["\<\
\tIf you just want to know the stability of the equilbrium without \
seeing the eigenvalues, you can get that by executing \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify[eqstate]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["For two-dimensional systems, you can get more detail from", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify2D[eqstate]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
This will tell you the equilibrium type (spiral, node, saddle) as \
well as the stability.  These routines calculate the eigenvalues without \
verifying that eqstate is actually an equilibrium.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"ORBIT TRAPPING AND INDEX THEORY IN TWO DIMENSIONS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe tools described here help in the determination of both \
equilibrium points and periodic orbits for autonomous systems.  We describe \
first the three user routines, and then we describe in detail exactly how one \
has to define a curve prior to using these routines.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tSuppose we have a curve named mycurve.  To plot this curve, we \
type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plotcurve[mycurve]    .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"This plot routine uses all of the graphics parameters already discussed with \
one exception:  it always plots a continuous curve no matter what the setting \
of pointcon."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn trying to localize orbits, one seeks curves which trap orbits \
-- that is, curves across which orbits flow only one way relative to the \
normal.  Testing a curve for this property requires a determination of the \
direction field relative to the curve normal along the entire curve.  To \
carry out this test for a curve named mycurve, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbcross[mycurve]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"This uses the currently defined slopevec and parmval, and scans mycurve.  \
The routine returns a brief printed report which tells you whether there are \
tangencies, and whether the orbits cross in one direction or both.   "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThere also is a routine that calculates the index of a curve with \
respect to the current slopevec.  To find this index for a simple closed \
curve called mycurve, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["index[mycurve]    .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"This returns a number equal to the rotation of the slopevector along the \
entire curve, divided by 2 Pi.  This is helpful in finding equilibrium points \
and also in looking for periodic solutions.   "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe number of points along a curve used by orbcross and index is \
contained in the variable ncurpoints.  The default value is 100, but you may \
need to increase this value if you have very oscillatory slope functions, or \
if you attempt to calculate an index on a curve close to the \
equilibrium.\
\>", "Text"],

Cell["\<\
\tNow we must consider the details of how to define a curve.  We \
take a standard approach and first define a smooth directed arc.  Curves are \
then defined as certain kinds of unions of these arcs.  A smooth directed arc \
is defined parametrically.  We require that the functions defining it be \
continuously differentiable.  We require further that the tangent vector be \
non-zero along the entire arc.  The best way to illustrate the format used \
here is by an example.  The definition below assigns to arc1 a quarter-circle \
with center at {x0,y0}, radius r0, with the arc starting at {x0+r0,y0}.\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["arc1 = {{x0+r0*Cos[u],y0+r0*Sin[u]},{u,0,N[Pi/2]}}  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"Thus an arc is a list of two lists.  The first list consists of two \
expressions -- one each for x and y, expressed in terms of a running \
parameter, in this case u.  The second list gives three things:  the name of \
the parameter (u), the beginning value (0), and the end value (Pi/2).  The \
other parameters in this example -- x0, y0, and r0 -- must be specified \
numerically by assignment statements before any actual calculations are \
attempted."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn some of the calculations, the tangent and normal vectors of \
these smooth arcs are used.  The tangent vector is the derivative with \
respect to u, and thus points in the direction of increasing u.  Of the two \
possible normal vectors, we choose the one which is obtained from the tangent \
by a clockwise rotation of 90 degrees.  Then for a simple closed curve which \
is positively oriented (with the usual convention that the enclosed region is \
on the left as we traverse the curve in the positive direction), the normal \
used here is the normal exterior to the region enclosed.  To find the tangent \
and normal vectors to an arc named arc1, type\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["tanvec[arc1]  ,   normvec[arc1]   .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
 \tFinally, we define a curve as a sequence of arcs, with the \
beginning point of each arc equal to the end point of the preceding arc.  \
Again an example is the easiest way to see this.  We define two more arcs.  \
The first is\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["arc2 = {{x0,y0 + r0*(1-u)},{u,0,1}}   , ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"which is a straight line, parallel to the y-axis dropping down from {x0,y0 + \
r0} to the circle center {x0,y0}.  Now we define"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["arc3 = {{x0 + r0*u,y0},{u,0,1}}    .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"This arc runs parallel to the x-axis from the circle center out to the \
starting point of arc1.  From these three arcs, we can define a simple closed \
curve by "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["mycurve = {arc1, arc2, arc3}    .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
This curve is positively oriented, so the normal vector, as \
calculated here, is the exterior normal.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["BENDIXSON AND DULAC TESTS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA well-known necessary condition for an orbit in two dimensions \
to be periodic is that the divergence of the slope vector must either take on \
both signs or vanish indentically in the region enclosed by the orbit.  This \
is Bendixson's test.  A generalization, called Dulac's test, is that the same \
statement may be made about the divergence of any scalar function times the \
slope vector.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe routines defined here make it easy to apply this test.  The \
function div[F] calculates the divergence of the vector F, and the function \
dival[F] calculates the divergence of the vector F with the current values of \
the parameters (taken from parmval)  substituted wherever they occur in F.  \
These functions work in any dimension, and they assume that the dimension of \
F is that of the current state vector, and that the divergence is to be taken \
with respect to the state vector symbols.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo apply Bendixson's test in two dimensions, we calculate \
dival[slopevec].  If it is identically zero, then periodic orbits are \
possible by this test, but not guaranteed.  If the divergence is not \
identically zero, we construct a special contour plot to look for sign \
changes of dival[slopevec].  This is done by the function signcontour[v], \
which produces a plot with regions of positive v white, negative v gray.  We \
may combine these last two steps by executing \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["signcontour[dival[slopevec]]    . ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
To apply Dulac's test, simply go through the same sequence with \
slopevec replaced by g*slopevec, where g is any continuously differentiable \
scalar expression in the symbols of statevec and parmvec.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["LIAPUNOV FUNCTIONS IN TWO DIMENSIONS"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tChoosing Liapunov functions to test for the stability of an \
equilibrium point is to some extent an art which cannot be reduced to an \
algorithm.  To establish stability, we need a function V which is positive \
definite and whose orbital derivative is negative definite.  To establish \
instability, we need a function U which assumes positive values in every \
neighborhood of the equilbrium and whose orbital derivative is positive \
definite.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe routines defined here give you a quick graphical look at sign \
changes in the functions you have chosen.  The orbital derivative of a \
function V is obtained by orbdt[V], where V is an expression in the state \
variables (more generally, orbdt works for functions which also depend \
explicitly on time).  If you wish the parameters in the slope vector to be \
replaced by their current values, use orbdtval[V].  These two functions are \
defined for arbitrary dimension.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tMany times it is desirable to include additional parameters in \
potential Liapunov functions to give more flexibility in the attempt to make \
them work.  To accommodate that, we use the same approach as for slopevec, \
parmvec, and parmval.  The vector liaparmvec contains the symbols of the \
parameters in the Liapunov function, and the vector liaparmval contains the \
current values of those parameters.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo test a given Liapunov function V, first define the function as \
a scalar expression (no curly brackets!) in the state variables, and, \
optionally, in the system parameters in parmvec and in any Liapunov \
parameters in liaparmvec.  Then set your plotting window to include the \
equilibrium point (by setting plrange),  and use the function liapsign:     \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["liapsign[V] and liapsign[orbdt[V]]  .  ", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
These each produce a contour graph in which regions of positive \
function are white, negative are grey.  Before constructing each plot, \
liapsign substitutes current values both for parmvec and liaparmvec.   \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo construct, with one command, a sequence of these contour plots \
with different parameter values, use\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["liapsignseq[liaparmlist,V].", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[
"This will execute liapsign for V, using as parameter values all of the sets \
in the list liaparmlist."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tOnce you have found a likely Liapunov function, you may wish to \
see its contours near the equibrium point.  This is accomplished by\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["liapcontours[V]  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
This routine also takes current values from parmval and liaparmval \
before constructing the contours.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ITERATED MAPS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAlthough the emphasis in this package is on differential \
equations, some functions have been added for iterated maps.  Every effort \
has been made to use the same general framework for maps as for differential \
equations.  Thus the command setstate is used to define the map state \
variables, and the mapping itself is assigned to slopevec.  Any parameters in \
the map are declared with setparm, and their values are assigned to parmval.  \
There are two words to switch back and forth between the differential \
equation mode and the map mode.  The command setde switches to differential \
equation mode, and the command setmap switches to the mapping mode.  \
Basically setmap turns off fastflag (calls to NDSolve) and turns off \
integration in both directions in time.  It also sets pointcon = False, so \
that points in graphs are not connected, and it makes a default setting of \
plrange = {{0,1},{0,1}}.\
\>", "Text"],

Cell["\<\
\tAs an example of defining a mapping, we consider the logistic \
map, defined by the sequence below.\
\>", "Text"],

Cell["\<\
setstate[{x}];  setparm[{r}]; slopevec={x*r*(1-x)}; parmval = {3}; \
setmap;\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
Although non-autonomous maps are not very often studied, they do \
fit into the present framework.  For example, a logistic map with a parameter \
varying sinusoidally from 1 to 3 is defined by\
\>", "Text"],

Cell["\<\
setstate[{x}];  setparm[{r}]; slopevec={x*(r + Sin[w*t])*(1 - x); \
parmval = {2}; setmap;\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
As with differential equations, the variable t is reserved for the \
independent variable.  When a mapping is iterated t increases in increments \
of 1.\
\>", "Text"],

Cell["\<\
\tOften in studying mappings, we wish to work directly with higher \
iterates of the map.  This is useful, for example, when we are looking for \
periodic solutions of the basic map.  These compositions may be constructed \
directly with the function mapcomp[n] which returns the nth composition of \
the basic map.  This has been automated for most of the functions defined \
here by an optional final argument ncomp, which specifies the level of \
composition.   If ncomp is not specified the default value is 1, which means \
the function in question is applied to the basic mapping.  We will see \
several examples of this below.\
\>", "Text"],

Cell["\<\
\tTo evaluate the map at a point pt, we type mapeval[pt,ncomp].  \
The vector pt may have parameter symbols in it.  The optional argument ncomp \
is the level of function composition.\
\>", "Text"],

Cell["\<\
\tWe may get a graph of a 1D map by typing viewmap[ncomp].  This \
will graph the mapping f[x] (or the ncompth composition if ncomp is present \
and differs from 1) and the fixed-point reference line f[x] = x.  \
\>", \
"Text"],

Cell["\tThe fundamental iteration function is  ", "Text"],

Cell["iterate[initval,t0,niter,ntoss,ncomp]  ", "Text",
  TextAlignment->Center],

Cell[TextData[{
  "where initval is the initial point in the iteration, t0 is the initial \
time, niter is the number of iterations kept, and ntoss is the number of \
initial iterations discarded.  The argument ncomp is the optional argument \
specifying the level of function composition.  For example, if the mapping is \
f[x], then iterate[initval,t0,niter] and iterate[initval,t0,niter,1] both do \
the same thing:  they construct niter iterates of f[x].  Executing \
iterate[initval,t0,niter,2] constructs niter iterates of f[f[x]].  If the \
arguments initval and t0 are entered as exact integers or rational numbers, \
and if the parameters are specified as rational numbers and the map itself \
contains no decimal numbers, then the iteration will be done using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s exact rational arithmetic.  It is not recommended that you use this \
mode for more than a dozen or so iterations, because of the time it takes ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to do the exact arithmetic.  To get real number results, just add a \
decimal point to any of the arguments of iterate.  The function iterate \
returns a solution list in exactly the same format as for a differential \
equation.  If for example we iterate a 1D map such as the logistic map 10 \
times, iterate returns an object of the form "
}], "Text"],

Cell["{{t0,x0},{t1,x1},{t2,x2},{t3,x3}, ..... {t10,x10}},", "Text",
  TextAlignment->Center],

Cell["\<\
\tSeveral routines have been defined for finding fixed points of \
maps.  The command findpolyfix[ncomp] searches for analytical expressions for \
fixed points, containing the literal parameters.  It works only for \
polynomial maps.  The optional argument ncomp is again the level of function \
composition.  Thus findpolyfix[] and findpolyfix[1] do the same thing -- \
namely they search for the fixed points of the basic map.  If we are looking \
for orbits of period 2, we can search for them by findpolyfix[2].  The \
command nfindpolyfix[ncomp] substitutes current parameter values and searches \
for numerical values of fixed points, again only for polynomial maps, and \
again ncomp is the optional level of composition.  The command \
nfindfix[init,ncomp] takes an initial guess init and uses the Newton-Raphson \
technique to search for fixed points.  It may be applied repeatedly to \
improve the result.  The accuracy of any result fxpoint for a fixed point may \
be checked by calculating the residual, using residualfix[fxpoint,ncomp].  \
\
\>", "Text"],

Cell["\<\
\t The stability of a fixed point fxpoint may be determined \
from\
\>", "Text"],

Cell["classifymap[fxpoint,ncomp] .", "Text",
  TextAlignment->Center],

Cell["\<\
The eigenvalues at the fixed point may be calculated with \
eigvalmap[fxpoint,ncomp], and the eigenvalues and eigenvectors with \
eigsysmap[fxpoint,ncomp].  In all of these, the argument ncomp is optional \
and is the level of composition.   \
\>", "Text"],

Cell["\<\
\tThere are two command for the Jacobian of the map.  The command \
jacob returns the Jacobian with parameters as symbols.  The command jacobval \
returns the Jacobian with parameter values substituted from parmval.\
\>", \
"Text"],

Cell["\<\
\tThe function periodmap[sol] scans the solution sol for \
periodicity.  If the solution is periodic, periodmap returns a message to \
that effect and the value of the period.  If the solution contains a periodic \
orbit, but also has some transients, periodmap gives that message and the \
value of the period.  If the solution does not contain a periodic orbit, a \
message saying so is returned. \
\>", "Text"],

Cell["\<\
\tTo get phase plots of several orbits with different initial \
conditions, we use portraitmap[intlist,t0,niter,ntoss,i,j,ncomp] for a 2D \
plot and portraitmap3D[intlist,t0,niter,ntoss,i,j,k,ncomp] for a 3D plot.  \
Here intlist is a list of initial conditions, t0 is the initial time, niter \
is the number of iterations kept, ntoss is the number of initial iterations \
thrown away, i, j, and k are the components to be plotted, and ncomp is the \
optional level of composition.  To make a sequence of such portraits for \
different parameter values, we use bifurcmap[intlist,t0,niter,ntoss, \
i,j,parmlist,ncomp] in 2D and \
bifurc3Dmap[intlist,t0,niter,ntoss,i,j,k,parmlist,ncomp] in 3D.  The \
additional argument in bifurc is parmlist, which is a list of parmval \
vectors.  In all cases the optional argument ncomp is the level of function \
composition.   \
\>", "Text"],

Cell["\<\
\tThe function cobweb[init,niter,ntoss,ncomp] produces a cobweb \
plot for 1D mapping functions.   The argument init is the initial value, or a \
list of initial values.  The argument niter is the number of iterations to be \
performed, and ntoss is the number of iterations calculated and thrown away \
first -- that is, a total of ntoss + niter iterations are calculated, and \
niter are kept.  The level of composition is ncomp.  The plotting window is \
taken from plrange, the image size from imsize, and the aspect ratio from \
asprat.  When init is a list, successive orbits are plotted using \
sequentially the colors in colorvec. \
\>", "Text"],

Cell["\<\
\tA function has been defined for generating bifurcation diagrams \
for maps when a single system parameter is varied.  It works for maps of any \
dimension, and the user chooses which state variable is to be plotted.  The \
function is\
\>", "Text"],

Cell["\<\
bimap[npts,ntoss,nparm,xname,xrange,initvec,pname, prange, ncomp]  \
.\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
Here npts is the number of orbit points to be plotted at each value \
of the parameter, and ntoss is the number of orbit points to be first \
calculated and thrown away (in order to minimize the effects of transients).  \
The argument nparm is the number of parameter values for which the \
calculations are to be done.  The name of the state variable to be plotted is \
xname, and its plotting range is xrange.  The name of the parameter to be \
varied is pname, and the range of parameter variation is prange (the \
variation is carried out in nparm - 1 equal steps).  Finally ncomp is an \
optional argument specifying the level of function composition.  The default \
is 1 and other values are rarely used for this calculation.  The output is a \
graph showing the iterate values on the ordinate and the parameter values on \
the abcissa.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["PARAMETER SETTINGS AND SYSTEM DEFINITION"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo help you keep track of the system and parameter settings, \
several report routines have been defined.  When you execute sysreport, you \
get the name and the values of the four vectors defining the current system.  \
When you execute intreport, you get the settings of the integration \
parameters.  When you execute plotreport, you get the graphics settings.  \
When you execute parmreport, you get all three.      \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo save the four vectors (statevec,slopevec,parmvec,parmval) that \
define your system, execute savesys[nameofsys], where you may choose \
nameofsys.  To make this saved system your current system, type \
restoresys[nameofsys}.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe function setstate[vec] (1) clears the symbols in vec, (2) \
assigns vec to statevec, and (3) protects the symbols in vec.  The function \
setparm[vec] performs the same sequence for parmvec.  Here is a little more \
detail on the protection and unprotection of state and parameter variables.  \
When a new statevec is defined, the variables in it must be cleared and then \
protected.  The function clearvec first unprotects the variables, then clears \
them, and then protects them again.  The function unproldst unprotects the \
current state vector.  The sequence of events when setstate is executed is \
the following:  (1) the old statevec is unprotected; (2) the symbols in the \
new statevec are unprotected, cleared and then protected; (3) the new vector \
is assignmed to statevec; (4) symbols used in systems which have been saved \
previously are protected; the system is given the default name of \"System.\" \
 The sequence is completely similar for setparm.  When a system is saved, \
both the state variables and parameters need to be protected, so that users \
cannot assign values to these variables while the systems are in a dormant \
saved state.  At the time a system is saved, its state variables are added to \
the set statesaves.  Every time setstate creates a new state vector, the \
symbols in statesaves are protected.  Similarly for the parmvec symbols.  The \
result of all of this is that at any given time, the symbols in the system \
currently in use are protected, as are the symbols in any system which has \
been saved during the same session.  No other state variables or parameter \
vector variables are protected.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIf you wish to include version numbers in any notebook, just type sysid. \
 This will return the version numbers both for  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and Dynamical Systems, and the current date. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Off[General::spell1];", "Input",
  AspectRatioFixed->True],

Cell["Off[General::spell];", "Input",
  AspectRatioFixed->True],

Cell["Needs[\"Graphics`PlotField`\"]", "Input",
  AspectRatioFixed->True],

Cell["Needs[\"Graphics`Arrow`\"]", "Input",
  CellTags->"S5.31.1"],

Cell["Needs[\"Graphics`Colors`\"]", "Input",
  CellTags->"S5.31.1"],

Cell["\<\
sysreport :=  (Print[\"SYSTEM DEFINITION\",\" (\",dynsysver,\")\"];
Print[\" \" ];
Print[\"     System name sysname = \",sysname];
Print[\"     State vector statevec = \",statevec];
Print[\"     State units stateunits = \",stateunits];
Print[\"     Slope vector slopevec = \",InputForm[slopevec]];
Print[\"     Parameter vector parmvec = \",parmvec];
Print[\"     Parameter values parmval = \",parmval];
Print[\"     Parameter units vector parmunits = \",parmunits];
Print[\"     Time unit timeunit = \",timeunit];
Print[\"     System Type = \",sysmode])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
intreport := (
Print[\"INTEGRATION PARAMETERS\"];
Print[\"(Values used in most recent integration.)\"];
Print[\" \"];
Print[\"     Integration by NDSolve (True) or RK (False) = \",
\t\t\tfastflag];
Print[\"     Max step size for NDSolve maxstepflag = \",
\t\t\tmaxstepflag];
Print[\"     Range checking rangeflag = \",rangeflag];
Print[\"     Range for checking ranger = \",ranger];\t\t\t\t\t\t
Print[\"     Initial vector initialvec = \",lastiv];
Print[\"     Time step h = \",lasth];
Print[\"     Number of solution points  = \",lastns];
Print[\"     Initial time t0 = \",lastt0];
Print[\"     Integration direction flag bothdirflag = \",bothdirflag];
Print[\"     System Type = \",sysmode])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
plotreport := (
Print[\"PLOTTING PARAMETERS\"];
Print[\" \"];
Print[\"     Aspect ratio asprat = \", asprat];
Print[\"     Color list for RGBColor colorvec = \",colorvecdis];
Print[\"     Dashing pattern for 2D dashvec = \",dashvec];
Print[\"     Box ratio for 3D boxrat = \",boxrat];
Print[\"     Viewpoint for 3D viewpt = \",viewpt];
Print[\"     Plot range for 2D plrange = \",plrange];
Print[\"     Plot range for 3D plrange3D = \",plrange3D];
Print[\"     Point size ptsize = \",ptsize];
Print[\"     Poincar\[EAcute] map dot poincptsize = \",poincptsize];
Print[\"     Line thickness lnthick = \",lnthick];
Print[\"     Grid points in direction field dirpt = \",dirpt];
Print[\"     Point connection flag pointcon = \",pointcon];
Print[\"     Axes flag axon = \",axon];
Print[\"     Axes origin axorg = \",axorg];
Print[\"     Axes label flag axlabon = \",axlabon];
Print[\"     Frame flag frameon = \",frameon];
Print[\"     Frame label flag framelabon = \",framelabon];
Print[\"     Plot label flag labon = \",labon];
Print[\"     Plot label shift labshift = \",labshift];
Print[\"     Total digits in plot label totdig = \",totdig];
Print[\"     Digits to right of decimal in label decdig = \",decdig];
Print[\"     Flag for scientific notation in labels sciflag = \",sciflag];
Print[\"     Gray level background graylev = \",graylev];
Print[\"     Display flag display = \",display];
Print[\"     Graphics image size imsize = \",imsize];
Print[\"     Graph background color backcolor = \",backcolordis];
Print[\"     Arrows on flag arrowflag = \",arrowflag];
Print[\"     Fractional arrow arclength arrowvec = \",arrowvec])
\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
parmreport := ( sysreport; Print[\" \"];
\t\t\t\tintreport; Print[\" \"];
\t\t\t\tplotreport; Print[\" \"])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(setde := \((deflag = True; intreset; plotreset)\)\)], "Input"],

Cell[BoxData[
    \(setmap := \((deflag = False; bothdirflag = False; pointcon = False; 
        fastflag = False; plrange = {{0, 1}, {0, 1}})\)\)], "Input"],

Cell[BoxData[
    \(sysmode := 
      If[\((deflag)\), \(("\<differential equation\>")\), \
\(("\<mapping\>")\)]\)], "Input"],

Cell["\<\
clearvec[arg_] := (Unprotect[arg];ClearAll[arg];Protect[arg])\
\>", \
"Input",
  AspectRatioFixed->True],

Cell["SetAttributes[clearvec,{HoldFirst,Listable}];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(provec[arg_] := Protect[arg]\)], "Input"],

Cell[BoxData[
    \(\(SetAttributes[provec, {Listable}];\)\)], "Input"],

Cell[BoxData[
    \(listunpro[arg_] := \ Unprotect[arg]\)], "Input"],

Cell[BoxData[
    \(\(SetAttributes[listunpro, \ Listable];\)\)], "Input"],

Cell[BoxData[
    \(unproldst := \((Map[listunpro, statevec])\)\)], "Input"],

Cell[BoxData[
    \(unproldpm := \((Map[listunpro, parmvec])\)\)], "Input"],

Cell[BoxData[
    \(\(statesaves = {};\)\)], "Input"],

Cell[BoxData[
    \(\(parmsaves = {};\)\)], "Input"],

Cell[BoxData[
    \(prostatesaves := \((Map[provec, statesaves])\)\)], "Input"],

Cell[BoxData[
    \(proparmsaves := \((Map[provec, parmsaves])\)\)], "Input"],

Cell[BoxData[
    \(stateunitsclear := 
      Module[{j}, 
        stateunits\  = \ Table["\<\>", {j, 1, Length[statevec]}]]\)], "Input"],

Cell[BoxData[
    \(timeunitclear := \((timeunit = "\<\>")\)\)], "Input"],

Cell["\<\
setstate[vec_] := Module[{},unproldst;clearvec[vec];
\t\tstatevec = vec; prostatesaves;sysname = \"System\";
\t\tstateunitsclear; timeunitclear]
\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
setstatesav[vec_] := (unproldst;clearvec[vec];
\t\t\t\t\tstatevec = vec;prostatesaves)\
\>", "Input",
  AspectRatioFixed->True],

Cell["SetAttributes[setstate,HoldAll];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(parmunitsclear := 
      Module[{j}, 
        parmunits\  = \ Table["\<\>", {j, 1, Length[parmvec]}]]\)], "Input"],

Cell[BoxData[
    \(unitsclear := \((stateunitsclear; parmunitsclear; 
        timeunitclear)\)\)], "Input"],

Cell["\<\
setparm[vec_] := Module[{},unproldpm; \
clearvec[vec];Unprotect[parmvec]; 
parmvec = vec;Protect[parmvec];proparmsaves;
parmunitsclear; parmval = parmvec]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
setparmsav[vec_] := (unproldpm; \
clearvec[vec];Unprotect[parmvec];parmvec = vec;Protect[parmvec];proparmsaves)\
\
\>", "Input",
  AspectRatioFixed->True],

Cell["SetAttributes[setparm,HoldAll];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(evalparm[exp_] := \ exp /. Thread[parmvec -> parmval]\)], "Input"],

Cell["\<\
savesys[savename_] := (statesaves = \t\t\t\t\t\t\t\t\t\
Union[statesaves,statevec];
\t\t\tparmsaves = Union[parmsaves,parmvec];
\t\t\tClear[savename]; 
\t\t\t\tsysname = ToString[savename];
\t\t\t\tsavename = {statevec,slopevec,
\t\t\t\tparmvec,parmval,sysname,stateunits,
\t\t\t\tparmunits,timeunit,deflag})\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetAttributes[savesys, HoldAll];\)\)], "Input"],

Cell["\<\
restoresys[savename_] := (setstatesav[savename[[1]]];
\t\t\t\t\t\tsetparmsav[savename[[3]]];\t
\t\t\t\t\t\tslopevec = savename[[2]];
\t\t\t\t\t\tparmval = savename[[4]];
\t\t\t\t\t\tsysname = savename[[5]];
\t\t\t\t\t\tstateunits = savename[[6]];
\t\t\t\t\t\tparmunits = savename[[7]];
\t\t\t\t\t\ttimeunit = savename[[8]];
\t\t\t\t\t\tdeflag = savename[[9]]) \
\>", "Input",
  AspectRatioFixed->True],

Cell["Protect[t];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(reversetime := \((slopevec = \(-\((slopevec /. 
                t -> \(-t\))\)\))\)\)], "Input"],

Cell[BoxData[
    \(transorg[
        vec_] := \((slopevec\  = \ 
          slopevec /. Thread[statevec -> \((statevec + vec)\)])\)\)], "Input"],

Cell[BoxData[
    \(statnum[var_] := 
      Module[{i, ans}, \[IndentingNewLine]Do[
          If[\((var \[Equal] statevec[\([i]\)])\), \((ans = 
                i)\)], \[IndentingNewLine]{i, 1, Length[statevec]}]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(parmnum[var_] := 
      Module[{i, ans}, \[IndentingNewLine]Do[
          If[\((var \[Equal] parmvec[\([i]\)])\), \((ans = 
                i)\)], \[IndentingNewLine]{i, 1, Length[parmvec]}]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(polartrans[recx_, recy_, polr_, 
        polthet_] := \[IndentingNewLine]Module[{f1, f2, ans1, ans2, 
          ans}, \[IndentingNewLine]f1 = 
          slopevec[\([statnum[recx]]\)]; \[IndentingNewLine]f2 = 
          slopevec[\([statnum[
                recy]]\)]; \[IndentingNewLine]ans1 = \((recx*f1 + recy*f2)\)/
            polr; \[IndentingNewLine]ans2 = \((recx*f2 - 
                recy*f1)\)/\((polr^2)\); \[IndentingNewLine]ans = {ans1, 
              ans2} //. \[IndentingNewLine]Thread[{recx, 
                  recy} \[Rule] \[IndentingNewLine]{polr*Cos[polthet], 
                  polr*Sin[polthet]}]; \[IndentingNewLine]FullSimplify[
          ans]]\)], "Input"],

Cell[BoxData[
    \(frompolartrans[polr_, polthet_, recx_, 
        recy_] := \[IndentingNewLine]Module[{f1, f2, ans1, ans2, 
          ans}, \[IndentingNewLine]f1 = 
          slopevec[\([statnum[polr]]\)]; \[IndentingNewLine]f2 = 
          slopevec[\([statnum[polthet]]\)]; \[IndentingNewLine]ans1 = 
          Cos[polthet]*f1 - polr*Sin[polthet]*f2; \[IndentingNewLine]ans2 = 
          Sin[polthet]*f1 + 
            polr*Cos[polthet]*f2; \[IndentingNewLine]ans = {ans1, 
              ans2} //. \[IndentingNewLine]Thread[{Cos[polthet], 
                  Sin[polthet]} \[Rule] \[IndentingNewLine]{recx/polr, 
                  recy/polr}]; \[IndentingNewLine]ans = 
          ans //. \((polr -> 
                Sqrt[recx^2 + recy^2])\); \[IndentingNewLine]FullSimplify[
          ans, polr\  > \ 0]]\)], "Input"],

Cell[BoxData[
    \(\(parmval = {};\)\)], "Input"],

Cell["sysname = \"System\";", "Input",
  AspectRatioFixed->True],

Cell["\<\
date := Module[{datevec},datevec = Date[];
\tSequenceForm[datevec[[2]],\"/\",datevec[[3]],\"/\",
\tdatevec[[1]]]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "sysid := Print[\"",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \",$VersionNumber,\n\t\t\", DynPac \",dynsysver,\", \",date]"
}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

3.  RUNGE-KUTTA INTEGRATION\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe Runge-Kutta algorithm given below was based on the very elegant \
implementations given by Roman Maeder in ",
  StyleBox["Programming in ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " (pp. 172-173), Addison-Wesley, 1991, and by John W. Gray in ",
  StyleBox["Mastering ",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " (pp. 257-258), Academic Press, 1994.  (A modification of this routine to \
include range checking is given in Section 4 below.)  The first routine gives \
one Runge-Kutta step using the standard fourth order algorithm.  The \
arguments are the slope vector slopeval, the state vector symbols statevec, \
the value of the state vector at the start of the time step oldstate, and the \
time step h.  The function returns the state vector value incremented by one \
time step.  The second routine, rungeKutta, carries out the entire \
integration by using NestList.  Its output is a list of lists, each of which \
is a state vector {x1, x2, .... xn}.  Mapstep is the stepping algorithm for \
an iterated map.  Stepper switches to the appropriate algorithm, based on the \
value of deflag.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

rkstep[slopeval_,statevec_,oldstate_,h_] := 
Module[{ k1, k2, k3, k4,hmod },hmod = N[h];
k1 = hmod N[ slopeval /. Thread[statevec -> oldstate] ];
k2 = hmod N[ slopeval /. Thread[statevec -> oldstate + k1/2] ];
k3 = hmod N[ slopeval /. Thread[statevec -> oldstate + k2/2] ];
k4 = hmod N[ slopeval /. Thread[statevec -> oldstate + k3] ];
\toldstate + (k1 + 2 k2 + 2 k3 + k4)/6 ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(mapstep[slopeval_, statevec_, oldstate_, h_] := 
      Module[{}, \[IndentingNewLine]slopeval /. 
          Thread[statevec -> oldstate]]\)], "Input"],

Cell[BoxData[
    \(stepper[slopeval_, statevec_, oldstate_, h_] := 
      If[\((deflag)\), \[IndentingNewLine]\((rkstep[slopeval, statevec, 
            oldstate, h])\), \[IndentingNewLine]\((mapstep[slopeval, 
            statevec, oldstate, h])\)]\)], "Input"],

Cell["\<\

rungeKutta[slopeval_,statevec_,initvec_, h_, nsteps_] := 
\tNestList[stepper[slopeval,statevec,#,h]&, 
\t  initvec, nsteps ]\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n4.  RUNGE-KUTTA WITH RANGE CHECKING"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tNow we modify the above routine to include range checking.  The \
resulting code is both slower and less elegant, but the range checking is \
sometimes essential.  The single Runge-Kutta step is carried out by the \
stepping routine rkstep defined above.  The overall integration is controlled \
by rangerungeKutta, which terminates the integration as soon as the state \
point is outside the limits specified by ranger.  No points outside the range \
are saved in the solution list.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
rangechek[vector_] := Module[{len,ans,a,b,comp,i},
\t\t\t\tlen = Length[vector]; ans = True;
\t\t\tDo[a = ranger[[i,1]]; b = ranger[[i,2]];
\t\t\t\tcomp = vector[[i]];
\t\t\t\tans = ans&&(a<=comp)&&(comp<=b),
\t\t\t\t\t\t{i,1,len}];
\t\t\t\t\tans]\t
\t\t\t\t\t \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
rangerungeKutta[slopeval_,statevec_,initialvec_,h_,nsteps_] := \
Module[{new,anslist,counter},new = initialvec;
\t  anslist = {new}; counter = 0;
\t  While[((rangechek[new])&&(counter<=nsteps)),
\t\t(new = stepper[slopeval,statevec,new,h];
\t\t\tcounter = counter+1;
\t\t\tanslist = Append[anslist,new];)];
\t\t anslist]\t
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["ranger = {{-10,10},{-10,10}};", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n5.  CODE CONNECTING TO NDSOLVE"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tConnecting to NDSolve is simple in principle but painful in \
practice.  The objective in writing the code below was to keep the user \
interface uniform, no matter which integration method is chosen.  Thus when \
NDSolve is to be used, this code generates the argument lists supplied to \
NDSolve.  No doubt the code below could be streamlined, but it does work.  \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
formndstatevec := Module[{addon,i}, addon = \"nd[t]\";
\t\tndstatevec = statevec;
 \t\tDo[ ndstatevec[[i]] = ToExpression[ 
 \t\tStringJoin[ToString[statevec[[i]]],addon]],
 \t\t\t   \t\t{i,1,Length[statevec]}]]
 \t\t\t   \t \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formndivec[initialvec_,t0_,h_,nsteps_] := 
\tModule[{len,i}, len = Length[statevec];
\t\tndivec = Range[len];
\t\tDo[ ndivec[[i]] = ToExpression[StringJoin[
\t\t\tToString[statevec[[i]]],\"nd[\",ToString[
\t\t\tN[t0]],\"] == \",
\t\t\tToString[Evaluate[initialvec[[i]]]]]],
\t\t\t{i,1,len}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formndslopeval := (ndslopeval = 
\t\tslopeval /. Thread[statevec -> ndstatevec ])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formnderivec := Module[{len,i}, 
\t\tlen = Length[statevec];
\t\t\tnderivec = Range[len];
\tDo[ nderivec[[i]] = ToExpression[StringJoin[
\tToString[statevec[[i]]],\"nd'[t]\"]], {i,1,len}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formndfirstarg[initialvec_,t0_,h_,nsteps_] := 
\tModule[{len,i}, len = Length[statevec];
\t\t\tndfirstarg = Range[2*len];
\t\t\tDo [ ndfirstarg[[i]] = ToExpression[
\t\t\t\tStringJoin[
\t\t\t\tToString[nderivec[[i]]],\" == \",
\t\t\t\t\tToString[InputForm[
\t\t\t\t\tndslopeval[[i]]]]]], {i,1,len}];
\t\t\tDo [ ndfirstarg[[i]] = ndivec[[i-len]],
\t\t\t\t\t{i,len+1,2*len}]]
\t\t\t\t\t\t \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formndsecarg[initialvec_,t0_,h_,nsteps_] := 
\t\t\t\t\t\t\t(ndsecarg = ndstatevec) \t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formndthirdarg[initialvec_,t0_,h_,nsteps_] := 
\t\t\t(If[(h>0),
\t\t\t\t\tndthirdarg = {t,t0,h*nsteps+t0},
\t\t\t\t\tndthirdarg = {t,h*nsteps+t0,t0}])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
formnd[initialvec_,t0_,h_,nsteps_] := 
\t\t       (formndstatevec;
\t\t\t\tformnderivec;
\t\t\t\tformndivec[initialvec,t0,h,nsteps];
\t\t\t\tformndslopeval;
\t\t\t\tformndfirstarg[initialvec,t0,h,nsteps];
\t\t\t\tformndsecarg[initialvec,t0,h,nsteps];
\t\t\t\tformndthirdarg[initialvec,t0,h,nsteps])\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n6.  GENERATE OUTPUT"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe user routine here is integrate[initialvec,t0,h,nsteps], which \
takes the initial vector initialvec, the initial time t0, the step size h, \
and the number of steps nsteps, and then calls the integration routine.  The \
routine called depends on the setting of a flag called fastflag.  For \
fastflag = True, NDSolve is called, and for fastflag = False, the fourth \
order Runge-Kutta routine is called.  In either case the output produced is a \
list of values of the time and the state vector, at time increments h.  For \
each of these choices, there is a further branching depending on other flags. \
 If NDSolve is called, there is a branching depending on the setting of \
maxstepflag.  If the setting is True, NDSolve is limited to a maximum step \
size of h.  If the setting is False, NDSolve chooses its own step size \
without restriction.  If Runge-Kutta is called, there is a branching \
depending on the setting of rangeflag.  If rangeflag is False, no range \
checking is done, and the integration is by rungeKutta.  If rangeflag is \
True, there is range checking, and the integration is carried out by \
rangerungeKutta. In all cases, integration occurs in one direction of time \
only unless bothdirflag = True.  The default settings for all of these \
integration flags are fastflag = False, maxstepflag = False, rangeflag = \
False, and bothdirflag = False.  The command intreset sets the default values \
for these integration flags.  The output of integrate is a list of lists, \
each member of which has the form {t,x1,x2,x3,..,xn}.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf you want to add some options to the NDSolve integration, \
simply add them in the usual way to the argument list of NDSolve as it \
appears below in the routine ndphaselist.  The options already present are \
MaxNumberSteps, set to five times nsteps, and MaxStepSize, set to Abs[h] if \
maxstepflag = True, and set to DirectedInfinity (the normal default) if \
maxstepflag is False.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBoth integration routines handle both autonomous and \
non-autonomous systems.  This capability is built into NDSolve.  For fastflag \
= False, the Runge-Kutta routine is used.  In that case the function \
integrate first scans slopevec to determine whether or not the system is \
autonomous.  If it is, integrate calls the routine solution, which handles \
autonomous systems.  If the system is not autonomous, integrate calls the \
routine nasolution, which works by first extending the system in a standard \
way to an autonomous system of order one higher, and then calling the basic \
integration routine.  All of this is transparent to the user.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe actual slope vector handed to the integration routines is \
slopeval, which is the slope vector with the current parameter values \
substituted for the parameter symbols.     \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBefore integrating with the Runge-Kutta routines, you may get an \
estimate of an appropriate time step from the routine sugtimestep[window], \
where window is a box region in which you will be working.\
\>", "Text"],

Cell["\<\
intreset := (fastflag = False; maxstepflag = False;
\t\t\trangeflag = False; bothdirflag = False; deflag=True)\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell["slopeval := slopevec /. Thread[parmvec -> parmval]", "Input",
  AspectRatioFixed->True],

Cell["\<\

phaselist[initialvec_,h_,nsteps_] := Module[{},
  If[rangeflag,
\t(rangerungeKutta[slopeval,statevec,initialvec,h,nsteps]),\t\t\t 
\t(rungeKutta[slopeval,statevec,initialvec,h,nsteps])]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
ndphaselist[initialvec_,t0_,h_,nsteps_] :=
\tModule[{ans,ndfunc,i},
\tClear[ndstatevec,ans]; 
\tformnd[initialvec,t0,h,nsteps];
\t\tans = {initialvec};
\t\tndfunc[t_] = ndstatevec /. NDSolve[
\t\tndfirstarg,ndsecarg,ndthirdarg,
\t\tMaxStepSize -> mxstep, MaxSteps ->mxnumstep];
\tDo[ ans = Append[ans,Flatten[ndfunc[t0+h*i]]],
\t\t{i,1,nsteps}];
\t\tClear[ndfunc];
\t\tans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\

timelist[t0_,h_,nsteps_] := Module[{i,j,hmod},
\t\t\tIf[(deflag),(hmod = N[h]),(hmod = h)];
\t\t\t\tTable[t0 + i*hmod,{i,0,nsteps},{j,1}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\

solutionaux[initialvec_,t0_,h_,nsteps_] := Module[
  {temphase,temptime,lensol,i},Clear[temphase,temptime];
  If[fastflag,(If[maxstepflag,mxstep = Abs[h],
  \t\t\tmxstep = DirectedInfinity[1]]; 
  \t\t\tmxnumstep = 5*nsteps;
  \t\t\ttemphase = ndphaselist[initialvec,t0,h,nsteps]),
\t(temphase = phaselist[initialvec,h,nsteps])];
\tlensol = Length[temphase]-1;
\ttemptime = timelist[t0,h,lensol];
\tIf[(h < 0),
\t\t(temptime = Reverse[temptime];\t
\t\t temphase = Reverse[temphase])];
\tTable[Join[Part[temptime,i],
\tPart[temphase,i]],{i,lensol+1}]]
\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
solution[initialvec_,t0_,h_,nsteps_] := (
\tIf[(bothdirflag),
\tjoinsol[solutionaux[initialvec,t0,-h,nsteps],
\t\t\t\tsolutionaux[initialvec,t0,h,nsteps]],
\tsolutionaux[initialvec,t0,h,nsteps]])\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
nasolution[initvec_,t0_,h_,nsteps_] := Module[
\t\t{init,tup,tlow,ans,len},
\t\t\t\tlen = Length[statevec];
\t\t\t\ttlow = t0-2.0*Abs[h]*nsteps;
\t\t\t\ttup = t0+2.0*Abs[h]*nsteps;
\t\t\t\tranger = Append[ranger,{tlow,tup}]; 
\t\t\t\tstatevec = Append[statevec,xfake];
\t\t\t\tslopevec = Append[slopevec,If[(deflag),(1.0),(t + 1)]];
\t\t\t\tslopevec = slopevec /. t -> xfake;
\t\t\t\tinit = Append[initvec,t0];
\t\t\t\tans = solution[init,t0,h,nsteps];
\t\t\t\tans = stripsol[ans,len+1];
\t\t\t\t\tans]
\t\t\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
nonautcheck[vec_] := Module[{lenfull,lennot},
\t\t\tlenfull = Length[vec];
\t\t\tlennot = Length[Select[vec,FreeQ[#,t]&]];
\t\t\tlenfull>lennot]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(truncate[list_] := 
      Module[{fir, las, ans}, ans = list; fir = Drop[First[list], 1]; 
        las = Drop[Last[list], 1]; 
        If[rangeflag, \((If[\((rangechek[fir]\  == \ False)\), \((outbound = 
                  Append[outbound, First[list]]; ans = Drop[list, 1])\)]; 
            If[\((rangechek[las]\  == \ False)\), \n\t\t\t\t\t\((outbound = \ 
                  Append[outbound, Last[list]]; 
                ans = Drop[list, \(-1\)])\)])\)]; ans]\)], "Input"],

Cell["\<\
integrate[initvec_,t0_,h_,nsteps_] := (CheckAbort
\t[Module[{ansalvin,initarg,t0arg,harg,nstepsarg},
\t\toutbound = {};
\t\tIf[(Length[initvec]==0),(modinitvec={initvec}),
\t\t(modinitvec=initvec)];
\t\ttempslope = slopevec;
\t\ttempstate = statevec;
\t\ttempranger = ranger;
\t\tinitarg = modinitvec /. Thread[parmvec -> parmval];
\t\tt0arg = t0 /. Thread[parmvec -> parmval];
\t\tharg = h /. Thread[parmvec -> parmval];
\t\tnstepsarg = Round[nsteps /. Thread[parmvec -> parmval]]; 
\t\tIf[fastflag,(ansalvin = solution[initarg,t0arg,harg,nstepsarg]),
\t\t\t(If[nonautcheck[slopevec],
\t\t\t\t(ansalvin = nasolution[initarg,t0arg,harg,nstepsarg]),
\t\t\t\t(ansalvin = solution[initarg,t0arg,harg,nstepsarg])])];
\t\tlastt0 = t0arg;
\t\tlasth = harg;
\t\tlastiv = initarg;
\t\tlastns = Length[ansalvin] - 1;
\t\tlasttx = Last[ansalvin];
\t\tlastt = First[lasttx];
\t\tlastx = Drop[lasttx,1];
\t\tfirsttx = First[ansalvin];
\t\tfirstt = First[firsttx];
\t\tfirstx = Drop[firsttx,1];
\t\tslopevec = tempslope;
\t\tstatevec = tempstate;
\t\tranger = tempranger;
\t\ttruncate[ansalvin]], 
\t\t(Print[\"Integration Aborted\"];
\t\t\tslopevec = tempslope;
\t\t\tstatevec = tempstate;
\t\t\tranger = tempranger)]);\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\tHere is the code for the suggested time step.  If Ai is the rms average \
of the ith slope component over the region, and if hi is the width of the \
region in the ith component, and if M is the maximum over i of the ratios \
Ai/hi, then the time step is chosen as 1/(100*M).  This means that on the \
average, there will be at least 100 time steps across each dimension of the \
chosen window.  In writing this code, I found very useful the technique for \
splicing in function arguments given by Thomas Bahder in ",
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" for Scientists and Engineers",
    FontWeight->"Bold"],
  ",  Addison-Wesley, 1995, p. 245.  "
}], "Text"],

Cell[BoxData[
    \(difunc[list_] := Last[list] - First[list]\)], "Input"],

Cell[BoxData[
    \(intarg[state_, win_] := \ 
      Module[{ans, i, el, len}, 
        ans\  = \ {}; \n\t\tlen = Length[state]; \n\t\tDo[
          el = Prepend[win[\([i]\)], state[\([i]\)]]; 
          ans = Append[ans, el], \n\t\t\t{i, 1, len}]; ans]\)], "Input"],

Cell[BoxData[
    \(\(\(sugtimestep[window_] := 
      Module[{diff, inters, scales, ans}, diff = Map[difunc, window]; 
        arger = intarg[statevec, 
            window]; \n\t\tinters = \((Sqrt[
                NIntegrate[Evaluate[\((slopeval)\)^2], 
                  Evaluate[Sequence\  @@ \ arger]]]/
              NIntegrate[1.0, 
                Evaluate[Sequence\  @@ \ arger]])\); \n\t\tscales = 
          Max[\ inters/diff]; \n\t\tans = \ 1.0/\((100. *scales)\); 
        ans]\)\(\n\)\(\t\t\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

6A.  LAG EQUATIONS\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\tThe code defined here allows the integration of equations with lag terms \
in the dependent variables.  Only one lag time is permitted, but any or all \
of the state variables may appear both as current and/or lag terms in the \
slope vector.  The routine that carries out the integration is \
lagintegrate[initfunc,initcond,t0,h,T,nlags].  Here initfunc is the vector of \
initial functions, specifying the solution over the first range t0 - T \
\[LessEqual] t \[LessEqual] t0, where t0 is the initial time and T is the lag \
time.  The initial conditions at the initial time are the vector initcond.  \
There are times when one wants a discontinuous jump between initfunc and \
initcond.  While it would be possible to incorporate this into initfunc by \
making it discontinuous, this might lead to errors in integrations using \
NDSolve, because there are serious bugs in that function associated with \
discontinuous functions as coefficients.  The time step for integrations is \
h, and the number of lag periods to be calculated is nlags.  The spacing h is \
adjusted by the routine (made smaller if necessary) so that T/h is an \
integer.  The routine lagintegrate calls the basic routine integrate to carry \
out the solution for each lag period.  The quantity returned by lagintegrate \
is a solution in the standard list format.  At the end of a lag period, the \
solution (which is in the standard list form) is built into an interpolating \
function for use in the next lag period. "], "Text"],

Cell["\<\
\tIn using this routine the state vector is set as usual.  Suppose \
for example the state vector is {x,y}.  Then the slope vector in general will \
contain x, y, xlag, ylag and t.  The routine interprets xlag and ylag as \
values lagged in time by T.  The routine makelagvec produces a vector of the \
lag variables.  That is, if {x,y} is the state vector, then the output of \
makelagvec is {xlag,ylag}.  This vector is used in constructing modified \
slope vectors in the integration.\
\>", "Text"],

Cell[BoxData[
    \(lagadd[x_] := StringJoin[ToString[x], "\<lag\>"]\)], "Input"],

Cell[BoxData[
    \(SetAttributes[lagadd, Listable]\)], "Input"],

Cell[BoxData[
    \(makelagvec := ToExpression[Map[lagadd, statevec]]\)], "Input"],

Cell[BoxData[
    \(makker[initfunc_, t0_, T_, hmod_, nper_] := 
      Module[{ii, listans, mem, tbeg}, tbeg = t0 - T; 
        listans = {Prepend[initfunc /. t -> tbeg, tbeg]}; \n\t\tDo[
          mem = initfunc /. t -> \((tbeg + ii*hmod)\); \n\t\t\tmem = 
            Prepend[mem, tbeg + ii*hmod]; \n\t\t\tlistans = 
            Append[listans, mem], {ii, 1, nper}]; \n\t\tlistans]\)], "Input"],

Cell[BoxData[
    \(\(\(lagintegrate[initfunc_, initcond_, t0_, h_, T_, 
        nlags_] := \n\t\t\t\t\t\t\t\t\t\t\((CheckAbort[
          Module[{storeslope, hmod, lagvec, nper, ans, piece, intpiece, 
              noneed, initer, ii}, \n\t\tnper = Ceiling[T/h]; hmod = T/nper; 
            lagvec = makelagvec; \n\t\tstoreslope = 
              slopevec; \n\t\tslopevec = 
              storeslope /. 
                Thread[lagvec -> \((initfunc /. 
                        t -> \((t - T)\))\)]; \n\t\tans = 
              makker[initfunc, t0, T, hmod, nper]; \n\t
            piece = integrate[initcond, t0, hmod, nper]; \n\t\tans = 
              joinsol[ans, piece]; \n\t\tDo[initer = lastx; 
              solinterp[piece, intpiece, noneed]; \n\t\t\tslopevec = 
                storeslope /. 
                  Thread[lagvec -> intpiece[t - T]]; \n\t\t\tpiece = 
                integrate[initer, t0 + ii*T, hmod, nper]; \n\t\t\tans = 
                joinsol[ans, piece], {ii, 1, nlags - 1}]; \n\t\tslopevec = 
              storeslope; 
            ans], \((Print["\<Lag Integration Aborted\>"]; \
\[IndentingNewLine]slopevec = 
              storeslope)\)])\)\)\(\n\)\(\t\t\t\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n7.  SCANNING AND MODIFYING SOLUTIONS"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThere are several commands with which to scan a solution.  The \
command trange[sol] returns the time range in the solution.  The command \
staterange[sol] returns the minimum and maximum values of each state \
variable, and the time at which each occurs.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tA subset of a solution based on the time range is produced by \
subsol.  To join two solutions obtained by consecutive integrations, use \
joinsol.  To strip out a state variable from a solution, use stripsol.  To \
replace a state variable in a solution by its value modulo a given interval, \
use modsol.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo apply one or several  functional transformations to a \
solution, use transol[sol, funclist].  Here sol is the solution to which the \
transformation is to be applied, and funclist is the list of expressions (in \
the state variables and time) which are to be applied.  \
\>", "Text"],

Cell["\<\
\tTranslation of either the time or the state vector in computed \
solutions is achieved by the functions timeshift[sol,\[Tau]], which \
increments all time values in sol by \[Tau], and stateshift[sol,vec], which \
increments all state values in sol by vec, which must be a vector of the same \
dimension as the state vector.\
\>", "Text"],

Cell["\<\
  \tAll of these solution modifying routines are described in more \
detail in the Overview (Section 2).\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tFor some purposes (placement of arrows for example), it is useful \
to have the arc length of a solution.  This is provided by the function \
arclen[sol], defined below.\
\>", "Text"],

Cell[TextData[{
  "\tBecause of a bug in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0, it is necessary to set $FormatType to the value OutputForm.  This is \
done below.  This sets the format of plot and axes labels to OutputForm.  Any \
other choice will lead to incorrect printing of the characters (, ), {, }, [, \
and ].  They will appear correctly on the screen, but will print incorrectly. \
 If you are running ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0.1 or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4, you no longer have that bug, and you either can omit the statement \
below or change the value of $FormatType to StandardForm."
}], "Text"],

Cell[BoxData[
    \(\($FormatType\  = \ StandardForm;\)\)], "Input"],

Cell["trange[sol_] := {First[First[sol]],First[Last[sol]]}", "Input",
  AspectRatioFixed->True],

Cell["\<\
elecheck[stvec_,rng_] := Module[{t,tmin,tmax},
\t\t\t\t\t\tt = First[stvec]; 
\t\t\t\t\t\ttmin = First[rng];
\t\t\t\t\t\ttmax = Last[rng];
\t\t\t\t\t\t((t >= tmin)&&(t <= tmax))]  \
\>", "Input",
  AspectRatioFixed->True],

Cell["subsol[sol_,rng_] := Select[sol,elecheck[#,rng]&] ", "Input",
  AspectRatioFixed->True],

Cell["\<\
staterange[sol_] := Module[{lensol,lenstate,xrange,temptime,
tempvec,tempx,tempmin,initvec,tempmax,i,j},
\t\tinitvec = sol[[1]];\t\t
\t\tlensol = Length[sol];
\t\tlenstate = Length[statevec];
\t\txrange = Table[{0,{0,0},{0,0}},{lenstate}];
\t\t\t\tDo[(xrange[[i,1]] = statevec[[i]];
\t\t\t\t\txrange[[i,2,1]] = initvec[[i+1]];
\t\t\t\t\txrange[[i,3,1]] = initvec[[i+1]];
\t\t\t\t\txrange[[i,2,2]] = initvec[[1]];
\t\t\t\t\txrange[[i,3,2]] = initvec[[1]];),
\t\t\t\t\t\t{i,1,lenstate}];
\t\t\t\t\tDo[(tempvec = Drop[sol[[i]],1];
\t\t\t\t\t\ttemptime = First[sol[[i]]];
\t\t\t\t\t(Do[(tempx = tempvec[[j]];
\t\t\t\t\ttempmin = First[xrange[[j,2]]];
\t\t\t\t\ttempmax = First[xrange[[j,3]]];
\t\t\t\t\tIf[(tempx<tempmin),
\t\t\t\t\t(xrange[[j,2,1]] = tempx;
\t\t\t\t\txrange[[j,2,2]] = temptime)];
\t\t\t\t\tIf[(tempx>tempmax),
\t\t\t\t\t(xrange[[j,3,1]] = tempx;
\t\t\t\t\txrange[[j,3,2]] = temptime)];),
\t\t\t\t\t{j,1,lenstate}];)),{i,1,lensol}];
\t\t\t\t\txrange]\t     \t\t\t\t
\t\t\t\t\t\t     \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
joinsol[sol1_,sol2_] := Module[{ans,solfirst,solast},
\tClear[ans,solfirst,solast];
    If[(Length[sol1]*Length[sol2] == 0),
\t\t(ans = Join[sol1,sol2]),
\t  (If[(First[First[sol1]] < First[First[sol2]]),
\t\t(solfirst = sol1; solast = sol2),
\t\t(solfirst = sol2; solast = sol1)];
\t  If[(First[Last[solfirst]] == First[First[solast]]),
\t\t(ans = Join[solfirst,Drop[solast,1]]),
\t\t(ans = {}; 
\t\tPrint[\"Solutions don't match!\"])])];
    \tans]\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["stripsol[sol_,n_] := Map[(Delete[#,n+1])&,sol]", "Input",
  AspectRatioFixed->True],

Cell["\<\
modaux[list_,k_,a_,b_] := ReplacePart[list,
\t\t\t\t\tMod[(list[[k]]-a),(b-a)]+a,k] \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
modsol[sol_,k_,a_,b_] := 
\t\tMap[(modaux[#,k+1,a,b])&,sol]
\
\>", "Input",
  AspectRatioFixed->True],

Cell["sqnorm[vec_] := Dot[vec,vec]\t", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(arlen[puresol_] := 
      Module[{len, i, ans}, len = Length[puresol]; ans = 0; 
        Do[ans = 
            ans + Sqrt[sqnorm[puresol[\([i + 1]\)] - puresol[\([i]\)]]], {i, 
            1, len - 1}]; ans]\)], "Input"],

Cell[BoxData[
    \(arclen[sol_] := 
      Module[{puresol, ans}, puresol = stripsol[sol, 0]; 
        arlen[puresol]]\)], "Input"],

Cell[BoxData[
    \(\(\(newel[oldel_, 
        funclist_]\)\(:=\)\(Module[{augstatevec}, \[IndentingNewLine]\t\t\t\
augstatevec = 
          Prepend[statevec, t]; \n\t\t\t\(funclist /. 
            Thread[augstatevec -> oldel]\)\t\n\t\t\t /. 
          Thread[parmvec -> parmval]]\)\(\t\)\)\)], "Input"],

Cell[BoxData[
    \(transol[sol_, funclist_] := 
      Module[{newfunclist, len, i}, \n\t\t\t\t\t\tlen = 
          Length[sol]; \n\t\t\t\t\tnewfunclist = 
          Prepend[funclist, t]; \n\t\t\t\tTable[
          newel[sol[\([i]\)], newfunclist], {i, 1, len}]]\)], "Input"],

Cell[BoxData[
    \(timeshift[sol_, a_] := 
      Module[{func}, 
        func[list_] := \((ReplacePart[list, First[list] + \ a, 1])\); 
        Map[\((func[#])\) &, sol]]\)], "Input"],

Cell[BoxData[
    \(stateshift[sol_, vec_] := \ 
      Module[{func, inker}, inker = Prepend[vec, 0]; 
        func[listel_] := \ inker + listel; 
        Map[\((func[#])\) &, sol]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n8.  PLOT CONTROL VARIABLES"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThese variables were described in detail in the Overview (Section \
2).  The settings in plotreset are the defaults.  To reset all the defaults, \
execute plotreset.  All of your graphs are automatically labeled with the \
system name and the values of the parameter vector.  If you wish the number \
to be in scientific notation, set sciflag = True.  If you prefer no  label, \
assign False to the variable plotlab below.  If you prefer to construct your \
own label, assign the code for it to plotlab. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
plotreset := (asprat = Automatic;
\t\t\t setcolor[{Black}];
\t\t\t setback[White];
\t\t\t dashvec = {{}};
\t\t\t viewpt = {13,-24,20};
\t\t\t boxrat = Automatic;
\t\t\t pointcon = True;
\t\t\t ptsize = 0.005;
\t\t\t poincptsize = 0.008;
\t\t\t lnthick = 0.002;
\t\t\t dirpt = 20;
\t\t\t plrange = All;
\t\t\t plrange3D = All;
\t\t\t axon = True;
\t\t\t frameon = False;
\t\t\t framelabon = True;
\t\t\t axorg = Automatic;
\t\t\t axlabon = True;
\t\t\t labon = True;
\t\t\t labshift = 0;
\t\t\t graylev = 0.49;
\t\t\t display = True;
\t\t\t colpoint = 1;
\t\t\t dashpoint = 1;
\t\t\t totdig = 4;
\t\t\t decdig = 2;
\t\t\t sciflag = False;
\t\t\t arrowflag = False;
\t\t\t arrowvec = {1/3,2/3};
\t\t\t imsize = 340)\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(dashlong = {0.03, 0.015};\)\)], "Input"],

Cell[BoxData[
    \(\(dashort = {0.015, 0.01};\)\)], "Input"],

Cell[BoxData[
    \(\(dashalt = {0.03, 0.01, 0.015, 0.01};\)\)], "Input"],

Cell[BoxData[
    \(\(dotted = {0.002, 0.01};\)\)], "Input"],

Cell[BoxData[
    \(\(solid = {};\)\)], "Input"],

Cell[BoxData[
    \(shfer[n_]\  := \ 
      Module[{ans, i}, 
        ans\  = \ "\<\>"; \n\t\t\tDo[
          ans\  = \ StringJoin[ans, "\< \>"], {i, 1, 
            n}]; \n\t\t\tans]\)], "Input"],

Cell[BoxData[
    \(stateun[j_] := 
      Module[{ans}, 
        ans = statevec[\([j]\)]; \n\t\t\tIf[
          Not[stateunits[\([j]\)] == "\<\>"], \n\t\t\tans = 
            SequenceForm[ans, "\< (\>", 
              stateunits[\([j]\)], "\<)\>"]]; \[IndentingNewLine]\ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ans]\)], "Input"],

Cell[BoxData[
    \(parmun[j_] := 
      Module[{ans}, 
        ans = parmvec[\([j]\)]; \n\t\t\tIf[
          Not[parmunits[\([j]\)] == "\<\>"], \n\t\tans = 
            SequenceForm[ans, "\<(\>", parmunits[\([j]\)], "\<)\>"]]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(statelab := 
      Module[{j}, \((Table[
            stateun[j], {j, 1, Length[statevec]}])\)]\)], "Input"],

Cell[BoxData[
    \(parmlab := 
      Module[{j}, \((Table[parmun[j], {j, 1, Length[parmvec]}])\)]\)], "Input"],

Cell[BoxData[
    \(timelab := 
      Module[{ans}, 
        ans = "\<t\>"; \n\t\tIf[
          Not[timeunit == "\<\>"], \n\t\tans = 
            SequenceForm[ans, "\< (\>", timeunit, "\<)\>"]]; ans]\)], "Input"],

Cell[BoxData[
    \(labfunc[i_] := \ 
      If[\((i == 0)\), \((timelab)\), statelab[\([i]\)]]\)], "Input"],

Cell["\<\
plotlab :=  Module[{ans,bert},
\t\tIf[(Length[parmval] == 0),(bert = \"\"),(If[(sciflag),
\t\t\tbert = SequenceForm[parmlab,\"=\",
\t\t\tScientificForm[parmval,decdig+1]],
\t\t\tbert = SequenceForm[parmlab,\"=\",
\t\t\tPaddedForm[parmval,{totdig,decdig}]]])]; 
\tIf[(labon),
\t \t(ans = SequenceForm[sysname,shfer[labshift],\" \",
\t\tbert]),
\t\t(ans = \" \"),(ans = labon)];ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Protect[plotlab];\)\)], "Input"],

Cell[BoxData[
    \(\(allcolors = AllColors;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[list_]\  := \((colorvecdis\  = \ HoldForm[list]; 
          colorvec = list; colpoint = 1)\);\)\)], "Input"],

Cell[BoxData[
    \(\(setback[col_] := \((backcolordis = HoldForm[col]; 
          backcolor = col)\);\)\)], "Input"],

Cell[BoxData[
    \(\(SetAttributes[setcolor, HoldAll];\)\)], "Input"],

Cell[BoxData[
    \(\(SetAttributes[setback, HoldAll];\)\)], "Input"],

Cell[BoxData[
    \(\(setdash[list_]\  := \((dashvec\  = \ list; 
          dashpoint = 1)\);\)\)], "Input"],

Cell[BoxData[
    \(colinc\  := \ \((colpoint = 
          colpoint + 
            1; \n\t\tIf[\((colpoint\  > \ 
              Length[colorvec])\), \ \((colpoint\  = \ 1)\)])\)\)], "Input"],

Cell[BoxData[
    \(dashinc\  := \ \((dashpoint = 
          dashpoint + 
            1; \n\t\tIf[\((dashpoint\  > \ 
              Length[dashvec])\), \ \((dashpoint\  = \ 1)\)])\)\)], "Input"],

Cell["\<\
The list of colors below is for compatibility with earlier \
versions.\
\>", "Text"],

Cell[BoxData[
    \(\(black\  = \ Black;\)\)], "Input"],

Cell[BoxData[
    \(\(red\  = \ Red;\)\)], "Input"],

Cell[BoxData[
    \(\(green\  = \ Green;\)\)], "Input"],

Cell[BoxData[
    \(\(blue\  = \ Blue;\)\)], "Input"],

Cell[BoxData[
    \(\(yellow\  = \ Yellow;\)\)], "Input"],

Cell[BoxData[
    \(\(magenta\  = \ Magenta;\)\)], "Input"],

Cell[BoxData[
    \(\(cyan\  = \ Cyan;\)\)], "Input"],

Cell["plotreset;", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["\n9.  PLOT ROUTINES"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe plotting routines all use graphics primatives and Show. To \
make a phaseplot of the ith and jth components of a solution stored in sol, \
execute phaseplot[sol,i,j].  The special case phaseplot[sol,1,2] can be \
executed by phaser[sol].  To make a plot of the ith component versus time, \
execute timeplot[sol,i].  To plot several components versus time on the same \
graph, execute timeplot[sol,ilist], where ilist is a list of the components \
to be plotted.  The 3D plot routine phaseplot3D is built on the graphics \
primitive Graphics3D[Point].  To plot the three dimensional phase view of \
components i, j, and k, execute phaseplot3D[sol,i,j,k].  The special case \
phaseplot[sol,1,2,3] can be executed by phaser3D[sol].  All of the plotting \
routines allow the plotting of more than one solution at a time.  To plot a \
single solution named sol1, just use sol1 as the argument.  To plot solutions \
sol1, sol2, and sol3 at the same time, use {sol1,sol2,sol3} as the argument.  \
To plot points at specified positions use dots[list] in 2D and dots3D[list] \
in 3D.
     \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

pairgen[liszt_,i_,j_] := {Part[liszt,i+1],
\t\t\t\t\t\t\t\tPart[liszt,j+1]}
\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
triogen[liszt_,i_,j_,k_] := {Part[liszt,i+1],
\t\t\t\t\tPart[liszt,j+1], Part[liszt,k+1]}\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
graphconaux[sol_,p_,q_] := Module[{dsh,cvec},
\t\tcvec = colorvec[[colpoint]]; colinc;
\t\tdsh = dashvec[[dashpoint]]; dashinc;
\t\t \tIf[pointcon,
\t\t\t\tGraphics[{Thickness[lnthick],
\t\t\t\tDashing[dsh],
\t\t\t\tcvec,
\t\t\t\tLine[Map[pairgen[#,p,q]&,sol]]}],
\t\t\t\tGraphics[{PointSize[ptsize],
\t\t\t\tcvec,
\t\t\t\tPoint /@
\t\t\t\t\tMap[pairgen[#,p,q]&,sol]}]]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(getarr[list_] := 
      Module[{arcl, numarr, runlen, ans, arrpoint, a, b, frac, i, oneflag, 
          ii}, oneflag = False; arcl = arlen[list]; 
        numarr = Length[arrowvec]; runlen = 0; ans = {}; arrpoint = 1; i = 1; 
        If[\((arrowvec[\([1]\)] == 0)\), \((ans = {2}; arrpoint = 2)\)]; 
        If[\((Last[arrowvec] == 1)\), \((oneflag = True; 
            numarr = 
              numarr - 
                1)\)]; \t\tWhile[\((\((arrpoint\  <= \ numarr)\) && \((arcl > 
                  0)\))\), \((a = list[\([i]\)]; b = list[\([i + 1]\)]; 
            runlen = runlen + Sqrt[sqnorm[b - a]]; frac = runlen/arcl; 
            If[\((frac\  >= \ arrowvec[\([arrpoint]\)])\), \((arrpoint = 
                  arrpoint + 1; 
                If[\((i == 1)\), \((ii = i + 1)\), \((ii = i)\)]; 
                ans = Append[ans, ii])\)]; i = i + 1)\)]; 
        If[\((oneflag)\), \((ans = Append[ans, Length[list] - 1])\)]; 
        If[\((arcl == 0)\), ans = {}]; ans]\)], "Input"],

Cell[BoxData[
    \(\(arropt = {HeadScaling -> Automatic, Headlength -> Automatic, 
          HeadWidth -> 0.5, HeadCenter -> 0.6};\)\)], "Input"],

Cell[BoxData[
    \(arrmak[list_] := 
      Module[{lenopt, lenarr, lenlist, i, j, ans, term, loclist, isub}, 
        loclist = getarr[list]; lenlist = Length[list]; 
        lenarr = Length[loclist]; lenopt = Length[arropt]; ans = {}; 
        Do[isub = loclist[\([i]\)]; 
          term = Arrow[list[\([isub - 1]\)], list[\([isub + 1]\)]]; 
          Do[term = Append[term, arropt[\([j]\)]], {j, 1, 
              lenopt}]; \n\t\t\t\t\ ans = Append[ans, term], {i, 1, lenarr}]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(arrowmak[sol_, p_, q_] := \ 
      Module[{cvec}, cvec = colorvec[\([colpoint]\)]; 
        Graphics[{cvec, arrmak[Map[pairgen[#, p, q] &, sol]]}]]\)], "Input"],

Cell["\<\
graphcon[sol_,p_,q_] := Module[{len,solist,
\t\tsolarg,glist,lena,r},
\t\tlena = Length[Dimensions[sol]];
\tIf[(lena == 2),(solist = {sol}),(solist = sol)];
\t\tlen = Length[solist];
\t\tglist = {};
\t\tDo[(solarg = solist[[r]];If[((arrowflag)&&(p > 0)),
\t\tglist = Append[glist,arrowmak[solarg,p,q]]];
\tglist = Append[glist,graphconaux[solarg,p,q]]),
\t\t\t\t{r,1,len}];\t\t
\t\t\tglist]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
timecon[sol_,ilist_] := Module[{len,glist,q},
\tlen=Length[ilist];
\t\tglist = {};
\t\tDo[(glist = Append[glist,
\t\tgraphcon[sol,0,ilist[[q]]]]),
\t\t\t\t\t{q,1,len}];
\t\t\t\tglist]\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
timeplot[sol_,i_] := Module[{ilist,ind},
\tIf[(Length[i]==0),(ilist={i};ind=i),(ilist=i)];
\t\t\t\tIf[(Length[i]==1),(ind=i[[1]])];
\t\t\t\t\t(Show[timecon[sol,ilist],
\t\t\t\tAxes -> axon, Frame -> frameon,
\t\t\t\tRotateLabel->False,
\t\t\t\tBackground -> backcolor,
\t\t\t\tPlotRange -> plrange,
\t\t\t\t\t\tAxesOrigin -> axorg,
\t\t\t\t\t\tImageSize -> imsize, 
\t\t\t\t\t\tAxesLabel -> If[(axlabon),{timelab,
\t\t\t(If[(Length[i]==0||Length[i]==1),
\t\t(statelab[[ind]]),(Part[statelab,ilist])])},None,axlabon],
\t\tFrameLabel -> If[(framelabon),{timelab,
\t\t\t(If[(Length[i]==0||Length[i]==1),
\t\t(statelab[[ind]]),(Part[statelab,ilist])])},None,framelabon],
\t\t\tPlotLabel -> plotlab,
\t\t\tDisplayFunction -> 
\t\t\t(If[display,$DisplayFunction,Identity]),
\t\t\t\t\t\tAspectRatio -> asprat])]\t
\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
phaseplot[sol_,i_,j_] := (Show[graphcon[sol,i,j],
\t\t\tAxes -> axon,PlotRange -> plrange,
\t\t\tAxesOrigin -> axorg, Frame -> frameon, 
\t\t\tAxesLabel -> If[(axlabon), 
\t\t\t{labfunc[i],labfunc[j]},None,axlabon],
\t\t\tRotateLabel->False,
\t\t\tBackground -> backcolor,
\t\t\tFrameLabel -> If[(framelabon), 
\t\t\t{labfunc[i],labfunc[j]},None,framelabon],
\t\t\tPlotLabel -> plotlab,
\t\t\tImageSize -> imsize,
\t\t\tDisplayFunction -> 
\t\t\t(If[display,$DisplayFunction,Identity]),
 \t\t\t\t\t\t\tAspectRatio -> asprat])\t
\
\>", "Input",
  AspectRatioFixed->True],

Cell["phaser[sol_] := phaseplot[sol,1,2]", "Input",
  AspectRatioFixed->True],

Cell["\<\
graphcon3aux[sol_,i_,j_,k_] := Module[{cvec},
\t\tcvec = colorvec[[colpoint]]; colinc;
\t\tIf[pointcon,
\t\t\tGraphics3D[{Thickness[lnthick],
\t\t\tcvec,
\t\t\tLine[Map[triogen[#,i,j,k]&,sol]]}],
\t\t\tGraphics3D[{PointSize[ptsize],
\t\t\tcvec,
\t\t\tPoint /@ Map[triogen[#,i,j,k]&,sol]}]]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
graphcon3[sol_,p_,q_,r_] := Module[
\t{len,solist,solarg,glist,lena,s},
\tlena = Length[Dimensions[sol]];
\tIf[(lena == 2),(solist = {sol}),(solist = sol)];
\t\tlen = Length[solist];
\t\tglist = {};
\t\tDo[(solarg = solist[[s]];
\tglist = Append[glist,graphcon3aux[solarg,p,q,r]]),{s,1,len}];\t\t
\t\t\tglist]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
phaseplot3D[sol_,i_,j_,k_] := 
\t(Show[graphcon3[sol,i,j,k],
\t\tAxes -> axon,Boxed -> True,
\t\tImageSize -> imsize,
\t\tBackground -> backcolor,
\t\tAxesLabel -> If[(axlabon),
\t\t{labfunc[i],labfunc[j],labfunc[k]},
\t\tNone,axlabon],
\t\tViewPoint -> viewpt, PlotRange -> plrange3D,
\t\tPlotLabel -> plotlab,
\t\tDisplayFunction -> 
\t\t\t\t(If[display,$DisplayFunction,Identity]),
\t\t\t\tSphericalRegion -> False,
\t\t\t\tBoxRatios -> boxrat])
\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["phaser3D[sol_] := phaseplot3D[sol,1,2,3]", "Input",
  AspectRatioFixed->True],

Cell["\<\
phaseplot3DS[sol_,i_,j_,k_,viewpt_] := (Show[
\t\tgraphcon3[sol,i,j,k],
\t\tBoxed -> True,
\t\tViewPoint -> viewpt,
\t\tImageSize -> imsize, \t
\t\tSphericalRegion -> True,
\t\tDisplayFunction -> 
\t\t(If[display,$DisplayFunction,Identity]),
\t\tBoxRatios -> boxrat, PlotRange -> plrange3D,
\t\t Background -> GrayLevel[graylev]])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe plotting routine below, animate, constructs a sequence of \
rotated three dimensional graphs which then may be selected and viewed with \
the animation command in the Graph Menu.  The graphs are produced by starting \
at the user's set value of viewpoint and rotating that viewpoint about the \
z-axis, in equal angular increments.  The number of increments is the \
argument ng. Animate uses a slightly modified version of phaseplot3D called \
phaseplot3DS, with the only differences being that in phaseplot3DS, \
SphericalRegion -> True and viewpt is an argument.  The user set value of \
viewpt is not changed by the execution of animate.  Also, the graphs produced \
for animation do not have axis labels or scales.  This produces a cleaner \
animation.  To produce a single 3D plot rotated by theta degrees about the \
z-axis, use rotphaseplot3D. 
\t\t\t\t\t\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
animate[sol_,i_,j_,k_,ng_] := Module[
{x0 = viewpt[[1]],y0 = viewpt[[2]], z0 = viewpt[[3]],
 ang = (2.*Pi)/ng,q},
Do[phaseplot3DS[sol,i,j,k,{x0*Cos[q*ang]-y0*Sin[q*ang],y0*Cos[q*ang]+x0*Sin[q*\
ang],z0}],{q,0,ng-1}]] 
\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
rotphaseplot3D[sol_,i_,j_,k_,theta_] := Module[
{x0 = viewpt[[1]],y0 = viewpt[[2]], z0 = viewpt[[3]],
 ang = (Pi/180.)*theta,tempview = viewpt,ans},
 viewpt = {x0*Cos[ang]-y0*Sin[ang],
\ty0*Cos[ang]+x0*Sin[ang],z0};
\tans = phaseplot3D[sol,i,j,k];
\tviewpt = tempview;
\tans]\t\t \t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe routines show and show3D are variations on the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Show, defined for convenience.  They both automatically use the current \
settings for plrange or plrange3D and axon.  In addtion, show uses the \
current setting for asprat, and show3D uses the current settings for viewpt \
and boxrat.  Both automatically display graphs, even if the graphs were \
created with the display option turned off.  The routine plot is a variation \
on ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Plot.  It automatically uses the current settings of asprat, axon, \
axorg, display, and plrange.  It labels the horizontal axis t and the \
vertical axis with the name of the function being plotted. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
show[graphlist__] := Show[{graphlist},DisplayFunction ->
\t\t\t\t\t\t\t$DisplayFunction,
\t\t\t\t\t\t\tPlotRange -> plrange,
\t\t\t\t\t\t\tAxesOrigin -> axorg,
\t\t\t\t\t\t\tBackground -> backcolor,
\t\t\t\t\t\t\tImageSize -> imsize,
\t\t\t\t\t\t\tAxes -> axon,
\t\t\t\t\t\t\tFrame -> frameon,
\t\t\t\t\t\t\tAspectRatio -> asprat]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
show3D[graphlist__] := Show[{graphlist},
\t\t \tDisplayFunction ->$DisplayFunction,
\t\t\t\t\tAxes -> axon,
\t\t\t\t\tImageSize -> imsize,
\t\t\t\t\tBackground -> backcolor,
\t\t\t\t\tPlotRange -> plrange3D,
\t\t\t\t\tBoxRatios -> boxrat,
\t\t\t\t\tViewPoint -> viewpt]
\t\t\t\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
plot[func_,rng_] := Module[{cvec,dsh},
\t\t\t\tcvec = colorvec[[colpoint]] colinc;
\t\t\t\tdsh = dashvec[[dashpoint]]; dashinc;
\t\t\t\tPlot[func,rng,Axes -> axon, Frame -> frameon,
\t\t\t\t\tPlotStyle->{{cvec,
\t\t\t\t\tDashing[dsh]}},
\t\t\t\t\tPlotRange -> plrange,
\t\t\t\t\tImageSize -> imsize,
\t\t\t\t\tAxesOrigin -> axorg,
\t\t\t\t\tBackground -> backcolor,
\t\t\t\t\tAspectRatio -> asprat,
\t\t\t\t\tDisplayFunction -> 
\t\t\t\t\t(If[display,
\t\t\t\t\t$DisplayFunction,Identity]),
\t\t\t\t\tRotateLabel->False,
\t\t\t\t\tFrameLabel -> If[(framelabon),{\"t\",func},None,
\t\t\t\t\tframelabon],
\t\t\t\t\tAxesLabel -> If[(axlabon),{\"t\",func},None,
\t\t\t\t\taxlabon]]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(dots[list_] := 
      Module[{artlist, inc, holdptcon, holdarrow, ele, i, 
          ans}, \[IndentingNewLine]holdptcon = pointcon; 
        pointcon = False; \[IndentingNewLine]holdarrow = arrowflag; 
        arrowflag = 
          False; \[IndentingNewLine]artlist = {}; \[IndentingNewLine]inc[
            arg_]\  := Insert[arg, 0, 1]; 
        Do[\((ele = list[\([i]\)]; 
            artlist = Append[artlist, inc[ele]])\), {i, 1, 
            Length[list]}]; \[IndentingNewLine]ans = phaser[artlist]; 
        pointcon = holdptcon; arrowflag = holdarrow; ans]\)], "Input"],

Cell[BoxData[
    \(dots3D[list_] := 
      Module[{artlist, inc, holdptcon, ele, i, 
          ans}, \[IndentingNewLine]holdptcon = pointcon; 
        pointcon = 
          False; \[IndentingNewLine]artlist = {}; \[IndentingNewLine]inc[
            arg_]\  := Insert[arg, 0, 1]; 
        Do[\((ele = list[\([i]\)]; 
            artlist = Append[artlist, inc[ele]])\), {i, 1, 
            Length[list]}]; \[IndentingNewLine]ans = phaser3D[artlist]; 
        pointcon = holdptcon; ans]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

10.  DIRECTION FIELDS\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tTo plot the direction field for a two-dimensional system, the function \
dirfield is defined below, in terms of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function PlotVectorField.  As described in the overview, the variable \
plrange controls the plotting window.  For this purpose, plrange MUST be set \
to a two-dimensional plotting window, and not to All or Automatic.  The \
Graphics package PlotField is loaded to make PlotVectorField available.  The \
option PlotPoints -> dirpt (default value of 20) causes the direction field \
to be displayed as a dirpt x dirpt grid."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(clr2[x_] := colorvec[\([colpoint]\)]\)], "Input"],

Cell["\<\
dirfield := Module[{ans},ans = PlotVectorField[slopeval,
\t\t\t\t{statevec[[1]],plrange[[1,1]],
\t\t\t\t\tplrange[[1,2]]},
\t\t\t\t{statevec[[2]],plrange[[2,1]],
\t\t\t\t\tplrange[[2,2]]}, 
\t\t\t\tProlog -> {Thickness[0.001]},
\t\t\t\tAxes -> axon,
\t\t\t\tFrame -> frameon,
\t\t\t\tImageSize -> imsize,
\t\t\t\tBackground -> backcolor,
\t\t\t\tAxesOrigin -> axorg,
\t\t\t\tPlotPoints -> dirpt,
\t\t\t\tScaleFunction -> (1&),
\t\t\t\tPlotLabel -> plotlab,
\t\t\t\tColorFunction -> clr2,
\t\t\t\tDisplayFunction -> 
\t\t\t\t(If[display,$DisplayFunction,Identity]),
\t\tAspectRatio -> asprat,
\t\tFrameLabel -> If[(framelabon),{statelab[[1]],statelab[[2]]},
\t\tNone,framelabon],
\t\tRotateLabel -> False,
\t\tAxesLabel -> If[(axlabon),{statelab[[1]],statelab[[2]]},
\t\tNone,axlabon]];colinc;ans]\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["11.  PHASE PORTRAITS", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe function portrait creates a phase portrait from a given list \
of initial conditions.  It takes as arguments (1) intlist,a list of initial \
conditions, (2) t0, an initial time or a list of initial times, (3) h, the \
step size, (4) nsteps, the number of time steps, (5) the indices i and j \
specifying which components are to be plotted.  If t0 is an initial time, \
that time is used to start each integration.  If t0 is a list of times, they \
are used sequentially in performing the integration for the different initial \
conditions in intlist.  The function portrait3D does exactly the same thing, \
except in three dimensions.  
     \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
portrait[intlist_,t0_,h_,nsteps_,i_,j_] := (CheckAbort[Module[
\t\t{numint, glist,tlen,tdum,q,hlen,hdum,stplen,stpdum,argsteps},
\t\ttlen = Length[t0];
\t\thlen = Length[h];
\t\targsteps = nsteps /. Thread[parmvec -> parmval];
\t\tstplen = Length[argsteps];
\t\tnumint = Length[intlist];
\t\tglist = {};
\t\tDo [If[(tlen == 0),(tdum = t0),(tdum = t0[[q]])];
\t\t\tIf[(hlen == 0),(hdum = h),(hdum = h[[q]])];
\t\t\tIf[(stplen == 0),(stpdum = argsteps),
\t\t\t(stpdum = argsteps[[q]])]; 
\t\t\tglist = Append[glist,graphcon[
\t\t\t\tintegrate[intlist[[q]],tdum,hdum,stpdum],i,j]],
\t\t\t{q,1,numint}];
\t\tShow[glist,Axes -> axon,PlotRange -> plrange,
\t\tAxesOrigin -> axorg, Frame -> frameon,
\t\tImageSize -> imsize,
\t\tBackground -> backcolor, 
\t\tAxesLabel -> If[(axlabon),{labfunc[i],labfunc[j]},
\t\t\t\t\tNone,axlabon],
\t\tFrameLabel -> If[(framelabon),{labfunc[i],labfunc[j]},
\t\t\t\t\tNone,framelabon],
\t\t\t\t\tRotateLabel -> False,\t
\t\t\tPlotLabel -> plotlab,
\t\t\tDisplayFunction -> 
\t\t\t(If[display,$DisplayFunction,Identity]),
\t\t\tAspectRatio -> asprat]],
\t\t\t(Print[\"Portrait Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
portrait3D[intlist_,t0_,h_,nsteps_,i_,j_,k_] := (CheckAbort[
Module[
\t{numint,glist,tlen,tdum,q,hlen,hdum,stplen,stpdum,argsteps},
\t\ttlen = Length[t0];
\t\thlen = Length[h];
\t\targsteps = nsteps /. Thread[parmvec -> parmval];
\t\tstplen = Length[argsteps];
\t\tnumint = Length[intlist];
\t\tglist = {};
\t\tDo [If[(tlen == 0),(tdum = t0),(tdum = t0[[q]])];
\t\t\tIf[(hlen == 0),(hdum = h),(hdum = h[[q]])];
\t\t\tIf[(stplen == 0),(stpdum = argsteps),
\t\t\t(stpdum = argsteps[[q]])]; 
\t\t\tglist = Append[glist,graphcon3[
\t\t\t\tintegrate[intlist[[q]],tdum,hdum,nsteps],i,j,k]],
\t\t\t{q,1,numint}];
\t\tShow[glist,Axes -> axon, Boxed -> True,
\t\tPlotRange -> plrange3D,
\t\tViewPoint -> viewpt,
\t\tImageSize -> imsize,
\t\tBackground -> backcolor,
\t\tAxesLabel -> If[(axlabon),
\t\t{labfunc[i],labfunc[j],labfunc[k]},
\t\tNone,axlabon],
\t\tPlotLabel -> plotlab,
\t\tDisplayFunction -> 
\t\t(If[display,$DisplayFunction,Identity]),
\t\tBoxRatios -> boxrat,
\t\tSphericalRegion -> False]],
\t\t\t(Print[\"3DPortrait Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we use portrait and portrait3D to define simple bifurcation \
routines.  These routines construct a sequence of phase portraits, one for \
each set of parameters in the list parmlist.  Both bifurcation routines have \
an optional argument, refgraph, which, if supplied, is a graph which will be \
superimposed on each graph of the sequence.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
bifurc[intlist_,t0_,h_,nsteps_,i_,j_,parmlist_,refgraph__: {}] := 
\t(CheckAbort[Module[{k,temgraph,temrefgraph},
\tPrint[\"Bifurcation sequence for parmlist = \", parmlist];
\t\t\tDo[(parmval = parmlist[[k]];
\t\t\tdisplay = False;
\t\t\t\ttemgraph = portrait[intlist,t0,h,nsteps,i,j]);
\t\t\t\ttemrefgraph = refgraph //. Thread[parmvec->parmval];
\t\t\t\tdisplay = True;
\t\t\t\tshow[Flatten[{temgraph,temrefgraph}]],
\t\t\t\t{k,1,Length[parmlist]}]],
\t\t\t(Print[\"Bifurcation Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetAttributes[bifurc, HoldAll];\)\)], "Input"],

Cell["\<\
bifurc3D[intlist_,t0_,h_,nsteps_,i_,j_,k_,parmlist_,refgraph__: {}] \
:=
   (CheckAbort[Module[{q,temgraph,temrefgraph},
\tPrint[\"Bifurcation sequence for parmlist = \", parmlist];
\t\tDo[(parmval = parmlist[[q]];
\t\tdisplay = False;
\t\t\ttemgraph = portrait3D[intlist,t0,h,nsteps,i,j,k]);
\t\t\ttemrefgraph = refgraph //. Thread[parmvec->parmval];
\t\t\tdisplay = True;
\t\t\tshow3D[Flatten[{temgraph,temrefgraph}]],
\t\t\t\t{q,1,Length[parmlist]}]],
\t\t\t(Print[\"3DBifurcation Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetAttributes[bifurc3D, HoldAll];\)\)], "Input"],

Cell["\<\
\tThe routine phaseseq constructs a time-sequence of phase \
portraits at equal time intervals.  By animating the graph sequence produced, \
one gets a simulation of the actual construction of the phase portrait and a \
valid representation of the speed of the system point along the orbits \
presented.  The routine phaseseq3D does exactly the same thing for \
three-dimensional phase plots.  In both cases the argument refgraph is \
optional.  When it is used, it is the name of a reference graph which you \
want superimposed on each graph in the sequence.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
phaseseq[initlist_,t0_,h_,nstepic_,npics_,i_,j_,refgraph__: {}] :=
\tModule[{bigsol,nsteps,tmin,tmax,startsol,tempoint,
\t\t\ttemptsize,delt,solpiece,lena,worklist,
\t\t\tleadergraph,basegraph,leaderpt,dtsize,q},
\tlena = Length[Dimensions[initlist]];
\tIf[(lena==1),(worklist={initlist}),(worklist=initlist)];
\tdtsize = 0.02;\t\t
\tnsteps = nstepic*npics;
\tdelt = nstepic*h;
\tstartsol = Map[Prepend[#,t0]&,worklist];
\ttempoint = pointcon;
\tpointcon = False;
\ttemptsize = ptsize;
\tptsize = dtsize;
\tdisplay = False;
\tbasegraph = phaseplot[startsol,i,j];
\tdisplay = True; 
\tshow[refgraph,basegraph];
\tpointcon = tempoint;
\tptsize = temptsize;
\tbigsol = Map[integrate[#,t0,h,nsteps]&,worklist];
\tDo[(tmin = t0;tmax = tmin + q*delt;
\t\tsolpiece = Map[subsol[#,{tmin,tmax}]&,bigsol];
\t\tdisplay = False;
\t\tbasegraph = phaseplot[solpiece,i,j];
\t\ttempoint = pointcon;
\t\tpointcon = False;
\t\ttemptsize = ptsize;
\t\tptsize = dtsize;
\t\tleaderpt = Map[Last[#]&,solpiece];
\t\tleadergraph = phaseplot[leaderpt,i,j];
\t\tdisplay = True;
\t\tpointcon = tempoint;
\t\tptsize = temptsize;
\t\tshow[{refgraph,basegraph,leadergraph}];),{q,1,npics}]]
\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
phaseseq3D[initlist_,t0_,h_,nstepic_,npics_,i_,j_,k_,refgraph__: \
{}] :=
\tModule[{bigsol,nsteps,tmin,tmax,startsol,tempoint,
\t\t\ttemptsize,delt,solpiece,lena,worklist,
\t\t\tleadergraph,basegraph,leaderpt,dtsize,q},
\tdtsize = 0.02;\t\t
\tlena = Length[Dimensions[initlist]];
\tIf[(lena==1),(worklist = {initlist}),(worklist = initlist)];\t
\tnsteps = nstepic*npics;
\tdelt = nstepic*h;
\tstartsol = Map[Prepend[#,t0]&,worklist];
\ttempoint = pointcon;
\tpointcon = False;
\ttemptsize = ptsize;
\tptsize = dtsize;
\tdisplay = False; 
\tbasegraph = phaseplot3D[startsol,i,j,k];
\tdisplay = True;
\tshow3D[refgraph,basegraph];
\tpointcon = tempoint;
\tptsize = temptsize;
\tbigsol = Map[integrate[#,t0,h,nsteps]&,worklist];
\tDo[(tmin = t0;tmax = tmin + q*delt;
\t\tsolpiece = Map[subsol[#,{tmin,tmax}]&,bigsol];
\t\tdisplay = False;
\t\tbasegraph = phaseplot3D[solpiece,i,j,k];
\t\ttempoint = pointcon;
\t\tpointcon = False;
\t\ttemptsize = ptsize;
\t\tptsize = dtsize;
\t\tleaderpt = Map[Last[#]&,solpiece];
\t\tleadergraph = phaseplot3D[leaderpt,i,j,k];
\t\tdisplay = True;
\t\tpointcon = tempoint;
\t\tptsize = temptsize;
\t\tshow3D[{refgraph,basegraph,leadergraph}];),{q,1,npics}]]
\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThere are four functions to give a basic phase portrait near an \
equilibrium in two dimensions.  Each function takes two arguments:  the \
equilbrium point eq, and the plotting range window.  The function \
saddleportrait[eq,window] gives a graph of the stable and unstable manifolds \
through a saddle point at eq.  The function spiralportrait[eq,window] gives a \
plot of two integral curves to or from the spiral.  The function \
nodeportrait[eq,window] gives the fast and slow eigenvectors, plus four \
additional integral curves.  The function centerportrait[eq,window] gives \
three closed orbits about the center.  \
\>", "Text"],

Cell[BoxData[
    \(norm[vec_] := 
      Module[{len, a, b}, a = First[vec]; 
        b = Last[vec]; \n\t\tlen = Sqrt[a^2 + b^2]; vec/len]\)], "Input"],

Cell[BoxData[
    \(\(\(makesadinitman[eq_, prange_] := 
      Module[{ans, esys, eigval, evecs, scale, invec, \n\t\t\toutvec, 
          outinit1, ininit1, outinit2, ininit2}, \n\t\t\tscale = 
          Min[\((prange[\([1, 2]\)] - 
                prange[\([1, 1]\)])\), \((prange[\([2, 2]\)] - 
                prange[\([2, 1]\)])\)]; \n\t\tesys = 
          Eigensystem[dermatval[eq]]; \n\t\teigval = First[esys]; 
        evecs = Last[
            esys]; \n\t\tIf[\((First[eigval] > 0)\), \((outvec = 
              norm[First[evecs]]; 
            invec = norm[Last[evecs]])\), \n\t\t\t\((outvec = Last[evecs]; 
            invec = First[evecs])\)]; \n\t\toutinit1 = 
          eq + 0.0025*scale*outvec; \n\t\toutinit2 = 
          eq - 0.0025*scale*outvec; \n\t\tininit1 = 
          eq + 0.0025*scale*invec; \n\t\tininit2 = 
          eq - 0.0025*scale*invec; \n\t\tans = {outinit1, outinit2, ininit1, 
            ininit2}; ans]\)\(\n\)\(\t\t\t\t\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(makesadinitcur[eq_, prange_] := \n\t
      Module[{ans, esys, evecs, scale, vec1, \n\t\t\tvec2, init1, init2, 
          init3, init4, fac}, \n\t\t\tscale = 
          Min[\((prange[\([1, 2]\)] - 
                prange[\([1, 1]\)])\), \((prange[\([2, 2]\)] - 
                prange[\([2, 1]\)])\)]; \n\t\tfac = 0.25*scale; \n\t\tevecs = 
          Eigenvectors[dermatval[eq]]; \n\t\tvec1 = norm[First[evecs]]; 
        vec2 = norm[Last[evecs]]; \n\t\tinit1 = 
          fac*norm[\((vec1 + vec2)\)]; \n\t\tinit2 = 
          fac*norm[\((vec1 - vec2)\)]; \n\t\tinit3 = 
          fac*norm[\((\(-vec1\) + vec2)\)]; \n\t\tinit4 = 
          fac*norm[\((\(-vec1\) - vec2)\)]; \n\t\tans = {init1, init2, init3, 
            init4}; ans]\)\(\n\)\(\t\t\t\t\)\)\)], "Input"],

Cell[BoxData[
    \(makespiralinit[eq_, prange_] := 
      Module[{ax, bx, ans, xlloc, xrloc, x2lloc, 
          x2rloc}, \n\t\t\t\t\t\t\t\tax = prange[\([1, 1]\)]; 
        bx = prange[\([1, 2]\)]; \n\t\t\t\t\t\t\t\txlloc = \ \((5. /6. )\)*
              ax + \((1. /6. )\)*bx; 
        xrloc = \((1. /3. )\)*ax + \((2. /3. )\)*
              bx; \n\t\t\t\t\t\t\t\tx2lloc = \((2. /3. )\)*ax + \((1. /3. )\)*
              bx; x2rloc = \((1. /6. )\)*ax + \((5. /6. )\)*
              bx; \n\t\t\t\t\t\t\t\tans = {{xlloc, 0}, {xrloc, 0}, {x2lloc, 
              0}, {x2rloc, 0}}; \n\t\t\t\tans]\)], "Input"],

Cell[BoxData[
    \(makecenterinit[eq_, prange_] := 
      Module[{ans, ym, ax, bx, xsp, 
          xm}, \n\t\tym = \((prange[\([2, 1]\)] + prange[\([2, 2]\)])\)/
            2.0; \n\t\tax = prange[\([1, 1]\)]; 
        bx = prange[\([1, 2]\)]; \n\t\txsp = \((bx - ax)\)/8; 
        xm = \((ax + bx)\)/
            2; \n\t\tans = {{xm + xsp, ym}, {xm + 2*xsp, ym}, {xm + 3*xsp, 
              ym}}; \n\t\tans]\)], "Input"],

Cell[BoxData[
    \(makenodeinit[eq_, prange_] := 
      Module[{ans1, ans2, ans, evecs, ax, ay, bx, by, xlloc, xrloc, ylloc, 
          yrloc, scale}, \n\t\t\tscale = 
          Min[\((prange[\([1, 2]\)] - 
                prange[\([1, 1]\)])\), \((prange[\([2, 2]\)] - 
                prange[\([2, 1]\)])\)]; \n\t\tevecs = 
          Eigenvectors[dermatval[eq]]; \n\t\t\t\tans1 = {eq, eq} + 
            0.05*scale*evecs; 
        ans2 = {eq, eq} - 0.05*scale*evecs; \n\t\t\t\tans2 = 
          Append[ans2, First[ans1]]; 
        ans\  = \ Append[ans2, Last[ans1]]; \n\t\t\t\t\t\tax = 
          prange[\([1, 1]\)]; 
        bx = prange[\([1, 2]\)]; \n\t\t\t\t\t\t\t\tay = prange[\([2, 1]\)]; 
        by = prange[\([2, 2]\)]; \n\t\t\t\t\t\t\t\txlloc = \ \((2. /3. )\)*
              ax + \((1. /3. )\)*bx; 
        xrloc = \((1. /3. )\)*ax + \((2. /3. )\)*
              bx; \n\t\t\t\t\t\t\t\tylloc = \((2. /3. )\)*ay + \((1. /3. )\)*
              by; yrloc = \((1. /3. )\)*ay + \((2. /3. )\)*by; \n\t\tans = 
          Append[ans, {xrloc, ylloc}]; 
        ans = Append[ans, {xrloc, yrloc}]; \n\t\tans = 
          Append[ans, {xlloc, yrloc}]; 
        ans = Append[ans, {xlloc, ylloc}]; \n\t\tans]\)], "Input"],

Cell[BoxData[
    \(allportrait[eq_, prange_, initcond_, steppes_, winfac_, arvec_, 
        sadflag_] := 
      Module[{tempfastflag, tempbothdir, tempplrange, temprangeflag, 
          tempranger, modslope, tstep, nsteps, ans, \n\t\t\ttempdisplay, 
          temparflag, temparvec}, tempfastflag = fastflag; 
        fastflag = False; \n\t\ttemparflag = arrowflag; 
        arrowflag = True; \n\t\ttemparvec = arrowvec; 
        arrowvec = arvec; \n\t\ttempbothdir = bothdirflag; 
        bothdirflag = True; \n\t\ttempplrange = plrange; 
        plrange = prange; \n\t\ttemprangeflag = rangeflag; 
        rangeflag = True; \n\t\ttempranger = 
          ranger; \n\t\tranger = \((winfac)\)*prange - \((winfac - 1)\)*
              Map[Reverse, prange]; \n\t\ttempdisplay\  = \ 
          display; \n\t\ttstep = 
          0.5*sugtimestep[
              prange]; \n\t\tIf[\((sadflag)\), \((tstep = {tstep, 
                tstep, \(-tstep\), \(-tstep\)}; \n\t\t\tbothdirflag = 
              False)\)]; \n\t\tans\  = 
          portrait[initcond, 0, tstep, steppes, 1, 2]; \n\t\tfastflag = 
          tempfastflag; \n\t\tbothdirflag = tempbothdir; \n\t\tplrange = 
          tempplrange; \n\t\tarrowflag = temparflag; \n\t\tarrowvec = 
          temparvec; \n\t\trangeflag = temprangeflag; \n\t\tdisplay = 
          tempdisplay; \n\t\tranger = tempranger; ans]\)], "Input"],

Cell[BoxData[
    \(saddleportraitman[eq_, prange_] := 
      Module[{ans, initcond}, 
        initcond = makesadinitman[eq, prange]; \n\t\tans = 
          allportrait[eq, prange, initcond, 750, 1.1, {1/2}, True]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(saddleportraitcur[eq_, prange_] := 
      Module[{ans, initcond}, 
        initcond = makesadinitcur[eq, prange]; \n\t\tans = 
          allportrait[eq, prange, initcond, 500, 1.1, {1/2}, False]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(saddleportrait[eq_, prange_] := 
      Module[{tempdisplay, ans1, ans2, ans}, 
        tempdisplay = display; \n\t\tdisplay\  = \ False; \n\t\tans1 = \ 
          saddleportraitman[eq, prange]; \n\t\tans2 = \ 
          saddleportraitcur[eq, prange]; \n\t\tdisplay = 
          tempdisplay; \n\t\tans = {ans1, ans2}; \n\t\tShow[ans, 
          Axes\  -> \ axon, 
          PlotRange\  -> \ plrange, \n\t\tAxesOrigin\  -> \ axorg, 
          Frame -> frameon, \n\t\tImageSize\  -> \ 
            imsize, \[IndentingNewLine]\t\tBackground\  -> \ 
            backcolor, \ \n\t\tAxesLabel\  -> \ 
            If[\((axlabon)\), {statelab[\([1]\)], 
                statelab[\([2]\)]}, \n\t\t\t\t\tNone, 
              axlabon], \[IndentingNewLine]RotateLabel -> \ 
            False, \[IndentingNewLine]\t\tFrameLabel\  -> \ 
            If[\((framelabon)\), {statelab[\([1]\)], 
                statelab[\([2]\)]}, \n\t\t\t\t\tNone, 
              framelabon], \t\n\t\t\tPlotLabel\  -> \ 
            plotlab, \n\t\t\tDisplayFunction\  -> \ \n\t\t\t\((If[
                display, $DisplayFunction, 
                Identity])\), \n\t\t\tAspectRatio\  -> \ asprat]]\)], "Input"],

Cell[BoxData[
    \(spiralportrait[eq_, prange_] := 
      Module[{ans, initcond}, 
        initcond = makespiralinit[eq, prange]; \n\t\tans = 
          allportrait[eq, prange, initcond, 750, 1.5, {1/3, 2/3}, False]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(nodeportrait[eq_, prange_] := 
      Module[{ans, initcond}, 
        initcond = makenodeinit[eq, prange]; \n\t\tans = 
          allportrait[eq, prange, initcond, 500, 1.5, {1/3, 2/3}, False]; 
        ans]\)], "Input"],

Cell[BoxData[
    \(centerportrait[eq_, prange_] := 
      Module[{ans, initcond}, 
        initcond = makecenterinit[eq, prange]; \n\t\tans = 
          allportrait[eq, prange, initcond, 400, 1.5, {1/2}, False]; 
        ans]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

12.  LIMIT CYCLES\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tHere we introduce a minor automation in the production of a limit \
cycle.  The object is to produce the pure limit cycle without the transients \
from an arbitrary startup point.  This is accomplished by performing two \
integrations.  The first integration starts from any guessed initial point.  \
The second integration, which is all that is saved, uses the final point of \
the first integration as an initial value.  Both integrations use the same \
number of user-specified time steps, nsteps, which must be large enough so \
that the first integration puts you on the limit cycle, and the second \
integration carries you through the cycle.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
limcyc[initialvec_,t0_,h_,nsteps_] := 
\t\tModule[{tempans},
\t\ttempans = integrate[initialvec,t0,h,nsteps];
         integrate[lastx,lastt,h,nsteps]]
                                  \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tOnce a pure limit cycle has been constructed, it is relatively \
easy to calculate the period.  The function period[cycsol] takes a solution \
list named cycsol from an autonomous system and calculates the period, with a \
resolution equal to the spacing h, by searching through the list and finding \
the first future point at which the solution is closest to the initial point. \
 It is essential that the solution list be purely periodic (no start-up \
transients) and that it contain at least three points beyond the full period. \
 This works only for autonomous systems.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
period[sol_] := Module[{h,old,new,ind,ans,ruler,len},
len = Length[sol];
ruler = sqnorm[(Drop[sol[[1]],1]-Drop[sol[[5]],1])];
h = First[sol[[2]]] - First[sol[[1]]];
old = sqnorm[(Drop[sol[[1]],1]-Drop[sol[[2]],1])];
new = sqnorm[(Drop[sol[[1]],1]-Drop[sol[[3]],1])];
ind = 3;
While[((new>old)&&(ind<(len-1))),
\t (old = new; ind = ind+1;
\t new = sqnorm[(Drop[sol[[1]],1]-Drop[sol[[ind]],1])])];
\tWhile[(((new<old)||(new>ruler))&&(ind<(len-1))), 
\t  (old = new; ind = ind+1;
\t  new = sqnorm[(Drop[sol[[1]],1]-Drop[sol[[ind]],1])])];
\tIf[(ind<(len-1)),((ind-2)*h),
\t\t(Print[\"Solution not periodic.\"])]]
\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tOften limit cycles depend on one or more parameters, and it is of \
interest to study how the cycle changes as the parameters change.  To make \
that process a little more convenient, we have defined a function limbifurc \
that constructs automatically a sequence of pure limit cycles for each set of \
parameter values in the list parmlist.  The function limbifurc3D does the \
same, except that it produces 3D plots.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
limbifurc[ivec_,t0_,h_,nsteps_,i_,j_,parmlist_,refgraph__: {}] := 
\t(CheckAbort[Module[{k,temgraph,temrefgraph},
\tPrint[\"Limit cycles for parmlist = \", parmlist];
\tDo[(parmval = parmlist[[k]];
\tdisplay = False;
\t\ttemgraph = phaseplot[limcyc[ivec,t0,h,nsteps],i,j];
\t\ttemrefgraph = refgraph //. Thread[parmvec->parmval];
\t\tdisplay = True;
\t\tshow[Flatten[{temgraph,temrefgraph}]]),
\t\t{k,1,Length[parmlist]}]],
\t\t(Print[\"Limit Cycle Bifurcation Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetAttributes[limbifurc, HoldAll];\)\)], "Input"],

Cell["\<\
limbifurc3D[ivec_,t0_,h_,nsteps_,i_,j_,k_,parmlist_,refgraph__: {}] \
:= 
\t(CheckAbort[Module[{q,temgraph,temrefgraph},
 Print[\"Limit cycles for parmlist = \", parmlist];
 Do[(parmval = parmlist[[q]];
 display = False;
 temgraph = phaseplot3D[limcyc[ivec,t0,h,nsteps],i,j,k];
 temrefgraph = refgraph //. Thread[parmvec->parmval];
 display = True;
 show3D[Flatten[{temgraph,temrefgraph}]]),
\t\t\t\t{q,1,Length[parmlist]}]],
\t\t\t\t(Print[\"3D Limit Cycle Bifurcation Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetAttributes[bifurc3D, HoldAll];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

13.  INTERPOLATING FUNCTIONS\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe function buildinterp[sol] builds a list containing an interpolating \
function for each component of the state vector from the solution list named \
sol.  It uses the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " routine Interpolation applied to appropriate parts of sol.  You may \
assign the functions to any vector of names, but you cannot use the state \
variables as function names.  The routine solinterp[sol,stname,slpname] \
builds an interpolating vector for the state and another for the slope \
vector.  To find the state vector at time t, execute stname[t].  To find the \
slope vector at time t, execute slpname[t]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
buildinterp[sol_] := Module[ {terplist,i},
\t\t\t\tterplist = {};
\t\tDo [ terplist = Append[terplist,
\t\t\tInterpolation[Map[pairgen[#,0,i]&,sol]]],
\t\t\t\t\t {i,1,Length[statevec]}];
\t\t\t\tterplist ]
\t\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(conv[name_, time_] := name[time];\)\)], "Input"],

Cell[BoxData[
    \(solinterp[sol_, stname_, slname_] := 
      Module[{locstate}, 
        locstate = buildinterp[sol]; \n\t\tstname[time_] = 
          Map[conv[#, time] &, locstate]; \n\t\tslname[
            time_] = \(slopeval /. Thread[statevec -> stname[time]]\) /. 
            t -> time]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

14.  LINEAR STABILITY\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe functions defined here facilitate the analysis of the stability of a \
known equilbrium point.  The routine dermat uses the current settings of \
statevec and slopevec to construct the derivative matrix of the system, with \
all state variables and parameters left as symbols.  The routine \
dermatval[eqstate] constructs the numerical derivative matrix at the point \
eqstate.  Any parameter symbols appearing either in eqstate or the derivative \
matrix are assigned values from the current setting of parmval.  The \
stability analysis can then be carried out using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in functions Eigenvalues, Eigenvectors or Eigensystem, or you can \
use the slight variations defined here, eigval and eigsys, which take as an \
argument the coordinates of the state at which the analysis is to be done.   \
If you just want to know the stability without seeing the numbers, use \
classify[eqstate].  For two-dimensional systems, you can get more detail by \
executing classify2D[eqstate].  This tells you the nature of the equilibrium \
(node, spiral, saddle) as well as the stability."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
dermat := Module[{len,ans,i,j}, 
\tlen = Length[statevec];
\t\t\t\tans = Table[Range[len],{len}];
\t\t\t\tDo[ans[[i,j]] = 
\t\t\t\tD[slopevec[[i]],statevec[[j]]],
\t\t\t\t\t{i,1,len},{j,1,len}];
\t\t\t\tans\t]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
eqstateval[eqstate_] := eqstate /. 
\t\t\t\t\tThread[parmvec -> parmval]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
dermatval[eqstate_] := dermat /. Thread[statevec -> 
\t\t\t\t\t\teqstateval[eqstate]] /.
\t\t\t\t\t\tThread[parmvec -> parmval]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
rpos[list_] := Module[ {len,ans,i},
\t\tlen = Length[statevec];
\t\t\t\tans = 0;
\t\t\tDo[If[(Re[list[[i]]]>0), ans = ans + 1],
\t\t\t\t{i,1,len}]; ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
rzero[list_] := Module[ {len,ans,i},
\t\tlen = Length[statevec];
\t\t\t\tans = 0;
\t\t\t\tDo[If[(Re[list[[i]]]==0), 
\t\t\t\t\t\t  ans = ans + 1],
\t\t\t\t\t\t{i,1,len}]; ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
classify2D[eqstate_] := Module[{p,q,delt,ans,A,mess,zertst},
\tA = dermatval[eqstate];q = Det[A];
\tp = A[[1,1]]+A[[2,2]];delt = p*p - 4*q;  
\tzertst = (A[[1,1]])^2 + (A[[1,2]])^2
\t\t\t\t\t+ (A[[2,1]])^2 + (A[[2,2]])^2;
mess0 = \"Abbreviations used in classify2D.\";\t\tmess1 =
\"L = linear, NL = nonlinear, R2 = repeated root.\";
mess2 = \"Z1 = one zero root, Z2 = two zero roots.\";
mess3 = \"This message printed once.\"; 
mess4 = \" \";
\tans := \"strictly stable - node\" /;
\t ((delt>0)&&(p<0)&&(q>0));
\tans := \"unstable - node\" /; 
\t((delt>0)&&(p>0)&&(q>0));
\tans := \"unstable - saddle\" /;
\t ((delt>0)&&(q<0));
\tans := \"strictly stable - spiral\" /;
\t ((delt<0)&&(p<0));
\tans := \"unstable - spiral\" /; 
\t((delt<0)&&(p>0));
\tans := 
\t\"unstable - spiral-node transition (R2)\" /;
\t\t\t((delt==0)&&(p>0));
\tans := 
\t\"strictly stable - spiral-node transition (R2)\" 
\t\t/;((delt==0)&&(p<0));
\tans := \"stable (L), indeterminate (NL) - center\"
\t\t\t\t/; ((p==0)&&(q>0));
\tans := 
\t\"unstable - saddle-node transition (Z1)\"
\t /; ((q==0)&&(p>0));
\tans := 
\"stable (L), indeterminate (NL) - saddle-node trans.(Z1)\"
\t /; ((q==0)&&(p<0));
\tans := \"unstable (Z2)\" /; 
\t((q==0)&&(p==0)&&(zertst>0));
\tans := \"stable (L), indeterminate (NL) (Z2)\" 
\t\t\t/; (zertst==0);
     If[(msgflag),(Print[mess0];Print[mess1];
     Print[mess2];Print[mess3];Print[mess4])];
     msgflag = False;Print[ans]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["msgflag = True;", "Input",
  AspectRatioFixed->True],

Cell["\<\
classify[eqstate_] := Module[{eiglist,npos,nzero,ans},
\t\teiglist = Eigenvalues[dermatval[eqstate]];
\t\t\t\tnpos = rpos[eiglist];
\t\t\t\tnzero = rzero[eiglist];
\t\t\t\tIf[(npos>0),(ans = \"unstable\"),
\t\t\t\t\t(If[(nzero>0),(ans = 
\t\"stable (linear) or indeterminate (nonlinear)\"),
\t\t\t\t\t\t(ans = \"strictly stable\")])];
\t\t\t\tPrint[ans]]\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eigval[eqstate_] := \ Eigenvalues[dermatval[eqstate]]\)], "Input"],

Cell[BoxData[
    \(eigsys[eqstate_] := Eigensystem[dermatval[eqstate]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["15.  FINDING EQUILIBRIUM POINTS", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThere are three root-finding routines defined here.  The first, \
findpolyeq, uses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve to attempt to find analytical expressions for equilibrium points \
in terms of the parameter symbols.  The second, nfindpolyeq, uses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s NSolve to find numerical values of equilibrium points, using the \
current parameter values in parmval.  They both work only for polynomial \
slope vectors.  With its easier task, nfindpolyeq is more likely to work in a \
given problem than is findpolyeq.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tFor more general systems, the function nfindeq[init], based on \
the Newton-Raphson technique, works reasonably well with a sufficiently good \
initial guess init.  If you want to change the minimum number of iterations \
nmin, the maximum number of iterations nmax, or the relative accuracy \
criterion eps, just change those parameter values in the defining code below. \
 To check your answer by evaluating the slopevector at the root, (symbolic or \
numerical) type residual[root].  If you want a more accurate answer without \
changing the value of eps, just apply nfindeq to your latest root.  Because \
the routine iterates at least nmin times, no matter what the residual, the \
accuracy of your root will increase.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["zervec := Table[0, {Length[statevec]}];", "Input",
  AspectRatioFixed->True],

Cell["findpolyeq := statevec /. Solve[slopevec==zervec,statevec]", "Input",
  AspectRatioFixed->True],

Cell["nfindpolyeq := statevec /. NSolve[slopeval==zervec,statevec]", "Input",
  AspectRatioFixed->True],

Cell["\<\
nfindeq[init_] := Module[{nmax,nmin,eps,ans,new,old,n,mess},
\t\tmess = \"Halt at max iterations.\";
\t\teps = 1.0*10^(-6); nmin = 3; nmax = 12;
\t\tnew = init; old = init; n = 0;
\t\tWhile[(((n<=nmax)&&
\t\t(sqnorm[new-old]>eps*eps*sqnorm[new]))
\t\t\t||(n<nmin)),
\t\t\t(n = n+1; old = new;
\t\t\tnew = old - Dot[Inverse[dermatval[old]],
\t\t\tslopeval /. Thread[statevec -> old]])];
\t\t\t\tIf[(n=nmax),Print[mess]];
\t\t\t\tnew]    
\t\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
residual[root_] := 
\tSimplify[If[(VectorQ[root,NumberQ]),
\t\t(slopeval /. Thread[statevec -> root]),
\t\t(slopevec /. Thread[statevec -> root])]] 

\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["16.  INDEX THEORY AND ORBIT TRAPPING", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe details of how to define a curve have been given in the \
Overview and won't be repeated here.  Once a curve has been defined, we can \
use it in three ways.  (1) The curve can be plotted by the command \
plotcurve[mycurve].  (2) We may calculate the index of the curve with respect \
to the current slope vector by the command index[mycurve].  (3) We may use \
orbcross[mycurve] to check the direction of the orbits relative to the curve \
normal.  Orbcross returns a brief report of the situation, and is used mainly \
to determine whether an orbit is trapped by a given curve.    \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe two routines arclist and curvlist construct lists of points \
from the curve definition.  The routine arclist does this for a single arc, \
and curvlist constructs a single list from all the component arcs.  These \
lists are used in plotting and in the orbit crossing calculations.  The \
variable ncurpoints (presently set to 100) determines how many points are \
constructed for each arc.  If you think you may not be resolving small scale \
oscillations in your particular slopevector, you can try increasing \
ncurpoints.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ncurpoints = 100;", "Input",
  AspectRatioFixed->True],

Cell["\<\
arclist[arc_] := Module[
\t\t{ans,runrange,posvec,runner,beg,en,h,i},
\t    ans = Range[ncurpoints+1];
\t\tposvec = First[arc];runrange = Last[arc];
\t\trunner = runrange[[1]]; beg = runrange[[2]];
\t\ten = runrange[[3]]; h = N[(en-beg)/(ncurpoints)]; 
\tDo[ans[[i+1]] = posvec /. runner -> beg + h*i,
\t\t\t{i,0,ncurpoints}];
\t\tans] \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
curvlist[curve_] := Module[{ans,len,i},
\t\tlen = Length[curve];
\t\tans = arclist[curve[[1]]];
\t\tIf[(len > 1),
\t\t(Do[ans = 
\t\tJoin[ans,Delete[arclist[curve[[i+1]]],1]],
\t\t\t\t\t   {i,1,len-1}])];
\t\t\t\t\tans]  \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe routine plotcurve[mycurve] plots mycurve in the phase plane, \
using the graphics settings discussed earlier in connection with phaseplot.  \
It ignores the setting of pointcon, and always produces a connected line \
rather than a point plot. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
plotcurve[curve_] := Module[{cvec,dsh},
\t\tcvec = colorvec[[colpoint]];colinc;
\t\tdsh = dashvec[[dashpoint]];dashinc;
\t\t(Show[Graphics[
\t{Thickness[lnthick], 
\tDashing[dsh],
\tcvec, Line[curvlist[curve]]}],
\t\tAxes -> axon,
\t\tFrame -> frameon,
\t\tImageSize -> imsize,
\t\tPlotRange -> plrange,
\t\tAxesOrigin -> axorg,
\t\tBackground -> backcolor, 
\t\tAxesLabel -> If[(axlabon),{statelab[[1]],statelab[[2]]},
\t\tNone,axlabon],
\t\tRotateLabel -> False,
\t\tFrameLabel -> If[(framelabon),{statelab[[1]],statelab[[2]]},
\t\tNone,framelabon],
\t\tPlotLabel -> plotlab,
\t\tDisplayFunction -> 
\t\t(If[display,$DisplayFunction,Identity]),
\t\t\t\t\t\tAspectRatio -> asprat])]\t
 \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we define the tangent and normal vectors for the curve.  Of \
the two possible normals, the one defined here is obtained from the tangent \
vector by a 90 degree clockwise rotation.  With this definition, the normal \
to a positively oriented closed curve (conventionally counterclockwise) is \
the exterior normal. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["tanvec[arc_] := D[First[arc],First[Last[arc]]]; ", "Input",
  AspectRatioFixed->True],

Cell["\<\
normvec[arc_] := {Last[tanvec[arc]],
\t\t\t\t\t-First[tanvec[arc]]}\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe code below defines orbcross.  The first routine, orbarcross, \
does the calculation for a single arc.  Then orbcross combines the results \
for the component arcs.  A more-or-less self-explanatory verbal report is \
returned by orbcross. Because of roundoff, we must redefine very small values \
of the dot product to be zero.  The parameter orbeps is the official zero in \
this calculation.  Be warned that, because of this zero fuzziness, a reported \
tangency could in principle be a very slight leak of an orbit in or out.  \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbeps = 1.0*10^(-8);", "Input",
  AspectRatioFixed->True],

Cell["\<\
orbarcross[arc_] := Module[{runner,tempos,tempnorm,tempslope,
result,sloval,nval,h,ans,npos,nneg,nzer,beg,en,i},
\trunner = First[Last[arc]];
\tbeg = arc[[2,2]]; en = arc[[2,3]];
\ttempos = First[arc]; tempnorm = normvec[arc];
\ttempslope = slopeval /. 
\tThread[statevec -> tempos];
\th = N[(en - beg)/ncurpoints];
\tnpos = 0; nneg = 0; nzer = 0;
\tDo[(sloval = tempslope /. runner -> beg + i*h;
\t\t\tnval = tempnorm /. runner -> beg + i*h;
\t\t\tans = Dot[sloval,nval];
\t\t\tIf[(Abs[ans]<orbeps),(ans = 0)];
\t\t\tIf[(ans > 0),(npos = npos + 1),
\t\t\t\t(If[(ans==0),(nzer = nzer+1),
\t\t\t\t\t  (nneg = nneg+1)])]),
\t\t\t\t\t   \t{i,0,ncurpoints}];
\t\tresult = {npos,nneg,nzer};
\t\tresult]
\t\t\t\t\t    \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
orbcross[curve_] := Module[{crossvec,len,incvec,i},
\t\tlen = Length[curve];
\t\tcrossvec = orbarcross[curve[[1]]];
\t\tIf[(len>1),
\t\t\t(Do[(incvec = orbarcross[curve[[i]]];
\t\t\t\tcrossvec = crossvec+incvec;),
\t\t\t\t\t{i,2,len}])];
\t\tIf[(crossvec[[3]]>0),(Print[
\t\t\"Tangencies:  Yes.\"]), (Print[
\t\t\"Tangencies:  No.\"])];
\t\tIf[(crossvec[[2]]>0), (Print[
\t\t\"Crossings in negative N direction:  Yes.\"]),
(Print[\"Crossings in negative N direction:  No.\"])];
\t\tIf[(crossvec[[1]]>0), (Print[
\t\t\"Crossings in positive N direction:  Yes.\"]),
(Print[\"Crossings in positive N direction:  No.\"])]]
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe final code in this section calculates the index of a curve \
with respect to the current slope vector.  The routine arcindex[arc] \
calculates the rotation of the slope vector in radians as arc is traversed.  \
The routine index[curve] applies arcindex to each arc of the curve, adds the \
results, divides by 2Pi, and then rounds to the nearest integer.  \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
arcindex[arc_] := Module[{ftemp,gtemp,delf,delg,delrot,rot,
\t\t\t\trunner,slopetemp,postemp,
\t\t\t\tnewg,oldg,newf,oldf,h,beg,en,i},
\t\t\t\trunner = First[Last[arc]];
\t\t\t\tpostemp = First[arc];
\t\t\t\tslopetemp = slopeval /. 
\t\t\t\t\tThread[statevec -> postemp];
\t\t\t\tbeg = arc[[2,2]]; en = arc[[2,3]];\t
\t\t\t\th = N[(en - beg)/ncurpoints];\t
\t\t\t\tftemp = slopetemp[[1]];
\t\t\t\tgtemp = slopetemp[[2]];
\t\t\t\tfnew = ftemp /. runner -> beg;
\t\t\t\tgnew = gtemp /. runner -> beg;
\t\t\t\trot = 0.0;
\t\t\tDo[(fold = fnew; gold = gnew;
\t\t\tfnew = ftemp /. runner -> beg + i*h;
\t\t\tgnew = gtemp /. runner -> beg + i*h;
\t\t\tdelf = fnew - fold; delg = gnew - gold;
\t\t\tdelrot = 
\t(fnew*delg - gnew*delf)/(fnew*fnew + gnew*gnew);
\t\t\t\t\trot = rot + delrot;),
\t\t\t\t\t{i,1,ncurpoints}];
\t\t\t\t\trot]\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
index[curve_] := Module[{ans,len,roter,i},
\t\t\t\t\tlen = Length[curve];
\t\t\t\t\troter = arcindex[curve[[1]]];
\t\t\t\t\tIf[(len>1), 
\t\t\t\t\t\t(Do[(roter = 
\t\t\t\t\troter + arcindex[curve[[i]]]),
\t\t\t\t\t\t{i,2,len}])];
\t\t\t\t\tRound[roter/N[2.0*Pi]]]\t\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

17.  BENDIXSON AND DULAC TESTS\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe begin by defining the divergence in n dimensions.  Given any \
vector F in the state variables and parameter symbols, we define div[F] as \
the divergence.  In particular the divergence of the slope vector is \
div[slopevec].  The divergence with the current parameter values substituted \
is dival[F].  Thus  dival[slopevec] = div[slopeval].\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tFor two-dimensional systems, we have Bendixson's test for \
periodic solutions, which requires the examination of the divergence of the \
slope vector for sign changes. In Dulac's test, this is generalized to the \
divergence of a scalar function g times the slope vector, which is calculated \
as div[g slopevec].  To give a quick picture of the sign changes in this \
two-dimensional case, we have defined signcontour[v] for any scalar \
expression v.  This gives a contour plot with areas of positive v being \
white, negative v being gray.  The plotting window for this is taken as the \
current value of plrange.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
div[F_] := Module[{ans,len,i},ans = 0;
\t\tlen = Length[statevec];
\t\tDo[ans = ans + D[F[[i]],statevec[[i]]],
\t\t{i,1,len}];
\t\tans] \
\>", "Input",
  AspectRatioFixed->True],

Cell["dival[F_] := div[F] /. Thread[parmvec -> parmval]", "Input",
  AspectRatioFixed->True],

Cell["clr[0.] = GrayLevel[0.8];", "Input",
  AspectRatioFixed->True],

Cell["clr[1.] = GrayLevel[1.0];", "Input",
  AspectRatioFixed->True],

Cell["\<\
signcontour[v_] := Module[{x,y,vmod},vmod = v /. 
\t\t\t\t\tThread[statevec -> {x,y}]; 
\t\t\t\t\tContourPlot[vmod,{x,
\t\t\t\t\tplrange[[1,1]],plrange[[1,2]]},
\t\t\t\t\t{y,plrange[[2,1]],
\t\t\t\t\tplrange[[2,2]]},Contours -> {0},
\t\t\t\t\tColorFunction -> clr,
\t\t\t\t\tImageSize -> imsize,
\t\t\t\t\tAxes -> axon, 
\t\t\t\t\tFrame -> frameon, AxesLabel -> 
\t\t\t\t\tIf[(axlabon),{statelab[[1]],statelab[[2]]},
\t\t\t\t\tNone,axlabon],
\t\t\t\t\tRotateLabel -> False,
\t\t\t\t\tFrameLabel -> 
\t\t\t\t\tIf[(framelabon),{statelab[[1]],statelab[[2]]},
\t\t\t\t\tNone,framelabon],
\t\t\t\t\tAxesOrigin -> Automatic,
\t\t\t\t\tDisplayFunction -> 
\t\t\t\t\t(If[display,$DisplayFunction,Identity]),
\t\t\t\t\tPlotLabel -> plotlab, \t
\t\t\t\t\tAspectRatio -> asprat]]\t\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

18.  LIAPUNOV FUNCTIONS IN TWO DIMENSIONS\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe function orbdt[V] takes an expression V in the current state \
variables and time,  and returns the orbital time derivative based on the \
current slope vector.  Any parameters in the slope function are left as \
symbols.  The function orbdtval[V] calculates the orbital derivative and \
replaces the parameters in parmvec with the current values in parmval.  These \
functions are defined for systems of any dimension.   \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo include parameters in a function V, specify their symbols in \
the vector liaparmvec and give their values in the vector liaparmval.  \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe function liapsign[V] produces a contour plot in which regions \
of positive V are white, and regions of negative V are grey.  Before \
constructing the plot, current values are substituted both for parmvec in the \
slope, and liapvec in V.  The function liapsignseq[parmlist,V] produces a \
sequence of such contour plots using the parameter values in parmlist.  \
\>",
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe function liapcontours[V] produces a full twenty-contour plot \
of V.  The plotting window for the graphics routines here is taken from the \
setting of plrange.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
orbdt[V_] := Module[{len,ans,i}, 
\t\tlen = Length[statevec];
\t\t\t ans = 0;
\tDo[ans = ans+(D[V,statevec[[i]]])(slopevec[[i]]),
\t\t\t \t{i,1,len}];
\t\t\t ans + D[V,t]]\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
orbdtval[V_] := (orbdt[V] /. Thread[parmvec ->
\t\t\t parmval] /. 
\t\t\t Thread[liaparmvec -> liaparmval])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
liaplab := Module[{ans,l1,l2,seq1,seq2,seq3},
\t\t\tl1 = Length[parmvec]; l2 = Length[liaparmvec];
\tseq1 = SequenceForm[parmvec,\"=\",parmval];
\tseq2 = \"  \";
\tseq3 = SequenceForm[liaparmvec,\"=\",liaparmval];
\t\t\tans := SequenceForm[seq1,seq2,seq3] /;
\t\t\t\t\t((l1>0)&&(l2>0));
\t\t\tans := seq1 /; ((l1>0)&&(l2==0));
\t\t\tans := seq3 /; ((l1==0)&&(l2>0));
\t\t\tans := sysname /; ((l1==0)&&(l2==0));
\t\t\tans]\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
liapsign[V_] := Module[{x,y,vmod},vmod = V /. 
\t\t\t\t\tThread[statevec -> {x,y}] /.
\t\t\t\t\tThread[parmvec -> parmval] /.
\t\t\t\t\tThread[liaparmvec -> liaparmval];
\t\t\t\t\tContourPlot[vmod,{x,
\t\t\t\t\tplrange[[1,1]],plrange[[1,2]]},
\t\t\t\t\t{y,plrange[[2,1]],
\t\t\t\t\tplrange[[2,2]]},Contours -> {0},
\t\t\t\t\tColorFunction -> clr,
\t\t\t\t\tAxes -> axon, Frame -> frameon,
\t\t\t\t\tAxesLabel -> 
\t\t\t\t\tIf[(axlabon),{statelab[[1]],statelab[[2]]},
\t\t\t\t\tNone,axlabon],
\t\t\t\t\tRotateLabel -> False,
\t\t\t\t\tFrameLabel -> 
\t\t\t\t\tIf[(framelabon),{statelab[[1]],statelab[[2]]},
\t\t\t\t\tNone,framelabon],
\t\t\t\t\tImageSize -> imsize,
\t\t\t\t\tAxesOrigin -> Automatic,
\t\t\t\t\tDisplayFunction -> 
\t\t\t\t\t(If[display,$DisplayFunction,Identity]),
\t\t\t\t\tPlotLabel -> liaplab, \t
\t\t\t\t\tAspectRatio -> asprat]]\t
\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
liapsignseq[parmlist_,V_] := Module[{num,i},
\t\t\t\tnum = Length[parmlist];
\t\t\t\tPrint[\"Liapunov Sequence for \",V];
\t\t\t\tDo[(liaparmval = parmlist[[i]];
\t\t\t\tliapsign[V]),{i,1,num}]]
\t\t\t\t\t\t\t \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
liapcontours[V_] := Module[{x,y,vmod},vmod = V /. 
\t\t\t\t\tThread[statevec -> {x,y}] /.
\t\t\t\t\tThread[parmvec -> parmval] /.
\t\t\t\t\tThread[liaparmvec -> liaparmval];
\t\t\t\t\tContourPlot[vmod,{x,
\t\t\t\t\tplrange[[1,1]],plrange[[1,2]]},
\t\t\t\t\t{y,plrange[[2,1]],
\t\t\t\t\tplrange[[2,2]]},
\t\t\t\t\tContourShading -> False,
\t\t\t\t\tContours -> 20,
\t\t\t\t\tImageSize -> imsize,
\t\t\t\t\tAxes -> axon, Frame -> frameon, AxesLabel -> 
\t\t\t\t\tIf[(axlabon),{statelab[[1]],statelab[[2]]},
\t\t\t\t\tNone,axlabon],
\t\t\t\t\tRotateLabel -> False,
\t\t\t\t\tFrameLabel -> 
\t\t\t\t\tIf[(framelabon),{statelab[[1]],statelab[[2]]},
\t\t\t\t\tNone,framelabon],
\t\t\t\t\tAxesOrigin -> Automatic,
\t\t\t\t\tDisplayFunction -> 
\t\t\t\t\t(If[display,$DisplayFunction,Identity]),
\t\t\t\t\tPlotLabel -> liaplab, \t
\t\t\t\t\tAspectRatio -> asprat]]\t\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

19.  POINCAR\[CapitalEAcute] MAPS FOR DRIVEN SYSTEMS\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe define here a Poincar\[EAcute] map for a periodically driven \
system.  The map is produced in two steps.  The first step is to execute the \
function drpoincsol, which produces a solution list appropriate for the map.  \
The second step is drpoincmap which produces the map from the solution list, \
or drpoincmap3D for a three-dimensional view.  To generate a list of the \
Poincar\[EAcute] points rather than a map, use drpoinclist.  A detailed \
description of the use of these functions is given in the Overview, so we \
just give a few remarks on implementation here.  The integration is carried \
out for poincpointper points per period, where poincpointper must be some \
multiple of 24 (including 24 itself).  The value of poincpointper is \
currently set at 48.  The available phases are at 15 degree intervals.     \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn the graphs produced, the default point size is 0.008.  To \
change that, just assign the value you wish to the variable poincptsize.\
\>",
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincpointper = 48;", "Input",
  AspectRatioFixed->True],

Cell["\<\
drpoincsol[initvec_,t0_,tau_,numper_] := Module[
\t{h,nsteps,tauint},
\ttauint = N[tau /. Thread[parmvec -> parmval]];\t
\t\t\t \th = tauint/N[poincpointper];
\t\t\t\tnsteps = poincpointper*(numper+1);
\t\t\t\tintegrate[initvec,t0,h,nsteps]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
drpoinclist[sol_,cycphase_] := Module[{subsol,elem,skipfac,
\tnphase,p},skipfac = poincpointper/24;
\tnphase = Round[Mod[cycphase, 360]/15];
\tlen = Length[sol] - poincpointper;
\tsubsol = {};
\tDo[(elem = sol[[p+skipfac*nphase]];
\t\tsubsol = Append[subsol,elem]),
\t\t{p,1,len,poincpointper}];
\t\t\t\t\tsubsol]\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
drpoincmap[sol_,cycphase_,i_,j_] := (CheckAbort[Module[
\t\t{subsol,nphase,len,deg,tempcon,poincgr,
\t\ttemppt,tempparmvec,tempparmval},
\t\tlen = Length[sol] - poincpointper;
\t\ttempcon = pointcon; temppt = ptsize;
\t\ttempparmunits = parmunits;
\t\ttempparmvec = parmvec; tempparmval = parmval;
\t\tparmunits = Append[parmunits,\"\"];
\t\tUnprotect[parmvec];
\t\tparmvec = Append[parmvec,HoldForm[phase]];
\t\tptsize = poincptsize; pointcon = False;
\t\tnphase = Round[Mod[cycphase, 360]/15];
\t\tdeg = 15*nphase;
\t\tparmval = Append[parmval,PaddedForm[deg,{3,0}]]; 
\t\tpoincgr = phaseplot[drpoinclist[sol,cycphase],i,j];
\t\tpointcon = tempcon; ptsize = temppt;
\t\tparmvec = tempparmvec; Protect[parmvec];
\t\tparmval = tempparmval;
\t\tparmunits = tempparmunits;
\t\tpoincgr],
\t\t(pointcon = tempcon; ptsize = temppt;
\t\tUnprotect[parmvec];parmvec = tempparmvec;
\t\tProtect[parmvec];parmval = tempparmval;
\t\tparmunits = tempparmunits)])\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
drpoincmap3D[sol_,cycphase_,i_,j_,k_] := (CheckAbort[Module[
\t\t{subsol,nphase,len,deg,tempcon,poincgr,
\t\ttemppt,tempparmvec,tempparmval},
\t\tlen = Length[sol] - poincpointper;
\t\ttempcon = pointcon; temppt = ptsize;
\t\ttempparmvec = parmvec; tempparmval = parmval;
\t\ttempparmunits = parmunits;
\t\tUnprotect[parmvec];
\t\tparmvec = Append[parmvec,HoldForm[phase]];
\t\tparmunits = Append[parmunits,\"\"];
\t\tptsize = poincptsize; pointcon = False;
\t\tnphase = Round[Mod[cycphase, 360]/15];
\t\tdeg = 15*nphase;
\t\tparmval = Append[parmval,PaddedForm[deg,{3,0}]]; 
\t\tpoincgr = phaseplot3D[drpoinclist[sol,cycphase],i,j,k];
\t\tpointcon = tempcon; ptsize = temppt;
\t\tparmvec = tempparmvec; 
\t\tProtect[parmvec];parmval = tempparmval;
\t\tparmunits = tempparmunits;
\t\tpoincgr],
\t\t(pointcon = tempcon; ptsize = temppt;Unprotect[parmvec];
\t\tparmvec = tempparmvec;
\t\tProtect[parmvec];parmval = tempparmval;
\t\tparmunits = tempparmunits)])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["20.  POINCAR\[CapitalEAcute] MAPS FOR AUTONOMOUS SYSTEMS", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe define here a Poincar\[EAcute] map for autonomous systems.  \
The basic function, poinclist, operates on any previously calculated solution \
and produces a list of the intersections of the solution with the plane \
specified by the user.  This plane is specified by poincplane = {a,b}, where \
a is the normal vector of the plane, and b is the constant in the plane \
equation a.x + b = 0.  If you wish to distinguish negative from positive \
crossings, you may apply the functions poincplus or poincminus to the list \
produced by poinclist.  To plot the Poincar\[EAcute] map, you may use any of \
the previously defined plotting routines.  To make it easier, we have defined \
poincmap and poincmap3D -- very minor variations of phaseplot and phaseplot3D \
-- which plot unconnected dots.  (To change the dot size, change the value of \
the variable poincptsize.)  For three-dimensional systems, the routine \
poincmapopt3D chooses a viewpoint for the three-dimensional plot aligned \
along the negative of the normal vector a.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
poinclist[sol_] := Module[{norm,con,newside,
\t\t\toldside,crosstest, ans,curx,curxt,
\t\t\toldxt,terpxt,len,lam,i},
\t\t\tlen = Length[sol]; ans = {};
\t\t\tcon = Last[poincplane]; 
\t\t\tnorm = Drop[poincplane,-1];  
\t\t\tcurxt = First[sol]; curx = Drop[curxt,1];
\t\t\tnewside = Dot[norm,curx] + con;
\t\t\tIf[(newside==0),
\t\t\t\t(ans = Append[ans,curxt])];
\t\t\tDo[(oldxt = curxt;curxt = sol[[i]];
\t\t\t\tcurx = Drop[curxt,1];
\t\t\t\toldside = newside;
\t\t\t\tnewside = Dot[norm,curx] + con;
\t\t\t\tcrosstest = oldside*newside;
\t\t\t\tIf[(newside==0),
\t\t\t\t\t(ans = Append[ans,curxt])];
\t\t\t\tIf[(crosstest<0),
\t\t\t\t(lam = (oldside)/(oldside-newside);
\t\t\t\tterpxt = oldxt + lam*(curxt-oldxt);
\t\t\t\t\tans = Append[ans,terpxt])]),
\t\t\t\t{i,2,len}];
\t\t\tans]\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
poincminus[sol_] := Module[
\t{norm,ans,curx,curxt,len,curslope,i},
\tlen = Length[sol]; ans = {};
\tnorm = Drop[poincplane,-1];
\tDo[(curxt = sol[[i]];curx = Drop[curxt,1];
\tcurslope = slopeval /. Thread[statevec -> curx];
\tIf[(Dot[curslope,norm]<0),
\t\t(ans=Append[ans,curxt])]),{i,1,len}];
\t\t\tans]\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
poincplus[sol_] := Module[
\t{norm,ans,curx,curxt,len,curslope,i},
\tlen = Length[sol]; ans = {};
\tnorm = Drop[poincplane,-1];
\tDo[(curxt = sol[[i]];curx = Drop[curxt,1];
\tcurslope = slopeval /. Thread[statevec -> curx];
\tIf[(Dot[curslope,norm]>0),
\t\t(ans=Append[ans,curxt])]),{i,1,len}];
\t\t\tans]\t\t
\t\t\t\t\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
poincmap[sol_,i_,j_] := Module[{ans},
\t\t\t\ttempcon = pointcon;
\t\t\t\ttemppt = ptsize;
\t\t\t\tptsize = poincptsize;
\t\t\t\tpointcon = False;
\t\t\t\tans = phaseplot[sol,i,j];
\t\t\t\tpointcon = tempcon;
\t\t\t\tptsize = temppt;
\t\t\t\tans]
\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
poincmap3D[sol_,i_,j_,k_] := Module[{ans},
\t\t\t\ttempcon = pointcon;
\t\t\t\ttemppt = ptsize;
\t\t\t\tptsize = poincptsize;
\t\t\t\tpointcon = False;
\t\t\t\tans = phaseplot3D[sol,i,j,k];
\t\t\t\tpointcon = tempcon;
\t\t\t\tptsize = temppt;
\t\t\t\tans]
\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
poincview := N[Module[{norm,uninorm},
\tnorm=Drop[poincplane,-1];
\t\tuninorm = norm/(Sqrt[Dot[norm,norm]]);
\t\t\t\t\t33.84*uninorm]]
\t\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
poincmapopt3D[sol_] := Module[{ans,tempview},
\t\t\t\ttempcon = pointcon;
\t\t\t\ttemppt = ptsize;
\t\t\t\ttempview = viewpt;
\t\t\t\tptsize = poincptsize;
\t\t\t\tpointcon = False;
\t\t\t\tviewpt = poincview;
\t\t\t\tans = phaser3D[sol];
\t\t\t\tpointcon = tempcon;
\t\t\t\tptsize = temppt;
\t\t\t\tviewpt = tempview;
\t\t\t\tans]
\t\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["21.  ITERATED MAPPINGS", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tMappings have been implemented here in a way that preserves as \
much as possible of the already existing structure for differential \
equations.  The state variables are specified by setstate, the parameters by \
setparm and parmval, and the mapping itself is assigned to slopevec.  We are \
often interested in studying directly the nth iterated mapping.  The function \
mapcomp[n] defined below gives the nth composition of the mapping assigned to \
slopevec.  Most of the functions defined here may be applied to compositions \
of the basic mapping.  Such functions have an optional final argument ncomp \
which specifies the level of function composition.  In every case, the \
default value is 1 and that value is used if ncomp is not specified.\
\>", \
"Text"],

Cell[BoxData[
    \(mapcomp[n_] := 
      Module[{i, ans}, ans = slopevec; 
        If[\((n > 1)\), \[IndentingNewLine]\((Do[
              ans = \ ans /. Thread[statevec \[Rule] slopevec], {i, 1, 
                n - 1}])\)]; ans]\)], "Input"],

Cell["\<\
\tThe Jacobian of a map is a measure of how the map changes volume \
(or area) in phase space.  The function jacob returns the Jacobian in terms \
of parameter symbols.  The function jacboval evaluates the Jacobian with the \
parameter values in parmval.  \
\>", "Text"],

Cell[BoxData[
    \(jacob := Det[dermat]; 
    jacobval := Det[dermat /. Thread[parmvec -> parmval]];\)], "Input"],

Cell["\<\
\tTo evaluate the map at a single point pt, we have the function \
mapval[pt,ncomp], where ncomp is an optional argument specifying the level of \
function composition.  The vector point may have parameter symbols in \
it.\
\>", "Text"],

Cell[BoxData[
    \(mapval[pt_, ncomp__:\ 1] := 
      Module[{tempslope, tempnew, ans, ptmod}, \[IndentingNewLine]tempslope = 
          slopevec; tempnew = mapcomp[ncomp]; 
        slopevec = tempnew; \[IndentingNewLine]ptmod = 
          pt /. Thread[
              parmvec -> parmval]; \[IndentingNewLine]ans = \((slopeval /. 
              Thread[statevec -> ptmod])\); slopevec = tempslope; 
        ans]\)], "Input"],

Cell["\<\
\tThe basic iteration function is \
iterate[initval,initime,niter,ncomp], which will start with the value initval \
at time initime, and iterate niter times.  The argument ntoss specifies the \
number of initial iterates to be thrown away.   The argument ncomp is \
optional.  When it is specified as a positive integer, the mapping which is \
iterated is the nth composition of the basic map.  Not specifying ncomp has \
the same effect as assigning it the value 1.\
\>", "Text"],

Cell[BoxData[
    \(iterate[initval_, initime_, niter_, ntoss_, ncomp__:\ 1] := 
      Module[{tempslope, tempnew, ans}, deflag = False; 
        fastflag = False; \[IndentingNewLine]bothdirflag = False; 
        If[\((Length[initval] \[Equal] 
              0)\), \((modinit\  = \ {initval})\), \((modinit = 
              initval)\)]; \[IndentingNewLine]tempslope = slopevec; 
        tempnew = mapcomp[ncomp]; 
        slopevec = tempnew; \[IndentingNewLine]ans = 
          integrate[modinit, initime, 1, 
            niter + ntoss]; \[IndentingNewLine]If[\((ntoss\  > \ 
              0)\), \((ans = Drop[ans, ntoss])\)]; slopevec = tempslope; 
        ans]\)], "Input"],

Cell["\<\
\tFor a quick look at the map, and the reference line y = x, we use \
viewmap[ncomp] defined below.  The argument ncomp, specifying the level of \
composition is optional, and the default value is 1.\
\>", "Text"],

Cell[BoxData[
    \(\(viewmap[ncomp__:\ 1] := 
        Module[{left, right, var, func, tempslope, tempnew, nmpt, 
            temsys}, \[IndentingNewLine]If[\((Length[statevec]\  > 
                1)\), \((Return[
                Print["\<viewmap for 1D maps only\>"]])\)]; \
\[IndentingNewLine]temsys = sysname; left = First[First[plrange]]; 
          right = Last[
              First[plrange]]; \[IndentingNewLine]If[\((ncomp\  > \ 
                1)\), \((nmpt\  = \ 
                SequenceForm["\<Comp \>", 
                  ncomp, "\< of \>"])\), \((nmpt = "\<\>")\)]; \
\[IndentingNewLine]sysname = 
            SequenceForm[nmpt, 
              First[slopevec], "\<, \>"]; \[IndentingNewLine]tempslope = 
            slopevec; tempnew = mapcomp[ncomp]; 
          slopevec = tempnew; \[IndentingNewLine]var = 
            First[statevec]; \[IndentingNewLine]func[var_] = 
            First[slopeval /. 
                Thread[statevec \[Rule] {var}]]; \
\[IndentingNewLine]Plot[{func[var], var}, {var, left, right}, 
            PlotRange \[Rule] plrange, \[IndentingNewLine]PlotLabel \[Rule] 
              plotlab, Frame \[Rule] True, 
            ImageSize \[Rule] imsize, \[IndentingNewLine]Background -> 
              backcolor, 
            PlotStyle -> {colorvec[\([colinc]\)]}, \
\[IndentingNewLine]FrameLabel \[Rule] {First[statevec], "\<\>"}, 
            DisplayFunction \[Rule] 
              If[\((display)\), \(($DisplayFunction)\), \((Identity)\)]]; 
          slopevec = tempslope];\)\)], "Input"],

Cell[TextData[{
  "\tThere are three routines for finding fixed points.  The first, \
findpolyfix, uses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Solve to attempt to find analytical expressions for equilibrium points \
in terms of the parameter symbols.  The second, nfindpolyfix, uses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s NSolve to find numerical values of equilibrium points, using the \
current parameter values in parmval.  They both work only for polynomial \
maps.  With its easier task, nfindpolyfix is more likely to work in a given \
problem than is findpolyfix.  Both of these functions take an optional \
argument ncomp, which is used as above to specify that the action is to be \
taken on the nth composition of the basic map.  The default (when ncomp is \
not specified) is ncomp = 1.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tFor more general systems, the function nfindfix[init], based on \
the Newton-Raphson technique, works reasonably well with a sufficiently good \
initial guess init.  If you want to change the minimum number of iterations \
nmin, the maximum number of iterations nmax, or the relative accuracy \
criterion eps, just change those parameter values in the defining code below. \
 If you want a more accurate answer without changing the value of eps, just \
apply nfindfix to your latest fixed point.  Because the routine iterates at \
least nmin times, no matter what the residual, the accuracy of your fixed \
point will increase.  To check the accuracy of your root, execute \
residualfix[root,ncomp].  This will calculate the residual of root.  As \
before, ncomp is optional and specifies the level of composition. \
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
findpolyfix[ncomp__: 1] := Module[{tempslope,tempnew},
tempslope = slopevec;tempnew = mapcomp[ncomp];slopevec = tempnew;
ans = (statevec /. Solve[slopevec == statevec,statevec]);
slopevec = tempslope;ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
nfindpolyfix[ncomp__: 1] := Module[{tempslope,tempnew},
tempslope = slopevec;tempnew = mapcomp[ncomp];slopevec = tempnew;
ans = (statevec /. NSolve[slopeval == statevec,statevec]);
slopevec = tempslope;ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
nfindfix[init_,ncomp__: 1] := \
Module[{nmax,nmin,eps,ans,new,old,n,mess,iden,tempslope,tempnew},
tempslope = slopevec;tempnew = mapcomp[ncomp];slopevec = tempnew;
\t\tmess = \"Halt at max iterations.\";
\t\tiden=IdentityMatrix[Length[statevec]];
\t\teps = 1.0*10^(-6); nmin = 3; nmax = 12;
\t\tnew = init; old = init; n = 0;
\t\tWhile[(((n<=nmax)&&
\t\t(sqnorm[new-old]>eps*eps*sqnorm[new]))
\t\t\t||(n<nmin)),
\t\t\t(n = n+1; old = new;
\t\t\tnew = old - Dot[Inverse[dermatval[old]-iden],
\t\t\t(slopeval -statevec) /. Thread[statevec -> old]])];
\t\t\t\tIf[(n=nmax),Print[mess]];slopevec = tempslope;
\t\t\t\tnew]    \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
residualfix[root_,ncomp__: 1] := Module[{tempslope,tempnew,ans},
tempslope = slopevec;tempnew = mapcomp[ncomp];slopevec = tempnew;
\tans = Simplify[If[(VectorQ[root,NumberQ]),
\t\t((slopeval - statevec) /. Thread[statevec -> root]),
\t\t((slopevec - statevec) /. Thread[statevec -> root])]];
\t\tslopevec = tempslope;ans] 

\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe now define a function which determines the stability of a \
fixed point fxpoint.  The function is classifymap[fxpoint,ncomp], where ncomp \
is, as above, an optional argument specifying the level of composition of the \
basic map.  Eigenvalues may be obtained from eigvalmap[fxpoint,ncomp], and \
both eigenvalues and eigenvectors from eigsysmap[fxpoint,ncomp]. \
\>", "Text"],

Cell["\<\
rgr1[list_] := Module[ {len,ans,i},
\t\tlen = Length[statevec];
\t\t\t\tans = 0;
\t\t\tDo[If[(Abs[list[[i]]] > 1), ans = ans + 1],
\t\t\t\t{i,1,len}]; ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
req1[list_] := Module[ {len,ans,i},
\t\tlen = Length[statevec];
\t\t\t\tans = 0;
\t\t\t\tDo[If[(Abs[list[[i]]] == 1), 
\t\t\t\t\t\t  ans = ans + 1],
\t\t\t\t\t\t{i,1,len}]; ans]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
classifymap[fxpoint_,ncomp__: 1] := 
Module[{eiglist,ngr1,neq1,ans,tempslope,tempnew},
tempslope = slopevec;tempnew = mapcomp[ncomp];slopevec = tempnew;
\t\teiglist = Eigenvalues[dermatval[fxpoint]];
\t\t\t\tngr1 = rgr1[eiglist];
\t\t\t\tneq1 = req1[eiglist];
\t\t\t\tIf[(ngr1>0),(ans = \"unstable\"),
\t\t\t\t\t(If[(neq1>0),(ans = 
\t\"stable (linear) or indeterminate (nonlinear)\"),
\t\t\t\t\t\t(ans = \"strictly stable\")])];
\t\t\t\tslopevec = tempslope; Print[ans]]\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eigvalmap[fxpoint_, ncomp__:\ 1] := 
      Module[{tempslope, tempnew}, 
        tempslope = slopevec; \[IndentingNewLine]tempnew = mapcomp[ncomp]; 
        slopevec = tempnew; \[IndentingNewLine]ans = eigval[fxpoint]; 
        slopevec = tempslope; ans]\)], "Input"],

Cell[BoxData[
    \(eigsysmap[fxpoint_, ncomp__:\ 1] := 
      Module[{tempslope, tempnew}, 
        tempslope = slopevec; \[IndentingNewLine]tempnew = mapcomp[ncomp]; 
        slopevec = tempnew; \[IndentingNewLine]ans = eigsys[fxpoint]; 
        slopevec = tempslope; ans]\)], "Input"],

Cell["\<\
\tWe can test a solution for periodicity by the function periodmap, \
which takes a single argument, the name of the solution.  There are three \
possible outcomes.  If the solution is periodic, periodmap returns a message \
to that effect, and the values of the period.  If the solution contains a \
periodic orbit (and some transients), a message saying so is returned, as is \
the value of the period.  If the solution does not contain a periodic orbit, \
a message so stating is returned.\
\>", "Text"],

Cell[BoxData[
    \(periodchk[sol_] := 
      Module[{modsol, modsol1, eps, i}, modsol = stripsol[sol, 0]; 
        modsol1 = 
          Table[First[modsol], {Length[sol]}]; \[IndentingNewLine]modsol = 
          modsol - modsol1; mag[vec_] := Sqrt[vec . vec]; 
        modsol = Map[mag, modsol]; \[IndentingNewLine]eps = 
          10^\((\(-6\))\)*Max[modsol]; i = 2; 
        While[\((modsol[\([i]\)] > eps)\) && \((i < Length[sol])\), 
          i\  = \ i + 1]; i - 1]\)], "Input"],

Cell[BoxData[
    \(periodmap[sol_] := 
      Module[{ans}, 
        ans = periodchk[
            sol]; \ \[IndentingNewLine]If[\((ans < 
              Length[sol] - 
                1)\), \((Print["\<Solution is periodic; period = \>", 
              ans])\), \[IndentingNewLine]\((ans = periodchk[Reverse[sol]]; 
            If[\((ans < 
                  Length[sol] - 
                    1)\), \((Print["\<Solution contains a periodic orbit; \
period = \>", 
                  ans])\), \n\((Print["\<Solution does not contain a periodic \
orbit.\>"])\)])\)]]\)], "Input"],

Cell["\<\
\tIf we wish to plot several orbits with one command, portraitmap \
and portrait3Dmap are useful.  They are very similar to and based on portrait \
and portrait3D as defined for differential equations.  The definitions are \
given below.  They have an optional argument ncomp, specifying the level of \
function composition.  All the functions have an argument ntoss, which \
specifies the number of initial iterates to be thrown away.  This is \
accomplished by updating the list of initial conditions before calling \
portrait.  The function which does this is updatic.\
\>", "Text"],

Cell[BoxData[
    \(updt[mem_, ntoss_, t0_] := \((integrate[mem, t0, 1, ntoss]; 
        lastx)\)\)], "Input"],

Cell[BoxData[
    \(updtic[init_, ntoss_, t0_] := 
      Map[updt[#, ntoss, t0] &, init]\)], "Input"],

Cell[BoxData[
    StyleBox[\(portraitmap[intlist_, t0_, nsteps_, ntoss_, i_, j_, 
          ncomp__:\ 1] := \[IndentingNewLine]Module[{tempslope, tempnew, 
            modinit, modt0}, \[IndentingNewLine]tempslope = slopevec; 
          tempnew = mapcomp[ncomp]; 
          slopevec = 
            tempnew; \[IndentingNewLine]If[\((ntoss\  > \ 0)\), \((modinit = 
                updtic[intlist, ntoss, t0]; 
              modt0 = t0 + ntoss)\), \((modinit = intlist; 
              modt0 = t0)\)]; \[IndentingNewLine]portrait[modinit, modt0, 1, 
            nsteps, i, j]; slopevec = tempslope]\),
      FontWeight->"Bold",
      FontColor->RGBColor[0, 0, 1]]], "Input"],

Cell[BoxData[
    \(portrait3Dmap[intlist_, t0_, nsteps_, ntoss_, i_, j_, k_, ncomp__:\ 1] := 
      Module[{tempslope, tempnew, modinit, 
          modt0}, \[IndentingNewLine]tempslope = slopevec; 
        tempnew = mapcomp[ncomp]; 
        slopevec = 
          tempnew; \[IndentingNewLine]If[\((ntoss\  > \ 0)\), \((modinit = 
              updtic[intlist, ntoss, t0]; 
            modt0 = t0 + ntoss)\), \((modinit = intlist; 
            modt0 = t0)\)]; \[IndentingNewLine]portrait3D[modinit, modt0, 1, 
          nsteps, i, j, k]; slopevec = tempslope]\)], "Input"],

Cell["\<\
\tTo create a sequence of phase portraits with varying parameters, \
we use bifurcmap and bifurc3Dmap, based on bifurc and bifurc3D.  As above, \
there is an optional argument ncomp.\
\>", "Text"],

Cell["\<\
bifurcmap[intlist_,t0_,nsteps_,ntoss_,i_,j_,parmlist_,ncomp__: 1] \
:= 
\t(CheckAbort[Module[{k,tempslope,tempnew,modinit,modt0},
\tPrint[\"Bifurcation sequence for parmlist = \", parmlist];
\ttempslope=slopevec;tempnew=mapcomp[ncomp];slopevec=tempnew;
\tIf[(ntoss > 0),(modinit=updtic[intlist,ntoss,t0];
      modt0=t0+ntoss),(modinit=intlist;modt0=t0)];
\t\t\tDo[parmval = parmlist[[k]];
\t\t\t\tportraitmap[modinit,modt0,nsteps,ntoss,i,j],
\t\t\t\t{k,1,Length[parmlist]}]],
\t\t\t(Print[\"Bifurcation Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
bifurc3Dmap[intlist_,t0_,nsteps_,ntoss_,i_,j_,k_,parmlist_,ncomp__: \
1] := (CheckAbort[Module[{q,tempslope,tempnew,modinit,modt0},
\tPrint[\"Bifurcation sequence for parmlist = \", parmlist];
\ttempslope=slopevec;tempnew=mapcomp[ncomp];slopevec=tempnew;
\tIf[(ntoss > 0),(modinit=updtic[intlist,ntoss,t0];
      modt0=t0+ntoss),(modinit=intlist;modt0=t0)];
\t\t\tDo[parmval = parmlist[[q]];
\t\t\t\tportrait3Dmap[modinit,modt0,nsteps,ntoss,i,j,k],
\t\t\t\t{q,1,Length[parmlist]}]],
\t\t\t(Print[\"Bifurcation Aborted\"])])
\t\t\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe function cobweb[init,niter,ntoss,ncomp] produces a cobweb \
plot of the current mapping function for 1D maps.  The argument init is the \
initial value, or a list of initial values.  The argument niter is the number \
of iterations to be performed, and ntoss is the number of iterations \
calculated and thrown away first -- that is, a total of ntoss + niter \
iterations are calculated, and niter are kept.  The argument ncomp is \
optional and specifies the level of compostion of the map.  The plotting \
window is taken from plrange, the image size from imsize, and the aspect \
ratio from asprat.  When init is a list, successive orbits are plotted using \
sequentially the colors in colorvec. \
\>", "Text"],

Cell[BoxData[
    \(coblist[list_] := 
      Module[{temp, i}, 
        temp = {{list[\([1]\)], list[\([2]\)]}, {list[\([2]\)], 
              list[\([2]\)]}}; \[IndentingNewLine]Do[
          temp = Append[
              temp, {list[\([i]\)], 
                list[\([i + 1]\)]}]; \[IndentingNewLine]temp = 
            Append[temp, {list[\([i + 1]\)], 
                list[\([i + 1]\)]}], \[IndentingNewLine]{i, 2, 
            Length[list] - 1}]; temp = Drop[temp, \(-1\)]; temp]\)], "Input"],

Cell[BoxData[
    \(cobweb[init_, niter_, ntoss_, ncomp__:\ 1] := 
      Module[{itlist, cobber, func, ans1, ans2, ans, var, left, right, i, 
          teminit, temel, temsys, tempslope, tempnew, nmpt}, 
        temsys = sysname; 
        If[\((ncomp\  > \ 1)\), \((nmpt\  = \ 
              SequenceForm["\<Comp \>", ncomp, "\< of \>"])\), 
          nmpt = \(("\<\>")\)]; \[IndentingNewLine]sysname = 
          SequenceForm[nmpt, 
            First[slopevec], "\<, \>"]; \[IndentingNewLine]If[\((Length[
                statevec]\  > 1)\), \((Return[
              Print["\<cobweb for 1D maps only\>"]])\)]; \
\[IndentingNewLine]tempslope = slopevec; tempnew = mapcomp[ncomp]; 
        slopevec = 
          tempnew; \[IndentingNewLine]If[\((Length[init] \[Equal] 
              0)\), \((modinit\  = \ {init})\), \((modinit = 
              init)\)]; \[IndentingNewLine]left = First[First[plrange]]; 
        right = Last[First[plrange]]; \[IndentingNewLine]var = 
          First[statevec]; \[IndentingNewLine]func[var_] = 
          First[slopeval /. 
              Thread[statevec \[Rule] {var}]]; \[IndentingNewLine]ans1 = 
          Plot[{func[var], var}, {var, left, right}, 
            PlotRange \[Rule] plrange, \[IndentingNewLine]PlotLabel \[Rule] 
              plotlab, Frame \[Rule] True, 
            FrameLabel \[Rule] {First[statevec], "\<\>"}, 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]ans2 = {}; \[IndentingNewLine]Do[
          teminit = modinit[\([i]\)]; \[IndentingNewLine]itlist\  = \ 
            NestList[func, teminit, 
              niter + ntoss]; \[IndentingNewLine]itlist = 
            Drop[itlist, ntoss]; \[IndentingNewLine]cobber = 
            coblist[itlist]; \[IndentingNewLine]If[\((ntoss \[Equal] 
                0)\), \((temel = {First[itlist], 0}; 
              cobber = Prepend[cobber, temel])\)]; \[IndentingNewLine]ans2 = 
            Append[ans2, 
              ListPlot[cobber, PlotRange \[Rule] plrange, 
                PlotLabel \[Rule] plotlab, Frame \[Rule] True, 
                FrameLabel \[Rule] {First[statevec], "\<\>"}, 
                PlotJoined \[Rule] True, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] colorvec[\([colpoint]\)]]]; 
          colinc, {i, 1, Length[modinit]}]; \[IndentingNewLine]Show[{ans1, 
            ans2}, DisplayFunction \[Rule] 
            If[\((display)\), \(($DisplayFunction)\), \((Identity)\)], 
          ImageSize \[Rule] imsize, Background -> backcolor, 
          AspectRatio \[Rule] asprat]; sysname = temsys; 
        slopevec = tempslope]\)], "Input"],

Cell[TextData[{
  "\tBifurcation diagrams are a useful way to show how the system evolves as \
a parameter is changed.   We define below a function \
bimap[npts,ntoss,nparm,xname,xrange,initvec,pname,prange,ncomp] which \
produces such a diagram for any map.  The varying parameter is plotted along \
the abcissa, and the iterates of a any state variable are plotted along the \
ordinate.  Here npts is the number of orbit points per parameter value, and \
ntoss is the number of orbit point discarded before plotting.  The number of \
parameter values to be used is nparm.  The name of the state variable to be \
plotted is xname, and the range of xname to be plotted is xrange.  The \
initial condition for iterations is initvec, which can be a function of the \
parameters.  The name of the parameter to be varied is pname, and the range \
of variation is prange.   Finally ncomp is an optional argument specifying \
the level of function composition used, with a default of 1.  The technique \
used here is more or less brute force.  For a much more efficient and elegant \
technique, see ",
  StyleBox["The Mathematica Programmer II",
    FontWeight->"Bold"],
  ", by Roman Maeder, Chapter 7, Academic Press, 1996."
}], "Text"],

Cell[BoxData[
    \(\(\(bimap[npts_, ntoss_, nparm_, xname_, xrange_, initvec_, pname_, 
        prange_, 
        ncomp__:\ 1]\)\(\ \)\(:=\)\(\[IndentingNewLine]\)\(\ \
\)\(Module[{tempslope, tempnew, pa, pb, pval, pstep, i, xnum, pnum, 
          labber, \[IndentingNewLine]rfunc, nmpt, el, gans, 
          ans}, \[IndentingNewLine]If[\((ncomp\  > \ 1)\), \((nmpt\  = \ 
              SequenceForm["\<Comp \>", 
                ncomp, "\< of \>"])\), \((nmpt = "\<\>")\)]; \
\[IndentingNewLine]labber = 
          SequenceForm[nmpt, slopevec]; \[IndentingNewLine]pa = 
          First[prange]; pb = Last[prange]; 
        pstep = \((pb - pa)\)/\((nparm - 1)\); \[IndentingNewLine]pnum = 
          parmnum[pname]; 
        xnum = statnum[xname]; \[IndentingNewLine]tempslope = slopevec; 
        tempnew = mapcomp[ncomp]; 
        slopevec = tempnew; \[IndentingNewLine]rfunc[list_] := 
          Prepend[list, pval]; \[IndentingNewLine]xtake[
            list_] := {Part[list, xnum + 1]}; 
        ans = {}; \[IndentingNewLine]Do[pval = pa + i*pstep; 
          parmval = ReplacePart[parmval, pval, pnum]; \[IndentingNewLine]el = 
            iterate[initvec, 0, npts, ntoss, ncomp]; \[IndentingNewLine]el = 
            Map[xtake, el]; el\  = \ Map[rfunc, el]; 
          ans = Join[ans, el], {i, 0, 
            nparm - 1}]; \[IndentingNewLine]plrange = {{pa, pb}, xrange}; 
        axon = False; 
        frameon = True; \[IndentingNewLine]gans = 
          ListPlot[ans, Frame \[Rule] True, 
            FrameLabel \[Rule] {pname, 
                xname}, \[IndentingNewLine]PlotLabel \[Rule] labber, 
            PlotRange \[Rule] plrange, RotateLabel -> False; 
            PlotJoined \[Rule] False, ImageSize \[Rule] imsize, 
            AspectRatio \[Rule] 
              asprat, \[IndentingNewLine]DisplayFunction -> \((If[
                  display, $DisplayFunction, 
                  Identity])\), \[IndentingNewLine]Background -> backcolor, 
            PlotStyle -> {PointSize[ptsize], colorvec[\([colpoint]\)]}]; 
        slopevec = tempslope; gans]\)\(\[IndentingNewLine]\)\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{753, 631},
WindowMargins->{{13, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000002n88o001
0000I00000000`<300000BL?00400@00000000000000JV0801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.31.1"->{
    Cell[99550, 2675, 66, 1, 27, "Input",
      CellTags->"S5.31.1"],
    Cell[99619, 2678, 67, 1, 27, "Input",
      CellTags->"S5.31.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.31.1", 255579, 7237}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 294, 12, 35, "Text",
  Evaluatable->False],
Cell[2014, 63, 74, 4, 42, "Input"],

Cell[CellGroupData[{
Cell[2113, 71, 128, 6, 190, "Title",
  Evaluatable->False],
Cell[2244, 79, 330, 8, 214, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2599, 91, 94, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[2696, 95, 1221, 23, 164, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3942, 122, 98, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[4043, 126, 484, 11, 66, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4576, 143, 92, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[4671, 147, 535, 10, 82, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5231, 161, 105, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5339, 165, 1360, 22, 168, "Text",
  Evaluatable->False],
Cell[6702, 189, 957, 15, 116, "Text",
  Evaluatable->False],
Cell[7662, 206, 133, 3, 31, "Text",
  Evaluatable->False],
Cell[7798, 211, 169, 5, 31, "Text",
  Evaluatable->False],
Cell[7970, 218, 398, 8, 65, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[8405, 231, 102, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[8510, 235, 526, 10, 82, "Text",
  Evaluatable->False],
Cell[9039, 247, 107, 3, 31, "Text",
  Evaluatable->False],
Cell[9149, 252, 150, 4, 31, "Text",
  Evaluatable->False],
Cell[9302, 258, 317, 7, 48, "Text",
  Evaluatable->False],
Cell[9622, 267, 143, 3, 31, "Text",
  Evaluatable->False],
Cell[9768, 272, 157, 4, 31, "Text",
  Evaluatable->False],
Cell[9928, 278, 335, 7, 48, "Text",
  Evaluatable->False],
Cell[10266, 287, 149, 3, 31, "Text",
  Evaluatable->False],
Cell[10418, 292, 140, 3, 31, "Text",
  Evaluatable->False],
Cell[10561, 297, 165, 4, 31, "Text",
  Evaluatable->False],
Cell[10729, 303, 214, 6, 31, "Text",
  Evaluatable->False],
Cell[10946, 311, 115, 3, 31, "Text",
  Evaluatable->False],
Cell[11064, 316, 387, 7, 65, "Text",
  Evaluatable->False],
Cell[11454, 325, 55, 1, 31, "Text"],
Cell[11512, 328, 373, 5, 65, "Text"],
Cell[11888, 335, 66, 1, 31, "Text"],
Cell[11957, 338, 100, 3, 31, "Text"],
Cell[12060, 343, 293, 7, 48, "Text",
  Evaluatable->False],
Cell[12356, 352, 1318, 20, 167, "Text",
  Evaluatable->False],
Cell[13677, 374, 324, 7, 48, "Text",
  Evaluatable->False],
Cell[14004, 383, 108, 3, 31, "Text",
  Evaluatable->False],
Cell[14115, 388, 129, 3, 31, "Text",
  Evaluatable->False],
Cell[14247, 393, 110, 3, 31, "Text",
  Evaluatable->False],
Cell[14360, 398, 269, 5, 48, "Text"],
Cell[14632, 405, 208, 6, 31, "Text",
  Evaluatable->False],
Cell[14843, 413, 133, 3, 31, "Text",
  Evaluatable->False],
Cell[14979, 418, 134, 3, 31, "Text",
  Evaluatable->False],
Cell[15116, 423, 161, 4, 31, "Text",
  Evaluatable->False],
Cell[15280, 429, 306, 6, 48, "Text",
  Evaluatable->False],
Cell[15589, 437, 110, 3, 31, "Text",
  Evaluatable->False],
Cell[15702, 442, 206, 4, 31, "Text",
  Evaluatable->False],
Cell[15911, 448, 114, 2, 31, "Text",
  Evaluatable->False],
Cell[16028, 452, 111, 3, 31, "Text",
  Evaluatable->False],
Cell[16142, 457, 301, 7, 48, "Text",
  Evaluatable->False],
Cell[16446, 466, 133, 3, 31, "Text"],
Cell[16582, 471, 55, 1, 31, "Text"],
Cell[16640, 474, 104, 3, 31, "Text"],
Cell[16747, 479, 60, 1, 31, "Text"],
Cell[16810, 482, 249, 5, 48, "Text"],
Cell[17062, 489, 73, 1, 31, "Text"],
Cell[17138, 492, 597, 13, 65, "Text"],
Cell[17738, 507, 72, 1, 31, "Text"],
Cell[17813, 510, 123, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17973, 518, 105, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[18081, 522, 218, 6, 48, "Text",
  Evaluatable->False],
Cell[18302, 530, 131, 3, 31, "Text",
  Evaluatable->False],
Cell[18436, 535, 793, 13, 99, "Text",
  Evaluatable->False],
Cell[19232, 550, 118, 3, 31, "Text"],
Cell[19353, 555, 64, 1, 31, "Text"],
Cell[19420, 558, 126, 3, 31, "Text"],
Cell[19549, 563, 67, 1, 31, "Text"],
Cell[19619, 566, 531, 8, 82, "Text"],
Cell[20153, 576, 419, 7, 65, "Text"],
Cell[20575, 585, 468, 9, 62, "Text",
  Evaluatable->False],
Cell[21046, 596, 136, 3, 31, "Text",
  Evaluatable->False],
Cell[21185, 601, 513, 9, 82, "Text",
  Evaluatable->False],
Cell[21701, 612, 110, 3, 31, "Text",
  Evaluatable->False],
Cell[21814, 617, 233, 6, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[22084, 628, 86, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[22173, 632, 179, 4, 48, "Text"],
Cell[22355, 638, 89, 1, 31, "Text"],
Cell[22447, 641, 168, 4, 31, "Text"],
Cell[22618, 647, 216, 5, 46, "Text"],
Cell[22837, 654, 131, 3, 31, "Text"],
Cell[22971, 659, 124, 4, 31, "Text"],
Cell[23098, 665, 1171, 15, 150, "Text"],
Cell[24272, 682, 269, 5, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24578, 692, 115, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[24696, 696, 534, 10, 82, "Text",
  Evaluatable->False],
Cell[25233, 708, 145, 3, 31, "Text",
  Evaluatable->False],
Cell[25381, 713, 226, 5, 31, "Text",
  Evaluatable->False],
Cell[25610, 720, 391, 8, 65, "Text",
  Evaluatable->False],
Cell[26004, 730, 122, 3, 30, "Text",
  Evaluatable->False],
Cell[26129, 735, 176, 4, 30, "Text",
  Evaluatable->False],
Cell[26308, 741, 541, 10, 78, "Text",
  Evaluatable->False],
Cell[26852, 753, 124, 3, 30, "Text",
  Evaluatable->False],
Cell[26979, 758, 145, 5, 30, "Text",
  Evaluatable->False],
Cell[27127, 765, 132, 3, 30, "Text",
  Evaluatable->False],
Cell[27262, 770, 210, 6, 30, "Text",
  Evaluatable->False],
Cell[27475, 778, 676, 10, 94, "Text"],
Cell[28154, 790, 83, 1, 31, "Text"],
Cell[28240, 793, 115, 3, 31, "Text"],
Cell[28358, 798, 83, 1, 31, "Text"],
Cell[28444, 801, 309, 5, 48, "Text"],
Cell[28756, 808, 97, 3, 31, "Text"],
Cell[28856, 813, 239, 5, 48, "Text"],
Cell[29098, 820, 183, 5, 31, "Text",
  Evaluatable->False],
Cell[29284, 827, 103, 3, 31, "Text",
  Evaluatable->False],
Cell[29390, 832, 293, 7, 48, "Text",
  Evaluatable->False],
Cell[29686, 841, 111, 3, 31, "Text",
  Evaluatable->False],
Cell[29800, 846, 100, 2, 31, "Text",
  Evaluatable->False],
Cell[29903, 850, 178, 6, 31, "Text",
  Evaluatable->False],
Cell[30084, 858, 346, 7, 48, "Text",
  Evaluatable->False],
Cell[30433, 867, 72, 0, 31, "Text"],
Cell[30508, 869, 60, 1, 31, "Text"],
Cell[30571, 872, 318, 7, 48, "Text",
  Evaluatable->False],
Cell[30892, 881, 121, 3, 31, "Text",
  Evaluatable->False],
Cell[31016, 886, 462, 9, 65, "Text",
  Evaluatable->False],
Cell[31481, 897, 70, 1, 31, "Text"],
Cell[31554, 900, 155, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31746, 908, 101, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[31850, 912, 393, 8, 65, "Text",
  Evaluatable->False],
Cell[32246, 922, 129, 3, 31, "Text",
  Evaluatable->False],
Cell[32378, 927, 591, 9, 82, "Text",
  Evaluatable->False],
Cell[32972, 938, 149, 5, 30, "Text",
  Evaluatable->False],
Cell[33124, 945, 109, 3, 30, "Text",
  Evaluatable->False],
Cell[33236, 950, 224, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[33497, 961, 101, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[33601, 965, 154, 5, 30, "Text",
  Evaluatable->False],
Cell[33758, 972, 116, 3, 30, "Text",
  Evaluatable->False],
Cell[33877, 977, 298, 7, 46, "Text",
  Evaluatable->False],
Cell[34178, 986, 126, 3, 30, "Text",
  Evaluatable->False],
Cell[34307, 991, 138, 3, 30, "Text",
  Evaluatable->False],
Cell[34448, 996, 169, 5, 30, "Text",
  Evaluatable->False],
Cell[34620, 1003, 122, 3, 30, "Text",
  Evaluatable->False],
Cell[34745, 1008, 245, 5, 46, "Text",
  Evaluatable->False],
Cell[34993, 1015, 117, 3, 30, "Text",
  Evaluatable->False],
Cell[35113, 1020, 351, 9, 48, "Text",
  Evaluatable->False],
Cell[35467, 1031, 448, 7, 65, "Text"],
Cell[35918, 1040, 703, 10, 99, "Text"],
Cell[36624, 1052, 406, 8, 65, "Text",
  Evaluatable->False],
Cell[37033, 1062, 145, 3, 31, "Text",
  Evaluatable->False],
Cell[37181, 1067, 177, 4, 31, "Text",
  Evaluatable->False],
Cell[37361, 1073, 369, 8, 65, "Text",
  Evaluatable->False],
Cell[37733, 1083, 138, 3, 31, "Text",
  Evaluatable->False],
Cell[37874, 1088, 193, 5, 31, "Text",
  Evaluatable->False],
Cell[38070, 1095, 111, 3, 31, "Text",
  Evaluatable->False],
Cell[38184, 1100, 582, 12, 83, "Text",
  Evaluatable->False],
Cell[38769, 1114, 183, 5, 31, "Text",
  Evaluatable->False],
Cell[38955, 1121, 126, 3, 31, "Text",
  Evaluatable->False],
Cell[39084, 1126, 240, 5, 48, "Text",
  Evaluatable->False],
Cell[39327, 1133, 118, 3, 31, "Text",
  Evaluatable->False],
Cell[39448, 1138, 189, 5, 31, "Text",
  Evaluatable->False],
Cell[39640, 1145, 135, 3, 31, "Text",
  Evaluatable->False],
Cell[39778, 1150, 190, 5, 31, "Text",
  Evaluatable->False],
Cell[39971, 1157, 118, 3, 31, "Text",
  Evaluatable->False],
Cell[40092, 1162, 173, 5, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[40302, 1172, 110, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[40415, 1176, 1541, 23, 201, "Text",
  Evaluatable->False],
Cell[41959, 1201, 2356, 36, 288, "Text",
  Evaluatable->False],
Cell[44318, 1239, 1824, 29, 221, "Text",
  Evaluatable->False],
Cell[46145, 1270, 304, 7, 46, "Text"],
Cell[46452, 1279, 155, 6, 30, "Text"],
Cell[46610, 1287, 64, 0, 30, "Text"],
Cell[46677, 1289, 62, 1, 30, "Text"],
Cell[46742, 1292, 218, 4, 46, "Text"],
Cell[46963, 1298, 70, 1, 30, "Text"],
Cell[47036, 1301, 325, 6, 48, "Text"],
Cell[47364, 1309, 658, 10, 99, "Text"],
Cell[48025, 1321, 117, 4, 31, "Text"],
Cell[48145, 1327, 88, 3, 31, "Text"],
Cell[48236, 1332, 72, 1, 31, "Text"],
Cell[48311, 1335, 418, 8, 66, "Text"],
Cell[48732, 1345, 830, 14, 117, "Text"],
Cell[49565, 1361, 61, 1, 31, "Text"],
Cell[49629, 1364, 117, 3, 31, "Text"],
Cell[49749, 1369, 94, 1, 31, "Text"],
Cell[49846, 1372, 232, 4, 48, "Text"],
Cell[50081, 1378, 1081, 17, 133, "Text",
  Evaluatable->False],
Cell[51165, 1397, 505, 10, 65, "Text",
  Evaluatable->False],
Cell[51673, 1409, 232, 6, 48, "Text",
  Evaluatable->False],
Cell[51908, 1417, 365, 8, 48, "Text",
  Evaluatable->False],
Cell[52276, 1427, 113, 3, 31, "Text",
  Evaluatable->False],
Cell[52392, 1432, 450, 9, 65, "Text",
  Evaluatable->False],
Cell[52845, 1443, 126, 3, 31, "Text",
  Evaluatable->False],
Cell[52974, 1448, 1095, 17, 150, "Text",
  Evaluatable->False],
Cell[54072, 1467, 514, 11, 66, "Text",
  Evaluatable->False],
Cell[54589, 1480, 169, 5, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[54795, 1490, 111, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[54909, 1494, 508, 9, 82, "Text",
  Evaluatable->False],
Cell[55420, 1505, 251, 6, 48, "Text",
  Evaluatable->False],
Cell[55674, 1513, 135, 3, 31, "Text",
  Evaluatable->False],
Cell[55812, 1518, 751, 13, 99, "Text",
  Evaluatable->False],
Cell[56566, 1533, 136, 3, 30, "Text",
  Evaluatable->False],
Cell[56705, 1538, 221, 6, 46, "Text",
  Evaluatable->False],
Cell[56929, 1546, 249, 6, 46, "Text",
  Evaluatable->False],
Cell[57181, 1554, 141, 3, 30, "Text",
  Evaluatable->False],
Cell[57325, 1559, 602, 11, 78, "Text",
  Evaluatable->False],
Cell[57930, 1572, 145, 3, 30, "Text",
  Evaluatable->False],
Cell[58078, 1577, 136, 3, 30, "Text"],
Cell[58217, 1582, 224, 6, 46, "Text",
  Evaluatable->False],
Cell[58444, 1590, 143, 3, 30, "Text",
  Evaluatable->False],
Cell[58590, 1595, 601, 11, 82, "Text",
  Evaluatable->False],
Cell[59194, 1608, 661, 13, 83, "Text",
  Evaluatable->False],
Cell[59858, 1623, 142, 3, 31, "Text",
  Evaluatable->False],
Cell[60003, 1628, 502, 9, 65, "Text",
  Evaluatable->False],
Cell[60508, 1639, 162, 6, 31, "Text",
  Evaluatable->False],
Cell[60673, 1647, 247, 5, 48, "Text",
  Evaluatable->False],
Cell[60923, 1654, 714, 11, 99, "Text"],
Cell[61640, 1667, 69, 1, 31, "Text"],
Cell[61712, 1670, 70, 0, 31, "Text"],
Cell[61785, 1672, 72, 1, 31, "Text"],
Cell[61860, 1675, 1043, 16, 133, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62940, 1696, 111, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[63054, 1700, 360, 8, 48, "Text",
  Evaluatable->False],
Cell[63417, 1710, 134, 3, 31, "Text",
  Evaluatable->False],
Cell[63554, 1715, 540, 9, 82, "Text",
  Evaluatable->False],
Cell[64097, 1726, 176, 5, 31, "Text",
  Evaluatable->False],
Cell[64276, 1733, 121, 3, 31, "Text",
  Evaluatable->False],
Cell[64400, 1738, 577, 9, 82, "Text",
  Evaluatable->False],
Cell[64980, 1749, 300, 7, 48, "Text",
  Evaluatable->False],
Cell[65283, 1758, 139, 5, 31, "Text",
  Evaluatable->False],
Cell[65425, 1765, 140, 3, 31, "Text",
  Evaluatable->False],
Cell[65568, 1770, 227, 5, 48, "Text",
  Evaluatable->False],
Cell[65798, 1777, 131, 3, 31, "Text",
  Evaluatable->False],
Cell[65932, 1782, 133, 3, 31, "Text",
  Evaluatable->False],
Cell[66068, 1787, 486, 9, 65, "Text",
  Evaluatable->False],
Cell[66557, 1798, 110, 3, 31, "Text",
  Evaluatable->False],
Cell[66670, 1803, 581, 9, 82, "Text",
  Evaluatable->False],
Cell[67254, 1814, 121, 3, 31, "Text",
  Evaluatable->False],
Cell[67378, 1819, 485, 8, 65, "Text",
  Evaluatable->False],
Cell[67866, 1829, 126, 3, 31, "Text",
  Evaluatable->False],
Cell[67995, 1834, 128, 3, 31, "Text",
  Evaluatable->False],
Cell[68126, 1839, 163, 4, 31, "Text",
  Evaluatable->False],
Cell[68292, 1845, 577, 10, 82, "Text",
  Evaluatable->False],
Cell[68872, 1857, 113, 3, 31, "Text",
  Evaluatable->False],
Cell[68988, 1862, 175, 4, 31, "Text",
  Evaluatable->False],
Cell[69166, 1868, 118, 3, 31, "Text",
  Evaluatable->False],
Cell[69287, 1873, 342, 7, 48, "Text",
  Evaluatable->False],
Cell[69632, 1882, 115, 3, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[69784, 1890, 108, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[69895, 1894, 695, 16, 84, "Text",
  Evaluatable->False],
Cell[70593, 1912, 99, 3, 31, "Text",
  Evaluatable->False],
Cell[70695, 1917, 337, 7, 48, "Text",
  Evaluatable->False],
Cell[71035, 1926, 111, 3, 31, "Text",
  Evaluatable->False],
Cell[71149, 1931, 141, 5, 31, "Text",
  Evaluatable->False],
Cell[71293, 1938, 104, 3, 31, "Text",
  Evaluatable->False],
Cell[71400, 1943, 251, 6, 48, "Text",
  Evaluatable->False],
Cell[71654, 1951, 111, 3, 31, "Text",
  Evaluatable->False],
Cell[71768, 1956, 265, 5, 48, "Text",
  Evaluatable->False],
Cell[72036, 1963, 106, 3, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[72179, 1971, 108, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[72290, 1975, 955, 16, 133, "Text",
  Evaluatable->False],
Cell[73248, 1993, 127, 3, 31, "Text",
  Evaluatable->False],
Cell[73378, 1998, 109, 3, 31, "Text"],
Cell[73490, 2003, 56, 1, 30, "Text"],
Cell[73549, 2006, 128, 3, 30, "Text"],
Cell[73680, 2011, 56, 1, 30, "Text"],
Cell[73739, 2014, 89, 3, 30, "Text"],
Cell[73831, 2019, 195, 5, 30, "Text",
  Evaluatable->False],
Cell[74029, 2026, 110, 3, 30, "Text",
  Evaluatable->False],
Cell[74142, 2031, 121, 2, 30, "Text",
  Evaluatable->False],
Cell[74266, 2035, 112, 3, 30, "Text",
  Evaluatable->False],
Cell[74381, 2040, 265, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[74683, 2051, 133, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[74819, 2056, 347, 7, 46, "Text",
  Evaluatable->False],
Cell[75169, 2065, 143, 5, 30, "Text",
  Evaluatable->False],
Cell[75315, 2072, 112, 3, 30, "Text",
  Evaluatable->False],
Cell[75430, 2077, 246, 5, 46, "Text",
  Evaluatable->False],
Cell[75679, 2084, 419, 8, 62, "Text",
  Evaluatable->False],
Cell[76101, 2094, 109, 3, 31, "Text",
  Evaluatable->False],
Cell[76213, 2099, 302, 6, 48, "Text",
  Evaluatable->False],
Cell[76518, 2107, 243, 6, 48, "Text",
  Evaluatable->False],
Cell[76764, 2115, 108, 3, 31, "Text",
  Evaluatable->False],
Cell[76875, 2120, 276, 5, 48, "Text",
  Evaluatable->False],
Cell[77154, 2127, 326, 6, 65, "Text"],
Cell[77483, 2135, 682, 12, 99, "Text",
  Evaluatable->False],
Cell[78168, 2149, 142, 3, 31, "Text",
  Evaluatable->False],
Cell[78313, 2154, 530, 9, 82, "Text",
  Evaluatable->False],
Cell[78846, 2165, 732, 12, 99, "Text",
  Evaluatable->False],
Cell[79581, 2179, 124, 3, 31, "Text",
  Evaluatable->False],
Cell[79708, 2184, 302, 7, 48, "Text",
  Evaluatable->False],
Cell[80013, 2193, 129, 3, 31, "Text",
  Evaluatable->False],
Cell[80145, 2198, 202, 4, 31, "Text",
  Evaluatable->False],
Cell[80350, 2204, 125, 3, 31, "Text",
  Evaluatable->False],
Cell[80478, 2209, 237, 5, 48, "Text",
  Evaluatable->False],
Cell[80718, 2216, 122, 3, 31, "Text",
  Evaluatable->False],
Cell[80843, 2221, 174, 5, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[81054, 2231, 108, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[81165, 2235, 470, 9, 65, "Text",
  Evaluatable->False],
Cell[81638, 2246, 578, 10, 82, "Text",
  Evaluatable->False],
Cell[82219, 2258, 551, 10, 82, "Text",
  Evaluatable->False],
Cell[82773, 2270, 123, 3, 31, "Text",
  Evaluatable->False],
Cell[82899, 2275, 273, 6, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[83209, 2286, 119, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[83331, 2290, 522, 10, 82, "Text",
  Evaluatable->False],
Cell[83856, 2302, 551, 10, 82, "Text",
  Evaluatable->False],
Cell[84410, 2314, 485, 9, 65, "Text",
  Evaluatable->False],
Cell[84898, 2325, 436, 9, 65, "Text",
  Evaluatable->False],
Cell[85337, 2336, 128, 3, 31, "Text",
  Evaluatable->False],
Cell[85468, 2341, 285, 7, 48, "Text",
  Evaluatable->False],
Cell[85756, 2350, 178, 5, 31, "Text",
  Evaluatable->False],
Cell[85937, 2357, 116, 3, 31, "Text",
  Evaluatable->False],
Cell[86056, 2362, 177, 4, 31, "Text",
  Evaluatable->False],
Cell[86236, 2368, 210, 6, 31, "Text",
  Evaluatable->False],
Cell[86449, 2376, 107, 3, 31, "Text",
  Evaluatable->False],
Cell[86559, 2381, 174, 5, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[86770, 2391, 86, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[86859, 2395, 943, 14, 133, "Text"],
Cell[87805, 2411, 125, 3, 31, "Text"],
Cell[87933, 2416, 125, 4, 31, "Text"],
Cell[88061, 2422, 217, 4, 48, "Text"],
Cell[88281, 2428, 139, 4, 31, "Text"],
Cell[88423, 2434, 176, 4, 31, "Text"],
Cell[88602, 2440, 657, 10, 99, "Text"],
Cell[89262, 2452, 207, 4, 48, "Text"],
Cell[89472, 2458, 237, 5, 48, "Text"],
Cell[89712, 2465, 57, 0, 31, "Text"],
Cell[89772, 2467, 80, 1, 31, "Text"],
Cell[89855, 2470, 1387, 22, 170, "Text"],
Cell[91245, 2494, 92, 1, 31, "Text"],
Cell[91340, 2497, 1077, 16, 150, "Text"],
Cell[92420, 2515, 90, 3, 31, "Text"],
Cell[92513, 2520, 69, 1, 31, "Text"],
Cell[92585, 2523, 266, 5, 48, "Text"],
Cell[92854, 2530, 241, 5, 48, "Text"],
Cell[93098, 2537, 423, 7, 65, "Text"],
Cell[93524, 2546, 889, 14, 116, "Text"],
Cell[94416, 2562, 663, 10, 99, "Text"],
Cell[95082, 2574, 260, 5, 48, "Text"],
Cell[95345, 2581, 119, 4, 31, "Text"],
Cell[95467, 2587, 866, 13, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96370, 2605, 123, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[96496, 2609, 494, 9, 65, "Text",
  Evaluatable->False],
Cell[96993, 2620, 301, 7, 48, "Text",
  Evaluatable->False],
Cell[97297, 2629, 1729, 25, 218, "Text",
  Evaluatable->False],
Cell[99029, 2656, 309, 8, 49, "Text",
  Evaluatable->False],
Cell[99341, 2666, 64, 1, 27, "Input"],
Cell[99408, 2669, 63, 1, 27, "Input"],
Cell[99474, 2672, 73, 1, 27, "Input"],
Cell[99550, 2675, 66, 1, 27, "Input",
  CellTags->"S5.31.1"],
Cell[99619, 2678, 67, 1, 27, "Input",
  CellTags->"S5.31.1"],
Cell[99689, 2681, 605, 13, 177, "Input"],
Cell[100297, 2696, 744, 18, 252, "Input"],
Cell[101044, 2716, 1685, 34, 492, "Input"],
Cell[102732, 2752, 167, 6, 72, "Input"],
Cell[102902, 2760, 82, 1, 27, "Input"],
Cell[102987, 2763, 157, 2, 43, "Input"],
Cell[103147, 2767, 125, 3, 27, "Input"],
Cell[103275, 2772, 114, 4, 27, "Input"],
Cell[103392, 2778, 88, 1, 27, "Input"],
Cell[103483, 2781, 61, 1, 27, "Input"],
Cell[103547, 2784, 71, 1, 27, "Input"],
Cell[103621, 2787, 68, 1, 27, "Input"],
Cell[103692, 2790, 74, 1, 27, "Input"],
Cell[103769, 2793, 76, 1, 27, "Input"],
Cell[103848, 2796, 75, 1, 27, "Input"],
Cell[103926, 2799, 53, 1, 27, "Input"],
Cell[103982, 2802, 52, 1, 27, "Input"],
Cell[104037, 2805, 79, 1, 27, "Input"],
Cell[104119, 2808, 77, 1, 27, "Input"],
Cell[104199, 2811, 137, 3, 27, "Input"],
Cell[104339, 2816, 73, 1, 27, "Input"],
Cell[104415, 2819, 200, 6, 72, "Input"],
Cell[104618, 2827, 137, 4, 42, "Input"],
Cell[104758, 2833, 75, 1, 27, "Input"],
Cell[104836, 2836, 134, 3, 27, "Input"],
Cell[104973, 2841, 108, 2, 27, "Input"],
Cell[105084, 2845, 205, 6, 57, "Input"],
Cell[105292, 2853, 164, 5, 42, "Input"],
Cell[105459, 2860, 74, 1, 27, "Input"],
Cell[105536, 2863, 86, 1, 27, "Input"],
Cell[105625, 2866, 359, 10, 132, "Input"],
Cell[105987, 2878, 69, 1, 27, "Input"],
Cell[106059, 2881, 411, 11, 147, "Input"],
Cell[106473, 2894, 54, 1, 27, "Input"],
Cell[106530, 2897, 116, 2, 27, "Input"],
Cell[106649, 2901, 144, 3, 27, "Input"],
Cell[106796, 2906, 240, 5, 59, "Input"],
Cell[107039, 2913, 238, 5, 59, "Input"],
Cell[107280, 2920, 700, 12, 171, "Input"],
Cell[107983, 2934, 819, 14, 187, "Input"],
Cell[108805, 2950, 50, 1, 27, "Input"],
Cell[108858, 2953, 64, 1, 27, "Input"],
Cell[108925, 2956, 164, 5, 57, "Input"],
Cell[109092, 2963, 195, 6, 42, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[109336, 2975, 104, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[109443, 2982, 1311, 27, 135, "Text",
  Evaluatable->False],
Cell[110757, 3011, 428, 10, 132, "Input"],
Cell[111188, 3023, 170, 3, 43, "Input"],
Cell[111361, 3028, 263, 4, 59, "Input"],
Cell[111627, 3034, 176, 6, 72, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111840, 3045, 115, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[111958, 3049, 557, 10, 82, "Text",
  Evaluatable->False],
Cell[112518, 3061, 312, 10, 132, "Input"],
Cell[112833, 3073, 382, 11, 147, "Input"],
Cell[113218, 3086, 72, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113327, 3092, 110, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[113440, 3096, 441, 9, 65, "Text",
  Evaluatable->False],
Cell[113884, 3107, 276, 8, 102, "Input"],
Cell[114163, 3117, 342, 10, 132, "Input"],
Cell[114508, 3129, 132, 4, 42, "Input"],
Cell[114643, 3135, 239, 7, 87, "Input"],
Cell[114885, 3144, 438, 13, 177, "Input"],
Cell[115326, 3159, 136, 4, 42, "Input"],
Cell[115465, 3165, 201, 6, 72, "Input"],
Cell[115669, 3173, 349, 10, 132, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116055, 3188, 99, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[116157, 3192, 1632, 24, 201, "Text",
  Evaluatable->False],
Cell[117792, 3218, 459, 9, 65, "Text",
  Evaluatable->False],
Cell[118254, 3229, 725, 12, 99, "Text",
  Evaluatable->False],
Cell[118982, 3243, 253, 6, 48, "Text",
  Evaluatable->False],
Cell[119238, 3251, 228, 4, 48, "Text"],
Cell[119469, 3257, 163, 4, 42, "Input"],
Cell[119635, 3263, 46, 1, 27, "Input"],
Cell[119684, 3266, 93, 1, 27, "Input"],
Cell[119780, 3269, 238, 7, 87, "Input"],
Cell[120021, 3278, 424, 14, 192, "Input"],
Cell[120448, 3294, 190, 6, 72, "Input"],
Cell[120641, 3302, 603, 18, 252, "Input"],
Cell[121247, 3322, 254, 7, 87, "Input"],
Cell[121504, 3331, 566, 16, 222, "Input"],
Cell[122073, 3349, 195, 6, 72, "Input"],
Cell[122271, 3357, 495, 8, 107, "Input"],
Cell[122769, 3367, 1258, 36, 522, "Input"],
Cell[124030, 3405, 734, 14, 100, "Text"],
Cell[124767, 3421, 74, 1, 27, "Input"],
Cell[124844, 3424, 266, 5, 75, "Input"],
Cell[125113, 3431, 520, 10, 139, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125670, 3446, 95, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[125768, 3453, 1523, 20, 184, "Text"],
Cell[127294, 3475, 511, 8, 82, "Text"],
Cell[127808, 3485, 81, 1, 27, "Input"],
Cell[127892, 3488, 64, 1, 27, "Input"],
Cell[127959, 3491, 82, 1, 27, "Input"],
Cell[128044, 3494, 396, 6, 107, "Input"],
Cell[128443, 3502, 1202, 21, 267, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129682, 3528, 116, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[129801, 3532, 331, 7, 48, "Text",
  Evaluatable->False],
Cell[130135, 3541, 380, 8, 65, "Text",
  Evaluatable->False],
Cell[130518, 3551, 299, 5, 48, "Text"],
Cell[130820, 3558, 349, 6, 65, "Text"],
Cell[131172, 3566, 176, 5, 31, "Text",
  Evaluatable->False],
Cell[131351, 3573, 195, 4, 48, "Text"],
Cell[131549, 3579, 705, 16, 84, "Text"],
Cell[132257, 3597, 68, 1, 27, "Input"],
Cell[132328, 3600, 95, 1, 27, "Input"],
Cell[132426, 3603, 231, 7, 87, "Input"],
Cell[132660, 3612, 93, 1, 27, "Input"],
Cell[132756, 3615, 1048, 28, 402, "Input"],
Cell[133807, 3645, 503, 14, 192, "Input"],
Cell[134313, 3661, 89, 1, 27, "Input"],
Cell[134405, 3664, 135, 4, 42, "Input"],
Cell[134543, 3670, 111, 5, 57, "Input"],
Cell[134657, 3677, 73, 1, 27, "Input"],
Cell[134733, 3680, 240, 5, 43, "Input"],
Cell[134976, 3687, 131, 3, 27, "Input"],
Cell[135110, 3692, 303, 6, 75, "Input"],
Cell[135416, 3700, 275, 5, 75, "Input"],
Cell[135694, 3707, 184, 4, 43, "Input"],
Cell[135881, 3713, 194, 4, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136112, 3722, 106, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[136221, 3726, 578, 10, 82, "Text",
  Evaluatable->False],
Cell[136802, 3738, 764, 32, 462, "Input"],
Cell[137569, 3772, 62, 1, 27, "Input"],
Cell[137634, 3775, 61, 1, 27, "Input"],
Cell[137698, 3778, 73, 1, 27, "Input"],
Cell[137774, 3781, 60, 1, 27, "Input"],
Cell[137837, 3784, 48, 1, 27, "Input"],
Cell[137888, 3787, 196, 5, 59, "Input"],
Cell[138087, 3794, 344, 7, 75, "Input"],
Cell[138434, 3803, 254, 6, 59, "Input"],
Cell[138691, 3811, 127, 3, 27, "Input"],
Cell[138821, 3816, 111, 2, 27, "Input"],
Cell[138935, 3820, 212, 5, 59, "Input"],
Cell[139150, 3827, 107, 2, 27, "Input"],
Cell[139260, 3831, 431, 12, 162, "Input"],
Cell[139694, 3845, 54, 1, 27, "Input"],
Cell[139751, 3848, 59, 1, 27, "Input"],
Cell[139813, 3851, 139, 2, 27, "Input"],
Cell[139955, 3855, 117, 2, 27, "Input"],
Cell[140075, 3859, 70, 1, 27, "Input"],
Cell[140148, 3862, 69, 1, 27, "Input"],
Cell[140220, 3865, 108, 2, 27, "Input"],
Cell[140331, 3869, 190, 4, 43, "Input"],
Cell[140524, 3875, 194, 4, 43, "Input"],
Cell[140721, 3881, 94, 3, 31, "Text"],
Cell[140818, 3886, 55, 1, 27, "Input"],
Cell[140876, 3889, 51, 1, 27, "Input"],
Cell[140930, 3892, 55, 1, 27, "Input"],
Cell[140988, 3895, 53, 1, 27, "Input"],
Cell[141044, 3898, 57, 1, 27, "Input"],
Cell[141104, 3901, 59, 1, 27, "Input"],
Cell[141166, 3904, 53, 1, 27, "Input"],
Cell[141222, 3907, 53, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141312, 3913, 97, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[141412, 3917, 1158, 19, 167, "Text",
  Evaluatable->False],
Cell[142573, 3938, 128, 6, 72, "Input"],
Cell[142704, 3946, 140, 4, 42, "Input"],
Cell[142847, 3952, 421, 14, 192, "Input"],
Cell[143271, 3968, 1008, 17, 171, "Input"],
Cell[144282, 3987, 146, 2, 43, "Input"],
Cell[144431, 3991, 507, 9, 107, "Input"],
Cell[144941, 4002, 180, 3, 43, "Input"],
Cell[145124, 4007, 441, 13, 177, "Input"],
Cell[145568, 4022, 236, 9, 117, "Input"],
Cell[145807, 4033, 862, 23, 327, "Input"],
Cell[146672, 4058, 579, 17, 237, "Input"],
Cell[147254, 4077, 77, 1, 27, "Input"],
Cell[147334, 4080, 341, 11, 147, "Input"],
Cell[147678, 4093, 360, 11, 147, "Input"],
Cell[148041, 4106, 502, 17, 237, "Input"],
Cell[148546, 4125, 83, 1, 27, "Input"],
Cell[148632, 4128, 381, 12, 162, "Input"],
Cell[149016, 4142, 941, 16, 133, "Text",
  Evaluatable->False],
Cell[149960, 4160, 273, 8, 102, "Input"],
Cell[150236, 4170, 335, 10, 132, "Input"],
Cell[150574, 4182, 834, 17, 101, "Text",
  Evaluatable->False],
Cell[151411, 4201, 381, 11, 147, "Input"],
Cell[151795, 4214, 335, 11, 147, "Input"],
Cell[152133, 4227, 729, 21, 297, "Input"],
Cell[152865, 4250, 597, 11, 123, "Input"],
Cell[153465, 4263, 497, 10, 107, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153999, 4278, 98, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[154100, 4285, 679, 13, 83, "Text",
  Evaluatable->False],
Cell[154782, 4300, 69, 1, 27, "Input"],
Cell[154854, 4303, 847, 25, 357, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155738, 4333, 88, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[155829, 4337, 720, 13, 116, "Text",
  Evaluatable->False],
Cell[156552, 4352, 1178, 32, 462, "Input"],
Cell[157733, 4386, 1098, 33, 477, "Input"],
Cell[158834, 4421, 418, 8, 65, "Text",
  Evaluatable->False],
Cell[159255, 4431, 554, 14, 192, "Input"],
Cell[159812, 4447, 68, 1, 27, "Input"],
Cell[159883, 4450, 557, 15, 192, "Input"],
Cell[160443, 4467, 70, 1, 27, "Input"],
Cell[160516, 4470, 631, 11, 82, "Text",
  Evaluatable->False],
Cell[161150, 4483, 1215, 38, 552, "Input"],
Cell[162368, 4523, 1244, 39, 552, "Input"],
Cell[163615, 4564, 649, 10, 99, "Text"],
Cell[164267, 4576, 151, 3, 43, "Input"],
Cell[164421, 4581, 971, 17, 251, "Input"],
Cell[165395, 4600, 791, 13, 235, "Input"],
Cell[166189, 4615, 606, 10, 155, "Input"],
Cell[166798, 4627, 422, 8, 107, "Input"],
Cell[167223, 4637, 1218, 22, 283, "Input"],
Cell[168444, 4661, 1376, 23, 411, "Input"],
Cell[169823, 4686, 241, 5, 59, "Input"],
Cell[170067, 4693, 242, 5, 59, "Input"],
Cell[170312, 4700, 1195, 21, 331, "Input"],
Cell[171510, 4723, 244, 5, 59, "Input"],
Cell[171757, 4730, 240, 5, 59, "Input"],
Cell[172000, 4737, 239, 5, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172276, 4747, 94, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[172373, 4754, 722, 12, 99, "Text",
  Evaluatable->False],
Cell[173098, 4768, 237, 7, 87, "Input"],
Cell[173338, 4777, 652, 11, 82, "Text",
  Evaluatable->False],
Cell[173993, 4790, 663, 18, 252, "Input"],
Cell[174659, 4810, 494, 9, 65, "Text",
  Evaluatable->False],
Cell[175156, 4821, 534, 14, 192, "Input"],
Cell[175693, 4837, 71, 1, 27, "Input"],
Cell[175767, 4840, 543, 15, 192, "Input"],
Cell[176313, 4857, 70, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176420, 4863, 105, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[176528, 4870, 727, 14, 83, "Text",
  Evaluatable->False],
Cell[177258, 4886, 267, 9, 117, "Input"],
Cell[177528, 4897, 70, 1, 27, "Input"],
Cell[177601, 4900, 309, 6, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177947, 4911, 98, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[178048, 4918, 1225, 20, 151, "Text",
  Evaluatable->False],
Cell[179276, 4940, 260, 9, 117, "Input"],
Cell[179539, 4951, 123, 4, 42, "Input"],
Cell[179665, 4957, 178, 5, 57, "Input"],
Cell[179846, 4964, 203, 7, 87, "Input"],
Cell[180052, 4973, 226, 8, 102, "Input"],
Cell[180281, 4983, 1483, 43, 627, "Input"],
Cell[181767, 5028, 58, 1, 27, "Input"],
Cell[181828, 5031, 409, 11, 147, "Input"],
Cell[182240, 5044, 86, 1, 27, "Input"],
Cell[182329, 5047, 84, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182450, 5053, 99, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[182552, 5057, 683, 15, 84, "Text",
  Evaluatable->False],
Cell[183238, 5074, 799, 13, 110, "Text",
  Evaluatable->False],
Cell[184040, 5089, 82, 1, 27, "Input"],
Cell[184125, 5092, 101, 1, 27, "Input"],
Cell[184229, 5095, 103, 1, 27, "Input"],
Cell[184335, 5098, 498, 15, 207, "Input"],
Cell[184836, 5115, 201, 8, 102, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185074, 5128, 104, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[185181, 5132, 661, 11, 82, "Text",
  Evaluatable->False],
Cell[185845, 5145, 604, 11, 82, "Text",
  Evaluatable->False],
Cell[186452, 5158, 60, 1, 27, "Input"],
Cell[186515, 5161, 387, 11, 147, "Input"],
Cell[186905, 5174, 272, 10, 132, "Input"],
Cell[187180, 5186, 321, 7, 48, "Text",
  Evaluatable->False],
Cell[187504, 5195, 738, 25, 357, "Input"],
Cell[188245, 5222, 394, 8, 65, "Text",
  Evaluatable->False],
Cell[188642, 5232, 91, 1, 27, "Input"],
Cell[188736, 5235, 118, 4, 42, "Input"],
Cell[188857, 5241, 609, 11, 82, "Text",
  Evaluatable->False],
Cell[189469, 5254, 64, 1, 27, "Input"],
Cell[189536, 5257, 763, 22, 312, "Input"],
Cell[190302, 5281, 678, 19, 267, "Input"],
Cell[190983, 5302, 437, 9, 65, "Text",
  Evaluatable->False],
Cell[191423, 5313, 885, 25, 357, "Input"],
Cell[192311, 5340, 316, 10, 132, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192664, 5355, 107, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[192774, 5362, 419, 8, 65, "Text",
  Evaluatable->False],
Cell[193196, 5372, 691, 12, 99, "Text",
  Evaluatable->False],
Cell[193890, 5386, 187, 7, 87, "Input"],
Cell[194080, 5395, 92, 1, 27, "Input"],
Cell[194175, 5398, 68, 1, 27, "Input"],
Cell[194246, 5401, 68, 1, 27, "Input"],
Cell[194317, 5404, 821, 23, 327, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195175, 5432, 118, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[195296, 5439, 500, 9, 65, "Text",
  Evaluatable->False],
Cell[195799, 5450, 214, 6, 31, "Text",
  Evaluatable->False],
Cell[196016, 5458, 444, 9, 65, "Text",
  Evaluatable->False],
Cell[196463, 5469, 238, 6, 48, "Text",
  Evaluatable->False],
Cell[196704, 5477, 226, 8, 102, "Input"],
Cell[196933, 5487, 158, 5, 57, "Input"],
Cell[197094, 5494, 476, 13, 177, "Input"],
Cell[197573, 5509, 903, 26, 372, "Input"],
Cell[198479, 5537, 261, 8, 102, "Input"],
Cell[198743, 5547, 909, 25, 357, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[199689, 5577, 129, 5, 87, "Subtitle",
  Evaluatable->False],
Cell[199821, 5584, 905, 15, 116, "Text",
  Evaluatable->False],
Cell[200729, 5601, 212, 6, 31, "Text",
  Evaluatable->False],
Cell[200944, 5609, 62, 1, 27, "Input"],
Cell[201009, 5612, 292, 8, 102, "Input"],
Cell[201304, 5622, 366, 11, 147, "Input"],
Cell[201673, 5635, 1000, 26, 372, "Input"],
Cell[202676, 5663, 1018, 27, 387, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203731, 5695, 124, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[203858, 5699, 1109, 17, 133, "Text",
  Evaluatable->False],
Cell[204970, 5718, 843, 25, 357, "Input"],
Cell[205816, 5745, 363, 11, 147, "Input"],
Cell[206182, 5758, 377, 12, 162, "Input"],
Cell[206562, 5772, 302, 12, 162, "Input"],
Cell[206867, 5786, 309, 12, 162, "Input"],
Cell[207179, 5800, 196, 7, 87, "Input"],
Cell[207378, 5809, 385, 15, 207, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207800, 5829, 90, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[207893, 5833, 779, 12, 116, "Text"],
Cell[208675, 5847, 244, 5, 43, "Input"],
Cell[208922, 5854, 280, 5, 48, "Text"],
Cell[209205, 5861, 114, 2, 27, "Input"],
Cell[209322, 5865, 246, 5, 48, "Text"],
Cell[209571, 5872, 423, 8, 75, "Input"],
Cell[209997, 5882, 490, 8, 82, "Text"],
Cell[210490, 5892, 675, 12, 123, "Input"],
Cell[211168, 5906, 223, 4, 48, "Text"],
Cell[211394, 5912, 1528, 29, 235, "Input"],
Cell[212925, 5943, 904, 18, 118, "Text",
  Evaluatable->False],
Cell[213832, 5963, 891, 15, 116, "Text",
  Evaluatable->False],
Cell[214726, 5980, 255, 6, 72, "Input"],
Cell[214984, 5988, 257, 6, 72, "Input"],
Cell[215244, 5996, 671, 17, 237, "Input"],
Cell[215918, 6015, 375, 10, 132, "Input"],
Cell[216296, 6027, 391, 6, 65, "Text"],
Cell[216690, 6035, 206, 7, 87, "Input"],
Cell[216899, 6044, 228, 8, 102, "Input"],
Cell[217130, 6054, 526, 13, 177, "Input"],
Cell[217659, 6069, 287, 5, 59, "Input"],
Cell[217949, 6076, 287, 5, 59, "Input"],
Cell[218239, 6083, 516, 8, 82, "Text"],
Cell[218758, 6093, 484, 9, 91, "Input"],
Cell[219245, 6104, 576, 13, 91, "Input"],
Cell[219824, 6119, 595, 9, 82, "Text"],
Cell[220422, 6130, 110, 2, 27, "Input"],
Cell[220535, 6134, 101, 2, 27, "Input"],
Cell[220639, 6138, 671, 12, 107, "Input"],
Cell[221313, 6152, 571, 10, 107, "Input"],
Cell[221887, 6164, 206, 4, 48, "Text"],
Cell[222096, 6170, 577, 14, 177, "Input"],
Cell[222676, 6186, 583, 13, 177, "Input"],
Cell[223262, 6201, 729, 11, 99, "Text"],
Cell[223994, 6214, 496, 10, 91, "Input"],
Cell[224493, 6226, 2616, 45, 443, "Input"],
Cell[227112, 6273, 1232, 19, 168, "Text"],
Cell[228347, 6294, 2109, 37, 363, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

