(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67187,       1837]*)
(*NotebookOutlinePosition[     92067,       2738]*)
(*  CellTagsIndexPosition[     92023,       2734]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Index of Principal
User Functions \
\>", "Title"],

Cell[TextData[{
  "\tIn this notebook, we give an alphabetical listing of all the principal \
user objects (variables and functions) in this package, along with a very \
brief description.  This is intended as a quick reference, and it does not \
replace the more detailed descriptions in the Overview (Section 2 of \
DynSys.nb).  For each object, we give the section of DynSys.nb in which the ",
  
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code is specified, and a list of the tutorials in which the object is \
used.       "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "allcolors",
  StyleBox[" -- Lists all available colors.  From the ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" package Graphics`Colors`.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["animate",
    FontWeight->"Bold"],
  "[sol,i,j,k,ng] -- Constructs from components i,j, and k of the solution \
sol a rotation sequence of three-dimensional phase plots, suitable for \
animation.  The number of graphs in the sequence is ng, with the increment of \
rotation about the z-axis being 360/ng degrees.  Section 9.  Tutorials 2 and \
14."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "arclen",
  StyleBox[
  "[sol] -- Returns the arclength of the solution sol.  Section 7.  Tutorial \
1.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "arrowflag ",
  StyleBox["-- Logical variable controlling arrows on two-dimensional phase \
plots.  When set to True, arrows are placed at regular time intervals of \
length = (time step)*(arrowinc).  The default value is False.  The shape of \
the arrowhead can be adjusted by changing the options in arropt.  Section 8.  \
Tutorials 1, 4, 8, 11 and 15.  ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "arrowvec ",
  StyleBox["-- Variable used in arrow plotting in two-dimensional phase \
plots.  If arrowflag = True, arrows are placed at positions specified by \
arrowvec.  Arrowvec is a list of numbers from 0 to 1 inclusive, in ascending \
order.  The numbers specify the fractional arclength from the beginning of \
the orbit at which to place arrows.  The default value is {1/3, 2/3).  \
Section 8.  Tutorials 1, 4, 8, 11 and 15.  ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["asprat",
    FontWeight->"Bold"],
  " -- Variable controlling aspect ratio of two-dimensional plots.  Can be \
set to a number (ratio of vertical to horizontal) or to Automatic.  Default \
is Automatic.  Section 8.  Tutorials 0, 1, 2, 5, 6, 7, 9, 10, 13, 14, 15, 16, \
and 17.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "axlabon",
  StyleBox[" -- Flag controlling axes labels.  If axlabon = True, the default \
labels are used.  If axlabon = False, no axis labels are printed.  If axlabon \
= \"user specified labels\", the user specified labels are used.  Section 2.  \
Tutorial 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["axon",
    FontWeight->"Bold"],
  " -- Logical variable controlling the appearance of axes in plots.  True \
for axes, False for no axes.  The default is True.  Section 8.  Tutorials 4 \
and 6."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axorg",
    FontWeight->"Bold"],
  " -- Variable controlling axes origin in two-dimensional plots.  Can be set \
to a list of two values, or to Automatic, which is the default.  Section 8.  \
Tutorial 6. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["backcolor",
    FontWeight->"Bold"],
  " -- Variable containing the color to be used in the background of plots.  \
The default value is White.  The value is set by the command setback.  To set \
to blue, for example, execute setback[Blue].  Section 8.  Tutorial 7. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["bifurc",
    FontWeight->"Bold"],
  "[intlist,t0,h,nsteps,i,j,parmlist,refgraph] -- Produces a sequence of \
two-dimensional phase plots of components i and j.  A value of zero for \
either i or j gives a plot with time for that coordinate.  For each plot, \
orbits are constructed for each set of initial conditions in the list \
intlist.  Each of the arguments t0, h, and nsteps may be a single expression, \
or a list of expressions of the same length as intlist.  When the argument is \
a list, the values are used in succession as the integrations are performed.  \
Any expression appearing in any of the first four arguments may contain \
parameter symbols.  These will be replaced by current values when the \
integration is performed.  A plot is constructed for each set of values of \
parmval in parmlist.  The argument refgraph is optional.  When present, it is \
taken to be the name of a graph which is then superimposed on each graph \
produced.  It may be a graph which has already been defined, or it may be a \
function which depends on the parameter vector and which returns a graph.  \
Section 11.  Tutorial 10.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["bifurcmap",
    FontWeight->"Bold"],
  "[intlist,t0,niter,ntoss,i,j,parmlist,ncomp] -- Produces a sequence of \
two-dimensional phase plots for a map of components i and j.  A value of zero \
for either i or j gives a plot with time for that coordinate.  For each plot, \
orbits are constructed for each set of initial conditions in the list \
intlist.  The first ntoss iterations are thrown away, and then niter \
iterations are kept.  Each of the arguments t0 and niter may be a single \
expression, or a list of expressions of the same length as intlist.  When the \
argument is a list, the values are used in succession as the iterations are \
performed.  Any expression appearing in any of the first three arguments may \
contain parameter symbols.  These will be replaced by current values when the \
integration is performed.  A plot is constructed for each set of values of \
parmval in parmlist.   The argument ncomp is an optional argument giving the \
level of function composition of the basic map.  Section 21.  Tutorial 17.   \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["bifurc3D",
    FontWeight->"Bold"],
  "[intlist,t0,h,nsteps,i,j,k,parmlist] -- Produces a sequence of \
three-dimensional phase plots of components i,j and k.  To make one of the \
coordinates time rather than a state variable, use i, j, or k equal to zero.  \
For each plot, orbits are constructed for each set of initial conditions in \
the list intlist.  Each of the arguments t0, h, and nsteps may be a single \
expression, or a list of expressions of the same length as intlist.  When the \
argument is a list, the values are used in succession as the integrations are \
performed.  Any expression appearing in any of the first four arguments may \
contain parameter symbols.  These will be replaced by current values when the \
integration is performed.  A plot is constructed for each set of values of \
parmval in parmlist.   The argument refgraph is optional.  When present, it \
is taken to be the name of a graph which is then superimposed on each graph \
produced.  It may be a graph which has already been defined, or it may be a \
function which depends on the parameter vector and which returns a graph.  \
Section 11.  Tutorials 10 and 12.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["bifurc3Dmap",
    FontWeight->"Bold"],
  "[intlist,t0,niter,ntoss,i,j,k,parmlist,ncomp] -- Produces a sequence of \
three-dimensional phase plots of components i,j and k for a map.  To make one \
of the coordinates time rather than a state variable, use i, j, or k equal to \
zero.  For each plot, orbits are constructed for each set of initial \
conditions in the list intlist.  The first ntoss iterations are thrown away, \
and then niter iterations are kept. Each of the arguments t0 and niter may be \
a single expression, or a list of expressions of the same length as intlist.  \
When the argument is a list, the values are used in succession as the \
integrations are performed.  Any expression appearing in any of the first \
three arguments may contain parameter symbols.  These will be replaced by \
current values when the iteration is performed.  A plot is constructed for \
each set of values of parmval in parmlist.  The argument ncomp is an optional \
argument giving the level of function composition of the basic map.  Section \
21.  Tutorial 17.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["bimap",
    FontWeight->"Bold"],
  "[npts,ntoss,nparm,xname,xrange,initvec,pname,prange,ncomp] -- Produces a \
bifurcation plot of iterates versus parameter values.  Works for any \
dimension map, although only one state variable is plotted, namely the one \
specified by xname.  It is plotted on the ordinate and the varying parameter \
pname is plotted on the abcissa.  For each parameter value, npts + ntoss \
values are calculated from the starting value initvec, and then ntoss are \
discarded to eliminate transients.  This is done for a number of parameter \
values nparm.  The range of parameter variation is prange.  The argument \
ncomp is an optional argument specifying the level of function composition.  \
The default is 1.  The image size is controlled by imsize, the aspect ratio \
by asprat, and the size of the plotted points by ptsize.  Section 21.  \
Tutorial 17."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["bothdirflag",
    FontWeight->"Bold"],
  " -- Logical variable controlling direction of integration.  When True, \
integration is carried out in both time directions from the initial time.  \
Default is False.  Section 6.  Tutorial 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["boxrat",
    FontWeight->"Bold"],
  " -- Variable controlling the aspect ratios of the enclosing box in \
three-dimensional plots.  Can be a list of three values (giving relative \
sizes of three box dimensions) or can be set to Automatic.  Default is \
Automatic.  Section 8.  Tutorials 2, 9, 10, 12, 13, 14, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["buildinterp",
    FontWeight->"Bold"],
  "[sol] -- Builds from the solution sol an interpolating function for the \
state vector as a function of time.  See also solinterp.  Section 13.  \
Tutorial 1.  "
}], "Text"],

Cell[TextData[{
  "centerportrait",
  StyleBox[
  "[eq,window] -- Gives a basic phase portrait for a 2D center at the \
equilibrium point eq, using the window for the plot range.  Section 11.  \
Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["classify",
    FontWeight->"Bold"],
  "[eqstate] -- Classify the equilibrium point eqstate with respect to \
stability.  The argument eqstate may contain parameter symbols, which are \
then evaluated from parmval.  Section 14.  Tutorials 3, 10, and 13. "
}], "Text"],

Cell[TextData[{
  StyleBox["classifymap",
    FontWeight->"Bold"],
  "[fxpoint,ncomp] -- Classify the fixed point fxpoint with respect to \
stability.  The argument fxpoint may contain parameter symbols, which are \
then evaluated from parmval.  The optional argument ncomp is the level of \
function composition to be used, with the default ncomp = 1.  Section 21.  \
Tutorial 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["classify2D",
    FontWeight->"Bold"],
  "[eqstate] -- Classify the equilibrium point eqstate of a two-dimensional \
system.  This gives more information than classify (i.e., node, saddle, \
spiral, etc.).  Section 14.  Tutorials 0, 3, 4, 8, 10, and 11."
}], "Text"],

Cell[TextData[{
  StyleBox["cobweb",
    FontWeight->"Bold"],
  "[init,niter,ntoss,ncomp] -- Produces a cobweb plot of the current mapping \
function.   It is only for 1D maps.  The argument init is the initial value, \
or a list of initial values.  The argument niter is the number of iterations \
to be performed,and ntoss is the number of iterations calculated and thrown \
away first -- that is, a total of ntoss+niter iterations are calculated, and \
niter are kept.  The optional argument ncomp is the level of function \
composition, with the default ncomp = 1.  The plotting window is taken from \
plrange,the image size from imsize, and the aspect ratio from asprat.  When \
init is a list, successive orbits are plotted using sequentially the colors \
in colorvec.  Section 21.  Tutorial 17."
}], "Text"],

Cell[TextData[{
  "colorvec",
  StyleBox[
  " -- A plot control variable specifying a list of colors to be used in \
plotting.  It is a set of  RGB colors.  If it contains a single color, that \
color will be used for all plots.  If it contains more than one color, the \
colors will be used cyclically for plots.  The default value of colorvec is \
{RGBColor[0,0,0]}, which plots everything in black.  Colors are based on the \
",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[
  " package Graphics`Colors` which is automatically loaded at startup.  To \
see a list of all available colors, type AllColors or allcolors.  Section 8.  \
Tutorials 1, 2,  8,  9, 10, 12, and 14.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "colorvecdis",
  StyleBox[
  " -- Vector containing current color settings by name.  Section 8.  \
Tutorial 1. ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "dashalt",
  StyleBox[
  " -- Dashing pattern (to be used in argument of setdash) which produces \
alternate long and short dashes.  Section 8.  Tutorial 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "dashlong",
  StyleBox[
  " -- Dashing pattern (to be used in argument of setdash) which produces \
long dashes.  Section 8.  Tutorial 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "dashort",
  StyleBox[
  " -- Dashing pattern (to be used in argument of setdash) which produces \
short dashes.  Section 8.  Tutorial 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "dashvec",
  StyleBox[
  " -- A plot control variable specifying a list of dashing patterns for \
dashing in two-dimensional plots.  It is a set of arguments for the option \
Dashing.  If it contains a single pattern, that pattern is used for all \
plots.  If it contains more than one pattern, the patterns will be used \
cyclically.  The default value is {{}}, which causes all plots to be made \
with a solid line.  The pattern {r1,r2,f3...} produces cyclically segments of \
length r1, r2, r3, with all lengths being interpreted as fractions of the \
graph width.  For example, dasher = {0.05,0.02} produces segments of length \
0.05 interspersed with gaps of length 0.02.  To change dashvec, use setdash.  \
Five patterns have been defined by name:  dashort, dashlong, dashalt, dotted, \
and solid.  Section 8.  Tutorials 1, 8, and 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "decdig",
  StyleBox[
  " -- A variable controlling the number of digits to the right of the \
decimal point in plot labels.  The default value is 2.  Section 8.  Tutorials \
14 and 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["dermat",
    FontWeight->"Bold"],
  " -- The derivative matrix of the slope vector with respect to the state \
variables.  State variables, parameters and time all appear as symbols.  \
Section 14.  Tutorials 3 and 4. "
}], "Text"],

Cell[TextData[{
  StyleBox["dermatval",
    FontWeight->"Bold"],
  "[eqstate] -- The result of evaluating the derivative matrix at the point \
eqstate, after substituting current parameter values from parmval.  The \
argument eqstate may contain parameter symbols.  For autonomous systems, the \
result will be numerical.  For non-autonomous systems, the symbol t will in \
general appear in dermatval.  Section 14.  Tutorials 3, 4, and 13. "
}], "Text"],

Cell[TextData[{
  StyleBox["dirfield",
    FontWeight->"Bold"],
  " -- Produces a two-dimensional direction field plot from the current \
statevec and slopevec.  The plotting window is taken to be plrange, which \
must be set to a numerical range for this application.  Section 10.  \
Tutorials 1 and 8."
}], "Text"],

Cell[TextData[{
  StyleBox["dirpt",
    FontWeight->"Bold"],
  " -- Variable controlling the number of grid points in a direction field \
plot.  The default value of 20 produces a 20 by 20 direction field grid.  \
Tutorial 8."
}], "Text"],

Cell[TextData[{
  StyleBox["display",
    FontWeight->"Bold"],
  " -- Logical variable for graph display.  When display is True, graphics \
object constructed is plotted.  When display is False, object is constructed \
but not plotted.  The default is True.  Section 8.  Tutorials 7, 8, and 9.  "
}], "Text"],

Cell[TextData[{
  StyleBox["div",
    FontWeight->"Bold"],
  "[vec] -- Returns the divergence of the vector vec with respect to the \
state vector.  Section 17.  Tutorial 6."
}], "Text"],

Cell[TextData[{
  StyleBox["dival",
    FontWeight->"Bold"],
  "[vec] -- Returns the divergence of the vector vec with respect to the \
state vector, and with parmvec replaced by the current values in parmval.  \
Section 17.  Tutorials 6 and 13."
}], "Text"],

Cell[TextData[{
  "dots",
  StyleBox["[list] -- Plots points in a 2D graph at locations specified in \
list, which is a list containing coordinate pairs.  Uses all of the graphics \
options.  The size of the points plotted is controlled by ptsize.  Section 9. \
 Tutorial 9.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "dots3D",
  StyleBox["[list] -- Plots points in a 3D graph at locations specified in \
list, which is a list containing coordinate triples.  Uses all of the \
graphics options.  The size of the points plotted is controlled by ptsize.  \
Section 9.  Tutorial 9.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "dotted",
  StyleBox[
  " -- Dashing pattern (to be used in the argument of setdash) which produces \
a dotted line.  Section 8.  Tutorial 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["drpoincsol",
    FontWeight->"Bold"],
  "[init,t0,tau,numper] -- Produces a solution suitable for a \
Poincar\[EAcute] map in a periodically driven system.  The initial value is \
init, the initial time is t0, the sampling interval (normally the period of \
the driver) is tau, and the number of periods to be produced is numper.  \
Section 19.  Tutorial 7. "
}], "Text"],

Cell[TextData[{
  StyleBox["drpoincmap",
    FontWeight->"Bold"],
  "[sol,cycphase,i,j] -- Operates on a solution sol which has been produced \
by drpoincsol.  Produces a Poincar\[EAcute] map with components i and j, and \
at a phase cycphase.  Cycphase is specified in degrees, and may be any of the \
24 values 0(15)345.  Section 19.  Tutorial 7. "
}], "Text"],

Cell[TextData[{
  StyleBox["drpoincmap3d",
    FontWeight->"Bold"],
  "[sol,cycphase,i,j,k] -- Operates on a solution sol which has been produced \
by drpoincsol.  Produces a Poincar\[EAcute] map with components i, j and k, \
and at a phase cycphase.  Cycphase is specified in degrees, and may be any of \
the 24 values 0(15)345.  Section 19.  Tutorial 7."
}], "Text"],

Cell[TextData[{
  StyleBox["drpoinclist",
    FontWeight->"Bold"],
  "[sol,cycphase] -- Operates on a solution sol which has been produced by \
drpoincsol.  Produces a list of all the points in the Poincar\[EAcute] map \
for the phase cycphase.  Section 19.  Tutorial 7."
}], "Text"],

Cell[TextData[{
  StyleBox["eigsys",
    FontWeight->"Bold"],
  "[state] -- Returns eigenvalues and eigenvectors of the derivative matrix \
evaluated at state.   Section 14.  Tutorial 3."
}], "Text"],

Cell[TextData[{
  StyleBox["eigsysmap",
    FontWeight->"Bold"],
  "[fxpoint,ncomp] -- Returns the eigenvalues and eigenvectors of a mapping \
evaluated at fxpoint.  The optional argument ncomp is the level of function \
composition, with the default ncomp = 1.  Section 21.  Tutorial 17."
}], "Text"],

Cell[TextData[{
  StyleBox["eigval",
    FontWeight->"Bold"],
  "[state] -- Returns the eigenvalues of the derivative matrix evaluated at \
state.  Section 14.  Tutorial 3."
}], "Text"],

Cell[TextData[{
  StyleBox["eigvalmap",
    FontWeight->"Bold"],
  "[fxpoint,ncomp] -- Returns the eigenvalues of a mapping evaluated at \
fxpoint.  The optional argument ncomp is the level of function composition, \
with the default ncomp = 1.  Section 21.  Tutorial 17."
}], "Text"],

Cell[TextData[{
  StyleBox["eqstateval",
    FontWeight->"Bold"],
  "[state] -- Evaluate the vector state by replacing all parmvec symbols by \
values from current parmval.  Useful when state is an equilibrium point with \
coordinates expressed in terms of the symbols of parmvec.  Same as evalparm. \
Section 14.  Tutorial 13. "
}], "Text"],

Cell[TextData[{
  "evalparm",
  StyleBox[
  "[exp] -- Evaluate exp by replacing all parmvec symbols with current values \
from parmval.  Same as eqstateval.  Section 2.  Tutorial 1. ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["fastflag",
    FontWeight->"Bold"],
  " -- Controls integration method.  When True, NDSolve is used.  When False, \
fourth order Runge-Kutta is used.  Default is False.  Section 6.  Tutorials \
5, 13, and 14. "
}], "Text"],

Cell[TextData[{
  StyleBox["findpolyeq",
    FontWeight->"Bold"],
  " -- Find symbolic expressions for equilibrium points for polynomial slope \
functions.  Section 15.  Tutorials 0, 3 and 13. "
}], "Text"],

Cell[TextData[{
  StyleBox["findpolyfix",
    FontWeight->"Bold"],
  "[ncomp]",
  " -- Find symbolic expressions for fixed points of polynomial maps.  The \
optional argument ncomp is the level of function composition to be used.  The \
default is 1.  Section 21.  Tutorial 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["firstt",
    FontWeight->"Bold"],
  " -- Returns the time coordinate in the first element of the most recently \
calculated solution.  Useful when integrating backwards in time.  Section 6.  \
Tutorial 1."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["firsttx",
    FontWeight->"Bold"],
  " -- Returns the time and state values in the first element of the most \
recently calculated solution.  Useful when integrating backwards in time.  \
Section 6.  Tutorial 1."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["firstx",
    FontWeight->"Bold"],
  " -- Returns the state values in the first element of the most recently \
calculated solution.  Useful when integrating backwards in time.  Section 6.  \
Tutorial 1."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "framelabon",
  StyleBox[" -- Flag controlling frame labels in 2D.  If framelabon = True, \
the default labels are used.  If framelabon = False, no frame labels are \
printed.  If framelabon = \"user specified labels\", the user specified \
labels are used.  Section 8.  Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "frameon",
  StyleBox[" -- A logical variable controlling the use of Frames in 2D \
graphics.  When set to True a frame is drawn.  The default is False.  Section \
8.  Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["frompolartrans",
    FontWeight->"Bold"],
  "[",
  "r,\[Theta],x,y] -- Function producing a transformation from polar \
coordinates r and \[Theta] (which may have any name) to rectangular \
coordinates x,y.   The function returns the slope vector for {",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  " }, but does not alter the original system in any way.   Section 2.  \
Tutorial 6."
}], "Text"],

Cell[TextData[{
  "graylev",
  StyleBox[
  " -- Controls the darkness of the gray background in 3D animations.  It \
ranges from 0 (black) to 1 (white).  The default is 0.49.  Values 0.5 and \
over give a black box frame.  Values below 0.5 give a white box frame.  \
Section 9.  Tutorials 2 and 14.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "imsize",
  StyleBox[" -- Variable controlling the width of displayed graphs.  The \
value is the width in printer's points.  The default is 380, which is larger \
than the standard ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" default of 288.  Section 2.  Tutorials 1, 7,  and 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["index",
    FontWeight->"Bold"],
  "[curv] -- Returns the index of the slope vector field with respect to the \
previously defined curve named curv.  Section 16.  Tutorial 8. "
}], "Text"],

Cell[TextData[{
  StyleBox["integrate",
    FontWeight->"Bold"],
  "[initvec,t0,h,nsteps] -- This is the main routine of this whole package.  \
It produces a solution list using initvec for the initial condition, t0 for \
the initial time, h for the time step, and nsteps for the number of time \
steps.  If h is negative, the integration proceeds backward in time.  Any or \
all of the four arguments may depend on the declared parameters of the \
system.  Before integrate is executed, all of its arguments are subjected to \
the replacement rule Thread[parmvec -> parmval].  For an example of this \
usage, see Tutorial 10.  Section 6.  Tutorials 0, 1, 2, 4, 5, 6, 7, 9, 12, \
13, 14 and 15. "
}], "Text"],

Cell[TextData[{
  StyleBox["intreport",
    FontWeight->"Bold"],
  " -- Gives a brief report on most recent values of integration.  Section 3. \
 Tutorial 1. "
}], "Text"],

Cell[TextData[{
  StyleBox["intreset",
    FontWeight->"Bold"],
  " -- Reset the four integration flags to default values:  fastflag = False; \
maxstepsize = False; rangeflag = False; bothdirflag = False.  Section 6.  \
Tutorials 0, 1, 2, 5, 6, 7, 9, 10, 13, 14, 15, 16, and 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["iterate",
    FontWeight->"Bold"],
  "[initval,initime,niter,ntoss,ncomp] -- Iterates a mapping niter+ntoss \
times, and throws away the first ntoss iterations.  The iterations start at \
initval and initime.  The argument ncomp is optional.  It specifies the level \
of function composition to be used.  The default when it is not specified is \
1.  The result returned by iterate is in exactly the same form as a solution \
to a differential equation.  State variables are declared with setstate, \
parameters are declared with setparm, and the mapping is assigned to \
slopevec.  If the arguments are exact rational numbers and if the parameters \
are exact rationals, then the calculation is done exactly.  Section 21.  \
Tutorial 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["jacob",
    FontWeight->"Bold"],
  " -- Returns the Jacobian of the slope vector with parameters as symbols.  \
Primarily used for iterated mappings. Section 21.  Tutorial 17."
}], "Text"],

Cell[TextData[{
  StyleBox["jacobval",
    FontWeight->"Bold"],
  " -- Returns the Jacobian of the slope vector with parameters replaced by \
values in parmval.  Primarily used for iterated mappings. Section 21.  \
Tutorial 17."
}], "Text"],

Cell[TextData[{
  StyleBox["joinsol",
    FontWeight->"Bold"],
  "[sol1,sol2] -- Joins into a single solution two contiguous solutions sol1 \
and sol2.  The last point of sol1 must be the same as the first point of \
sol2.  Section 7.  Tutorials 1, 6, and 13."
}], "Text"],

Cell[TextData[{
  "labon ",
  StyleBox["-- Variable controlling plot label.  For labon = True, each plot \
is labeled with the system name and the parameter names and values.  For \
labon = False, no label is printed on the plot.  For labon = string, the \
string is printed as a graph label.  Section 8.  Tutorials 4, 8, 15, and 16.",
    
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "labshift ",
  StyleBox[
  "-- Integer-valued variable which when equal to n, causes the plot label to \
be spread.  The spaces are inserted between the system name on the left and \
the parameters on the right.  This allows for correcting the situation when \
the plot label and the y-axis label collide.  Section 8.  Tutorials 4, 6, 9, \
10, 11, 12 and 15. ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["lagintegrate",
    FontWeight->"Bold"],
  "[initfunc,initcond,t0,h,T,nlags] -- Integration routine for equations with \
time-lagged dependent variables.  The integration starts at the initial time \
t0.  The lag is T.  Because of the lag, the dependent variables must be known \
in the time interval t0 - T \[LessEqual] t \[LessEqual] t0.  The vector of \
those functions is the argument initfunc.  When the integration is started at \
t = t0, the initial conditions are taken from initcond.  Discontinuities are \
allowable so that initcond does not have to equal initfunc at t0.  The \
integration spacing is h, although the routine makes it smaller if necessary \
so that T is an integral multiple of h.  Finally, nlags is the number of lag \
periods over which the integration is to be performed.  Section 6A.  Tutorial \
16."
}], "Text"],

Cell[TextData[{
  StyleBox["lastt",
    FontWeight->"Bold"],
  " -- Time coordinate in the last point calculated in the most recent \
integration.  Section 6.  Tutorials 1, 2, 6, 7, and 13. "
}], "Text"],

Cell[TextData[{
  StyleBox["lasttx",
    FontWeight->"Bold"],
  " -- Last values of time and state vector calculated in the most recent \
integration.  Section 6.  Tutorial 1."
}], "Text"],

Cell[TextData[{
  StyleBox["lastx",
    FontWeight->"Bold"],
  " -- Last value of state vector calculated in the most recent integration.  \
Section 6.  Tutorials 1, 2, 6, 7, and 13."
}], "Text"],

Cell[TextData[{
  StyleBox["liaparmval",
    FontWeight->"Bold"],
  " -- Variable containing the current values of the parameters in \
liaparmvec.  Section 18.  Tutorial 11."
}], "Text"],

Cell[TextData[{
  StyleBox["liaparmvec",
    FontWeight->"Bold"],
  " -- Variable containing the names of the parameters in a Liapunov \
function.  Section 18.  Tutorial 11."
}], "Text"],

Cell[TextData[{
  StyleBox["liapcontours",
    FontWeight->"Bold"],
  "[v] -- Produces a full 20-contour plot of v.  For two dimensions only.  \
Takes plot range from plrange.  Section 18.  Tutorial 11. "
}], "Text"],

Cell[TextData[{
  StyleBox["liapsign",
    FontWeight->"Bold"],
  "[v] -- Produces a plot in which regions of positive v are white and \
regions of negative v are grey.  Current values for parmvec and liaparmvec \
are taken from parmval and liaparmval before constructing the plot.  Takes \
plot range from plrange.  Section 18.  Tutorial 11. "
}], "Text"],

Cell[TextData[{
  StyleBox["liapsignseq",
    FontWeight->"Bold"],
  "[parmlist,v] -- Produces a sequence of contour plots.  In each plot, \
regions of positive v are white and regions of negative v are grey.  A plot \
is produced for each value of liaparmval in the list parmlist.  Section 18.  \
Tutorial 11. "
}], "Text"],

Cell[TextData[{
  StyleBox["limbifurc",
    FontWeight->"Bold"],
  "[initvec,t0,h,nsteps,i,j,parmlist] -- Produces a sequence of \
two-dimensional phase plots (components i and j -- use i or j equal to zero \
to get time) of pure limit cycles.  Each of the arguments t0, h, and nsteps \
may be a single expression, or a list of expressions of the same length as \
intlist.  When the argument is a list, the values are used in succession as \
the integrations are performed.  Any expression appearing in any of the first \
four arguments may contain parameter symbols.  These will be replaced by \
current values when the integration is performed.  A plot is constructed for \
each set of values of parmval in parmlist.  The argument refgraph is \
optional.  When present, it is taken to be the name of a graph which is then \
superimposed on each graph produced.  It may be a graph which has already \
been defined, or it may be a function which depends on the parameter vector \
and which returns a graph.  Section 12.  Tutorial 10.   "
}], "Text"],

Cell[TextData[{
  StyleBox["limbifurc3D",
    FontWeight->"Bold"],
  "[initvec,t0,h,nsteps,i,j,k,parmlist] -- Produces a sequence of \
three-dimensional phase plots (components i, j, and k -- use i,j, or k equal \
to zero to get time) of pure limit cycles. Each of the arguments t0, h, and \
nsteps may be a single expression, or a list of expressions of the same \
length as intlist.  When the argument is a list, the values are used in \
succession as the integrations are performed.  Any expression appearing in \
any of the first four arguments may contain parameter symbols.  These will be \
replaced by current values when the integration is performed.  A plot is \
constructed for each set of values of parmval in parmlist.  The argument \
refgraph is optional.  When present, it is taken to be the name of a graph \
which is then superimposed on each graph produced.  It may be a graph which \
has already been defined, or it may be a function which depends on the \
parameter vector and which returns a graph.  Section 12.  Tutorial 10."
}], "Text"],

Cell[TextData[{
  StyleBox["limcyc",
    FontWeight->"Bold"],
  "[intvec,t0,h,nsteps] -- The purpose of this function is to produce a pure \
limit cycle without any startup transients.  It integrates nsteps starting at \
intvec, and then uses the last point of this integration as an initial \
condition for a new integration.  Only the second integration is saved.  \
Section 12.  Tutorials 6, 8, and 9. "
}], "Text"],

Cell[TextData[{
  StyleBox["lnthick",
    FontWeight->"Bold"],
  " -- Variable controlling the thickness of lines in plots.  Thickness is \
given relative to plot size.  The default is 0.002.  Section 8.  Tutorial 1."
}], "Text"],

Cell[TextData[{
  StyleBox["mapcomp",
    FontWeight->"Bold"],
  "[n]",
  " -- Produces an expression for the nth composition of a mapping.  Section \
21.  Tutorial 17."
}], "Text"],

Cell[TextData[{
  StyleBox["mapval",
    FontWeight->"Bold"],
  "[pt,ncomp] -- Evaluates the map at the point pt.  The vector pt may have \
parameter symbols in it.  The argument ncomp is optional, and specifies the \
level of function composition of the map.  The default is 1.  Section 21.  \
Tutorial 17."
}], "Text"],

Cell[TextData[{
  StyleBox["maxstepflag",
    FontWeight->"Bold"],
  " -- Only relevant when fastflag is True.  When True, the NDSolve \
integration takes the specified step size as a maximum step size.  Default is \
False.  Section 6.  Tutorial 5."
}], "Text"],

Cell[TextData[{
  StyleBox["modsol",
    FontWeight->"Bold"],
  "[sol,k,a,b] -- Replaces the kth component of the solution sol by its value \
modulo the interval [a,b).  Section 7.  Tutorial 7. "
}], "Text"],

Cell[TextData[{
  StyleBox["nfindeq",
    FontWeight->"Bold"],
  "[init] -- Find numerical values for an equilibrium point using init as a \
starting guess.  Apply a second time to the result of the first application \
to refine the root.  Section 15.  Tutorial 3. "
}], "Text"],

Cell[TextData[{
  StyleBox["nfindfix",
    FontWeight->"Bold"],
  "[init,ncomp] -- Find numerical values for a fixed point of a map using \
init as a starting guess.  Apply a second time to the result of the first \
application to refine the root.  The optional argument ncomp is the level of \
function composition to be used, with ncomp = 1 the default.  Section 21.  \
Tutorial 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["nfindpolyeq",
    FontWeight->"Bold"],
  " -- Find numerical expressions for equilibrium points for polynomial slope \
vectors, using values in parmval for parmvec.  Section 15.  Tutorial 3. "
}], "Text"],

Cell[TextData[{
  StyleBox["nfindpolyfix",
    FontWeight->"Bold"],
  "[ncomp]",
  " -- Find numerical expressions for fixed points of polynomial maps, using \
values in parmval for parmvec.  The optional argument ncomp is the level of \
function composition to be used, with ncomp = 1 as the default.  Section 21.  \
Tutorial 17. "
}], "Text"],

Cell[TextData[{
  "nodeportrait",
  StyleBox[
  "[eq,window] -- Gives a basic phase portrait for a 2D node at the \
equilibrium point eq, using the window for the plot range.  Section 11.  \
Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["ncurpoints ",
    FontWeight->"Bold"],
  "-- Variable controlling the number of points used in index calculations \
and orbit trapping calculations.  The default is 100.  Section 16.  Tutorial \
8."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["orbcross",
    FontWeight->"Bold"],
  "[curv] -- Scans a previously defined curve named curv to determine whether \
curv traps orbits.  The output of orbcross is a brief report on crossing \
directions.  Section 16.  Tutorial 8."
}], "Text"],

Cell[TextData[{
  StyleBox["orbdt",
    FontWeight->"Bold"],
  "[v] -- Gives the orbital derivative of any function v of the state \
variables and time.  Section 18.  Tutorial 11."
}], "Text"],

Cell[TextData[{
  StyleBox["orbdtval",
    FontWeight->"Bold"],
  "[v] -- Gives the orbital derivative of v with parameter symbols replaced \
by current values in parmval and Liapunov parameter symbols in liaparmvec \
replace by current values in liaparmval.  Section 18.  Tutorial 11."
}], "Text"],

Cell[TextData[{
  "outbound ",
  StyleBox["-- Variable containing the coordinates of the first point out of \
bounds in range checking.  Section 6.  Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["parmreport",
    FontWeight->"Bold"],
  " -- Causes a list of system parameters to be displayed on the screen.  \
Equivalent to executing intreport, plotreport, and sysreport.  Section 2.  \
Tutorial 1."
}], "Text"],

Cell[TextData[{
  StyleBox["parmunits",
    FontWeight->"Bold"],
  " -- Vector containing any units assigned to parameters.  Units are used in \
graph labels.  Sections 2 and 8.  Tutorial 15."
}], "Text"],

Cell[TextData[{
  "parmunitsclear",
  StyleBox[
  " -- Clears units assigned to parameters.  Section 2.  Tutorial 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["parmval",
    FontWeight->"Bold"],
  " -- The vector giving current numerical values of parmvec.  It may contain \
parameter symbols as well as numbers.  Tutorials 0, 1, 2, 3, 4, 5, 6, 7, 8, \
9, 10, 11, 12, 13, 15, 16, and 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["parmvec",
    FontWeight->"Bold"],
  " -- The vector giving the names of the system parameters.  Tutorials 0, 1, \
2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14 and 15. "
}], "Text"],

Cell[TextData[{
  StyleBox["period",
    FontWeight->"Bold"],
  "[sol] -- Returns the period of the periodic motion sol.  Section 12.  \
Tutorials 2, 6, 8, and 9. "
}], "Text"],

Cell[TextData[{
  StyleBox["periodmap",
    FontWeight->"Bold"],
  "[sol] -- When applied to the solution sol, periodmap has three possible \
outcomes:  (1) a message that the solution is periodic, and the value of the \
period; (2) a message that the solution contains a periodic orbit, and the \
value of the period; (3) a message that the solution is not periodic.  \
Section 21.  Tutorial 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["phaseplot",
    FontWeight->"Bold"],
  "[sol,i,j] -- Produces a phaseplot of ith component (horizontal) of the \
solution sol versus jth component (vertical).  Use a value of zero for i or j \
to get time.  The argument sol may be a single solution or a list of \
solutions. Section 9.  Tutorials 0, 1, 2, 5, 6, 12, and 13."
}], "Text"],

Cell[TextData[{
  StyleBox["phaseplot3D",
    FontWeight->"Bold"],
  "[sol,i,j,k] -- Produces a three-dimensional phase plot of ith, jth, and \
kth components of solution sol.  Use a value of zero for i, j, or k to get \
time.  The argument sol may be a single solution or a list of solutions.  \
Section 9.  Tutorial 2.  "
}], "Text"],

Cell[TextData[{
  StyleBox["phaser",
    FontWeight->"Bold"],
  "[sol] -- Equivalent to phaseplot with i = 1, j = 2.  Section 9.  Tutorials \
1, 4, 6, 7, 8, 9, 15, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["phaser3D",
    FontWeight->"Bold"],
  "[sol] -- Equivalent to phaseplot3D with i = 1, j = 2, k = 3.  Section 9.  \
Tutorials 2, 6, 13, 14, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["phaseseq",
    FontWeight->"Bold"],
  "[intlist,t0,h,nstepic,npics,i,j,refgraph] -- Produces a sequence of \
two-dimensional phase plots (with components i and j -- use i or j equal to \
zero to get time) suitable for animation.  Each plot contains orbits for each \
set of initial conditions in intlist, with time step h.  The plots form a \
sequence in time, with the time increment between plots being h*nstepic.  The \
total number of plots is npics.  When the sequence is animated, it gives a \
simulation of the integral curves being constructed in time.  The argument \
refgraph is optional, and when used is the name of a reference graph which is \
to be superimposed on all graphs of the sequence.  Section 11.  Tutorial 9.   \
 "
}], "Text"],

Cell[TextData[{
  StyleBox["phaseseq3D",
    FontWeight->"Bold"],
  "[intlist,t0,h,nstepic,npics,i,j,k] -- Produces a sequence of \
three-dimensional phase plots (with components i,j and k -- use i, , or k \
equal to zero to get time) suitable for animation.  Each plot contains orbits \
for each set of initial conditions in intlist, with time step h.  The plots \
form a sequence in time, with the time increment between plots being \
h*nstepic.  The total number of plots is npics.  When the sequence is \
animated, it gives a simulation of the integral curves being constructed in \
time.  The argument refgraph is optional, and when used is the name of a \
reference graph which is to be superimposed on all graphs of the sequence.  \
Section 11.  Tutorial 9.    "
}], "Text"],

Cell[TextData[{
  StyleBox["plot",
    FontWeight->"Bold"],
  "[f[t],{t,tmin,tmax}] -- A variation of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Plot.  The arguments are f[t], a previously defined function, and the \
list {t,tmin,tmax} which gives the independent variable and the range for the \
plot.  It uses current settings of asprat, axon, axorg, display, and plrange. \
 Section 9.  Tutorial 7."
}], "Text"],

Cell[TextData[{
  StyleBox["plotcurve",
    FontWeight->"Bold"],
  "[curv] -- Generates a plot of the previously defined curve named curv.  \
Section 16.  Tutorial 8. "
}], "Text"],

Cell[TextData[{
  StyleBox["plotreport",
    FontWeight->"Bold"],
  " --  Gives a brief report on the most recent settings of the plotting \
parameters.  Section 3.  Tutorial 1. "
}], "Text"],

Cell[TextData[{
  StyleBox["plotreset",
    FontWeight->"Bold"],
  " -- Resets all of the plotting control variables to their defaults.  \
Variables reset are asprat, axon, boxrat, display, lnthick, plrange, \
poincptsize, pointcon, ptsize, and viewpt.  Section 8.  Tutorials 0, 1, 2, 5, \
6, 7, 8, 9, 10, 11,12, 13, 14, 15, 16, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["plrange",
    FontWeight->"Bold"],
  " -- Variable controlling the window for two-dimensional plots.  May be set \
to Automatic, All, or to a numerical range.  Automatic plots all points \
except outliers, All plots all points.  The default is All.  Section 8.  \
Tutorials 1, 4, 6, 7, 8, 9, 10, 11, 13, 16, and 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["plrange3D",
    FontWeight->"Bold"],
  " -- Variable controlling the window for three-dimensional plots.  May be \
set to Automatic, All, or to a numerical range.  Automatic plots all points \
except outliers, All plots all points.  The default is All.  Section 8.  \
Tutorials 6, 7, 9, 10, 12, 13, and 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["poinclist",
    FontWeight->"Bold"],
  "[sol] -- Produces a list of the time and space coordinates of all the \
crossings of the Poincar\[EAcute] plane in the solution sol for an autonomous \
system. Sol may be any solution produced by integrate.  Section 20.  Tutorial \
6.  "
}], "Text"],

Cell[TextData[{
  StyleBox["poincmap",
    FontWeight->"Bold"],
  "[sol,i,j] -- The argument sol is a solution list produced by poinclist, or \
by poincminus or poincplus.  Then poincmap returns the Poincar\[EAcute] map \
of the components i and j.  Section 20.  Tutorial 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["poincmapopt3D",
    FontWeight->"Bold"],
  "[sol] -- For three-dimensional systems only.  The argument sol is a \
solution list produced by poinclist, or by poincminus or poincplus.  Then \
poincmapopt3D returns the three-dimensional view of the Poincar\[EAcute] map, \
with the view point being chosen in the direction -a, where a is the normal \
to the Poincar\[EAcute] plane.  Section 20.  Tutorial 6.  "
}], "Text"],

Cell[TextData[{
  StyleBox["poincmap3D",
    FontWeight->"Bold"],
  "[sol,i,j,k] -- The argument sol is a solution list produced by poinclist, \
or by poincminus or poincplus.  Then poincmap returns a three-dimensional \
view of the Poincar\[EAcute] map of the components i, j and k.  Section 20.  \
Tutorial 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["poincminus",
    FontWeight->"Bold"],
  "[sol] -- The argument sol is a solution list produced by poinclist.  Then \
poincminus returns the subset of sol corresponding to negative crossings (in \
the direction of the negative of the normal to the Poincar\[EAcute] plane).  \
Section 20.  Tutorial 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["poincplane",
    FontWeight->"Bold"],
  " -- Variable containing the parameters defining a Poincar\[EAcute] plane \
for maps in autonomous systems.  It has the form {a,b} where a stands for the \
n components of the normal vector of the Poincar\[EAcute] plane, and b is the \
constant defining the plane.  The plane is given by   a.x + b = 0.  Section \
20.  Tutorial 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["poincplus",
    FontWeight->"Bold"],
  "[sol] -- The argument sol is a solution list produced by poinclist.  Then \
poincplus returns the subset of sol corresponding to positive crossings (in \
the direction of the normal to the Poincar\[EAcute] plane).  Section 20.  \
Tutorial 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["poincpointper",
    FontWeight->"Bold"],
  " -- A variable defining the number of integration points per period for a \
Poincar\[EAcute] map in a driven system.  It must be a multiple of 24.  The \
default is 48.  Section 19.  Tutorial 7. "
}], "Text"],

Cell[TextData[{
  StyleBox["poincptsize",
    FontWeight->"Bold"],
  " -- Variable controlling the size of points plotted in Poincar\[EAcute] \
maps.  The size is given relative to the size of the plot.  The default is \
0.008.  Section 8.  Tutorials 6 and 7."
}], "Text"],

Cell[TextData[{
  StyleBox["pointcon",
    FontWeight->"Bold"],
  " -- Logical variable controlling connection of points in graphs.  When \
True, points are connected in a smooth line.  When False, points are plotted \
with no connecting line.  Default is True.  Section 8.  Tutorials 1, 7, 12, \
14, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["polartrans",
    FontWeight->"Bold"],
  "[statx,staty,r,\[Theta]]",
  " -- Function producing a transformation to polar coordinates r and \
\[Theta] (which may have any name) from the state variables statx and staty.  \
The transformation is statx = rCos[\[Theta]], staty = rSin[\[Theta]].  The \
function returns the slope vector for {",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\& . \)\)]],
  " }, but does not alter the original system in any way.   Section 2.  \
Tutorial 6."
}], "Text"],

Cell[TextData[{
  StyleBox["portrait",
    FontWeight->"Bold"],
  "[intlist,t0,h,nsteps,i,j] -- Constructs a two-dimensional phase plot with \
components i and j (use i or j equal to zero to get time).  For each set of \
initial conditions in the list intlist, an orbit is constructed.  Each of the \
arguments t0, h, and nsteps may be a single expression, or a list of \
expressions of the same length as intlist.  When the argument is a list, the \
values are used in succession as the integrations are performed.  Any \
expression appearing in any of the first four arguments may contain parameter \
symbols.  These will be replaced by current values when the integration is \
performed. Section 11.  Tutorials 9, 11, and 12."
}], "Text"],

Cell[TextData[{
  StyleBox["portraitmap",
    FontWeight->"Bold"],
  "[intlist,t0,niter,ntoss,i,j,ncomp] -- Constructs a two-dimensional phase \
plot for a map, showing components i and j (use i or j equal to zero to get \
time).  For each set of initial conditions in the list intlist, an orbit is \
constructed.  The first ntoss iterations are thrown away, and then niter are \
kept.  Each of the arguments t0 and niter may be a single expression, or a \
list of expressions of the same length as intlist.  When the argument is a \
list, the values are used in succession as the integrations are performed.  \
Any expression appearing in any of the first three arguments may contain \
parameter symbols.  These will be replaced by current values when the \
integration is performed.  The argument ncomp is an optional argument giving \
the level of function composition of the basic map.  Section 21.  Tutorial \
17."
}], "Text"],

Cell[TextData[{
  StyleBox["portrait3D",
    FontWeight->"Bold"],
  "[intlist,t0,h,nsteps,i,j,k] -- Constructs a three-dimensional phase plot \
with components i, j and k (use i, j or k equal to 0 to get time).  For each \
set of initial conditions in intlist, an orbit is constructed with time step \
h and number of steps nsteps.  Each of the arguments t0, h, and nsteps may be \
a single expression, or a list of expressions of the same length as intlist.  \
When the argument is a list, the values are used in succession as the \
integrations are performed.  Any expression appearing in any of the first \
four arguments may contain parameter symbols.  These will be replaced by \
current values when the integration is performed.  Section 11.  Tutorials 9 \
and 13. "
}], "Text"],

Cell[TextData[{
  StyleBox["portrait3Dmap",
    FontWeight->"Bold"],
  "[intlist,t0,niter,ntoss,i,j,k,ncomp] -- Constructs a three-dimensional \
phase plot for a map with components i, j and k (use i, j or k equal to 0 to \
get time).  For each set of initial conditions in intlist, an orbit is \
constructed with number of iterations niter + ntoss, after which the first \
ntoss are thrown away.  Each of the arguments t0 and niter may be a single \
expression, or a list of expressions of the same length as intlist.  When the \
argument is a list, the values are used in succession as the integrations are \
performed.  Any expression appearing in any of the first three arguments may \
contain parameter symbols.  These will be replaced by current values when the \
integration is performed.  The argument ncomp is an optional argument giving \
the level of function composition of the basic map.  Section 21.  Tutorial \
17. "
}], "Text"],

Cell[TextData[{
  StyleBox["ptsize",
    FontWeight->"Bold"],
  " -- Variable controlling the size of points plotted.  The size is given \
relative to the plot size.  Default is 0.005.  Section 8.  Tutorials 1, 14, \
and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["rangeflag",
    FontWeight->"Bold"],
  " -- Logical variable controlling range checking.  When True, integration \
stops whenever system state leaves box specified in ranger.  Only works when \
fastflag is False.  Default is False.  Section 6.  Tutorials 4, 5, 10, 13, \
and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["ranger",
    FontWeight->"Bold"],
  " -- Variable containing the range to be used for range checking during \
integration.  Section 4.  Tutorials 4, 5, 10, 13, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["residual",
    FontWeight->"Bold"],
  "[root] -- Evaluates the slope vector at the point root.  The argument root \
may contain parameter symbols.  Section 15.  Tutorial 3. "
}], "Text"],

Cell[TextData[{
  StyleBox["residualfix",
    FontWeight->"Bold"],
  "[root,ncomp] -- Evaluates the slope vector minus the state vector at the \
point root.  The argument root may contain parameter symbols.  The optional \
argument ncomp is the level of function composition to be used, with ncomp = \
1 the default.  Section 21.  Tutorial 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["restoresys",
    FontWeight->"Bold"],
  "[nme] -- Replace statevec, slopevec, parmvec, parmval, and sysname by \
values previously stored under name nme by a savesys command.  Section 2.  \
Tutorials 4, 6, 9, 12, 15, and 16.  "
}], "Text"],

Cell[TextData[{
  "reversetime",
  StyleBox[
  " -- Replaces t by -t in the system definition.  Section 2.  Tutorial 1.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["rotphaseplot3D",
    FontWeight->"Bold"],
  "[sol,i,j,k,theta] -- Produces a three-dimensional phase plot of components \
i,j,k (use i, j, or k equal to zero to get time) of solution sol, rotated by \
theta degrees about the z-axis.  (The zero angle of rotation is defined by \
the setting of the variable viewpt.)  Section 9.  Tutorial 2. "
}], "Text"],

Cell[TextData[{
  "saddleportrait",
  StyleBox[
  "[eq,window] -- Creates a graph of stable and unstable manifolds passing \
through a known 2D saddle point at eq, along with four nearby integral \
curves.  Uses window as a plotting window.  Section 11.  Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "saddleportraitman",
  StyleBox[
  "[eq,window] -- Creates a graph of stable and unstable manifolds passing \
through a known 2D saddle point at eq.  Uses window as a plotting window.  \
Section 11.  Tutorial 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["savesys",
    FontWeight->"Bold"],
  "[nme] -- Save current values of statevec, slopevec, parmvec, and parmval \
under the name nme.  Save nme under sysname.  System may be recalled with \
restoresys[nme].  Section 2.  Tutorials 4, 6, 9, 10, 12, 15, and 16."
}], "Text"],

Cell[TextData[{
  StyleBox["sciflag",
    FontWeight->"Bold"],
  " -- Flag controlling number output in graph labels.  When sciflag = True, \
numbers are printed in scientific notation with number of digits to right of \
decimal = decdig.  Section 8.  Tutorial 5 and 15."
}], "Text"],

Cell[TextData[{
  "setback",
  StyleBox["[col] -- This sets the value of backcolor to col.  Graphs will be \
constructed with a background color of col.  The default is White.  Section \
8.  Tutorial 7.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "setcolor",
  StyleBox["[vec] -- This sets the value of colorvec to vec, and resets the \
color pointer to the first color in the list.  Section 8.  Tutorials 1, 2, 4, \
8, 9, 10, 12, 14, 16, and 17.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "setdash",
  StyleBox[
  "[vec] -- This sets the value of dashvec to vec, and resets the dashing \
pointer to the first pattern in the list.  Section 8.  Tutorials 1 and 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "setde",
  StyleBox[" -- This declares that the problem to be solved is a differential \
equation (rather than a mapping).  Section 21.  Tutorial 17.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "setmap",
  StyleBox[" -- This declares that the problem is an iterated mapping (rather \
than a differential equation).  Section 21.  Tutorial 17.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["setparm",
    FontWeight->"Bold"],
  "[vec] -- Does four things:  (1) clears each of the symbols in vec, (2) \
assigns the list vec to parmvec, (3) protects each symbol in vec; and (4) \
assigns the symbols in vec to the value vector parmval.  Section 2.  \
Tutorials 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,12, 13, 14, 15, 16, and 17. "
}], "Text"],

Cell[TextData[{
  StyleBox["setstate",
    FontWeight->"Bold"],
  "[vec] -- Does four things: (1) clears each of the symbols in vec, (2) \
assigns the list vec to statevec, (3) protects each of the symbols in vec, \
and (4) clears sysname.  Section 2.  Tutorials 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, \
10, 11, 12, 13, 14, 15, 16, and 17.   "
}], "Text"],

Cell[TextData[{
  StyleBox["show",
    FontWeight->"Bold"],
  "[graphlist] -- A variation of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Show.  The argument graphlist is a list of graphics objects.  This \
command shows them all, regardless of whether display was True or False when \
they were created.  It uses current settings of asprat, axon, axorg, labon \
and plrange.  Section 9.  Tutorials 1, 6, 7, 8, 9, and 16."
}], "Text"],

Cell[TextData[{
  StyleBox["show3D",
    FontWeight->"Bold"],
  "[graphlist] -- The argument graphlist is a list of 3D graphics obects.  \
This command shows them all, regardless of whether display was True or False \
when they were created.  It uses current settings of axon, boxrat, viewpt and \
plrange.  Section 9.  Tutorials 13 and 14. "
}], "Text"],

Cell[TextData[{
  StyleBox["signcontour",
    FontWeight->"Bold"],
  "[v] -- For any scalar function v of the state variables this shows a plot \
in which the region of positive values of v is white, negative grey.  Works \
only for two-dimensional systems.  Takes plot range from plrange.  Section \
17.  Tutorial 6. "
}], "Text"],

Cell[TextData[{
  StyleBox["slopevec",
    FontWeight->"Bold"],
  " -- User specified vector containing the slope vector in terms of the \
state vector and system parameters.  Tutorials 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, \
10, 11, 12, 13, 14, 15, 16, and 17. "
}], "Text"],

Cell[TextData[{
  "solid",
  StyleBox[
  " -- Dashing pattern (to be used as an argument for setdash) which produces \
a solid curve.  Section 8.  Tutorial 12.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "solinterp",
  StyleBox[
  "[sol,stname,slpname] -- Constructs interpolating functions for a given \
solution sol.  After execution, stname[t] will give the state vector at time \
t, and slpname[t] will give the slope vector at time t.  See also \
buildinterp.  Section 13.  Tutorial 1.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "spiralportrait",
  StyleBox[
  "[eq,window] -- Gives a basic phase portrait for a 2D spiral at the \
equilibrium point eq, using the window for the plot range.  Section 11.  \
Tutorials 0 and 4.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["staterange",
    FontWeight->"Bold"],
  "[sol] -- Returns the minimimum and maximum values in solution sol for each \
component of the state vector, and the time at which these occur.  Section 7. \
 Tutorials 1, 5, 7, and 13."
}], "Text"],

Cell[TextData[{
  "stateshift",
  StyleBox["[sol,vec] -- Increments every state vector in the solution list \
sol by vec.  Section 7.  Tutorial 6.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["stateunits",
    FontWeight->"Bold"],
  " -- Vector containing any assigned units to state variables.  The units \
are used in graph labels.  Sections 2 and 8.  Tutorial 15."
}], "Text"],

Cell[TextData[{
  "stateunitsclear",
  StyleBox[
  " -- Function which clears units assigned to state variables.  Section 2.  \
Tutorial 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["statevec",
    FontWeight->"Bold"],
  " -- User specified vector containing the names of the components of the \
state vector.  Tutorials 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, and 14."
}], "Text"],

Cell[TextData[{
  StyleBox["stripsol",
    FontWeight->"Bold"],
  "[sol,n] -- Removes the nth component of the state vector from solution \
sol.  Section 7.  Tutorials 1 and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["subsol",
    FontWeight->"Bold"],
  "[sol,rng] -- Returns the subset of solution sol for which the time is in \
the range specifed by rng.  The form of rng is {tmin,tmax}.  Section 7.  \
Tutorial 1. "
}], "Text"],

Cell[TextData[{
  "sugtimestep",
  StyleBox[
  "[window] -- Returns a suggested time step for an autonomous system in a \
coordinate box specified by window.  Section 6.  Tutorials 1 and 2.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["sysid",
    FontWeight->"Bold"],
  " -- Causes version numbers to be printed for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and this package, and the current date.  Section 2.  Tutorials 0, 1, 2, \
3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["sysname",
    FontWeight->"Bold"],
  " -- Variable containing the optional name of the system.  Default is \
blank.  Sysname is cleared by setstate, so sysname assignment must come after \
setstate.  Section 2.  Tutorials 0, 1, 7, 10, 11, 12, 13, 16, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["sysreport",
    FontWeight->"Bold"],
  " -- Gives a brief report of the most recent settings of the system \
variables (statevec,slopevec,parmvec,parmval and sysname).  Section 2.  \
Tutorials 0, 1, 6, 9, 15, 16, and 17."
}], "Text"],

Cell[TextData[{
  StyleBox["t",
    FontWeight->"Bold"],
  " -- Reserved name for independent variable.  It is used explicitly only in \
non-autonomous systems.  Section 2.  Tutorial 7.  "
}], "Text"],

Cell[TextData[{
  StyleBox["timeplot",
    FontWeight->"Bold"],
  "[sol,i] -- Produces a plot of the ith component of solution sol versus \
time.  The argument sol may be a single solution or a list of solutions.  The \
argumen i may be a single index or a list of indices.  Section 9.  Tutorials \
0, 1, 7, 12, 13, 14, 15, 16, and 17."
}], "Text"],

Cell[TextData[{
  "timeshift",
  StyleBox["[sol,\[Tau]] -- Increments every time value in the solution list \
sol by \[Tau].  Section 7.  Tutorial 6.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "timeunit",
  StyleBox[
  " -- Variable containing any unit assigned to time variable.  Sections 2 \
and 8.  Tutorial 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "timeunitclear",
  StyleBox[
  " -- Function which clears unit assigned to time.  Section 2.  Tutorial \
15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "totdig",
  StyleBox[
  " -- Variable controlling the total number of digits in a number in a plot \
label.  The default is 4.  Section 8.  Tutorials 14 and 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["trange",
    FontWeight->"Bold"],
  "[sol] -- Returns a list {tmin,tmax}, where tmin is the minimum time \
occuring in solution sol, tmax the maximum.  Section 7.  Tutorials 1 and 7."
}], "Text"],

Cell[TextData[{
  "transorg",
  StyleBox[
  "[vec] -- Translates the origin to the position vec.  Section 2.  Tutorial \
3.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "transol",
  StyleBox[
  "[sol,funclist] -- The argument funclist contains a list of expressions in \
the state variables, the parameters and time.  The argument sol is a \
previously computed solution.  Transol produces a list in the format of a \
solution.  Each element of the list has the form {t, f1, f2, .. fk}, where \
the fi's are the expressions appearing in funclist, evaluated at each t for \
the solution at that time.  Section 7.  Tutorial 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "unitsclear",
  StyleBox[
  " -- Function which clears all units assigned to parameters, state \
variables and time.  Section 2.  Tutorial 15.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["viewmap",
    FontWeight->"Bold"],
  "[ncomp]",
  " -- Produces a graph of a mapping, along with the fixed-point reference \
line f[x] = x.  The optional argument ncomp specifies the level of \
composition to be used.  The default is ncomp = 1.   Section 21.  Tutorial \
17."
}], "Text"],

Cell[TextData[{
  StyleBox["viewpt",
    FontWeight->"Bold"],
  " -- Variable controlling viewpoint for three-dimensional plots.  A list of \
three numbers giving vector direction of viewpoint and distance of viewpoint. \
 Default is {13,-24,20}. Section 8.  Tutorial 2."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{662, 562},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000Kf0801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 77, 4, 190, "Title"],
Cell[1819, 57, 601, 13, 82, "Text",
  Evaluatable->False],
Cell[2423, 72, 290, 10, 32, "Text"],
Cell[2716, 84, 436, 10, 64, "Text",
  Evaluatable->False],
Cell[3155, 96, 182, 7, 32, "Text"],
Cell[3340, 105, 435, 9, 64, "Text"],
Cell[3778, 116, 513, 10, 80, "Text"],
Cell[4294, 128, 367, 9, 48, "Text",
  Evaluatable->False],
Cell[4664, 139, 342, 8, 48, "Text"],
Cell[5009, 149, 282, 8, 48, "Text",
  Evaluatable->False],
Cell[5294, 159, 293, 8, 48, "Text",
  Evaluatable->False],
Cell[5590, 169, 355, 8, 48, "Text",
  Evaluatable->False],
Cell[5948, 179, 1221, 20, 160, "Text",
  Evaluatable->False],
Cell[7172, 201, 1131, 19, 144, "Text",
  Evaluatable->False],
Cell[8306, 222, 1247, 20, 160, "Text",
  Evaluatable->False],
Cell[9556, 244, 1155, 19, 144, "Text",
  Evaluatable->False],
Cell[10714, 265, 947, 16, 128, "Text"],
Cell[11664, 283, 323, 8, 48, "Text",
  Evaluatable->False],
Cell[11990, 293, 358, 7, 64, "Text"],
Cell[12351, 302, 243, 6, 48, "Text"],
Cell[12597, 310, 267, 8, 48, "Text"],
Cell[12867, 320, 294, 6, 48, "Text"],
Cell[13164, 328, 395, 8, 64, "Text"],
Cell[13562, 338, 293, 6, 48, "Text"],
Cell[13858, 346, 814, 13, 112, "Text"],
Cell[14675, 361, 804, 19, 98, "Text"],
Cell[15482, 382, 190, 7, 32, "Text"],
Cell[15675, 391, 236, 7, 48, "Text"],
Cell[15914, 400, 217, 7, 32, "Text"],
Cell[16134, 409, 217, 7, 32, "Text"],
Cell[16354, 418, 919, 16, 128, "Text"],
Cell[17276, 436, 264, 8, 48, "Text"],
Cell[17543, 446, 259, 6, 48, "Text"],
Cell[17805, 454, 454, 8, 64, "Text"],
Cell[18262, 464, 316, 7, 48, "Text"],
Cell[18581, 473, 238, 6, 48, "Text"],
Cell[18822, 481, 308, 6, 48, "Text"],
Cell[19133, 489, 186, 5, 32, "Text"],
Cell[19322, 496, 258, 6, 48, "Text"],
Cell[19583, 504, 335, 8, 48, "Text"],
Cell[19921, 514, 339, 8, 48, "Text"],
Cell[20263, 524, 221, 7, 32, "Text"],
Cell[20487, 533, 399, 8, 64, "Text"],
Cell[20889, 543, 362, 7, 64, "Text"],
Cell[21254, 552, 368, 7, 64, "Text"],
Cell[21625, 561, 283, 6, 48, "Text"],
Cell[21911, 569, 199, 5, 32, "Text"],
Cell[22113, 576, 301, 6, 48, "Text"],
Cell[22417, 584, 185, 5, 32, "Text"],
Cell[22605, 591, 284, 6, 48, "Text"],
Cell[22892, 599, 341, 7, 64, "Text"],
Cell[23236, 608, 243, 7, 48, "Text"],
Cell[23482, 617, 250, 6, 48, "Text"],
Cell[23735, 625, 206, 5, 48, "Text"],
Cell[23944, 632, 291, 7, 48, "Text"],
Cell[24238, 641, 268, 7, 48, "Text"],
Cell[24509, 650, 275, 7, 48, "Text"],
Cell[24787, 659, 265, 7, 48, "Text"],
Cell[25055, 668, 361, 8, 48, "Text"],
Cell[25419, 678, 258, 7, 48, "Text"],
Cell[25680, 687, 503, 14, 64, "Text"],
Cell[26186, 703, 359, 9, 48, "Text"],
Cell[26548, 714, 433, 12, 50, "Text"],
Cell[26984, 728, 216, 5, 48, "Text"],
Cell[27203, 735, 708, 12, 96, "Text"],
Cell[27914, 749, 171, 5, 32, "Text"],
Cell[28088, 756, 292, 6, 48, "Text"],
Cell[28383, 764, 780, 13, 112, "Text"],
Cell[29166, 779, 216, 5, 48, "Text"],
Cell[29385, 786, 240, 6, 48, "Text"],
Cell[29628, 794, 272, 6, 48, "Text"],
Cell[29903, 802, 399, 9, 64, "Text"],
Cell[30305, 813, 438, 10, 64, "Text"],
Cell[30746, 825, 870, 14, 112, "Text"],
Cell[31619, 841, 203, 5, 32, "Text"],
Cell[31825, 848, 188, 5, 32, "Text"],
Cell[32016, 855, 195, 5, 32, "Text"],
Cell[32214, 862, 186, 5, 32, "Text"],
Cell[32403, 869, 186, 5, 32, "Text"],
Cell[32592, 876, 216, 5, 48, "Text"],
Cell[32811, 883, 356, 7, 64, "Text"],
Cell[33170, 892, 324, 7, 48, "Text"],
Cell[33497, 901, 1049, 16, 144, "Text"],
Cell[34549, 919, 1058, 16, 144, "Text"],
Cell[35610, 937, 418, 8, 64, "Text"],
Cell[36031, 947, 229, 5, 48, "Text"],
Cell[36263, 954, 181, 6, 32, "Text"],
Cell[36447, 962, 320, 7, 48, "Text"],
Cell[36770, 971, 261, 6, 48, "Text"],
Cell[37034, 979, 207, 5, 48, "Text"],
Cell[37244, 986, 278, 6, 48, "Text"],
Cell[37525, 994, 398, 8, 64, "Text"],
Cell[37926, 1004, 232, 5, 48, "Text"],
Cell[38161, 1011, 344, 8, 64, "Text"],
Cell[38508, 1021, 263, 8, 48, "Text"],
Cell[38774, 1031, 261, 7, 48, "Text"],
Cell[39038, 1040, 269, 6, 48, "Text"],
Cell[39310, 1048, 192, 5, 32, "Text"],
Cell[39505, 1055, 298, 6, 48, "Text"],
Cell[39806, 1063, 221, 6, 32, "Text"],
Cell[40030, 1071, 243, 6, 48, "Text"],
Cell[40276, 1079, 204, 5, 48, "Text"],
Cell[40483, 1086, 178, 6, 32, "Text"],
Cell[40664, 1094, 269, 6, 48, "Text"],
Cell[40936, 1102, 207, 5, 48, "Text"],
Cell[41146, 1109, 176, 5, 32, "Text"],
Cell[41325, 1116, 410, 8, 64, "Text"],
Cell[41738, 1126, 364, 7, 64, "Text"],
Cell[42105, 1135, 335, 7, 48, "Text"],
Cell[42443, 1144, 184, 5, 32, "Text"],
Cell[42630, 1151, 187, 5, 32, "Text"],
Cell[42820, 1158, 779, 13, 112, "Text"],
Cell[43602, 1173, 781, 13, 112, "Text"],
Cell[44386, 1188, 432, 10, 64, "Text"],
Cell[44821, 1200, 180, 5, 32, "Text"],
Cell[45004, 1207, 191, 5, 32, "Text"],
Cell[45198, 1214, 349, 7, 64, "Text"],
Cell[45550, 1223, 357, 7, 64, "Text"],
Cell[45910, 1232, 348, 7, 64, "Text"],
Cell[46261, 1241, 317, 7, 48, "Text"],
Cell[46581, 1250, 288, 6, 48, "Text"],
Cell[46872, 1258, 447, 8, 64, "Text"],
Cell[47322, 1268, 325, 7, 48, "Text"],
Cell[47650, 1277, 341, 7, 64, "Text"],
Cell[47994, 1286, 412, 8, 64, "Text"],
Cell[48409, 1296, 323, 7, 48, "Text"],
Cell[48735, 1305, 280, 6, 48, "Text"],
Cell[49018, 1313, 272, 6, 48, "Text"],
Cell[49293, 1321, 321, 7, 48, "Text"],
Cell[49617, 1330, 594, 15, 65, "Text"],
Cell[50214, 1347, 741, 12, 112, "Text"],
Cell[50958, 1361, 931, 15, 128, "Text"],
Cell[51892, 1378, 784, 13, 112, "Text"],
Cell[52679, 1393, 943, 15, 128, "Text"],
Cell[53625, 1410, 237, 6, 48, "Text"],
Cell[53865, 1418, 319, 7, 48, "Text"],
Cell[54187, 1427, 208, 5, 48, "Text"],
Cell[54398, 1434, 214, 5, 48, "Text"],
Cell[54615, 1441, 357, 7, 64, "Text"],
Cell[54975, 1450, 267, 6, 48, "Text"],
Cell[55245, 1458, 180, 6, 32, "Text"],
Cell[55428, 1466, 381, 7, 64, "Text"],
Cell[55812, 1475, 327, 8, 48, "Text"],
Cell[56142, 1485, 290, 8, 48, "Text"],
Cell[56435, 1495, 298, 6, 48, "Text"],
Cell[56736, 1503, 283, 6, 48, "Text"],
Cell[57022, 1511, 263, 7, 48, "Text"],
Cell[57288, 1520, 278, 7, 48, "Text"],
Cell[57569, 1529, 252, 7, 48, "Text"],
Cell[57824, 1538, 228, 6, 32, "Text"],
Cell[58055, 1546, 226, 6, 32, "Text"],
Cell[58284, 1554, 374, 7, 64, "Text"],
Cell[58661, 1563, 346, 7, 64, "Text"],
Cell[59010, 1572, 450, 10, 64, "Text"],
Cell[59463, 1584, 354, 7, 64, "Text"],
Cell[59820, 1593, 331, 7, 48, "Text"],
Cell[60154, 1602, 267, 6, 48, "Text"],
Cell[60424, 1610, 220, 7, 32, "Text"],
Cell[60647, 1619, 365, 9, 48, "Text"],
Cell[61015, 1630, 274, 8, 48, "Text"],
Cell[61292, 1640, 266, 6, 48, "Text"],
Cell[61561, 1648, 207, 6, 32, "Text"],
Cell[61771, 1656, 214, 5, 48, "Text"],
Cell[61988, 1663, 201, 7, 32, "Text"],
Cell[62192, 1672, 229, 5, 48, "Text"],
Cell[62424, 1679, 190, 5, 32, "Text"],
Cell[62617, 1686, 240, 6, 48, "Text"],
Cell[62860, 1694, 250, 7, 48, "Text"],
Cell[63113, 1703, 311, 8, 48, "Text"],
Cell[63427, 1713, 299, 6, 48, "Text"],
Cell[63729, 1721, 261, 6, 48, "Text"],
Cell[63993, 1729, 200, 5, 32, "Text"],
Cell[64196, 1736, 348, 7, 64, "Text"],
Cell[64547, 1745, 210, 6, 32, "Text"],
Cell[64760, 1753, 200, 7, 32, "Text"],
Cell[64963, 1762, 187, 7, 32, "Text"],
Cell[65153, 1771, 239, 7, 48, "Text"],
Cell[65395, 1780, 223, 5, 48, "Text"],
Cell[65621, 1787, 184, 7, 32, "Text"],
Cell[65808, 1796, 535, 11, 80, "Text"],
Cell[66346, 1809, 221, 7, 32, "Text"],
Cell[66570, 1818, 315, 8, 48, "Text"],
Cell[66888, 1828, 283, 6, 48, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

