(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19113,        477]*)
(*NotebookOutlinePosition[     43994,       1378]*)
(*  CellTagsIndexPosition[     43950,       1374]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial List \
\>", "Title"],

Cell["\<\
\tThere are 17 tutorial notebooks accompanying this package.   \
Brief descriptions are given below.  Tutorial 0 is a good starting point.  It \
deals only with very basic functions, and with a very limited number of \
option changes.  Tutorials 1 through 16 give a systematic set of examples \
which illustrate every function and option in the package.  \
\>", "Text",
  Evaluatable->False,
  PageBreakBelow->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["TUTORIAL ZERO -- INTRODUCTION TO DYNPAC", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis tutorial uses the linear, damped, undriven oscillator as an \
example.  The purpose of the tutorial is to give a very basic introduction to \
DynPac.  The functions and variables used in this tutorial are asprat, \
classify2D, findpolyeq, ntegrate, intreset, parmval, parmvec, phaseplot, \
plotreset, setparm, setstate, slopevec, spiralportrait, stripsol, subsol, \
sysid, sysname, sysreport, and timeplot.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL ONE -- INTEGRATION AND PLOTTING (2D)", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis tutorial uses the linear, damped, undriven oscillator as an \
example.  The focus is on basic integration and plotting in two dimensions.  \
The functions and variables used in this tutorial are arrowflag, arrowvec, \
asprat, bothdirflag, buildinterp, colorvec, colorvecdis, dashvec, dirfield, \
evalparm, firstt, firsttx, firstx, imsize, integrate, intreport, intreset, \
joinsol, lastt, lasttx,lastx, lnthick, parmreport, parmval, parmvec, \
phaseplot, phaser, plrange, plotreport, plotreset, pointcon, ptsize, \
reversetime, setcolor, setdash, setparm, setstate, show, slopevec,  \
solinterp, staterange, statevec, stripsol, subsol, sugtimestep, sysid, \
sysname, sysreport, timeplot, and trange.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL TWO -- INTEGRATION AND PLOTTING (3D)", "Subsubsection",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[
  "This tutorial uses the R\[ODoubleDot]ssler system, a three-dimensional, \
nonlinear, autonomous system.  The system exhibits a period doubling route to \
chaos, although only the stable limit cycles are considered in this tutorial. \
 Most of the 3D plotting routines are illustrated.  The functions and \
variables used are animate, asprat, boxrat, colorvec, graylev, integrate, \
inreset, lastt, lastx, parmval, parmvec, period, phaseplot, phaseplot3D, \
phaser3D, plotreset, rotphaseplot3D, setcolor, setparm, setstate, slopevec, \
statevec, sugtimestep, sysid, and viewpt.",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL THREE -- EQUILIBRIUM AND STABILITY", "Subsubsection",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[
  "This tutorial uses two systems as examples.  The first is a linear system \
of dimension two with a single parameter.  The single equilbrium is at the \
origin.  The stability is examined for three different values of the \
parameter.  The second system studied is the Lorenz system.  This system has \
a pitchfork bifurcation as one of the parameters is varied.  The location and \
stability of the equilibria are found for several different sets of parameter \
values.  The functions and variables used are classify, classify2D, dermat, \
dermatval, eigval, eigsys, findpolyeq, nfindeq, nfindpolyeq, parmval, \
parmvec, residual, setparm, setstate, slopevec, statevec, sysid, and \
transorg.",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL FOUR -- LOCAL SOLUTION NEAR EQUILIBRIUM POINT", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox["This tutorial uses a nonlinear autonomous system of dimension two \
as an example.  The system has a single equilibrium at the origin which is a \
saddle.  The stable and unstable manifolds of the saddle are constructed.  \
The stable and unstable manifolds of the linearized system are constructed to \
illustrate the tangency connection at the equilibrium point.  The functions \
and variables used are arrowflag, arrowvec, axon, centerportrait, classify2D, \
dermat, dermatval, framelabon, frameon, integrate, labon, labshift, \
nodeportrait, outbound, parmval, parmvec, phaser, plrange, rangeflag, ranger, \
restoresys, saddleportrait, saddleportraitman, savesys, setcolor, setparm, \
setstate, slopevec, spiralportrait, statevec, sysname, and sysid.",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL FIVE -- COMPARISON OF INTEGRATION METHODS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThis tutorial uses the Lorenz equations as an example.  The four \
methods of integration in the package are used to construct 2000 time steps \
of a solution in the chaotic regime of parameters.  The four methods are (1) \
NDSolve without a maximum step size, (2) NDSolve with a maximum step size, \
(3) fourth order Runge-Kutta without range checking, (4) fourth order \
Runge-Kutta with range checking.  Each method is timed, and a graph of the \
results is constructed for each method.  The functions and variables used are \
asprat, fastflag, integrate, intreset, maxstepflag, parmval, parmvec, \
phaseplot, plotreset, rangeflag, ranger, sciflag, setparm, setstate, \
slopevec, staterange, statevec, sysid, and sysname.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL SIX -- PERIODIC SOLUTIONS OF AUTONOMOUS SYSTEMS", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, we use three different systems to illustrate \
calculations with periodic solutions.  We use the undamped Duffing equation \
to illustrate a nonlinear center, the van der Pol equation to illustrate a 2D \
limit cycle, and the R\[ODoubleDot]ssler equations to illustrate a 3D limit \
cycle.  In addition to calculating and plotting the solutions, we use the \
function period to find periods, and we construct several Poincar\[EAcute] \
maps.  We also illustrate the use of slope divergence to learn something \
about the location of periodic solutions (Bendixson test).  The functions and \
variables used here are asprat, axon, axorg, div, dival, frompolartrans, \
integrate, intreset, joinsol, labshift, lastt, lastx, limcyc, parmval, \
parmvec, period, phaseplot, phaser, phaser3D, plotreset, plrange, plrange3D, \
poinclist, poincmap, poincmapopt3D, poincmap3D, poincminus, poincplane, \
poincplus, poincptsize, polartrans, restoresys, savesys, setparm, setstate, \
show, signcontour, slopevec, statevec, sysname, sysid, sysreport, stateshift, \
and timeshift.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL SEVEN -- PERIODIC SOLUTIONS OF DRIVEN SYSTEMS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox["We use the damped driven pendulum here to illustrate the routines \
for periodic solutions of periodically driven systems.  We construct \
solutions and Poincar\[EAcute] maps for several different parameter sets -- \
some leading to periodic solutions, one leading to a chaotic solution.  The \
functions and variables used in this tutorial are asprat, backcolor, display, \
drpoinclist, drpoincmap, drpoincmap3D, drpoincsol, imsize, integrate, \
intreset, lastt, lastx, modsol, parmval, parmvec, phaser, plotreset, plot, \
plrange, plrange3D, poincpointper, poincptsize, pointcon, setparm, setstate, \
show, slopevec, staterange, statevec, sysid, sysname, timeplot, and trange.   \
",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL EIGHT -- ORBIT TRAPPING AND INDEX THEORY", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox["This tutorial illustrates the use of routines for index \
calculations and orbit trapping in two-dimensional systems.  As examples, we \
use several simple linear and nonlinear systems.  We show how to define \
curves, how to determine whether a curve traps orbits, and how to find the \
index of a closed curve with respect to a given system.   The functions and \
variables used in this tutorial are arrowflag, arrowvec, classify2D, \
colorvec, dashvec, dirfield, dirpt, display, index, labon, limcyc, \
ncurpoints, orbcross,  parmval, parmvec, period, phaser, plotcurve, \
plotreset, plrange, setcolor, setdash, setparm, setstate, show, slopevec, \
statevec, and sysid.   ",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL NINE -- PHASE PORTRAITS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox["In this tutorial, we illustrate the production of phase portraits \
from a given set of initial conditions.  We also show how to construct a \
sequence of graphs which, when animated, gives a dynamic view of the orbits \
in time.  For a two-dimensional example, we use the van der Pol equation.  \
For a three-dimensional example, we use the van der Pol equation embedded in \
a three-dimensional system.  The functions and variables used in this \
tutorial are asprat, boxrat, colorvec, display, dots, dots3D, integrate, \
intreset, labshift, limcyc,  parmval, parmvec, period, phaser, phaseseq, \
phaseseq3D, plotreset, plrange, plrange3D, portrait, portrait3D, restoresys, \
savesys, setcolor, setparm, setstate, show, slopevec, statevec, sysid, and \
sysreport.   ",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL TEN -- BIFURCATION SEQUENCES", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[
  "In this tutorial, we use the routines bifurc, bifurc3D, limbifurc, and \
limbifurc3D to construct sequences of phase portraits corresponding to \
specified sequences of system parameters.  As examples, we use both two- and \
three-dimensional linear systems depending on a single parameters.  We also \
use two- and three-dimensional versions of the van der Pol equation.  The \
graph sequences, when animated, give a dynamic view of the bifurcations.  The \
functions and variables used in this tutorial are asprat, bifurc, bifurc3D, \
boxrat, classify, classify2D, colorvec, intreset, labshift, limbifurc, \
limbifurc3D, parmval, parmvec, plotreset, plrange, plrange3D, rangeflag, \
ranger, savesys, setcolor, setparm, setstate, slopevec, statevec, sysid, and \
sysname.   ",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL ELEVEN -- LIAPUNOV FUNCTIONS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox["In this tutorial, we use Liapunov functions to look at the \
stability of some planar equilibria.  The routines demonstrated  do not help \
in the selection of a trial form for a Liapunov function, but they do allow a \
quick graphical check on the sign of either the function or its orbital \
derivative.  As examples, we use two simple nonlinear systems for which \
linearization does not yield a definite answer on the stability question.  \
The functions and variables used in this tutorial are arrowflag, arrowvec, \
classify2D,labshift, liaparmval, liaparmvec, liapcontours, liapsign, \
liapsignseq, orbdt, orbdtval, parmval, parmvec, plotreset, plrange, portrait, \
setparm, setstate, slopevec, statevec, sysid, and sysname.        ",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL TWELVE -- COLORING AND DASHING", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this tutorial, we look at the methods for assigning color and \
dashing to plots.  The system used for an example is a simple linear \
oscillator in both 2D and 3D.  The functions and variables used in this \
tutorial are bifurc3D, boxrat, colorvec, dashalt, dashlong, dashort, dashvec, \
dotted, integrate, labshift, parmval, parmvec, phaseplot, plotreset, \
plrange3D, pointcon, portrait, restoresys, savesys, setcolor, setdash, \
setparm, setstate, slopevec, solid, statevec, sysid, sysname, and timeplot.   \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL THIRTEEN -- THE LORENZ EQUATIONS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[
  "In this tutorial, we look at some interesting features of solutions of the \
Lorenz equations.  The mode is not that of exploration, but rather \
verification and visualization of some results that are known for these \
equations.  The three parameters of the Lorenz equations are sigma, r, and b. \
 Here we take the frequently used values of sigma = 10.0 and b = 8/3, and we \
look at properties of the solutions for selected values of r.  The functions \
and variables used in this tutorial are asprat, boxrat, classify, dermatval, \
dival, eqstateval, fastflag, findpolyeq, integrate, intreset, joinsol, lastt, \
lastx,  parmval, parmvec, phaseplot, phaser3D, plotreset, plrange, plrange3D, \
portrait3D, rangeflag, ranger, setparm, setstate, show3D, slopevec, \
staterange, statevec, sysid, sysname, and timeplot.     ",
    FontWeight->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL FOURTEEN -- ANIMATING THE LORENZ ATTRACTOR", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIn this tutorial, we have the single objective of producing an animation \
of the three-dimensional strange attractor associated with chaotic motion.  \
The parameter values used are the ones most commonly used for chaotic motion: \
 sigma = 10, b = 8/3, and r = 28.  The functions and variables used in this \
tutorial are animate,",
  StyleBox[" ",
    FontWeight->"Bold"],
  "asprat, boxrat, colorvec, decdig, fastflag, graylev, integrate, intreset, \
parmval, parmvec, phaser3D, plotreset, pointcon, ptsize, setcolor, setparm, \
setstate, show3D, slopevec, statevec, sysid, sysname, timeplot, and totdig.   \
"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL FIFTEEN -- GRAPH LABELS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this tutorial, we illustrate the options for graph labels.  \
The systems used are an RLC circuit, and a driven damped linear spring-mass \
oscillator.  The functions and variables used in this tutorial are axlabon, \
arrowflag, arrowvec, asprat, decdig, imsize, integrate, intreset, labon, \
labshift, parmunits, parmunitsclear, parmval, phaser, plotreset, restoresys, \
savesys, sciflag,  setparm, setstate, slopevec, stateunits, stateunitsclear, \
sysname, sysreport, timeplot, timeunit, timeunitclear, totdig, transol, and \
unitsclear. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL SIXTEEN -- LAG EQUATIONS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this tutorial we illustrate the use of the function \
lagintegrate, which integrates systems of equations containing time-lagged \
dependent variables.  The routines are applied to the logistic equation, with \
a lag in the amplitude dependent growth rate, and to the SIR model for \
epidemics.  In the SIR model, the recovery time is taken to be uniform, and \
this leads to a system of two first-order equations with lags.  The functions \
and variables used in this tutorial are asprat, intreset, labon, \
lagintegrate, parmval, plotreset, plrange, restoresys, savesys, setcolor, \
setparm, setstate, show, slopevec, sysid, sysname, sysreport, and timeplot. \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TUTORIAL SEVENTEEN -- ITERATED MAPS", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn this tutorial we illustrate the use of the functions defined \
for iterated mappings.  Examples include the logistic map and the Henon map.  \
The functions and variables used in this tutorial are asprat, bifurcmap, \
bifurc3Dmap, bimap, boxrat, classifymap, cobweb,  eigsysmap, eigvalmap, \
findpolyfix, imsize, intreset, iterate, jacob, jacobval, mapcomp, mapval, \
nfindfix, nfindpolyfix, parmval, periodmap, phaser, phaser3D, plotreset, \
plrange, plrange3D, pointcon, portraitmap, portrait3Dmap, ptsize, rangeflag, \
ranger, residualfix, setback, setcolor, setmap, setde, setparm, setstate, \
slopevec, stripsol, sysid, sysreport, timeplot, and viewmap.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{632, 433},
WindowMargins->{{2, Automatic}, {Automatic, -1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000L60801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 57, 3, 152, "Title"],
Cell[1799, 56, 452, 9, 65, "Text",
  Evaluatable->False,
  PageBreakBelow->False],

Cell[CellGroupData[{
Cell[2276, 69, 112, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[2391, 73, 439, 7, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2867, 85, 118, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[2988, 89, 730, 11, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3755, 105, 147, 3, 42, "Subsubsection",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[3905, 110, 731, 15, 99, "Text",
  Evaluatable->False,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[4673, 130, 146, 3, 42, "Subsubsection",
  Evaluatable->False,
  PageBreakWithin->Automatic],
Cell[4822, 135, 849, 17, 116, "Text",
  Evaluatable->False,
  PageBreakWithin->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[5708, 157, 127, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[5838, 161, 877, 15, 133, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[6752, 181, 123, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[6878, 185, 800, 13, 133, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[7715, 203, 132, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[7850, 208, 1207, 20, 168, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[9094, 233, 127, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[9224, 237, 806, 15, 116, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[10067, 257, 122, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[10192, 261, 798, 15, 116, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[11027, 281, 105, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[11135, 285, 891, 16, 133, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[12063, 306, 110, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[12176, 310, 901, 17, 133, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[13114, 332, 110, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[13227, 336, 862, 15, 116, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[14126, 356, 112, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[14241, 360, 542, 9, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14820, 374, 114, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[14937, 378, 949, 17, 133, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[15923, 400, 124, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[16050, 404, 647, 12, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16734, 421, 105, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[16842, 425, 570, 9, 99, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17449, 439, 106, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[17558, 443, 692, 11, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18287, 459, 108, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[18398, 463, 687, 10, 116, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

