(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18601,        657]*)
(*NotebookOutlinePosition[     43748,       1566]*)
(*  CellTagsIndexPosition[     43704,       1562]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 0\
\>", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Introduction to DynPac
\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "asprat, classify2D, findpolyeq, integrate, intreset, parmval, parmvec, \
phaseplot, plotreset, setparm, setstate, slopevec, spiralportrait, sysid, \
sysname, sysreport, and timeplot.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of System Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We use the damped, linear, undriven oscillator to illustrate the basic \
features of DynPac."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Differential Equations",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tOur starting point is the standard second-order equation for a damped, \
linear, undriven spring-mass oscillator.  The basic differential equation \
governing the displacement ",
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  StyleBox["t",
    FontSlant->"Italic"],
  ") of the oscillator comes from Newton's law and is given by"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontSlant->"Italic"], 
              FractionBox[
                StyleBox[\(\(d\^2\) x\),
                  FontSlant->"Italic"], 
                SuperscriptBox[
                  StyleBox["dt",
                    FontSlant->"Italic"], "2"]]}], " ", "+", "  ", 
            RowBox[{
              StyleBox["b",
                FontSlant->"Italic"], 
              FractionBox[
                StyleBox["dx",
                  FontSlant->"Italic"], 
                StyleBox["dt",
                  FontSlant->"Italic"]]}], " ", "+", " ", 
            StyleBox["kx",
              FontSlant->"Italic"]}], "  ", "=", "  ", "0"}], "  ", ",", 
        "                                                                     \
                              ", 
        StyleBox[\((1)\),
          FontWeight->"Bold"]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "where ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "is the mass, ",
  StyleBox["b",
    FontSlant->"Italic"],
  " is the damping constant, and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " is the spring constant (with ",
  StyleBox["m",
    FontSlant->"Italic"],
  " and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " positive and ",
  StyleBox["b ",
    FontSlant->"Italic"],
  "non-negative).  We now convert this to a system of two-first order \
equations in the standard way by introducing the velocity "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["v",
          FontSlant->"Italic"], 
        StyleBox[
          RowBox[{" ", 
            StyleBox[" ",
              FontSlant->"Italic"]}]], "=", 
        RowBox[{
          FractionBox[
            StyleBox["dx",
              FontSlant->"Italic"], 
            StyleBox["dt",
              FontSlant->"Italic"]], "   ", ".", 
          "                                                                   \
                                                      ", 
          StyleBox[\((2)\),
            FontWeight->"Bold"]}]}], TextForm]], "Text",
  TextAlignment->Right],

Cell[TextData[{
  "Then we may rewrite equations (1) and (2) as a system of first-order \
equations in ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  ": "
}], "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FractionBox[
              StyleBox["dx",
                FontSlant->"Italic"], 
              StyleBox["dt",
                FontSlant->"Italic"]], " ", "=", "  ", 
            StyleBox["v",
              FontSlant->"Italic"]}], 
          StyleBox["    ",
            FontSlant->"Italic"], 
          StyleBox[",",
            FontSlant->"Italic"], 
          
          StyleBox[
            "                                                                 \
                                                           ",
            FontSlant->"Italic"], "\n", 
          StyleBox[\((3)\),
            FontWeight->"Bold"]}]}], TextForm], 
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"and", "             ", 
            FractionBox[
              StyleBox["dv",
                FontSlant->"Italic"], 
              StyleBox["dt",
                FontSlant->"Italic"]]}], "  ", "=", "  ", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                FractionBox[
                  StyleBox["b",
                    FontSlant->"Italic"], 
                  StyleBox["m",
                    FontSlant->"Italic"]]}], 
              StyleBox["v",
                FontSlant->"Italic"]}], " ", "-", 
            RowBox[{
              FractionBox[
                StyleBox["k",
                  FontSlant->"Italic"], 
                StyleBox["m",
                  FontSlant->"Italic"]], 
              RowBox[{
                StyleBox["x",
                  FontSlant->"Italic"], "      ", "."}]}]}]}], 
        "                                                                     \
                         "}], TextForm]}], "Text",
  TextAlignment->Right],

Cell["\<\
These equations will be solved subject to initial conditions of the \
form\
\>", "Text"],

Cell[TextData[{
  StyleBox["x",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ",    ",
  StyleBox["v",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)]],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`v\_0\)]],
  "    .                                                                      \
",
  StyleBox["(4)",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Right],

Cell["\<\
After the equations are solved, we will generate both time plots \
and phase plane plots of the solutions.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Defining the System for DynPac",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "There are four steps in defining a system for DynPac.  The first step is \
to declare the state variables (dependent variables), which in this case are \
",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["v",
    FontSlant->"Italic"],
  ".  This is done by the command setstate:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,v}];", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The next step is to declare all of the parameter names for the system, in \
this case ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["k",
    FontSlant->"Italic"],
  ".  This is done with the setparm command:"
}], "Text"],

Cell["setparm[{m,b,k}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
The third step is to define the slopevector for the system, which \
is just the right-hand sides of the equations in the normal form (3).  \
\>", 
  "Text"],

Cell["slopevec = {v,-(b/m)*v -(k/m)*x};", "Input",
  AspectRatioFixed->True],

Cell["\<\
These three statements define the system (3).  Before carrying out \
an integration, we must also give values to the parameters.  The names of the \
parameters have been stored in a vector called parmvec.  This occurred when \
setparm was executed.  We can at any time recall the names and their order by \
simply typing parmvec:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(parmvec\)], "Input"],

Cell[TextData[{
  "The vector parmvec is used only for the names.  The values of these \
parameters are stored in a vector named parmval.  Thus to assign values of \
say ",
  StyleBox["m",
    FontSlant->"Italic"],
  " = 2 kg, ",
  StyleBox["b",
    FontSlant->"Italic"],
  " = 4 N\[CenterDot]s/m, and ",
  StyleBox["k",
    FontSlant->"Italic"],
  " = 74 N/m, we type"
}], "Text"],

Cell[BoxData[
    \(\(parmval = {2, 4, 74};\)\)], "Input"],

Cell["\<\
At this point, our system is fully defined.  At this point, we can \
give our system a name, which will appear on any graphs that we construct.  \
We do this by assigning our chosen name to the variable sysname:\
\>", "Text"],

Cell[BoxData[
    \(\(sysname = "\<Osc\>";\)\)], "Input"],

Cell["\<\
To refresh our memory on everything we have specified about the \
system, we type\
\>", "Text"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
We see all the items we have defined, plus a few others that we \
won't worry about in this tutorial.  \
\>", "Text"],

Cell[TextData[{
  "\tIn DynPac, the independent variable is always ",
  StyleBox["t, ",
    FontSlant->"Italic"],
  "so we do not have to define it."
}], "Text"],

Cell["\<\
\tThere is one more bit of housekeeping before we proceed.  We \
reset the integration parameters and plotting parameters to their defaults \
with the following two commands:\
\>", "Text"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell["\<\
This insures that any non-default settings from previous \
calculations during this session will not take us by surprise.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integration of the System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Integrations are carried out by the routine integrate.  Integrate makes \
use of the items already defined.  In addition, it requires values for four \
arguments:  the initial vector, the initial time, the time step, and the \
number of time steps, in that order.  We will give names to each of these as \
we define them (the names can be anything we like).  Let's start with the \
initial vector.  We start our oscillator up with a displacement of 1 m, and \
no initial velocity.  We call this initial vector initvec:",
  StyleBox["\t\t",
    FontWeight->"Bold"],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {1.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["We take the initial time, called t0, to be zero:", "Text"],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["For the time step h, we choose", "Text"],

Cell["h = 0.025;", "Input",
  AspectRatioFixed->True],

Cell["\<\
For the number of time steps nsteps, we take a value which will \
carry us out to 5 seconds, so\
\>", "Text"],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tAfter this rather elaborate warmup, we are now actually ready to \
integrate.  The routine integrate returns a solution.  In order to use this \
solution in plots, we give it a name.  We call it firstsol:\
\>", "Text"],

Cell[BoxData[
    \(\(firstsol = integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell["\<\
That's all there is to it.  The solution is now stored under the \
name firstsol, and we may make plots of it.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Time Plots",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tLet's begin by plotting ",
  StyleBox["x",
    FontSlant->"Italic"],
  " as a function of time.  The function which does this is timeplot, and it \
takes two arguments.  The first argument is the name of the solution, and the \
second argument is the component that is to be plotted.  Before plotting, we \
ask for an aspect ratio of 0.7 by setting"
}], "Text"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[firstsol, 1];\)\)], "Input"],

Cell[TextData[{
  "We see that the graph is labeled with ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", and with the parameter names and values, as well as the system name."
}], "Text"],

Cell["\<\
\tTo plot the velocity, we repeat, only this time we ask for the \
second component:\
\>", "Text"],

Cell[BoxData[
    \(\(timeplot[firstsol, 2];\)\)], "Input"],

Cell["To get both components on the same plot, we type", "Text"],

Cell[BoxData[
    \(\(timeplot[firstsol, {1, 2}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Phase Plane Plots",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We can also generate a phase plane plot of our solution.  The function \
which does this is phaseplot.  Phaseplot has two arguments -- the name of the \
solution, and the components which are to be plotted.  (In a system of \
dimension higher than 2, we have a choice of components).  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(phaseplot[firstsol, 1, 2];\)\)], "Input"],

Cell["\<\
This is a little squashed, so we need to exercise an option here \
and change the aspect ratio, by setting\
\>", "Text"],

Cell[BoxData[
    \(\(asprat = 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(phaseplot[firstsol, 1, 2];\)\)], "Input"],

Cell["\<\
That's better.  We see clearly the inward spiral of the damped \
oscillator.\
\>", "Text"],

Cell["\<\
We can also use phaseplot to get a time plot, because the time \
coordinate may be referenced by index 0.  \
\>", "Text"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(phaseplot[firstsol, 0, 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Learning More About the System With Special Purpose Functions",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe look here at just a few functions which automate some of the \
labor in studying a dynamical system.  We start with the location of \
equilibrium states.  For this particular system, it is physically obvious \
that the only equilibrium state is that of the oscillator at rest at zero \
displacement.  In more complicated systems, the equilibria are not always so \
obvious.  The function findpolyeq finds equilibrium states for systems with \
polynomial slope vectors.  Let's try it. \
\>", "Text"],

Cell[BoxData[
    \(findpolyeq\)], "Input"],

Cell["\<\
The routine correctly tells us that the origin is an equilibrium.  \
From our previous phase plane picture, it is fairly obvious that this \
equilibrium is a spiral.  A function which will perform this analysis for us \
is classify2D.  This function takes one argument -- the coordinates of the \
equilibrium point -- and returns a classification of the point.  We try it:\
\
\>", "Text"],

Cell[BoxData[
    \(classify2D[{0, 0}]\)], "Input"],

Cell["\<\
We are told that the equilibrium is strictly stable and that it is \
a spiral.  \
\>", "Text"],

Cell[TextData[{
  "\tSuppose we wanted a simple phase plane plot of several solutions near \
this equilibrium.  We could of course construct it curve by curve, but there \
is an easier way.  The routine spiralportrait automates this process.  It \
takes two arguments:  the first is the location of the equilibrium point, and \
the second is the plotting window for the graph.  We try this with a window \
{{-1,1},{-6,6}}, corresponding to ",
  StyleBox["x",
    FontSlant->"Italic"],
  " varying from -1 to 1 m and the velocity ",
  StyleBox["v",
    FontSlant->"Italic"],
  " varying from -6 to 6 m/s."
}], "Text"],

Cell[BoxData[
    \(\(spiralportrait[{0, 0}, {{\(-1\), 1}, {\(-6\), 6}}];\)\)], "Input"],

Cell["\<\
\tWe get the general idea of the phase portrait from this.  We \
could of course construct a better picture by constructing the integral \
curves individually, but the spiralportrait routine gives us a quick and easy \
look.  There are similar routines for nodes, saddles, and centers.\
\>", 
  "Text"],

Cell[TextData[{
  "\tTo label our notebook with the current version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the current version of DynPac, and the date, we type"
}], "Text"],

Cell[BoxData[
    \(sysid\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{0, Automatic}, {Automatic, -3}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 101, 5, 152, "Title",
  Evaluatable->False],
Cell[1843, 58, 99, 5, 87, "Subtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1967, 67, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2127, 72, 306, 8, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2470, 85, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2628, 90, 214, 7, 32, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2879, 102, 134, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3016, 107, 366, 10, 64, "Text"],
Cell[3385, 119, 1002, 28, 47, "Text"],
Cell[4390, 149, 547, 21, 48, "Text"],
Cell[4940, 172, 637, 19, 44, "Text"],
Cell[5580, 193, 219, 9, 32, "Text"],
Cell[5802, 204, 1794, 53, 90, "Text"],
Cell[7599, 259, 98, 3, 30, "Text"],
Cell[7700, 264, 509, 23, 32, "Text"],
Cell[8212, 289, 130, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8379, 297, 142, 3, 46, "Subsection",
  Evaluatable->False],
Cell[8524, 302, 417, 14, 50, "Text",
  Evaluatable->False],
Cell[8944, 318, 59, 1, 27, "Input"],
Cell[9006, 321, 311, 12, 48, "Text"],
Cell[9320, 335, 60, 1, 27, "Input"],
Cell[9383, 338, 166, 4, 46, "Text"],
Cell[9552, 344, 76, 1, 27, "Input"],
Cell[9631, 347, 401, 8, 62, "Text",
  Evaluatable->False],
Cell[10035, 357, 40, 1, 27, "Input"],
Cell[10078, 360, 381, 13, 48, "Text"],
Cell[10462, 375, 58, 1, 27, "Input"],
Cell[10523, 378, 235, 4, 46, "Text"],
Cell[10761, 384, 57, 1, 27, "Input"],
Cell[10821, 387, 105, 3, 30, "Text"],
Cell[10929, 392, 42, 1, 27, "Input"],
Cell[10974, 395, 127, 3, 30, "Text"],
Cell[11104, 400, 161, 5, 32, "Text"],
Cell[11268, 407, 198, 4, 46, "Text"],
Cell[11469, 413, 46, 1, 27, "Input"],
Cell[11518, 416, 47, 1, 27, "Input"],
Cell[11568, 419, 145, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11750, 427, 137, 3, 46, "Subsection",
  Evaluatable->False],
Cell[11890, 432, 692, 15, 98, "Text",
  Evaluatable->False],
Cell[12585, 449, 63, 1, 27, "Input"],
Cell[12651, 452, 64, 0, 30, "Text"],
Cell[12718, 454, 52, 1, 27, "Input"],
Cell[12773, 457, 46, 0, 30, "Text"],
Cell[12822, 459, 53, 1, 27, "Input"],
Cell[12878, 462, 119, 3, 30, "Text"],
Cell[13000, 467, 56, 1, 27, "Input"],
Cell[13059, 470, 230, 4, 46, "Text"],
Cell[13292, 476, 82, 1, 27, "Input"],
Cell[13377, 479, 136, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13550, 487, 122, 3, 46, "Subsection",
  Evaluatable->False],
Cell[13675, 492, 382, 8, 64, "Text"],
Cell[14060, 502, 50, 1, 27, "Input"],
Cell[14113, 505, 59, 1, 27, "Input"],
Cell[14175, 508, 241, 8, 32, "Text"],
Cell[14419, 518, 108, 3, 30, "Text"],
Cell[14530, 523, 59, 1, 27, "Input"],
Cell[14592, 526, 64, 0, 30, "Text"],
Cell[14659, 528, 64, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14760, 534, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[14892, 539, 407, 9, 64, "Text",
  Evaluatable->False],
Cell[15302, 550, 63, 1, 27, "Input"],
Cell[15368, 553, 130, 3, 30, "Text"],
Cell[15501, 558, 50, 1, 27, "Input"],
Cell[15554, 561, 63, 1, 27, "Input"],
Cell[15620, 564, 100, 3, 30, "Text"],
Cell[15723, 569, 131, 3, 30, "Text"],
Cell[15857, 574, 50, 1, 27, "Input"],
Cell[15910, 577, 63, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16010, 583, 174, 4, 46, "Subsection",
  Evaluatable->False],
Cell[16187, 589, 513, 8, 78, "Text"],
Cell[16703, 599, 43, 1, 27, "Input"],
Cell[16749, 602, 398, 7, 62, "Text"],
Cell[17150, 611, 51, 1, 27, "Input"],
Cell[17204, 614, 104, 3, 30, "Text"],
Cell[17311, 619, 616, 13, 96, "Text"],
Cell[17930, 634, 88, 1, 27, "Input"],
Cell[18021, 637, 312, 6, 62, "Text"],
Cell[18336, 645, 196, 5, 48, "Text"],
Cell[18535, 652, 38, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

