(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30419,       1119]*)
(*NotebookOutlinePosition[     55512,       2026]*)
(*  CellTagsIndexPosition[     55468,       2022]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 1\
\>", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Integration and Plotting (2D)\n"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "arclen, arrowflag, arrowvec, asprat, bothdirflag, buildinterp, colorvec, \
colorvecdis, dashvec, dirfield, evalparm, firstt, firsttx, firstx, imsize, \
integrate, intreport, intreset, joinsol, lastt, lastx, lastx, lnthick, \
parmreport, parmval, parmvec, phaseplot, phaser, plrange, plotreport, \
plotreset, pointcon, ptsize, reversetime, setcolor, setdash, setparm, \
setstate, show, slopevec, solinterp, staterange, statevec, stripsol, subsol, \
sugtimestep, sysid, sysname, sysreport, timeplot, trange.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of System Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We use the damped, linear, undriven oscillator to illustrate the basics \
about defining systems, and constructing and plotting solutions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We denote the position by x and the velocity (x-dot) by y.  We use a \
dimensionless formulation in which the undamped frequency is unity, and the \
dimensionless damping constant is 2 eps.  To define the system, we must \
specify statevec, slopevec, and parmvec. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{eps}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y,-x -2*eps*y};", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThese three statements define the system of differential \
equations given by\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" dx/dt = y ,  dy/dt = -x -2*eps*y  .", "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell["\<\
\tWe choose a moderately damped system by setting eps = 0.2.  We do \
this not by assigning eps a value, but by assigning the vector parmval a \
value.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {0.2};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"In fact, the state variables x and y and the parameter eps were protected \
when the routines setstate and setparm were executed.  Thus we will fail if \
we attempt the inappropriate command of directly assigning eps a=(or x and y) \
a value. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["eps = 0.3;", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tIf we wish to evaluate any expression containing the parameter \
symbols, we can do this with evalparm, a function which will replace all \
symbols with their current values in parmval.  For example, the slope vector \
is\
\>", "Text"],

Cell[BoxData[
    \(evalparm[slopevec]\)], "Input"],

Cell[TextData["We check our definition with sysreport."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integration Parameters",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We will be ready to do our first integration as soon as we have chosen an \
initial state, an initial time, a time step, and the number of time steps  \
These four quantities appear as arguments of integrate, and they may have any \
name.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {1.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell["\<\
We also could have asked DynPac for a suggested time step.  Let's \
do that and compare it with our choice.  The function which returns the time \
step suggestion is sugtimestep, and it has a single argument -- a box region \
in phase space over which it performs the sampling necessary to compute the \
time step.  Thus the box region should be representative of the part of phase \
space in which we are going to study the solution.  We define the region and \
ask for the suggestion:\
\>", "Text"],

Cell[BoxData[
    \(\(window = {{\(-1\), 1}, {\(-1\), 1}};\)\)], "Input"],

Cell[BoxData[
    \(sugtimestep[window]\)], "Input"],

Cell["\<\
We see that the suggested time step is fairly close to our earlier \
choice.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integration",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We have a choice of methods of integration.  In this tutorial, we will use \
the default, which is the fourth order Runge-Kutta with a uniform time step, \
and with no range checking.  In other tutorials we will look at some of the \
other options.  We use the command intreset to set the default values for \
integration. Then we invoke integrate to find the solution, and we name our \
first solution sol1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["sol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tLet's see what this solution actually looks like by examining the \
first five elements.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Take[sol1,5]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The solution is a list of lists.  Each element in the list has t, x and y \
values in that order.  If for any purpose we need to remove one of the \
coordinates from the list, we can do that with the function stripsol.  For \
this purpose, the time coordinate is numbered 0 and x and y are 1 and 2 \
respectively.  As an example, we remove the time coordinate and look at the \
first five elements of the modified list."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["notimesol1 = stripsol[sol1,0];", "Input",
  AspectRatioFixed->True],

Cell["Take[notimesol1,5]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tIf we have an application which requires a solution in the form \
of a smooth function rather than a list, we can use the function buildinterp \
to produce a smooth function from our list.  We do that here for sol1.  We \
calculate a few sample values.  We will graph this interpolated solution \
later.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["{X,Y} = buildinterp[sol1];", "Input",
  AspectRatioFixed->True],

Cell["X[0]", "Input",
  AspectRatioFixed->True],

Cell["Y[0]", "Input",
  AspectRatioFixed->True],

Cell["X[0.2]", "Input",
  AspectRatioFixed->True],

Cell["Y[0.2]", "Input",
  AspectRatioFixed->True],

Cell["\<\
An alternative interpolation scheme is provided by solinterp.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(solinterp[sol1, state, slope];\)\)], "Input"],

Cell["\<\
This constructs state[t], which gives the value of the state vector \
at t, and slope[t], which gives the value of the slope vector at t.\
\>", 
  "Text"],

Cell[BoxData[
    \(state[0.2]\)], "Input"],

Cell[BoxData[
    \(slope[0.2]\)], "Input"],

Cell["\<\
As an accuracy check, we evaluate the differential equation at a \
few times:\
\>", "Text"],

Cell[BoxData[
    \(\(err[t_] = D[state[t], t] - slope[t];\)\)], "Input"],

Cell[BoxData[
    \(err[0]\)], "Input"],

Cell[BoxData[
    \(err[5]\)], "Input"],

Cell[BoxData[
    \(err[10]\)], "Input"],

Cell["\<\
We appear to have good accuracy, both with the numerical \
integration and the interpolation, and even differentiating the interpolating \
function.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Time Plots",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "To see what the solution really looks like, we need to plot it. We first \
do some time plots.  We reset the plotting parameters to their default values \
by executing plotreset, and then we set the aspect ratio to 0.5, which is \
generally a good choice for time plots."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we ask for a plot of x (component 1 of statevec) versus t, \
then a plot of y (component 2 of statevec) versus t, and then a plot of both \
versus t.  We name each graph in case we want to use them later.  We render \
the first graph in red, the second in green and the third in blue by using \
colorvec.  We dash the second graph by setting dasher = {0.05}.  This gives \
equal segments and gaps of length 0.05 of the width of the graph.  We dash \
the third graph by setting dasher = {0.05,0.02}.  This gives segments of \
length 0.05, gaps of length 0.02. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Red, Green, Blue}];\)\)], "Input"],

Cell["Let's check the action of this by looking at colorvec.", "Text"],

Cell[BoxData[
    \(colorvec\)], "Input"],

Cell["\<\
This has returned the actual RGB settings.  To see the colors by \
name, type colorvecdis:\
\>", "Text"],

Cell[BoxData[
    \(colorvecdis\)], "Input"],

Cell["graph1 = timeplot[sol1,1];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setdash[{{0.05}}];\)\)], "Input"],

Cell["graph2 = timeplot[sol1,2];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setdash[{{0.05, 0.02}}];\)\)], "Input"],

Cell["graph3 = timeplot[sol1,{1,2}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNotice that we have cycled through our three colors, and returned \
to red for the fourth graph.  Notice also that each graph is scaled slightly \
differently.  That's because we are using the default of All for plrange, the \
variable that controls the plotting window.  We may set our own window.  We \
return to black and to solid curves.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input"],

Cell[BoxData[
    \(\(setdash[{\ {}}];\)\)], "Input"],

Cell["plrange = {{0,10}, {-1,1}};", "Input",
  AspectRatioFixed->True],

Cell["graph4 = timeplot[sol1,{1,2}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
The size of the above graph is governed by the setting of imsize:\
\
\>", "Text"],

Cell[BoxData[
    \(imsize\)], "Input"],

Cell["\<\
This is the default value in this package.  Let's look at the \
effect of changing imsize.\
\>", "Text"],

Cell[BoxData[
    \(\(imsize\  = \ 288;\)\)], "Input"],

Cell[BoxData[
    \(\(graph4small\  = \ timeplot[sol1, {1, 2}];\)\)], "Input"],

Cell["Now we restore imsize to the default.", "Text"],

Cell[BoxData[
    \(\(imsize\  = \ 340;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Phase Plot",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We can also get a phase plane plot of our solution.  We first reset \
plrange and asprat, and then construct the plot with the function phaseplot.  \
We plot the curve in magenta."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-1,1},{-1,1}};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Magenta}];\)\)], "Input"],

Cell["graph5 = phaseplot[sol1,1,2];", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\tNotice that the plot label collides with the y-axis label, which is a \
defect in the way ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " handles text in graphics.  We will see in Tutorial 4 how to fix this."
}], "Text"],

Cell["\<\
\tLet's graph our interpolated solution and compare it with the \
above graph.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
graph5interp = ParametricPlot[{X[t],Y[t]}, {t,0.0,10.0},PlotRange \
-> plrange, AspectRatio -> asprat];\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\tNotice that the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " default graph size has been used for this graph.  Now  we compare this \
with graph5 by showing them together."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["show[graph5,graph5interp];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe can add arrows in the direction of increasing time to our \
phase plots by setting\
\>", "Text"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell["To get arrows at intervals of 1/5 of the arclength, we set", "Text"],

Cell[BoxData[
    \(\(arrowvec = {1/5, 2/5, 3/5, 4/5};\)\)], "Input"],

Cell[BoxData[
    \(\(graph5a = phaseplot[sol1, 1, 2];\)\)], "Input"],

Cell["We turn off the arrows by setting", "Text"],

Cell[BoxData[
    \(\(arrowflag = False;\)\)], "Input"],

Cell["\<\
\tIt is often of interest to compare a solution or solutions with \
the direction field.  We can generate a direction field plot with the command \
dirfield.  The plotting window for dirfield is always taken from \
plrange.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["dirfield;", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Continuation of Integration",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Let's continue the integration which produced sol1.  This is made easy by \
the quantities lastt and lastx (or the combination lasttx) which give the \
last point calculated.  We look at these quantities first before we use \
them."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["lasttx", "Input",
  AspectRatioFixed->True],

Cell["lastt", "Input",
  AspectRatioFixed->True],

Cell["lastx", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we continue the integration, using the same number of time \
steps and the same spacing.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["moresol1 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe plot this piece of the solution and then show it with the \
previous piece.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph5plus = phaseplot[moresol1,1,2];", "Input",
  AspectRatioFixed->True],

Cell["Now we plot both pieces together.", "Text"],

Cell["show[graph5,graph5plus];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tAlternatively, we can combine the solutions first, using joinsol, \
and then plot the combination.  We change the color to cyan.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["bigsol1 = joinsol[sol1,moresol1];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Cyan}];\)\)], "Input"],

Cell["bigraph5 = phaseplot[bigsol1,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tAs a third alternative, we can plot both pieces with a single \
phaseplot command.\
\>", "Text"],

Cell["To show the two pieces, we use two colors.", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(altbigraph5\  = \ phaseplot[{sol1, moresol1}, 1, 2];\)\)], "Input"],

Cell["Now we get the colors that have been assigned to the pieces.", "Text"],

Cell["\<\
\tAs an illustration of the use of dashing, we plot sol1 and \
moresol1 with different dashing patterns, by assigning two patterns via \
setdash.\
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{{0.05}, {0.05, 0.02, 0.02, 0.02}}]\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(alt2bigraph5\  = \ phaseplot[{sol1, moresol1}, 1, 2];\)\)], "Input"],

Cell["\<\
Now we use setdash to plot the first piece dashed, the second \
solid. \
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{{0.05}, {}}];\)\)], "Input"],

Cell[BoxData[
    \(\(alt3bigraph5\  = \ phaseplot[{sol1, moresol1}, 1, 2];\)\)], "Input"],

Cell["We reset to black, solid curves.", "Text"],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input"],

Cell[BoxData[
    \(\(setdash[{{}}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integrating Backwards in Time",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Now suppose we want to start at the original initial point and go backward \
in time.  We do that with a negative value of the time step.  We also \
generate the phase plot with a shortcut command, namely phaser.  This is the \
same as phaseplot, but with indices i = 1 and j = 2 automatically.  It simply \
saves a little typing."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = -0.05;", "Input",
  AspectRatioFixed->True],

Cell["sol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-10,10},{-10,10}};", "Input",
  AspectRatioFixed->True],

Cell["\<\
We turn the arrows on again, to demonstrate that they point forward \
in time no matter the actual direction of the integration.\
\>", "Text"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(arrowvec\)], "Input"],

Cell["graph6 = phaser[sol2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
We can continue the backwards integration in time by using firsttx, \
firstt and firstx, which return elements of the first set of coordinates in \
the solution.  Because solutions are always stored with the earliest element \
first, the last point calculated in a backwards integration in time is \
obtained from firsttx.\
\>", "Text"],

Cell[BoxData[
    \(firsttx\)], "Input"],

Cell[BoxData[
    \(firstt\)], "Input"],

Cell[BoxData[
    \(firstx\)], "Input"],

Cell[BoxData[
    \(\(sol2a\  = \ integrate[firstx, firstt, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graph6a\  = \ phaser[sol2a];\)\)], "Input"],

Cell["\<\
\tWe can combine these two solutions as before -- either \
pictorially with a show command, or by using joinsol to combine the solutions \
before plotting.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph7 = show[graph5,graph6,graph6a];", "Input",
  AspectRatioFixed->True],

Cell["sol3 = joinsol[sol2a,joinsol[sol1,sol2]];", "Input",
  AspectRatioFixed->True],

Cell["graph8 = phaser[sol3];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Range of Solution",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We see that t",
  "he backward-time part of the solution extends beyond the range of the \
graph.  We easily can check the time range with trange and the range of the \
state vector with staterange."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["trange[sol3]", "Input",
  AspectRatioFixed->True],

Cell["staterange[sol3]", "Input",
  AspectRatioFixed->True],

Cell["\<\
This last result shows that the minimum of x is -24.68... and it \
occurs at t = -16.05, and the maximum is 46.87.... and it occurs at t = \
-19.25.  Similarly for the y numbers.  We see indeed that both x and y range \
outside the plotting window.  To graph all of the points calculated, we \
simply reset plrange and plot again.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-50,50},{-50,50}};", "Input",
  AspectRatioFixed->True],

Cell["graph9 = phaser[sol3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tAn alternative way of integrating backwards in time is to reverse \
time in the system definition and then integrate forward.  In this case \
arrows on the graph will point in the new forward direction which is the old \
backwards direction.  Let's try this.\
\>", "Text"],

Cell[BoxData[
    \(\(h = 0.05;\)\)], "Input"],

Cell[BoxData[
    \(\(reversetime;\)\)], "Input"],

Cell[BoxData[
    \(\(sysreport;\)\)], "Input"],

Cell["sol2r = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plrange = {{\(-10\), 10}, {\(-10\), 10}};\)\)], "Input"],

Cell["graph6r = phaser[sol2r];", "Input",
  AspectRatioFixed->True],

Cell["\<\
Now we restore the original time direction and check our system \
with sysreport.\
\>", "Text"],

Cell[BoxData[
    \(\(reversetime;\)\)], "Input"],

Cell[BoxData[
    \(\(sysreport;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Integrating Both Directions in Time",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Another way of producing a solution which goes both ways in time from the \
initial state is to set the flag bothdirflag to True and then integrate.  We \
turn off the arrows first."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(arrowflag = False;\)\)], "Input"],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["bothdirflag = True;", "Input",
  AspectRatioFixed->True],

Cell["sol4 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plot1 = phaser[sol4];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"This gives us the same graph we constructed earlier by piecing together the \
two solutions."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Undamped Oscillator",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tAs a special case, we look at an undamped oscillator, obtained by \
setting the parameter eps to zero.\
\>", "Text"],

Cell[BoxData[
    \(\(bothdirflag = False;\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {0};\)\)], "Input"],

Cell[BoxData[
    \(\(solundamp = integrate[{1, 0}, 0, 0.01, 628];\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}};\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 1;\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[solundamp];\)\)], "Input"],

Cell["\<\
We have chosen exactly the right number of steps and spacing to go \
exactly once around the circular orbit.  We can check the arc length function \
on this case, knowing that the answer should be 2 Pi.\
\>", "Text"],

Cell[BoxData[
    \(arclen[solundamp]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Checking System Parameters",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "At this point we have changed a number of the parameters from default \
settings.  We can check our present settings with intreport (integration \
parameters), plotreport (plotting parameters), or sysreport (system \
parameters).  (Or you can execute all three of these with parmreport.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreport", "Input",
  AspectRatioFixed->True],

Cell["plotreport", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe could have gotten all three of these reports at once by typing \
parmreport.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Naming the System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The sysreport shows that the system name is the default \"System.\"  We \
can give the system a name of our own choosing.  Let's do that now."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysname = \"Damped Oscillator\";", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Controlling Plot Appearance",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Now let's look at a few variations in plot appearance, produced by our \
choices of some of the plot control variables.  Let's redo the last phase \
plot with dots rather than connected lines.  Because we have given the system \
a name, that name will now be part of the plot title."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["pointcon = False;", "Input",
  AspectRatioFixed->True],

Cell["plot2 = phaser[sol4];", "Input",
  AspectRatioFixed->True],

Cell["\<\
     These dots are constructed at equal time intervals (the \
spacing h), so that their density gives some indication of orbital velocity.  \
We can change the size of the dots.  The present (default) size is 0.005.  \
Let's use a larger dot and change the color to green.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ptsize = 0.01;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Green}]\ ;\)\)], "Input"],

Cell["plot3 = phaser[sol4];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"     Now we go back to a connected line, but thicker than before."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["pointcon = True;", "Input",
  AspectRatioFixed->True],

Cell["lnthick = 0.01;", "Input",
  AspectRatioFixed->True],

Cell["plot4 = phaser[sol4];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"     Let's now return to the default values of the plot control variables, \
by using plotreset, and then check the values with plotreport."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreport", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Selecting a Subset of the Solution",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The solution sol4 is defined on the time interval {-10,10}.  We can easily \
establish this by applying trange to sol4."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["trange[sol4]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"     Sometimes we wish to deal with a solution over only part of the time \
range for which it was calculated.  The function subsol lets us select a \
subset of the solution based on the time range.  Let's use this to plot sol4 \
from t = 3 to t = 7.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{0,10},{-0.75,0.75}};", "Input",
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell["plot5 = timeplot[subsol[sol4,{3,7}],1];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Adding Version Numbers to Your Output",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The command sysid returns the version numbers of Dynamical Systems and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  In the remaining tutorials, it will be the first command executed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Redo some or all of the above calculations for different values of the \
damping constant -- for example, eps = 0.05 (very lightly damped), eps = 1.0 \
(critically damped), and eps = 2.0 (overdamped).  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{725, 702},
WindowMargins->{{-5, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 101, 5, 152, "Title",
  Evaluatable->False],
Cell[1843, 58, 109, 2, 87, "Subtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1977, 64, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2137, 69, 629, 12, 83, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2803, 86, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2961, 91, 260, 7, 49, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3258, 103, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3390, 108, 386, 9, 49, "Text",
  Evaluatable->False],
Cell[3779, 119, 59, 1, 27, "Input"],
Cell[3841, 122, 58, 1, 27, "Input"],
Cell[3902, 125, 70, 1, 27, "Input"],
Cell[3975, 128, 151, 5, 31, "Text",
  Evaluatable->False],
Cell[4129, 135, 125, 3, 31, "Text",
  Evaluatable->False],
Cell[4257, 140, 225, 6, 48, "Text",
  Evaluatable->False],
Cell[4485, 148, 59, 1, 27, "Input"],
Cell[4547, 151, 318, 6, 48, "Text",
  Evaluatable->False],
Cell[4868, 159, 53, 1, 27, "Input"],
Cell[4924, 162, 247, 5, 48, "Text"],
Cell[5174, 169, 51, 1, 27, "Input"],
Cell[5228, 172, 113, 2, 31, "Text",
  Evaluatable->False],
Cell[5344, 176, 52, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5433, 182, 134, 3, 46, "Subsection",
  Evaluatable->False],
Cell[5570, 187, 362, 9, 49, "Text",
  Evaluatable->False],
Cell[5935, 198, 63, 1, 27, "Input"],
Cell[6001, 201, 52, 1, 27, "Input"],
Cell[6056, 204, 52, 1, 27, "Input"],
Cell[6111, 207, 56, 1, 27, "Input"],
Cell[6170, 210, 510, 8, 82, "Text"],
Cell[6683, 220, 73, 1, 27, "Input"],
Cell[6759, 223, 52, 1, 27, "Input"],
Cell[6814, 226, 100, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6951, 234, 123, 3, 46, "Subsection",
  Evaluatable->False],
Cell[7077, 239, 530, 11, 83, "Text",
  Evaluatable->False],
Cell[7610, 252, 52, 1, 27, "Input"],
Cell[7665, 255, 81, 1, 27, "Input"],
Cell[7749, 258, 162, 5, 31, "Text",
  Evaluatable->False],
Cell[7914, 265, 55, 1, 27, "Input"],
Cell[7972, 268, 494, 8, 65, "Text",
  Evaluatable->False],
Cell[8469, 278, 73, 1, 27, "Input"],
Cell[8545, 281, 61, 1, 27, "Input"],
Cell[8609, 284, 377, 8, 65, "Text",
  Evaluatable->False],
Cell[8989, 294, 69, 1, 27, "Input"],
Cell[9061, 297, 47, 1, 27, "Input"],
Cell[9111, 300, 47, 1, 27, "Input"],
Cell[9161, 303, 49, 1, 27, "Input"],
Cell[9213, 306, 49, 1, 27, "Input"],
Cell[9265, 309, 88, 3, 31, "Text"],
Cell[9356, 314, 67, 1, 27, "Input"],
Cell[9426, 317, 164, 4, 31, "Text"],
Cell[9593, 323, 43, 1, 27, "Input"],
Cell[9639, 326, 43, 1, 27, "Input"],
Cell[9685, 329, 101, 3, 31, "Text"],
Cell[9789, 334, 73, 1, 27, "Input"],
Cell[9865, 337, 39, 1, 27, "Input"],
Cell[9907, 340, 39, 1, 27, "Input"],
Cell[9949, 343, 40, 1, 27, "Input"],
Cell[9992, 346, 172, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10201, 355, 122, 3, 46, "Subsection",
  Evaluatable->False],
Cell[10326, 360, 392, 9, 49, "Text",
  Evaluatable->False],
Cell[10721, 371, 53, 1, 27, "Input"],
Cell[10777, 374, 56, 1, 27, "Input"],
Cell[10836, 377, 637, 11, 82, "Text",
  Evaluatable->False],
Cell[11476, 390, 66, 1, 27, "Input"],
Cell[11545, 393, 70, 0, 31, "Text"],
Cell[11618, 395, 41, 1, 27, "Input"],
Cell[11662, 398, 114, 3, 31, "Text"],
Cell[11779, 403, 44, 1, 27, "Input"],
Cell[11826, 406, 69, 1, 27, "Input"],
Cell[11898, 409, 55, 1, 27, "Input"],
Cell[11956, 412, 69, 1, 27, "Input"],
Cell[12028, 415, 61, 1, 27, "Input"],
Cell[12092, 418, 73, 1, 27, "Input"],
Cell[12168, 421, 417, 8, 65, "Text",
  Evaluatable->False],
Cell[12588, 431, 55, 1, 27, "Input"],
Cell[12646, 434, 53, 1, 27, "Input"],
Cell[12702, 437, 70, 1, 27, "Input"],
Cell[12775, 440, 73, 1, 27, "Input"],
Cell[12851, 443, 91, 3, 31, "Text"],
Cell[12945, 448, 39, 1, 27, "Input"],
Cell[12987, 451, 114, 3, 31, "Text"],
Cell[13104, 456, 54, 1, 27, "Input"],
Cell[13161, 459, 78, 1, 27, "Input"],
Cell[13242, 462, 53, 0, 31, "Text"],
Cell[13298, 464, 54, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13389, 470, 122, 3, 46, "Subsection",
  Evaluatable->False],
Cell[13514, 475, 301, 8, 49, "Text",
  Evaluatable->False],
Cell[13818, 485, 56, 1, 27, "Input"],
Cell[13877, 488, 69, 1, 27, "Input"],
Cell[13949, 491, 57, 1, 27, "Input"],
Cell[14009, 494, 72, 1, 27, "Input"],
Cell[14084, 497, 252, 6, 49, "Text"],
Cell[14339, 505, 152, 5, 31, "Text",
  Evaluatable->False],
Cell[14494, 512, 154, 4, 42, "Input"],
Cell[14651, 518, 276, 8, 49, "Text",
  Evaluatable->False],
Cell[14930, 528, 69, 1, 27, "Input"],
Cell[15002, 531, 111, 3, 31, "Text"],
Cell[15116, 536, 54, 1, 27, "Input"],
Cell[15173, 539, 74, 0, 31, "Text"],
Cell[15250, 541, 69, 1, 27, "Input"],
Cell[15322, 544, 69, 1, 27, "Input"],
Cell[15394, 547, 49, 0, 31, "Text"],
Cell[15446, 549, 55, 1, 27, "Input"],
Cell[15504, 552, 295, 7, 48, "Text",
  Evaluatable->False],
Cell[15802, 561, 52, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15891, 567, 139, 3, 46, "Subsection",
  Evaluatable->False],
Cell[16033, 572, 353, 9, 49, "Text",
  Evaluatable->False],
Cell[16389, 583, 49, 1, 27, "Input"],
Cell[16441, 586, 48, 1, 27, "Input"],
Cell[16492, 589, 48, 1, 27, "Input"],
Cell[16543, 592, 166, 5, 31, "Text",
  Evaluatable->False],
Cell[16712, 599, 86, 1, 27, "Input"],
Cell[16801, 602, 152, 5, 31, "Text",
  Evaluatable->False],
Cell[16956, 609, 80, 1, 27, "Input"],
Cell[17039, 612, 49, 0, 31, "Text"],
Cell[17091, 614, 67, 1, 27, "Input"],
Cell[17161, 617, 202, 5, 31, "Text",
  Evaluatable->False],
Cell[17366, 624, 76, 1, 27, "Input"],
Cell[17445, 627, 54, 1, 27, "Input"],
Cell[17502, 630, 77, 1, 27, "Input"],
Cell[17582, 633, 108, 3, 31, "Text"],
Cell[17693, 638, 58, 0, 31, "Text"],
Cell[17754, 640, 59, 1, 27, "Input"],
Cell[17816, 643, 89, 1, 27, "Input"],
Cell[17908, 646, 76, 0, 31, "Text"],
Cell[17987, 648, 169, 4, 48, "Text"],
Cell[18159, 654, 83, 1, 27, "Input"],
Cell[18245, 657, 90, 1, 27, "Input"],
Cell[18338, 660, 95, 3, 31, "Text"],
Cell[18436, 665, 59, 1, 27, "Input"],
Cell[18498, 668, 90, 1, 27, "Input"],
Cell[18591, 671, 48, 0, 31, "Text"],
Cell[18642, 673, 55, 1, 27, "Input"],
Cell[18700, 676, 51, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18788, 682, 141, 3, 46, "Subsection",
  Evaluatable->False],
Cell[18932, 687, 452, 10, 66, "Text",
  Evaluatable->False],
Cell[19387, 699, 53, 1, 27, "Input"],
Cell[19443, 702, 81, 1, 27, "Input"],
Cell[19527, 705, 73, 1, 27, "Input"],
Cell[19603, 708, 152, 3, 31, "Text"],
Cell[19758, 713, 54, 1, 27, "Input"],
Cell[19815, 716, 41, 1, 27, "Input"],
Cell[19859, 719, 65, 1, 27, "Input"],
Cell[19927, 722, 346, 6, 65, "Text"],
Cell[20276, 730, 40, 1, 27, "Input"],
Cell[20319, 733, 39, 1, 27, "Input"],
Cell[20361, 736, 39, 1, 27, "Input"],
Cell[20403, 739, 86, 1, 27, "Input"],
Cell[20492, 742, 65, 1, 27, "Input"],
Cell[20560, 745, 227, 6, 48, "Text",
  Evaluatable->False],
Cell[20790, 753, 80, 1, 27, "Input"],
Cell[20873, 756, 84, 1, 27, "Input"],
Cell[20960, 759, 65, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21062, 765, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[21194, 770, 320, 9, 49, "Text",
  Evaluatable->False],
Cell[21517, 781, 55, 1, 27, "Input"],
Cell[21575, 784, 59, 1, 27, "Input"],
Cell[21637, 787, 402, 8, 65, "Text",
  Evaluatable->False],
Cell[22042, 797, 73, 1, 27, "Input"],
Cell[22118, 800, 65, 1, 27, "Input"],
Cell[22186, 803, 284, 5, 48, "Text"],
Cell[22473, 810, 46, 1, 27, "Input"],
Cell[22522, 813, 49, 1, 27, "Input"],
Cell[22574, 816, 47, 1, 27, "Input"],
Cell[22624, 819, 82, 1, 27, "Input"],
Cell[22709, 822, 78, 1, 27, "Input"],
Cell[22790, 825, 67, 1, 27, "Input"],
Cell[22860, 828, 105, 3, 31, "Text"],
Cell[22968, 833, 49, 1, 27, "Input"],
Cell[23020, 836, 47, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23104, 842, 147, 3, 46, "Subsection",
  Evaluatable->False],
Cell[23254, 847, 303, 8, 49, "Text",
  Evaluatable->False],
Cell[23560, 857, 55, 1, 27, "Input"],
Cell[23618, 860, 52, 1, 27, "Input"],
Cell[23673, 863, 62, 1, 27, "Input"],
Cell[23738, 866, 81, 1, 27, "Input"],
Cell[23822, 869, 64, 1, 27, "Input"],
Cell[23889, 872, 167, 4, 31, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[24093, 881, 131, 3, 46, "Subsection",
  Evaluatable->False],
Cell[24227, 886, 128, 3, 31, "Text"],
Cell[24358, 891, 57, 1, 27, "Input"],
Cell[24418, 894, 51, 1, 27, "Input"],
Cell[24472, 897, 81, 1, 27, "Input"],
Cell[24556, 900, 82, 1, 27, "Input"],
Cell[24641, 903, 48, 1, 27, "Input"],
Cell[24692, 906, 55, 1, 27, "Input"],
Cell[24750, 909, 226, 4, 48, "Text"],
Cell[24979, 915, 50, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25066, 921, 138, 3, 46, "Subsection",
  Evaluatable->False],
Cell[25207, 926, 409, 9, 66, "Text",
  Evaluatable->False],
Cell[25619, 937, 52, 1, 27, "Input"],
Cell[25674, 940, 53, 1, 27, "Input"],
Cell[25730, 943, 52, 1, 27, "Input"],
Cell[25785, 946, 105, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25927, 954, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[26059, 959, 263, 7, 49, "Text",
  Evaluatable->False],
Cell[26325, 968, 75, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26437, 974, 139, 3, 46, "Subsection",
  Evaluatable->False],
Cell[26579, 979, 404, 9, 49, "Text",
  Evaluatable->False],
Cell[26986, 990, 60, 1, 27, "Input"],
Cell[27049, 993, 64, 1, 27, "Input"],
Cell[27116, 996, 345, 7, 48, "Text",
  Evaluatable->False],
Cell[27464, 1005, 57, 1, 27, "Input"],
Cell[27524, 1008, 57, 1, 27, "Input"],
Cell[27584, 1011, 64, 1, 27, "Input"],
Cell[27651, 1014, 140, 3, 31, "Text",
  Evaluatable->False],
Cell[27794, 1019, 59, 1, 27, "Input"],
Cell[27856, 1022, 58, 1, 27, "Input"],
Cell[27917, 1025, 64, 1, 27, "Input"],
Cell[27984, 1028, 214, 4, 31, "Text",
  Evaluatable->False],
Cell[28201, 1034, 53, 1, 27, "Input"],
Cell[28257, 1037, 53, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28347, 1043, 146, 3, 46, "Subsection",
  Evaluatable->False],
Cell[28496, 1048, 241, 7, 32, "Text",
  Evaluatable->False],
Cell[28740, 1057, 55, 1, 27, "Input"],
Cell[28798, 1060, 327, 6, 48, "Text",
  Evaluatable->False],
Cell[29128, 1068, 75, 1, 27, "Input"],
Cell[29206, 1071, 56, 1, 27, "Input"],
Cell[29265, 1074, 82, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29384, 1080, 149, 3, 46, "Subsection",
  Evaluatable->False],
Cell[29536, 1085, 320, 9, 49, "Text",
  Evaluatable->False],
Cell[29859, 1096, 48, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29944, 1102, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[30067, 1107, 324, 8, 49, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

