(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19787,        693]*)
(*NotebookOutlinePosition[     44881,       1600]*)
(*  CellTagsIndexPosition[     44837,       1596]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 3\
\>", "Title"],

Cell[TextData["Equilibrium and Stability"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tclassify, classify2D, dermat, dermatval, eigsys, eigval, \
findpolyeq, nfindeq, nfindpolyeq, parmval, parmvec, residual, setparm, \
setstate, slopevec, statevec, and transorg.   \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Two systems are studied here.  The first is a simple two-dimensional, \
linear, autonomous system depending on a single parameter.  Although such a \
system is easily analyzed \"by hand,\" it also makes a good starting point \
for learning the routines in this package.  The second system analyzed is the \
Lorenz system.  In both cases we concentrate on locating equilibrium states, \
and finding whether they are stable or unstable. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Reference",
    FontWeight->"Bold"],
  " "
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tAlmost every text on dynamical systems has material on the Lorenz \
equations.  A very accessible treatment is given in Chapter 9 of ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontWeight->"Bold"],
  ", S.H. Strogatz, Addison-Wesley, 1994."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition for 2D Linear System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We denote the two state variables by x and y.  The system contains a \
single parameter, denoted by a.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{a}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {a*(y-2),-1-x-2*(y-2)};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {-3};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
\tThis system has a single equilibrium point at x = -1, y = 2 for \
all values of a.  The first thing we do is to move the equilibrium point to \
the origin by a translation, executed by transorg:  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(transorg[{\(-1\), 2}];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
\tNow our equilibrium is at {0,0}.  For the special case a = 0, the \
coefficient matrix is singular, and there is an equilbrium line y = -x/2.  In \
a complete bifurcation study, we would characterize the system behavior for \
all values of a.  In particular, we would find the values for which the \
system makes major transitions.  Here we set the more limited goal of \
determining the nature of the equibrium for three values of a:  -3, 3/4, and \
5.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Equilibrium and Stability Using Classify",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The nature of the equilibrium point can be determined with the function \
classify, which takes the coordinates of the equilibrium point as an \
argument."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We thus learn that the equilibrium is unstable.  We can get more information \
for a 2D system such as this by using classify2D."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now we learn that the unstable equilibrium is a saddle point."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Equilibrium and Stability Using dermat",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The routines classify and classify2D are very useful in that they give us \
a quick answer.  However, they hide some details which are of interest.  Now \
we take a more hands-on approach to the determination of stability by finding \
the eigenvalues of the derivative matrix (which of course is exactly what \
classify does behind the scenes).  The function dermat returns the derivative \
matrix of the system.  The function dermatval[eqstate] returns the numerical \
derivative matrix evaluated at the equilibrium state and with parameter \
values taken from parmval.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["dermat", "Input",
  AspectRatioFixed->True],

Cell["dermatval[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The stability is determined by the eigenvalues of dermatval.  We use the \
built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Eigenvalues to get these.     "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[{0,0}]]", "Input",
  AspectRatioFixed->True],

Cell["As a shortcut, we may get the same result with ", "Text"],

Cell[BoxData[
    \(eigval[{0, 0}]\)], "Input"],

Cell[TextData[
"We have two real eigenvalues, one positive and one negative, and thus this \
is a saddle point."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"     Let's repeat this with less verbiage for the other two values of a."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {3/4};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[{0,0}]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus for a = 3/4, there are two negative real eigenvalues, and the \
equilibrium is a stable node.  For many purposes, it is useful to know the \
eigenvectors also, which we may easily get with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command Eigenvectors.  Alternatively, we can get both eigenvalues and \
eigenvectors with the command Eigensystem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvectors[dermatval[{0,0}]]", "Input",
  AspectRatioFixed->True],

Cell["Eigensystem[dermatval[{0,0}]]", "Input",
  AspectRatioFixed->True],

Cell["Again we have a shortcut for this last function:", "Text"],

Cell[BoxData[
    \(eigsys[{0, 0}]\)], "Input"],

Cell[TextData["     Now we look at the last value of a."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {5};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[{0,0}]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Thus for a = 5, there are two complex conjugate eigenvalues with negative \
real parts, hence a stable spiral."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Summary of Stability for Linear Example",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We have shown that the equilibrium is unstable for a = -3, and stable for \
a = 3/4 and a = 5.  This is not very useful.  We really want to know the \
bifurcation point -- that is, the a-value at which the transition takes place \
between unstable and stable equilibrium.  For this simple problem, we can do \
that analytically by asking for the eigenvalues of the derivative matrix with \
a retained as a symbol rather than replaced as a number.  That is, we ask for \
the eigenvalues of dermat."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermat]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"It is easy to show from this expression that the transition occurs at a = 0. \
 For a < 0, the equilibrium is unstable.  For a > 0, it is stable.  The \
transition a = 0 requires a special investigation, but by integrating the \
equations, it is easy to show that the equilibrium is unstable for a = 0. "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition for Lorenz System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We denote the three state variables by x, y, and z.  The system contains a \
three parameters, denoted by r, sigma and b.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{sigma,r,b}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {sigma*(y-x),r*x-y-x*z,x*y-b*z};", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe will make a fairly thorough study of the Lorenz system in \
Tutorials 12 and 13.  For now, we just look at the equilibrium states for a \
few parameter values.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval1 = {10,0.5,8/3};", "Input",
  AspectRatioFixed->True],

Cell["parmval2 = {10,1.1,8/3};", "Input",
  AspectRatioFixed->True],

Cell["parmval3 = {10,10,8/3};", "Input",
  AspectRatioFixed->True],

Cell["parmval4 = {10,30,8/3};", "Input",
  AspectRatioFixed->True],

Cell[TextData["We start with parmval1."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = parmval1;", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Equilibrium States",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell["\<\
 \tThere is the obvious equilibrium at the origin.  We will look \
for others.  We have three tools for this.  The routine findpolyeq will look \
for analytical expressions for the equilibria, provided the slope functions \
are polynomials.  The routine nfindpolyeq will look for numerical expressions \
for equilibria for polynomial slope functions.  The routine nfindeq[init] \
will take the initial guess init and look for a numerical root, using the \
Newton-Raphson method.  The routine nfindeq is not restricted to polynomials.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["loroots = findpolyeq", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We see that there are three roots.  For r < 1, only one of them is real, and \
for r > 1 all three are real.  We will name our three roots C0 (origin), C1, \
and C2.  We define them as parts of the above result."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["C0 = loroots[[1]]", "Input",
  AspectRatioFixed->True],

Cell["C1 = loroots[[2]]", "Input",
  AspectRatioFixed->True],

Cell["C2 = loroots[[3]]", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Stability of Equilibrium for r = 0.5",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The only relevant root for the values parmval1 is C0, because the others \
are not real.  We look at the stability of this equilibrium by using \
classify."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify[C0]", "Input",
  AspectRatioFixed->True],

Cell[TextData["Let's look at the eigenvalues too."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We have already noted that two new roots appear at r = 1, and so we might \
suspect that is an important bifurcation.  Let's look at the stability of C0 \
for r = 1."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10,1,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell[TextData["The zero eigenvalue signifies a bifurcation."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Stability of All Three Equilibria for r = 1.1.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Let's move on to parmval2, for which r = 1.1.  We first find the numerical \
equilibrium positions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = parmval2;", "Input",
  AspectRatioFixed->True],

Cell["N[C0 /. Thread[parmvec -> parmval]]", "Input",
  AspectRatioFixed->True],

Cell["N[C1 /. Thread[parmvec -> parmval]]", "Input",
  AspectRatioFixed->True],

Cell["N[C2 /. Thread[parmvec -> parmval]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We can also find these numerical values for the roots directly, by using \
nfindpolyeq."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["nfindpolyeq", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Still a third way to find the equilibrium points is with nfindeq, which uses \
the Newton-Raphson technique and requires an initial guess.  We can apply \
nfindeq again to the answer to get a better value of the root.  The accuracy \
can be checked by residual, which evaluates the slope at the root.  We do all \
of this for C2 to illustrate the techniques."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["r1 = nfindeq[{0.4,0.4,0.0}]", "Input",
  AspectRatioFixed->True],

Cell["residual[r1]", "Input",
  AspectRatioFixed->True],

Cell["r2 = nfindeq[r1]", "Input",
  AspectRatioFixed->True],

Cell["residual[r2]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The refinement produced by a second application of nfindeq wasn't necessary \
in this case to get good accuracy."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tNow we check the stability of all three equilibria.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C0]]]", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C1]]]", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C2]]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We see that C0 is unstable (saddle), and C2 and C3 are stable nodes.  Thus \
the bifurcation at r = 1 is a pitchfork bifurcation.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIf we just want the conclusion for stability without the \
eigenvalues, we can use classify. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify[C0]", "Input",
  AspectRatioFixed->True],

Cell["classify[C1]", "Input",
  AspectRatioFixed->True],

Cell["classify[C2]", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Stability of All Three Equilibria at r = 10.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We go on to the next set of parameter values and examine the stability of \
each equilibrium point."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = parmval3;", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C0]]]", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C1]]]", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C2]]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Thus C0 is still unstable (saddle), and C1 and C2 are now stable spirals."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Stability of All Three Equilibria at r = 30.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We go on to the last set of parameter values and examine the stability of \
each equilbrium point."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = parmval4;", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C0]]]", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C1]]]", "Input",
  AspectRatioFixed->True],

Cell["N[Eigenvalues[dermatval[C2]]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now the spirals at C1 and C2 have become unstable, so that all three \
equilibria are unstable.  If none of the equilibria are stable, where does \
the system spend its time?  It turns out that this is a parameter set for \
which there are chaotic motions.  These will be explored in Tutorial 12."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe have shown that for an r value of 10.0, the equilibria C1 and \
C2 are stable, and that for r = 30.0, they are unstable.  Find approximately \
the r value at which the transition occurs.   \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{645, 556},
WindowMargins->{{37, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 3, 152, "Title"],
Cell[1795, 56, 103, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1901, 60, 48, 1, 27, "Input"],
Cell[1952, 63, 46, 1, 27, "Input"],
Cell[2001, 66, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2073, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2233, 76, 252, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2522, 87, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2681, 92, 557, 11, 80, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3275, 108, 136, 6, 46, "Subsection",
  Evaluatable->False],
Cell[3414, 116, 327, 8, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3778, 129, 150, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3931, 134, 226, 7, 32, "Text",
  Evaluatable->False],
Cell[4160, 143, 59, 1, 27, "Input"],
Cell[4222, 146, 56, 1, 27, "Input"],
Cell[4281, 149, 77, 1, 27, "Input"],
Cell[4361, 152, 58, 1, 27, "Input"],
Cell[4422, 155, 42, 1, 27, "Input"],
Cell[4467, 158, 270, 6, 46, "Text",
  Evaluatable->False],
Cell[4740, 166, 59, 1, 27, "Input"],
Cell[4802, 169, 42, 1, 27, "Input"],
Cell[4847, 172, 529, 10, 78, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[5413, 187, 152, 3, 46, "Subsection",
  Evaluatable->False],
Cell[5568, 192, 276, 8, 48, "Text",
  Evaluatable->False],
Cell[5847, 202, 58, 1, 27, "Input"],
Cell[5908, 205, 203, 4, 46, "Text",
  Evaluatable->False],
Cell[6114, 211, 60, 1, 27, "Input"],
Cell[6177, 214, 136, 3, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[6350, 222, 150, 3, 46, "Subsection",
  Evaluatable->False],
Cell[6503, 227, 694, 13, 96, "Text",
  Evaluatable->False],
Cell[7200, 242, 49, 1, 27, "Input"],
Cell[7252, 245, 59, 1, 27, "Input"],
Cell[7314, 248, 262, 8, 48, "Text",
  Evaluatable->False],
Cell[7579, 258, 72, 1, 27, "Input"],
Cell[7654, 261, 63, 0, 30, "Text"],
Cell[7720, 263, 47, 1, 27, "Input"],
Cell[7770, 266, 170, 4, 30, "Text",
  Evaluatable->False],
Cell[7943, 272, 150, 4, 30, "Text",
  Evaluatable->False],
Cell[8096, 278, 59, 1, 27, "Input"],
Cell[8158, 281, 60, 1, 27, "Input"],
Cell[8221, 284, 72, 1, 27, "Input"],
Cell[8296, 287, 451, 10, 64, "Text",
  Evaluatable->False],
Cell[8750, 299, 73, 1, 27, "Input"],
Cell[8826, 302, 72, 1, 27, "Input"],
Cell[8901, 305, 64, 0, 30, "Text"],
Cell[8968, 307, 47, 1, 27, "Input"],
Cell[9018, 310, 114, 2, 30, "Text",
  Evaluatable->False],
Cell[9135, 314, 57, 1, 27, "Input"],
Cell[9195, 317, 60, 1, 27, "Input"],
Cell[9258, 320, 72, 1, 27, "Input"],
Cell[9333, 323, 185, 4, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[9555, 332, 151, 3, 46, "Subsection",
  Evaluatable->False],
Cell[9709, 337, 618, 12, 96, "Text",
  Evaluatable->False],
Cell[10330, 351, 62, 1, 27, "Input"],
Cell[10395, 354, 381, 7, 62, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[10813, 366, 147, 3, 46, "Subsection",
  Evaluatable->False],
Cell[10963, 371, 245, 7, 48, "Text",
  Evaluatable->False],
Cell[11211, 380, 61, 1, 27, "Input"],
Cell[11275, 383, 64, 1, 27, "Input"],
Cell[11342, 386, 86, 1, 27, "Input"],
Cell[11431, 389, 236, 6, 46, "Text",
  Evaluatable->False],
Cell[11670, 397, 67, 1, 27, "Input"],
Cell[11740, 400, 67, 1, 27, "Input"],
Cell[11810, 403, 66, 1, 27, "Input"],
Cell[11879, 406, 66, 1, 27, "Input"],
Cell[11948, 409, 97, 2, 30, "Text",
  Evaluatable->False],
Cell[12048, 413, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12147, 419, 155, 4, 46, "Subsection",
  Evaluatable->False,
  PageBreakAbove->False],
Cell[12305, 425, 607, 11, 94, "Text",
  Evaluatable->False],
Cell[12915, 438, 63, 1, 27, "Input"],
Cell[12981, 441, 286, 5, 46, "Text",
  Evaluatable->False],
Cell[13270, 448, 60, 1, 27, "Input"],
Cell[13333, 451, 60, 1, 27, "Input"],
Cell[13396, 454, 60, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13493, 460, 148, 3, 46, "Subsection",
  Evaluatable->False],
Cell[13644, 465, 277, 8, 48, "Text",
  Evaluatable->False],
Cell[13924, 475, 55, 1, 27, "Input"],
Cell[13982, 478, 108, 2, 30, "Text",
  Evaluatable->False],
Cell[14093, 482, 69, 1, 27, "Input"],
Cell[14165, 485, 240, 5, 46, "Text",
  Evaluatable->False],
Cell[14408, 492, 64, 1, 27, "Input"],
Cell[14475, 495, 69, 1, 27, "Input"],
Cell[14547, 498, 118, 2, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[14702, 505, 158, 3, 46, "Subsection",
  Evaluatable->False],
Cell[14863, 510, 221, 7, 32, "Text",
  Evaluatable->False],
Cell[15087, 519, 62, 1, 27, "Input"],
Cell[15152, 522, 78, 1, 27, "Input"],
Cell[15233, 525, 78, 1, 27, "Input"],
Cell[15314, 528, 78, 1, 27, "Input"],
Cell[15395, 531, 162, 4, 30, "Text",
  Evaluatable->False],
Cell[15560, 537, 54, 1, 27, "Input"],
Cell[15617, 540, 433, 7, 62, "Text",
  Evaluatable->False],
Cell[16053, 549, 70, 1, 27, "Input"],
Cell[16126, 552, 55, 1, 27, "Input"],
Cell[16184, 555, 59, 1, 27, "Input"],
Cell[16246, 558, 55, 1, 27, "Input"],
Cell[16304, 561, 187, 4, 30, "Text",
  Evaluatable->False],
Cell[16494, 567, 117, 2, 30, "Text",
  Evaluatable->False],
Cell[16614, 571, 72, 1, 27, "Input"],
Cell[16689, 574, 72, 1, 27, "Input"],
Cell[16764, 577, 72, 1, 27, "Input"],
Cell[16839, 580, 206, 4, 46, "Text",
  Evaluatable->False],
Cell[17048, 586, 167, 5, 30, "Text",
  Evaluatable->False],
Cell[17218, 593, 55, 1, 27, "Input"],
Cell[17276, 596, 55, 1, 27, "Input"],
Cell[17334, 599, 55, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17426, 605, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[17585, 610, 221, 7, 32, "Text",
  Evaluatable->False],
Cell[17809, 619, 62, 1, 27, "Input"],
Cell[17874, 622, 72, 1, 27, "Input"],
Cell[17949, 625, 72, 1, 27, "Input"],
Cell[18024, 628, 72, 1, 27, "Input"],
Cell[18099, 631, 151, 4, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[18287, 640, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[18446, 645, 220, 7, 32, "Text",
  Evaluatable->False],
Cell[18669, 654, 62, 1, 27, "Input"],
Cell[18734, 657, 72, 1, 27, "Input"],
Cell[18809, 660, 72, 1, 27, "Input"],
Cell[18884, 663, 72, 1, 27, "Input"],
Cell[18959, 666, 374, 7, 62, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[19370, 678, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[19493, 683, 266, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

