(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17150,        623]*)
(*NotebookOutlinePosition[     42297,       1532]*)
(*  CellTagsIndexPosition[     42253,       1528]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 4\
\>", "Title"],

Cell[TextData["Local Solution\nNear an Equilibrium Point"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(intreset; plotreset;\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tarrowflag, arrowvec, axon, centerportrait, classify2D, dermat, \
dermatval, framelabon, frameon, integrate, labon, labshift, nodeportrait, \
outbound, parmval, parmvec, phaser, plrange, rangeflag, ranger, restoresys, \
saddleportrait, saddleportraitman, savesys, setcolor, setparm, setstate, \
slopevec, spiralportrait, and statevec.   \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We consider here a simple nonlinear, two-dimensional autonomous system \
with a single equilibrium point at the origin.  The equilibrium is a saddle \
with stable and unstable manifolds.  Our computations will illustrate the \
tangency connection between the manifolds for the linearized system and the \
full system.  To illustrate the four portrait commands centerportrait, \
nodeportrait, saddleportrait, and spiralportrait, we use a linear system with \
varying parameters."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We denote the two state variables by x and y.  The system contains no \
parameters, but we still define parmvec and parmval as empty lists, because a \
number of routines make use of these vectors behind the scenes.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {-x+y^2,x+y+x*y};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"nlsystem\";", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Equilibrium Point",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe start by analyzing the equilibrium at the origin.  We first \
use classify2D, but, because we will need the eigenvalues and eigenvectors \
later, we also carry out the more detailed analysis, by finding the matrix of \
the linearized system, which we call linmat, and finding its eigenvalues and \
eigenvectors.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["linmat = dermatval[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["Eigensystem[linmat]", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Construction of Stable and Unstable Manifolds for Nonlinear System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The stable manifold corresponds to the negative eigenvalue.  To construct \
it, we integrate backward in time, starting very near the equilibrium, \
displaced from the equilibrium along the eigenvector associated with the \
eigenvalue -1.  The solution going backward in time could grow very rapidly, \
so we avoid the possibility of overflow and crash by using range checking.  \
We limit the range to a box from -2 to 2 in both variables.  In each case \
after an integration, we check the out-of-bounds point by looking at \
outbound.  We add an arrow to the mid-point of each orbit."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ranger = {{-2,2},{-2,2}};", "Input",
  AspectRatioFixed->True],

Cell["rangeflag = True;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = -0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 300;", "Input",
  AspectRatioFixed->True],

Cell["initvec = 0.01*{-2,1};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell["stablesol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(outbound\)], "Input"],

Cell["initvec = -0.01*{-2,1};", "Input",
  AspectRatioFixed->True],

Cell["stablesol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(outbound\)], "Input"],

Cell["plrange = ranger;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell["graph1 = phaser[{stablesol1,stablesol2}];", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\tWe see an example of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s annoying unconcern with the overlapping of the y axes label and the \
plot label.  There are several fixes for this.  The first fix is simply to \
turn off the plot label by setting labon = False:"
}], "Text"],

Cell[BoxData[
    \(\(labon\  = \ False;\)\)], "Input"],

Cell["graph1a = phaser[{stablesol1,stablesol2}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tAlternatively, we may keep the label on but \"spread\" it by \
inserting blanks between the system name and the parameter list.  We insert a \
blank of 15 spaces by setting labshift = 15.\
\>", "Text"],

Cell[BoxData[
    \(\(labon\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(labshift\  = \ 15;\)\)], "Input"],

Cell["graph1b = phaser[{stablesol1,stablesol2}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe can also change the graph label to any string by assigning \
that string to labon.  For example, to label the graph \"Stable Manifold\",\
\
\>", "Text"],

Cell[BoxData[
    \(\(labon = "\<Stable Manifold\>";\)\)], "Input"],

Cell["graph1c = phaser[{stablesol1,stablesol2}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tIn the remainder of this tutorial, we will use the standard label \
with the 15 space shift.\
\>", "Text"],

Cell[BoxData[
    \(\(labon = True;\)\)], "Input"],

Cell["\<\
\tNow we use an entirely analogous procedure to construct the \
unstable manifold:  we start displaced slightly from the equilibrium along \
the eigenvector, and integrate forward in time.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["initvec = 0.01*{0,1};", "Input",
  AspectRatioFixed->True],

Cell["unstablesol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["initvec = -0.01*{0,1};", "Input",
  AspectRatioFixed->True],

Cell["unstablesol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph2 = phaser[{unstablesol1,unstablesol2}];", "Input",
  AspectRatioFixed->True],

Cell["\tWe combine these two graphs.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
manifoldgraph = phaser[{stablesol1,stablesol2,
\t\t\t\t\t\tunstablesol1,unstablesol2}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we use a much easier technique to get the same graph -- \
namely saddleportraitman, which takes as arguments the position of the saddle \
point and the desired plotting window.\
\>", "Text"],

Cell[BoxData[
    \(\(easygraph1 = 
        saddleportraitman[{0, 0}, {{\(-2\), 2}, {\(-2\), 2}}];\)\)], "Input"],

Cell["\<\
If we want some nearby integral curves in addition to the unstable \
and stable manifolds, we type\
\>", "Text"],

Cell[BoxData[
    \(\(easygraph1a = 
        saddleportrait[{0, 0}, {{\(-2\), 2}, {\(-2\), 2}}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Construction of Stable and Unstable Manifolds for Linearized System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tNow we construct the linearized system and then go through the \
same manifold constructions for it.  We first save the four vectors \
(statevec, slopevec, parmvec, and parmval) defining the original system, \
under the name nlsystem, and then we construct these vectors for the \
linearized system.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["savesys[nlsystem]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe continue to use {x,y} for the state vector, and both parmval \
and parmvec remain empty lists.  Thus for the linear system, we must redefine \
only the slope function.  It is the derivative matrix at equilibrium times \
the state vector.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["slopevec = Dot[dermatval[{0,0}],{x,y}]", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"linsystem\";", "Input",
  AspectRatioFixed->True],

Cell["\tNow we construct the linear stable manifold.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ranger = {{-2,2},{-2,2}};", "Input",
  AspectRatioFixed->True],

Cell["rangeflag = True;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = -0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 300;", "Input",
  AspectRatioFixed->True],

Cell["initvec = 0.01*{-2,1};", "Input",
  AspectRatioFixed->True],

Cell["linstablesol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["initvec = -0.01*{-2,1};", "Input",
  AspectRatioFixed->True],

Cell["linstablesol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plrange = ranger;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell["lingraph1 = phaser[{linstablesol1,linstablesol2}];", "Input",
  AspectRatioFixed->True],

Cell["\tNow we construct the linear unstable manifold.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["initvec = 0.01*{0,1};", "Input",
  AspectRatioFixed->True],

Cell["linunstablesol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["initvec = -0.01*{0,1};", "Input",
  AspectRatioFixed->True],

Cell["linunstablesol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["lingraph2 = phaser[{linunstablesol1,linunstablesol2}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe manifold is actually there, but it coincides with the y-axis. \
 We will make it visible in our next graph.    We set axon = False to remove \
the axes for a better view, set frameon = True to get a box around the \
picture, and we combine the two manifolds of the linear system.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["axon = False;frameon = True;", "Input",
  AspectRatioFixed->True],

Cell["lingraph = show[{lingraph1,lingraph2}];", "Input",
  AspectRatioFixed->True],

Cell["As before, there is an easier way to get this graph:", "Text"],

Cell[BoxData[
    \(\(easygraph2 = 
        saddleportraitman[{0, 0}, {{\(-2\), 2}, {\(-2\), 2}}];\)\)], "Input"],

Cell["Now we combine the linear and nonlinear manifolds.", "Text"],

Cell[BoxData[
    \(\(show[easygraph1, easygraph2];\)\)], "Input"],

Cell["We can turn off the labels on the frame as follows:", "Text"],

Cell[BoxData[
    \(\(framelabon = False;\)\)], "Input"],

Cell[BoxData[
    \(\(easygraph3 = 
        saddleportraitman[{0, 0}, {{\(-2\), 2}, {\(-2\), 2}}];\)\)], "Input"],

Cell["\<\
This shows clearly how, at the equilibrium point, the manifolds of \
the linearized system are tangent to the manifolds of the nonlinear system.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe now save the linearized system under the name linsystem, and \
restore the nonlinear system.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["savesys[linsystem]", "Input",
  AspectRatioFixed->True],

Cell["restoresys[nlsystem];", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Phase Portraits for a Bifurcating Linear System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe start by defining the system.  It is a linear system in x and \
y, with parameters a and b, with an equilibrium at {0,0}.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{x, y}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{a, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {x + a*y, x + b*y};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {0, \(-2\)};\)\)], "Input"],

Cell[BoxData[
    \(\(eq = {0, 0};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[eq]\)], "Input"],

Cell[BoxData[
    \(axon = \ True; frameon\  = \ False;\)], "Input"],

Cell["Now we use saddleportrait to get a basic phase portrait.", "Text"],

Cell[BoxData[
    \(\(window = {{\(-2\), 2}, {\(-2\), 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Portest\>";\)\)], "Input"],

Cell[BoxData[
    \(\(saddleportrait[eq, window];\)\)], "Input"],

Cell["\tNow we change the parameters.", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-10\), 3};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[eq]\)], "Input"],

Cell["\<\
We now have a spiral, so we use spiralportrait to get the basic \
phase picture.\
\>", "Text"],

Cell[BoxData[
    \(\(spiralportrait[eq, window];\)\)], "Input"],

Cell["\tOnce again we change the parameters.", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-5\), \(-1\)};\)\)], "Input"],

Cell[BoxData[
    \(classify2D[eq]\)], "Input"],

Cell["\<\
\tWith a center, we use centerportrait (with the caution that in \
general with a nonlinear system, the center predicted by linear theory may \
actually be a spiral for the nonlinear system).\
\>", "Text"],

Cell[BoxData[
    \(\(centerportrait[eq, window];\)\)], "Input"],

Cell["\tOne final parameter change.", "Text"],

Cell[BoxData[
    \(\(parmval = {\(-6\), \(-4\)};\)\)], "Input"],

Cell["\<\
This time we have a node, so the relevant routine is \
nodeportrait.\
\>", "Text"],

Cell["\<\
We set the colors so that the two straight line solutions (actually \
four straight line segments) will be in red, the others in blue.\
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Red, Red, Red, Blue, Blue, Blue, Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(nodeportrait[eq, window];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tRepeat the above analysis for both equilibria of the system given \
by statevec = {x,y}, slopevec = {-x-y*y,y+x*x}.  Do this with both the \
portrait routines and the \"hand\" construction. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{3, Automatic}, {Automatic, -3}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 3, 152, "Title"],
Cell[1795, 56, 119, 2, 87, "Subtitle",
  Evaluatable->False],
Cell[1917, 60, 48, 1, 27, "Input"],
Cell[1968, 63, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2046, 68, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2206, 73, 410, 8, 65, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2653, 86, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2812, 91, 599, 12, 96, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3448, 108, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3580, 113, 339, 8, 48, "Text",
  Evaluatable->False],
Cell[3922, 123, 59, 1, 27, "Input"],
Cell[3984, 126, 55, 1, 27, "Input"],
Cell[4042, 129, 71, 1, 27, "Input"],
Cell[4116, 132, 56, 1, 27, "Input"],
Cell[4175, 135, 66, 1, 27, "Input"],
Cell[4244, 138, 52, 1, 27, "Input"],
Cell[4299, 141, 53, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4389, 147, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[4521, 152, 388, 8, 62, "Text",
  Evaluatable->False],
Cell[4912, 162, 60, 1, 27, "Input"],
Cell[4975, 165, 68, 1, 27, "Input"],
Cell[5046, 168, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5145, 174, 179, 4, 46, "Subsection",
  Evaluatable->False],
Cell[5327, 180, 708, 13, 96, "Text",
  Evaluatable->False],
Cell[6038, 195, 68, 1, 27, "Input"],
Cell[6109, 198, 60, 1, 27, "Input"],
Cell[6172, 201, 52, 1, 27, "Input"],
Cell[6227, 204, 53, 1, 27, "Input"],
Cell[6283, 207, 56, 1, 27, "Input"],
Cell[6342, 210, 65, 1, 27, "Input"],
Cell[6410, 213, 54, 1, 27, "Input"],
Cell[6467, 216, 54, 1, 27, "Input"],
Cell[6524, 219, 87, 1, 27, "Input"],
Cell[6614, 222, 41, 1, 27, "Input"],
Cell[6658, 225, 66, 1, 27, "Input"],
Cell[6727, 228, 87, 1, 27, "Input"],
Cell[6817, 231, 41, 1, 27, "Input"],
Cell[6861, 234, 60, 1, 27, "Input"],
Cell[6924, 237, 53, 1, 27, "Input"],
Cell[6980, 240, 84, 1, 27, "Input"],
Cell[7067, 243, 312, 7, 48, "Text"],
Cell[7382, 252, 55, 1, 27, "Input"],
Cell[7440, 255, 85, 1, 27, "Input"],
Cell[7528, 258, 213, 4, 46, "Text"],
Cell[7744, 264, 54, 1, 27, "Input"],
Cell[7801, 267, 55, 1, 27, "Input"],
Cell[7859, 270, 85, 1, 27, "Input"],
Cell[7947, 273, 167, 4, 46, "Text"],
Cell[8117, 279, 67, 1, 27, "Input"],
Cell[8187, 282, 85, 1, 27, "Input"],
Cell[8275, 285, 118, 3, 30, "Text"],
Cell[8396, 290, 50, 1, 27, "Input"],
Cell[8449, 293, 260, 6, 46, "Text",
  Evaluatable->False],
Cell[8712, 301, 52, 1, 27, "Input"],
Cell[8767, 304, 64, 1, 27, "Input"],
Cell[8834, 307, 89, 1, 27, "Input"],
Cell[8926, 310, 65, 1, 27, "Input"],
Cell[8994, 313, 89, 1, 27, "Input"],
Cell[9086, 316, 88, 1, 27, "Input"],
Cell[9177, 319, 94, 2, 30, "Text",
  Evaluatable->False],
Cell[9274, 323, 138, 4, 42, "Input"],
Cell[9415, 329, 206, 4, 46, "Text"],
Cell[9624, 335, 113, 2, 27, "Input"],
Cell[9740, 339, 122, 3, 30, "Text"],
Cell[9865, 344, 111, 2, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10013, 351, 180, 4, 46, "Subsection",
  Evaluatable->False],
Cell[10196, 357, 373, 8, 62, "Text",
  Evaluatable->False],
Cell[10572, 367, 60, 1, 27, "Input"],
Cell[10635, 370, 314, 7, 46, "Text",
  Evaluatable->False],
Cell[10952, 379, 81, 1, 27, "Input"],
Cell[11036, 382, 67, 1, 27, "Input"],
Cell[11106, 385, 110, 2, 30, "Text",
  Evaluatable->False],
Cell[11219, 389, 68, 1, 27, "Input"],
Cell[11290, 392, 60, 1, 27, "Input"],
Cell[11353, 395, 52, 1, 27, "Input"],
Cell[11408, 398, 53, 1, 27, "Input"],
Cell[11464, 401, 56, 1, 27, "Input"],
Cell[11523, 404, 65, 1, 27, "Input"],
Cell[11591, 407, 90, 1, 27, "Input"],
Cell[11684, 410, 66, 1, 27, "Input"],
Cell[11753, 413, 90, 1, 27, "Input"],
Cell[11846, 416, 60, 1, 27, "Input"],
Cell[11909, 419, 54, 1, 27, "Input"],
Cell[11966, 422, 93, 1, 27, "Input"],
Cell[12062, 425, 112, 2, 30, "Text",
  Evaluatable->False],
Cell[12177, 429, 52, 1, 27, "Input"],
Cell[12232, 432, 64, 1, 27, "Input"],
Cell[12299, 435, 92, 1, 27, "Input"],
Cell[12394, 438, 65, 1, 27, "Input"],
Cell[12462, 441, 92, 1, 27, "Input"],
Cell[12557, 444, 97, 1, 27, "Input"],
Cell[12657, 447, 357, 7, 62, "Text",
  Evaluatable->False],
Cell[13017, 456, 71, 1, 27, "Input"],
Cell[13091, 459, 82, 1, 27, "Input"],
Cell[13176, 462, 68, 0, 30, "Text"],
Cell[13247, 464, 113, 2, 27, "Input"],
Cell[13363, 468, 66, 0, 30, "Text"],
Cell[13432, 470, 66, 1, 27, "Input"],
Cell[13501, 473, 67, 0, 30, "Text"],
Cell[13571, 475, 56, 1, 27, "Input"],
Cell[13630, 478, 113, 2, 27, "Input"],
Cell[13746, 482, 218, 6, 46, "Text",
  Evaluatable->False],
Cell[13967, 490, 169, 5, 30, "Text",
  Evaluatable->False],
Cell[14139, 497, 61, 1, 27, "Input"],
Cell[14203, 500, 64, 1, 27, "Input"],
Cell[14270, 503, 52, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14359, 509, 159, 3, 46, "Subsection",
  Evaluatable->False],
Cell[14521, 514, 150, 3, 46, "Text"],
Cell[14674, 519, 54, 1, 27, "Input"],
Cell[14731, 522, 53, 1, 27, "Input"],
Cell[14787, 525, 67, 1, 27, "Input"],
Cell[14857, 528, 59, 1, 27, "Input"],
Cell[14919, 531, 49, 1, 27, "Input"],
Cell[14971, 534, 47, 1, 27, "Input"],
Cell[15021, 537, 68, 1, 27, "Input"],
Cell[15092, 540, 72, 0, 30, "Text"],
Cell[15167, 542, 73, 1, 27, "Input"],
Cell[15243, 545, 61, 1, 27, "Input"],
Cell[15307, 548, 64, 1, 27, "Input"],
Cell[15374, 551, 47, 0, 30, "Text"],
Cell[15424, 553, 60, 1, 27, "Input"],
Cell[15487, 556, 47, 1, 27, "Input"],
Cell[15537, 559, 104, 3, 30, "Text"],
Cell[15644, 564, 64, 1, 27, "Input"],
Cell[15711, 567, 54, 0, 30, "Text"],
Cell[15768, 569, 64, 1, 27, "Input"],
Cell[15835, 572, 47, 1, 27, "Input"],
Cell[15885, 575, 215, 4, 46, "Text"],
Cell[16103, 581, 64, 1, 27, "Input"],
Cell[16170, 584, 45, 0, 30, "Text"],
Cell[16218, 586, 64, 1, 27, "Input"],
Cell[16285, 589, 92, 3, 30, "Text"],
Cell[16380, 594, 158, 3, 46, "Text"],
Cell[16541, 599, 92, 1, 27, "Input"],
Cell[16636, 602, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16735, 608, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[16858, 613, 264, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

