(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28723,       1066]*)
(*NotebookOutlinePosition[     53869,       1975]*)
(*  CellTagsIndexPosition[     53825,       1971]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 6\
\>", "Title"],

Cell["\<\
Periodic Solutions
of
Autonomous Systems\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "asprat, axon, axorg, div, dival, frompolartrans, integrate, intreset, \
joinsol, labshift, lastt, lastx, limcyc, parmval, parmvec, period, phaseplot, \
phaser, phaser3D, plotreset, plrange, plrange3D, poinclist, poincmap, \
poincminus, poincmapopt3D, poincmap3D, poincplane, poincplus, poincptsize, \
polartrans, restoresys, savesys, setparm, setstate, show, signcontour, \
slopevec, statevec, sysreport, stateshift, and timeshift.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We use here four different systems with periodic solutions:  the undamped \
Duffing equation to illustrate a nonlinear center, both the van der Pol \
equation and a simpler equation with a circular orbit to illustrate 2D limit \
cycles, and the R\[ODoubleDot]ssler equations to illustrate a 3D limit cycle. \
 In addition to calculating and plotting the solutions and finding the \
periods, we construct several Poincar\[EAcute] maps.  We also illustrate the \
use of the slope divergence to learn something about the location of periodic \
solutions (Bendixson test)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["References",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The systems used here for examples are discussed in many books on \
dynamical systems.  Introductory treatments are given in ",
  StyleBox["Nonlinear Dynamical Systems and Chaos",
    FontWeight->"Bold"],
  ", S.H. Strogatz, Addison-Wesley, 1994, Chapter 7 (van der Pol and Duffing) \
and Section 10.6 (R\[ODoubleDot]ssler)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We define all four systems here and then save them by name. The state \
variables are x and y for the Duffing, van der Pol and circular systems, and \
x,y, and z for the R\[ODoubleDot]ssler system.  Each system has one or more \
parameters, for which we take typical values."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["First the R\[ODoubleDot]ssler equations."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{a,b,c}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {-y-z,x+a*y,b+z*(x-c)};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {0.2,0.2,2.0};", "Input",
  AspectRatioFixed->True],

Cell["savesys[Rossler];", "Input",
  AspectRatioFixed->True],

Cell[TextData["Now the van der Pol equation."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{mu}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y, -x -mu*(x*x-1)*y};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {2};", "Input",
  AspectRatioFixed->True],

Cell["savesys[vanderPol];", "Input",
  AspectRatioFixed->True],

Cell[TextData["Now the undamped Duffing equation."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{a}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y,-x-a*x^3};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {1};", "Input",
  AspectRatioFixed->True],

Cell["savesys[Duffing];", "Input",
  AspectRatioFixed->True],

Cell["\<\
Finally, the simple two-dimensional system which has a circular \
limit cycle.\
\>", "Text"],

Cell[BoxData[
    \(\(setstate[{x, y}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{\[Mu]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {y - x*\((x^2 + y^2 - \[Mu])\), \(-x\) - 
            y*\((x^2 + y^2 - \[Mu])\)};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {1};\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[Circular];\)\)], "Input"],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Duffing Equation",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "All of the solutions of the undamped Duffing equation are periodic.  Here \
we look briefly at the dependence of the period on amplitude, by considering \
three different solutions with different amplitudes.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(restoresys[Duffing];\)\)], "Input"],

Cell["initvec = {0.2,0.0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell["sol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labshift\  = \ 10;\)\)], "Input"],

Cell["graph1 = phaser[sol1];", "Input",
  AspectRatioFixed->True],

Cell["period[sol1]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see several interesting things from these results.  The \
amplitude ranges from -0.2 to 0.2, and this is small, in the sense that the \
cubic force term is much smaller than the linear force term.  Thus this \
oscillator is behaving like a linear oscillator.  We see that also from the \
circular orbit (which is the orbit the system would have without the cubic \
term), and the period which is 6.2 (to within one spacing h = 0.05).  Without \
the cubic term, the period would be exactly 2 Pi, so we see the period is \
very slightly shortened.  Now we go to a larger amplitude.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {1.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["sol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph2 = phaser[sol2];", "Input",
  AspectRatioFixed->True],

Cell["period[sol2]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow there is a oblong shape to the curve, and the period is \
considerably shorter.  The cubic force is larger in this amplitude range, and \
the larger restoring force shortens the period.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe consider one last case, with another factor of 5 increase in \
the amplitude.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {5.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["sol3 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph3 = phaser[sol3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe curve is slightly thickened because our time step is really \
not quite small enough, so the repeat orbits don't quite match.  We can cure \
this with a smaller time step. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = 0.01;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell["sol4 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph4 = phaser[sol4];", "Input",
  AspectRatioFixed->True],

Cell["period[sol4]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see that the period is dramatically shortened, and that the \
orbit is even further elongated.  The true elongation is even more apparent \
on a plot which shows all three orbits.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-20,20},{-20,20}};", "Input",
  AspectRatioFixed->True],

Cell["show[graph1,graph2, graph4];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The System Circular",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe restore the circular system and use sysreport to check our \
definitions.\
\>", "Text"],

Cell[BoxData[
    \(\(restoresys[Circular];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell[TextData[{
  "\tThe fact that the system has a circular orbit is not completely obvious \
in the present form.  We temporarily transform to polar coordinates ",
  StyleBox["r",
    FontSlant->"Italic"],
  " and \[Theta].  We use polartrans, a function which returns the slope \
vector for the polar coordinate system."
}], "Text"],

Cell[BoxData[
    \(polartrans[x, y, r, \[Theta]]\)], "Input"],

Cell[TextData[{
  "We see that ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\& . \)\)]],
  " = -",
  Cell[BoxData[
      \(TraditionalForm\`r\^3\)]],
  "+ ",
  StyleBox["r",
    FontSlant->"Italic"],
  "\[Mu] = ",
  StyleBox["r",
    FontSlant->"Italic"],
  "(\[Mu] - ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  "), so there is a stable limit cycle at ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Mu]\)]],
  ".  We construct a phase portrait with a few approach orbits."
}], "Text"],

Cell[BoxData[
    \(\(initset = {{0.02, 0}, {\(-0.02\), 0}, {1.5, 0}, {\(-1.5\), 0}, {0, 
            1.5}, {0, \(-1.5\)}};\)\)], "Input"],

Cell[BoxData[
    \(t0 = 0.0; h = 0.02; nsteps = 300; bothdirflag = False;\)], "Input"],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/4};\)], "Input"],

Cell[BoxData[
    \(plrange = {{\(-2\), 2}, {\(-2\), 2}}; asprat = 1.0;\)], "Input"],

Cell[BoxData[
    \(\(portrait[initset, t0, h, nsteps, 1, 2];\)\)], "Input"],

Cell[TextData[{
  "We see the circular stable limit cycle of radius ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Mu]\)]],
  " = 1."
}], "Text"],

Cell["\<\
\tIf we originally define the system in polar form, we can obtain \
the rectangular form from the function frompolartrans.  We carry that \
out.\
\>", "Text"],

Cell[BoxData[
    \(setstate[{r, \[Theta]}]; setparm[{\[Mu]}]; 
    slopevec = {r*\((\[Mu]\  - \ r\^2)\), \(-1\)};\)], "Input"],

Cell[BoxData[
    \(frompolartrans[r, \[Theta], x, y]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The van der Pol Equation",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe restore the van der Pol system and check to see that it has \
been correctly entered.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["restoresys[vanderPol];", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Bendixson Test for the van der Pol Equation",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe Bendixson Test is based on the fact that the divergence of \
the slope vector must either be identically zero or change sign inside a \
periodic orbit.  Thus we can look at the sign of the divergence to determine \
constraints on the possible locations of periodic orbits.  We first calculate \
the divergence and then plot the sign.  The divergence is given by\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["u = div[slopevec]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"If we want the current parameter value to be substituted automatically, we \
use dival instead of div."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["v = dival[slopevec]", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-5,5},{-5,5}};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now we use the routine signcontour, which shows white regions for positive, \
grey regions for negative."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["signcontour[v];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThus the divergence is positive in the white band between x = -1 \
and x = 1.  (A result easily seen from the above formula for \
dival[slopevec].)  The conclusion is that any periodic solution must \
encompass parts of both the white and grey regions.  We will verify that when \
we actually calculate the limit cycle.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Limit Cycle Solution of the van der Pol Equation",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "As is well-known, this system has a unique limit cycle which is a global \
attractor.  We look at a few orbits to show the approach to the limit cycle."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-5,5},{-5,5}};", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 400;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["van1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labshift\  = \ 10;\)\)], "Input"],

Cell["vangraph1 = phaser[van1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe didn't go quite far enough, so we continue the \
integration.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["van2 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["vangraph2 = phaser[van2];", "Input",
  AspectRatioFixed->True],

Cell["\tNow we have the limit cycle.  We find the period.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["period[van2]", "Input",
  AspectRatioFixed->True],

Cell["\tNow we look at an approach from outside.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {3.0,0};", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 800;", "Input",
  AspectRatioFixed->True],

Cell["van3 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["vangraph3 = phaser[van3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe can combine these graphs to see a little better the approach \
to the limit cycle.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["show[vangraph1, vangraph2,vangraph3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tIf we wish to produce the pure limit cycle without the startup \
transient, we use the routine limcyc.  We do that starting at the same \
initial point {3.0,0.0}.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["van4 = limcyc[initvec,t0,h,400];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(arrowflag = True; arrowvec = {1/3, 2/3};\)], "Input"],

Cell["vangraph4 = phaser[van4];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tGiven a solution such as van4, it is easy to produce a translated \
solution with the function stateshift. Although that has no particular \
technical value here, we illustrate its use by generating an interesting \
picture.\
\>", "Text"],

Cell[BoxData[
    \(solist = {}; inc = 0.1;\)], "Input"],

Cell[BoxData[
    \(\(Do[
        solist = 
          Append[solist, stateshift[van4, {i*inc, i*inc}]], {i, \(-10\), 
          10}];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag\  = \ False;\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[solist];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input"],

Cell["\tNow we look at the period of the limit cycle.", "Text"],

Cell["\[Tau] = period[van4]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis gives us the pure limit cycle.  It was necessary that \
initvec and nsteps be such that the cycle is reached in nsteps, starting from \
initvec.  This period and the earlier period agree to within the time step \
0.02.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBecause of the way the limit cycle is calculated, the initial \
time in the solution is not zero.  It is\
\>", "Text"],

Cell[BoxData[
    \(tint\  = \ First[First[van4]]\)], "Input"],

Cell["\<\
In plotting the solution versus time, it is slightly more \
convenient to have the time start at 0.  We can achieve this with the \
function timeshift: \
\>", "Text"],

Cell[BoxData[
    \(\(van4shift = timeshift[van4, \(-tint\)];\)\)], "Input"],

Cell["Now we construct a time plot showing one period.", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, \ \[Tau]}, {\(-4\), 4}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[van4shift, 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Poincar\[EAcute] Map for the van der Pol Limit Cycle",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe Poincar\[EAcute] map really isn't needed for this case \
because the phase plots show clearly how the cycle is approached.  However, \
we construct the map anyway as a simple exercise in using the \
Poincar\[EAcute] map routines.  We take line x = y as the Poincar\[EAcute] \
\"plane,\" and we construct a new solution starting further from the cycle.  \
The first step is to simply construct a solution in the usual way. \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {0.1,0.0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 2000;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-5,5},{-5,5}};", "Input",
  AspectRatioFixed->True],

Cell["vanpoinc = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["vangraph5 = phaser[vanpoinc];", "Input",
  AspectRatioFixed->True],

Cell["\tNow we define the Poincar\[EAcute] plane.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincplane = {1.0,-1.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Next we use poinclist to generate from the solution vanpoinc a list of \
intersections of the orbit with the Poincar\[EAcute] plane.  To see what this \
list looks like, we display the first five elements."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["vanlist = poinclist[vanpoinc];", "Input",
  AspectRatioFixed->True],

Cell["Take[vanlist,5]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Finally we construct the Poincar\[EAcute] map from vanlist with the routine \
poincmap."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincmap[vanlist,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe approach to the limit cycle is rapid and we see only \
fourpoints in the Poincar\[EAcute] map.  We see from the graph of the limit \
cycle that we would also expect four points if the Poincar\[EAcute] plane \
were the y-axis.  We try this. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincplane = {1.0,0.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["vanlist2 = poinclist[vanpoinc];", "Input",
  AspectRatioFixed->True],

Cell["axon = False;", "Input",
  AspectRatioFixed->True],

Cell["poincmap[vanlist2,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe do get the expected four points.  Rather than removing the \
axes to make the dots visible, we can either move the axes or make the dots \
larger.  We try each, starting with moving the axes by using axorg, which \
controls the position of the origin.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-5,5},{-5,5}};", "Input",
  AspectRatioFixed->True],

Cell["axorg = {-5,-5};", "Input",
  AspectRatioFixed->True],

Cell["axon = True;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["poincmap[vanlist2,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe can make the dots larger to be more visible.  Then we can \
restore the axes to the original position and still see them.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincptsize = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["axorg = Automatic;", "Input",
  AspectRatioFixed->True],

Cell["poincmap[vanlist2,1,2];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Limit Cycle Solution of the R\[ODoubleDot]ssler Equations",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe begin by changing the current system to the \
R\[ODoubleDot]ssler equations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["restoresys[Rossler];", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe reset the integration and plot defaults, and then set the \
integration parameters.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["poincptsize = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-5,5},{-5,5},{0,5}};", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.025;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 1000;", "Input",
  AspectRatioFixed->True],

Cell["ross1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["rossgraph1 = phaser3D[ross1];", "Input",
  AspectRatioFixed->True],

Cell["\tWe continue the integration.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ross2 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["rossgraph2 = phaser3D[ross2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis is very close to a pure limit cycle, though the curve is \
still a little thick, suggesting some transients remain.  We integrate once \
more.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ross3 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["rossgraph3 = phaser3D[ross3];", "Input",
  AspectRatioFixed->True],

Cell["\tThis looks like a pure limit cycle.  Let's find the period.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["period[ross3]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we join all of these solutions into one big solution, and \
construct a Poincar\[EAcute] map for that joined solution.  We use the plane \
z = 1 for the Poincar\[EAcute] plane.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["bigross = joinsol[ross1,joinsol[ross2,ross3]];", "Input",
  AspectRatioFixed->True],

Cell["poincplane = {0,0,1,-1};", "Input",
  AspectRatioFixed->True],

Cell["rosslist = poinclist[bigross];", "Input",
  AspectRatioFixed->True],

Cell["poincmap3D[rosslist,1,2,3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we choose a different Poincar\[EAcute] plane -- namely, \
2x+y+3z = 4.  We also change the viewpoint. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincplane = {2,1,3,-4};", "Input",
  AspectRatioFixed->True],

Cell["rosslist2 = poinclist[bigross];", "Input",
  AspectRatioFixed->True],

Cell["viewpt = {12,-24,-2};", "Input",
  AspectRatioFixed->True],

Cell["poincmap3D[rosslist2,1,2,3];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The Poincar\[EAcute] plane and the viewpoint we have chosen have caused the \
points to be clumped together.  We can get a better view of the map by using \
poincmapopt3D, which automatically chooses a viewpoint along the negative \
normal to the Poincar\[EAcute] plane."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincmapopt3D[rosslist2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe can also construct a 2D view of the Poincar\[EAcute] map by \
plotting the x and y components of rosslist.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-5,5},{-5,5}};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labshift\  = \ 16;\)\)], "Input"],

Cell["poincmap[rosslist,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe above two Poincar\[EAcute] maps show both the transients and \
the periodic solution.  The Poincar\[EAcute] map for the periodic solution \
has a simpler form, which we exhibit by using the periodic solution \
ross3.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["vanlist3 = poinclist[ross3];", "Input",
  AspectRatioFixed->True],

Cell["poincmap[vanlist3,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we see two points only in the Poincar\[EAcute] map -- one for \
the upward intersection of the orbit with the plane, and one for the downward \
intersection.  We can split our list into upward and downward by using the \
functions poincplus and poincminus.  The crossings in the direction of the \
positive normal to the Poincar\[EAcute] plane are given by poincplus, and the \
crossings in the negative normal direction are given by poincminus.  \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincmap[poincplus[vanlist3],1,2];", "Input",
  AspectRatioFixed->True],

Cell["poincmap[poincminus[vanlist3],1,2];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Construct Poincar\[EAcute] maps (both transient and periodic) for the R\
\[ODoubleDot]ssler system when {a,b,c} = {0.2,0.2,3.0}."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000M60801T1T00000000000
00000000000000>1R]00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 3, 152, "Title"],
Cell[1795, 56, 116, 6, 118, "Subtitle",
  Evaluatable->False],
Cell[1914, 64, 48, 1, 27, "Input"],
Cell[1965, 67, 46, 1, 27, "Input"],
Cell[2014, 70, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2086, 75, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2246, 80, 556, 11, 83, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2839, 96, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2998, 101, 690, 13, 100, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3725, 119, 122, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3850, 124, 446, 11, 67, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4333, 140, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[4465, 145, 396, 9, 66, "Text",
  Evaluatable->False],
Cell[4864, 156, 114, 2, 31, "Text",
  Evaluatable->False],
Cell[4981, 160, 61, 1, 27, "Input"],
Cell[5045, 163, 60, 1, 27, "Input"],
Cell[5108, 166, 77, 1, 27, "Input"],
Cell[5188, 169, 67, 1, 27, "Input"],
Cell[5258, 172, 60, 1, 27, "Input"],
Cell[5321, 175, 103, 2, 31, "Text",
  Evaluatable->False],
Cell[5427, 179, 59, 1, 27, "Input"],
Cell[5489, 182, 57, 1, 27, "Input"],
Cell[5549, 185, 76, 1, 27, "Input"],
Cell[5628, 188, 57, 1, 27, "Input"],
Cell[5688, 191, 62, 1, 27, "Input"],
Cell[5753, 194, 108, 2, 31, "Text",
  Evaluatable->False],
Cell[5864, 198, 59, 1, 27, "Input"],
Cell[5926, 201, 56, 1, 27, "Input"],
Cell[5985, 204, 67, 1, 27, "Input"],
Cell[6055, 207, 57, 1, 27, "Input"],
Cell[6115, 210, 60, 1, 27, "Input"],
Cell[6178, 213, 102, 3, 31, "Text"],
Cell[6283, 218, 54, 1, 27, "Input"],
Cell[6340, 221, 54, 1, 27, "Input"],
Cell[6397, 224, 129, 2, 27, "Input"],
Cell[6529, 228, 51, 1, 27, "Input"],
Cell[6583, 231, 55, 1, 27, "Input"],
Cell[6641, 234, 52, 1, 27, "Input"],
Cell[6696, 237, 53, 1, 27, "Input"],
Cell[6752, 240, 56, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6845, 246, 128, 3, 46, "Subsection",
  Evaluatable->False],
Cell[6976, 251, 331, 8, 49, "Text",
  Evaluatable->False],
Cell[7310, 261, 57, 1, 27, "Input"],
Cell[7370, 264, 63, 1, 27, "Input"],
Cell[7436, 267, 52, 1, 27, "Input"],
Cell[7491, 270, 52, 1, 27, "Input"],
Cell[7546, 273, 56, 1, 27, "Input"],
Cell[7605, 276, 81, 1, 27, "Input"],
Cell[7689, 279, 55, 1, 27, "Input"],
Cell[7747, 282, 65, 1, 27, "Input"],
Cell[7815, 285, 55, 1, 27, "Input"],
Cell[7873, 288, 656, 11, 99, "Text",
  Evaluatable->False],
Cell[8532, 301, 63, 1, 27, "Input"],
Cell[8598, 304, 81, 1, 27, "Input"],
Cell[8682, 307, 65, 1, 27, "Input"],
Cell[8750, 310, 55, 1, 27, "Input"],
Cell[8808, 313, 263, 6, 48, "Text",
  Evaluatable->False],
Cell[9074, 321, 154, 5, 31, "Text",
  Evaluatable->False],
Cell[9231, 328, 63, 1, 27, "Input"],
Cell[9297, 331, 81, 1, 27, "Input"],
Cell[9381, 334, 65, 1, 27, "Input"],
Cell[9449, 337, 250, 6, 48, "Text",
  Evaluatable->False],
Cell[9702, 345, 52, 1, 27, "Input"],
Cell[9757, 348, 56, 1, 27, "Input"],
Cell[9816, 351, 81, 1, 27, "Input"],
Cell[9900, 354, 65, 1, 27, "Input"],
Cell[9968, 357, 55, 1, 27, "Input"],
Cell[10026, 360, 256, 6, 48, "Text",
  Evaluatable->False],
Cell[10285, 368, 73, 1, 27, "Input"],
Cell[10361, 371, 71, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10469, 377, 131, 3, 46, "Subsection",
  Evaluatable->False],
Cell[10603, 382, 102, 3, 31, "Text"],
Cell[10708, 387, 58, 1, 27, "Input"],
Cell[10769, 390, 42, 1, 27, "Input"],
Cell[10814, 393, 335, 7, 66, "Text"],
Cell[11152, 402, 62, 1, 27, "Input"],
Cell[11217, 405, 550, 23, 50, "Text"],
Cell[11770, 430, 138, 2, 43, "Input"],
Cell[11911, 434, 87, 1, 27, "Input"],
Cell[12001, 437, 68, 1, 27, "Input"],
Cell[12072, 440, 84, 1, 27, "Input"],
Cell[12159, 443, 76, 1, 27, "Input"],
Cell[12238, 446, 146, 5, 33, "Text"],
Cell[12387, 453, 168, 4, 48, "Text"],
Cell[12558, 459, 127, 2, 31, "Input"],
Cell[12688, 463, 66, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12791, 469, 136, 3, 46, "Subsection",
  Evaluatable->False],
Cell[12930, 474, 162, 5, 31, "Text",
  Evaluatable->False],
Cell[13095, 481, 65, 1, 27, "Input"],
Cell[13163, 484, 52, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13252, 490, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[13410, 495, 442, 9, 65, "Text",
  Evaluatable->False],
Cell[13855, 506, 60, 1, 27, "Input"],
Cell[13918, 509, 177, 4, 31, "Text",
  Evaluatable->False],
Cell[14098, 515, 62, 1, 27, "Input"],
Cell[14163, 518, 69, 1, 27, "Input"],
Cell[14235, 521, 179, 4, 31, "Text",
  Evaluatable->False],
Cell[14417, 527, 58, 1, 27, "Input"],
Cell[14478, 530, 393, 8, 65, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[14908, 543, 160, 3, 46, "Subsection",
  Evaluatable->False],
Cell[15071, 548, 273, 7, 49, "Text",
  Evaluatable->False],
Cell[15347, 557, 53, 1, 27, "Input"],
Cell[15403, 560, 52, 1, 27, "Input"],
Cell[15458, 563, 56, 1, 27, "Input"],
Cell[15517, 566, 69, 1, 27, "Input"],
Cell[15589, 569, 63, 1, 27, "Input"],
Cell[15655, 572, 52, 1, 27, "Input"],
Cell[15710, 575, 56, 1, 27, "Input"],
Cell[15769, 578, 52, 1, 27, "Input"],
Cell[15824, 581, 81, 1, 27, "Input"],
Cell[15908, 584, 55, 1, 27, "Input"],
Cell[15966, 587, 68, 1, 27, "Input"],
Cell[16037, 590, 138, 5, 31, "Text",
  Evaluatable->False],
Cell[16178, 597, 82, 1, 27, "Input"],
Cell[16263, 600, 68, 1, 27, "Input"],
Cell[16334, 603, 115, 2, 31, "Text",
  Evaluatable->False],
Cell[16452, 607, 55, 1, 27, "Input"],
Cell[16510, 610, 106, 2, 31, "Text",
  Evaluatable->False],
Cell[16619, 614, 61, 1, 27, "Input"],
Cell[16683, 617, 56, 1, 27, "Input"],
Cell[16742, 620, 81, 1, 27, "Input"],
Cell[16826, 623, 68, 1, 27, "Input"],
Cell[16897, 626, 159, 5, 31, "Text",
  Evaluatable->False],
Cell[17059, 633, 80, 1, 27, "Input"],
Cell[17142, 636, 236, 6, 48, "Text",
  Evaluatable->False],
Cell[17381, 644, 75, 1, 27, "Input"],
Cell[17459, 647, 73, 1, 27, "Input"],
Cell[17535, 650, 68, 1, 27, "Input"],
Cell[17606, 653, 250, 5, 48, "Text"],
Cell[17859, 660, 56, 1, 27, "Input"],
Cell[17918, 663, 148, 4, 43, "Input"],
Cell[18069, 669, 53, 1, 27, "Input"],
Cell[18125, 672, 59, 1, 27, "Input"],
Cell[18187, 675, 52, 1, 27, "Input"],
Cell[18242, 678, 55, 1, 27, "Input"],
Cell[18300, 681, 63, 0, 31, "Text"],
Cell[18366, 683, 64, 1, 27, "Input"],
Cell[18433, 686, 297, 7, 48, "Text",
  Evaluatable->False],
Cell[18733, 695, 130, 3, 31, "Text"],
Cell[18866, 700, 62, 1, 27, "Input"],
Cell[18931, 703, 176, 4, 48, "Text"],
Cell[19110, 709, 76, 1, 27, "Input"],
Cell[19189, 712, 64, 0, 31, "Text"],
Cell[19256, 714, 76, 1, 27, "Input"],
Cell[19335, 717, 60, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19432, 723, 165, 4, 46, "Subsection",
  Evaluatable->False],
Cell[19600, 729, 503, 10, 82, "Text",
  Evaluatable->False],
Cell[20106, 741, 63, 1, 27, "Input"],
Cell[20172, 744, 52, 1, 27, "Input"],
Cell[20227, 747, 52, 1, 27, "Input"],
Cell[20282, 750, 57, 1, 27, "Input"],
Cell[20342, 753, 56, 1, 27, "Input"],
Cell[20401, 756, 69, 1, 27, "Input"],
Cell[20473, 759, 85, 1, 27, "Input"],
Cell[20561, 762, 72, 1, 27, "Input"],
Cell[20636, 765, 107, 2, 31, "Text",
  Evaluatable->False],
Cell[20746, 769, 71, 1, 27, "Input"],
Cell[20820, 772, 280, 5, 48, "Text",
  Evaluatable->False],
Cell[21103, 779, 73, 1, 27, "Input"],
Cell[21179, 782, 58, 1, 27, "Input"],
Cell[21240, 785, 162, 4, 31, "Text",
  Evaluatable->False],
Cell[21405, 791, 65, 1, 27, "Input"],
Cell[21473, 794, 318, 7, 48, "Text",
  Evaluatable->False],
Cell[21794, 803, 70, 1, 27, "Input"],
Cell[21867, 806, 74, 1, 27, "Input"],
Cell[21944, 809, 56, 1, 27, "Input"],
Cell[22003, 812, 66, 1, 27, "Input"],
Cell[22072, 815, 328, 7, 65, "Text",
  Evaluatable->False],
Cell[22403, 824, 69, 1, 27, "Input"],
Cell[22475, 827, 59, 1, 27, "Input"],
Cell[22537, 830, 55, 1, 27, "Input"],
Cell[22595, 833, 56, 1, 27, "Input"],
Cell[22654, 836, 66, 1, 27, "Input"],
Cell[22723, 839, 198, 5, 48, "Text",
  Evaluatable->False],
Cell[22924, 846, 62, 1, 27, "Input"],
Cell[22989, 849, 61, 1, 27, "Input"],
Cell[23053, 852, 66, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23156, 858, 170, 4, 46, "Subsection",
  Evaluatable->False],
Cell[23329, 864, 153, 5, 31, "Text",
  Evaluatable->False],
Cell[23485, 871, 63, 1, 27, "Input"],
Cell[23551, 874, 52, 1, 27, "Input"],
Cell[23606, 877, 160, 5, 31, "Text",
  Evaluatable->False],
Cell[23769, 884, 52, 1, 27, "Input"],
Cell[23824, 887, 53, 1, 27, "Input"],
Cell[23880, 890, 62, 1, 27, "Input"],
Cell[23945, 893, 77, 1, 27, "Input"],
Cell[24025, 896, 61, 1, 27, "Input"],
Cell[24089, 899, 52, 1, 27, "Input"],
Cell[24144, 902, 53, 1, 27, "Input"],
Cell[24200, 905, 57, 1, 27, "Input"],
Cell[24260, 908, 82, 1, 27, "Input"],
Cell[24345, 911, 60, 1, 27, "Input"],
Cell[24408, 914, 72, 1, 27, "Input"],
Cell[24483, 917, 94, 2, 31, "Text",
  Evaluatable->False],
Cell[24580, 921, 83, 1, 27, "Input"],
Cell[24666, 924, 72, 1, 27, "Input"],
Cell[24741, 927, 221, 6, 48, "Text",
  Evaluatable->False],
Cell[24965, 935, 83, 1, 27, "Input"],
Cell[25051, 938, 72, 1, 27, "Input"],
Cell[25126, 941, 125, 2, 31, "Text",
  Evaluatable->False],
Cell[25254, 945, 56, 1, 27, "Input"],
Cell[25313, 948, 254, 6, 48, "Text",
  Evaluatable->False],
Cell[25570, 956, 89, 1, 27, "Input"],
Cell[25662, 959, 67, 1, 27, "Input"],
Cell[25732, 962, 73, 1, 27, "Input"],
Cell[25808, 965, 70, 1, 27, "Input"],
Cell[25881, 968, 180, 5, 31, "Text",
  Evaluatable->False],
Cell[26064, 975, 67, 1, 27, "Input"],
Cell[26134, 978, 74, 1, 27, "Input"],
Cell[26211, 981, 64, 1, 27, "Input"],
Cell[26278, 984, 71, 1, 27, "Input"],
Cell[26352, 987, 345, 6, 65, "Text",
  Evaluatable->False],
Cell[26700, 995, 68, 1, 27, "Input"],
Cell[26771, 998, 183, 5, 31, "Text",
  Evaluatable->False],
Cell[26957, 1005, 69, 1, 27, "Input"],
Cell[27029, 1008, 55, 1, 27, "Input"],
Cell[27087, 1011, 66, 1, 27, "Input"],
Cell[27156, 1014, 294, 7, 48, "Text",
  Evaluatable->False],
Cell[27453, 1023, 71, 1, 27, "Input"],
Cell[27527, 1026, 66, 1, 27, "Input"],
Cell[27596, 1029, 528, 10, 82, "Text",
  Evaluatable->False],
Cell[28127, 1041, 77, 1, 27, "Input"],
Cell[28207, 1044, 78, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28322, 1050, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[28445, 1055, 250, 7, 32, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

