(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24929,        899]*)
(*NotebookOutlinePosition[     50075,       1808]*)
(*  CellTagsIndexPosition[     50031,       1804]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 7\
\>", "Title"],

Cell["\<\
Periodic Solutions
of
Driven Systems\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(imsize\  = \ 380;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "asprat, backcolor, display, drpoinclist, drpoincmap, drpoincmap3D, \
drpoincsol, imsize, integrate, intreset, lastt, lastx, modsol, parmval, \
parmvec, phaser, plot,  plotreset, plrange, plrange3D, poincpointper, \
poincptsize, pointcon, setback, setparm, setstate, show, slopevec, \
staterange, statevec, sysname, timeplot, and trange.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of System Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We use the damped driven pendulum here to illustrate the routines for \
periodic solutions of periodically driven systems.  We construct solutions \
and Poincar\[EAcute] maps for several different parameter sets -- some \
leading to periodic solutions, one leading to a chaotic solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Reference",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Although the driven pendulum is covered in many different texts, a \
particularly useful reference is ",
  StyleBox["Chaotic Dynamics",
    FontWeight->"Bold"],
  ", second edition, by G.L. Baker and J.P. Gollub, Cambridge Press, 1996.  \
The parameter values used here are taken from Chapter 3 of that reference."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We use the pendulum equation in dimensionless form, with the scaling such \
that the angular frequency of small amplitude, undamped, undriven \
oscillations is unity. We denote the dimensionless damping constant by eps. \
The driving function is f*Cos[w*t], where f is the dimensionless amplitude, \
and w is the dimensionless frequency."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{\[Theta], \[Omega]}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{\[Epsilon],f,w}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
slopevec = {\[Omega], -\[Epsilon]*\[Omega] -Sin[\[Theta]] + \
f*Cos[w*t]};\
\>", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"Pen\";", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"A Periodic Solution With Period Equal to Driver Period",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tWe set the parameter values and then integrate.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {0.5,0.9,2./3.};", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 1000;", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["pen1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["pengraph1 = phaser[pen1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe system may have reached a periodic orbit, but we will have to \
integrate further to see.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["pen2 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["pengraph2 = phaser[pen2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis looks periodic.  Let's look at a time plot of the solution, \
and plot the driver on the same graph.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell["pengraphtime2 = timeplot[pen2,1];", "Input",
  AspectRatioFixed->True],

Cell["driver[t_] := N[f*Cos[w*t] /. Thread[parmvec -> parmval]]", "Input",
  AspectRatioFixed->True],

Cell["drivergraph = plot[driver[t],{t,50,100}];", "Input",
  AspectRatioFixed->True],

Cell["show[pengraphtime2,drivergraph];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see from the graph that the solution is periodic with the same \
period as the driver, the period being\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["driverperiod = N[(2 Pi)/(2/3)]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tLet's construct a Poincar\[EAcute] map showing both the approach \
and the final periodic solution.  We begin by constructing an appropriate \
solution list with drpoinclist.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["pen3 = drpoincsol[initvec,t0,driverperiod,20];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The arguments of drpoinclist are the initial condition initvec, the initial \
time t0, the strobe period driverperiod, and the number of periods 20. "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["pengraph3 = phaser[pen3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis graph is very similar to pengraph1 because it was \
constructed in essentially the same way.  The only significant difference \
between an arbitrary solution list and one constructed by poinclist, is that \
the time spacing in poinclist is commensurate with the strobe period, and the \
number of integration points per period is equal to the value of pointper \
(the default is 48 points per period).  
     
\tThe Poincar\[EAcute] map is now constructed from pen3 by the routine \
drpoincmap.  The second argument of drpoincmap is the phase (in degrees) at \
which the map is to be made.  This may be any multiple of 15 degrees from 0 \
to 345.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincptsize = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["phase = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["poincgr3 = drpoincmap[pen3,phase,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe list of coordinates plotted in the Poincar\[EAcute] map may \
be obtained with the function drpoinclist acting on the solution pen3.\
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincerlist3 = drpoinclist[pen3,phase]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see from this that the approach to the periodic solution is \
rapid.  By the fourth strobe period, the system point has settled down to the \
final one, within graphical accuracy.  This is consistent with the graph, on \
which we see four points only.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe now construct a sequence of graphs which simulates the strobe \
process.  We plot each system state in white on a black background, and we \
alternate these graphs with a completely black graph.\
\>", "Text"],

Cell[BoxData[
    \(strobe[list_] := 
      Module[{temp, i, templist}, templist = stripsol[list, 0]; axon = False; 
        labon = False; ptsize = 0.02; setback[Black]; 
        Do[temp = templist[\([i]\)]; setcolor[{White}]; dots[{temp}]; 
          setcolor[{Black}]; dots[{temp}], {i, 1, Length[list]}]]\)], "Input"],

Cell[BoxData[
    \(\(plrange\  = \ {{\(-2\), 2}, {\(-2\), 2}};\)\)], "Input"],

Cell[BoxData[
    \(\(strobe[poincerlist3];\)\)], "Input"],

Cell["\<\
\tIf you animate the graph sequence, you will see the strobing of \
the system point at time increments equal to the period of the driver.\
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution Period Equal to Twice the Driver Period",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe consider another set of parameter values for which the \
response is periodic with twice the period of the driver.  In this example, \
we start with drpoincsol, rather than doing a preliminary integration first.  \
We go 10 periods at a time. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell["parmval = {0.5,1.07,2./3.};", "Input",
  AspectRatioFixed->True],

Cell["initvec = {8.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["pen5 = drpoincsol[initvec,t0,driverperiod,10];", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["pengraph5 = phaser[pen5];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tIt looks as though we may have reached a periodic solution.  We \
continue the integration, to get a pure periodic solution without the startup \
transient.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["pen6 = drpoincsol[lastx,lastt,driverperiod,10];", "Input",
  AspectRatioFixed->True],

Cell["pengraph6 = phaser[pen6];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis appears to be periodic with a period of twice the driver \
period.  We check that with a timeplot.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell["plrange = All;", "Input",
  AspectRatioFixed->True],

Cell["display = False;", "Input",
  AspectRatioFixed->True],

Cell["pengraph7 = timeplot[pen6,1];", "Input",
  AspectRatioFixed->True],

Cell["trange[pen6]", "Input",
  AspectRatioFixed->True],

Cell["driver2 = plot[driver[t], {t,100,210}];", "Input",
  AspectRatioFixed->True],

Cell["show[pengraph7,driver2];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"A close look shows that indeed the solution repeats every second period of \
the driver."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tNow we construct the Poincar\[EAcute] map.  Because we are \
strobing at the driver period and because the solution has a period twice \
this, we expect to see exactly two dots on the Poincar\[EAcute] plot. \
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["display = True;", "Input",
  AspectRatioFixed->True],

Cell["poincptsize = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["phase = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{2,10},{-3,3}};", "Input",
  AspectRatioFixed->True],

Cell["poincgr6 = drpoincmap[pen6,phase,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see the two dots, indicative of the subharmonic of order \
two.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe now construct a strobe sequence showing the approach to the \
orbit with period twice the driver period.  We integrate for 20 driver \
periods. \
\>", "Text"],

Cell["pen6mod = drpoincsol[initvec,t0,driverperiod,20];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(poincerlist6mod = drpoinclist[pen6mod, 0]\)], "Input"],

Cell["We strobe this list.", "Text"],

Cell[BoxData[
    \(\(strobe[poincerlist6mod];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rotary Solution With Period Equal to Driver Period",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tNow we look at a periodic solution in which the pendulum rotates \
over the top in each cycle.  The coordinate theta increases without limit.  \
We will use the function modsol to frame the solution in a single 2 Pi range \
of theta.  We begin by resetting integration flags and plot variables, and \
then setting the parameter values.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["parmval = {0.5,1.35,2./3.};", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe start with a 500 point integration to get onto the periodic \
solution.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {0,0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 500;", "Input",
  AspectRatioFixed->True],

Cell["oversol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["\tWe check the range before plotting.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["staterange[oversol1]", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-20,5},{-2,2}};", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["overgraph1 = phaser[oversol1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe continue the integration to get the pure periodic \
solution.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["oversol2 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["staterange[oversol2]", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-40,-10},{-2,2}};", "Input",
  AspectRatioFixed->True],

Cell["overgraph2 = phaser[oversol2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis looks periodic.  (A minor mathematical point.  Strictly \
speaking the solution is not periodic because the theta values do not repeat. \
 However, theta values differing by 2 Pi represent the same physical point.  \
If points differing by 2 Pi are considered to be the same, then the solution \
is periodic.)  There are two practical difficulties.  First, the solution \
will keep drifting to the left, and we will have to keep changing our phase \
plane window if we wish to follow it.  Second, it is hard to tell periodicity \
because the loops do not overlay as they do in the case when the pendulum \
oscillates rather than going around.  We can cure both of those difficulties \
by using modsol, a function which maps any coordinate onto a specified \
interval modulo the interval length.  Here we use the interval -Pi to Pi, and \
we ask for the first component (theta) to be so mapped.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["modsol1 = modsol[oversol1,1,N[-Pi],N[Pi]];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we plot the modified solution.  We use dots rather than a \
connected line, so that we avoid connecting lines at the jumps at the \
interval ends.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["pointcon = False;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-4,4},{-2,2}};", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["modgraph1 = phaser[modsol1];", "Input",
  AspectRatioFixed->True],

Cell["\tWe repeat for the pure periodic solution oversol2.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["modgraph2 = phaser[modsol[oversol2,1,N[-Pi],N[Pi]]];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe solution looks periodic, but the slight thickening suggests \
that there is a small residual of a transient.  We integrate once more to \
clean it up.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["oversol3 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["modgraph3 = phaser[modsol[oversol3,1,N[-Pi],N[Pi]]];", "Input",
  AspectRatioFixed->True],

Cell["\tNow we have a clean periodic solution.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A Chaotic Solution",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe complete our look at the driven pendulum with a chaotic \
solution.  We start by setting the parameter values, and resetting the \
integration flags and plot variables.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {0.5,1.5,2./3.};", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe start with a 500-point integration just to see what the \
solution looks like.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 500;", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1,0};", "Input",
  AspectRatioFixed->True],

Cell["cha1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["staterange[cha1]", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-10,2},{-3,3}};", "Input",
  AspectRatioFixed->True],

Cell["chagraph1 = phaser[cha1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tToo early to tell if it is chaotic, although it might be.  We do \
next a very long integration, using poinclist, and then look at the results.  \
We reduce the number of points per period from 48 to 24, just to halve the \
integration time.  The 200 periods asked for below takes a LONG time to \
calculate, and the basic ideas would still come through with a much smaller \
number of periods -- say 30.  On the other hand, the Poincar\[EAcute] maps \
get more interesting with more periods.  If you have enough memory and time, \
try 600 or even more periods.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poincpointper = 24;", "Input",
  AspectRatioFixed->True],

Cell["poinchao = drpoincsol[lastx,lastt,driverperiod,200];", "Input",
  AspectRatioFixed->True],

Cell["staterange[poinchao]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe large theta range shows that we need to use modsol to get a \
more compact description.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["poinchaomod = modsol[poinchao,1,N[-Pi],N[Pi]];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we write a simple loop to produce a sequence of Poincar\
\[EAcute] maps for each of the allowable phases -- that is, a sequence of 24 \
maps at 15 degree phase intervals.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-4,4},{-4,4}};", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["Do[(drpoincmap[poinchaomod,q,1,2]),{q,0,345,15}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tAn animation of the 24 graphs gives some insight into the \
variation of the Poincar\[EAcute] map with phase.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A Three-Dimensional Driven Solution",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tTo illustrate the use of the Poincar\[EAcute] map for 3D driven \
systems, we consider a simple but somewhat artificial extension of the \
pendulum into three dimensions, by adding a z-coordinate which simply decays \
with time to the plane z = 0.  We start by defining the system.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{\[Theta],\[Omega],z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{\[Epsilon],f,w}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
slopevec = {\[Omega], -\[Epsilon]*\[Omega] -Sin[\[Theta]] + \
f*Cos[w*t],-0.05*z};\
\>", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"Pen3D\";", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe choose the parameter values that in the 2D case gave us an \
oscillatory solution with period equal to the driver period.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {0.5,0.9,2./3.};", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe start above the plane z = 0.  We will make a Poincar\[EAcute] \
map of the approach to a periodic solution.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["driverperiod = N[(2 Pi)/(2/3)];", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1.0,0.0,2.0};", "Input",
  AspectRatioFixed->True],

Cell["penpoinc3D = drpoincsol[initvec,t0,driverperiod,20];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we construct the Poincar\[EAcute] map for this solution, at \
zero phase.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["phase = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-2,2},{-4,4},{0,2}};", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["poincptsize = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["viewpt = {2,-24,10}; ", "Input",
  AspectRatioFixed->True],

Cell["graphpoinc3d = drpoincmap3D[penpoinc3D,phase,1,2,3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tIt is helpful to view a projection of this map on the theta-omega \
plane.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-2,2},{-4,4}};", "Input",
  AspectRatioFixed->True],

Cell["graphpoinc2D = drpoincmap[penpoinc3D,phase,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\tLet's look at the coordinates in the Poincar\[EAcute] map. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["drpoinclist[penpoinc3D,phase]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tFrom here we see that the eventual periodic point in the map is \
at theta = -0.560, omega = 1.934.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Consider again the two-dimensional rotary solution with period equal to \
the driver period, for the parameter values parmval = {0.5,1,35,2/3}.  By \
experimenting with initial conditions, find a second rotary solution in the \
opposite sense, with the same parameter values."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{651, 535},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000MF0801T1T00000000000
00000000000000>1RU00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 3, 152, "Title"],
Cell[1795, 56, 112, 6, 118, "Subtitle",
  Evaluatable->False],
Cell[1910, 64, 48, 1, 27, "Input"],
Cell[1961, 67, 46, 1, 27, "Input"],
Cell[2010, 70, 47, 1, 27, "Input"],
Cell[2060, 73, 54, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2139, 78, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2299, 83, 461, 10, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2797, 98, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2955, 103, 409, 9, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3401, 117, 121, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3525, 122, 435, 11, 66, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3997, 138, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[4129, 143, 459, 10, 64, "Text",
  Evaluatable->False],
Cell[4591, 155, 74, 1, 27, "Input"],
Cell[4668, 158, 69, 1, 27, "Input"],
Cell[4740, 161, 125, 4, 27, "Input"],
Cell[4868, 167, 61, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4966, 173, 167, 4, 46, "Subsection",
  Evaluatable->False],
Cell[5136, 179, 113, 2, 30, "Text",
  Evaluatable->False],
Cell[5252, 183, 69, 1, 27, "Input"],
Cell[5324, 186, 52, 1, 27, "Input"],
Cell[5379, 189, 57, 1, 27, "Input"],
Cell[5439, 192, 63, 1, 27, "Input"],
Cell[5505, 195, 52, 1, 27, "Input"],
Cell[5560, 198, 52, 1, 27, "Input"],
Cell[5615, 201, 81, 1, 27, "Input"],
Cell[5699, 204, 53, 1, 27, "Input"],
Cell[5755, 207, 56, 1, 27, "Input"],
Cell[5814, 210, 68, 1, 27, "Input"],
Cell[5885, 213, 167, 5, 30, "Text",
  Evaluatable->False],
Cell[6055, 220, 82, 1, 27, "Input"],
Cell[6140, 223, 68, 1, 27, "Input"],
Cell[6211, 226, 179, 5, 30, "Text",
  Evaluatable->False],
Cell[6393, 233, 56, 1, 27, "Input"],
Cell[6452, 236, 76, 1, 27, "Input"],
Cell[6531, 239, 100, 1, 27, "Input"],
Cell[6634, 242, 84, 1, 27, "Input"],
Cell[6721, 245, 75, 1, 27, "Input"],
Cell[6799, 248, 180, 5, 30, "Text",
  Evaluatable->False],
Cell[6982, 255, 73, 1, 27, "Input"],
Cell[7058, 258, 248, 6, 46, "Text",
  Evaluatable->False],
Cell[7309, 266, 89, 1, 27, "Input"],
Cell[7401, 269, 227, 5, 46, "Text",
  Evaluatable->False],
Cell[7631, 276, 56, 1, 27, "Input"],
Cell[7690, 279, 68, 1, 27, "Input"],
Cell[7761, 282, 727, 14, 126, "Text",
  Evaluatable->False],
Cell[8491, 298, 62, 1, 27, "Input"],
Cell[8556, 301, 56, 1, 27, "Input"],
Cell[8615, 304, 55, 1, 27, "Input"],
Cell[8673, 307, 81, 1, 27, "Input"],
Cell[8757, 310, 213, 6, 46, "Text",
  Evaluatable->False],
Cell[8973, 318, 81, 1, 27, "Input"],
Cell[9057, 321, 328, 7, 62, "Text",
  Evaluatable->False],
Cell[9388, 330, 223, 4, 46, "Text"],
Cell[9614, 336, 321, 5, 91, "Input"],
Cell[9938, 343, 78, 1, 27, "Input"],
Cell[10019, 346, 58, 1, 27, "Input"],
Cell[10080, 349, 164, 4, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10281, 358, 160, 3, 46, "Subsection",
  Evaluatable->False],
Cell[10444, 363, 320, 7, 46, "Text",
  Evaluatable->False],
Cell[10767, 372, 47, 1, 27, "Input"],
Cell[10817, 375, 70, 1, 27, "Input"],
Cell[10890, 378, 63, 1, 27, "Input"],
Cell[10956, 381, 52, 1, 27, "Input"],
Cell[11011, 384, 89, 1, 27, "Input"],
Cell[11103, 387, 56, 1, 27, "Input"],
Cell[11162, 390, 68, 1, 27, "Input"],
Cell[11233, 393, 230, 6, 46, "Text",
  Evaluatable->False],
Cell[11466, 401, 90, 1, 27, "Input"],
Cell[11559, 404, 68, 1, 27, "Input"],
Cell[11630, 407, 177, 5, 30, "Text",
  Evaluatable->False],
Cell[11810, 414, 56, 1, 27, "Input"],
Cell[11869, 417, 57, 1, 27, "Input"],
Cell[11929, 420, 59, 1, 27, "Input"],
Cell[11991, 423, 72, 1, 27, "Input"],
Cell[12066, 426, 55, 1, 27, "Input"],
Cell[12124, 429, 82, 1, 27, "Input"],
Cell[12209, 432, 67, 1, 27, "Input"],
Cell[12279, 435, 163, 4, 30, "Text",
  Evaluatable->False],
Cell[12445, 441, 283, 7, 46, "Text",
  Evaluatable->False],
Cell[12731, 450, 58, 1, 27, "Input"],
Cell[12792, 453, 62, 1, 27, "Input"],
Cell[12857, 456, 55, 1, 27, "Input"],
Cell[12915, 459, 56, 1, 27, "Input"],
Cell[12974, 462, 69, 1, 27, "Input"],
Cell[13046, 465, 81, 1, 27, "Input"],
Cell[13130, 468, 140, 5, 30, "Text",
  Evaluatable->False],
Cell[13273, 475, 173, 4, 46, "Text"],
Cell[13449, 481, 92, 1, 27, "Input"],
Cell[13544, 484, 74, 1, 27, "Input"],
Cell[13621, 487, 36, 0, 30, "Text"],
Cell[13660, 489, 61, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13758, 495, 162, 3, 46, "Subsection",
  Evaluatable->False],
Cell[13923, 500, 409, 8, 62, "Text",
  Evaluatable->False],
Cell[14335, 510, 52, 1, 27, "Input"],
Cell[14390, 513, 53, 1, 27, "Input"],
Cell[14446, 516, 70, 1, 27, "Input"],
Cell[14519, 519, 148, 5, 30, "Text",
  Evaluatable->False],
Cell[14670, 526, 59, 1, 27, "Input"],
Cell[14732, 529, 52, 1, 27, "Input"],
Cell[14787, 532, 52, 1, 27, "Input"],
Cell[14842, 535, 56, 1, 27, "Input"],
Cell[14901, 538, 85, 1, 27, "Input"],
Cell[14989, 541, 101, 2, 30, "Text",
  Evaluatable->False],
Cell[15093, 545, 63, 1, 27, "Input"],
Cell[15159, 548, 70, 1, 27, "Input"],
Cell[15232, 551, 56, 1, 27, "Input"],
Cell[15291, 554, 73, 1, 27, "Input"],
Cell[15367, 557, 138, 5, 30, "Text",
  Evaluatable->False],
Cell[15508, 564, 86, 1, 27, "Input"],
Cell[15597, 567, 63, 1, 27, "Input"],
Cell[15663, 570, 72, 1, 27, "Input"],
Cell[15738, 573, 73, 1, 27, "Input"],
Cell[15814, 576, 972, 15, 142, "Text",
  Evaluatable->False],
Cell[16789, 593, 85, 1, 27, "Input"],
Cell[16877, 596, 224, 6, 46, "Text",
  Evaluatable->False],
Cell[17104, 604, 60, 1, 27, "Input"],
Cell[17167, 607, 69, 1, 27, "Input"],
Cell[17239, 610, 56, 1, 27, "Input"],
Cell[17298, 613, 71, 1, 27, "Input"],
Cell[17372, 616, 116, 2, 30, "Text",
  Evaluatable->False],
Cell[17491, 620, 95, 1, 27, "Input"],
Cell[17589, 623, 228, 6, 46, "Text",
  Evaluatable->False],
Cell[17820, 631, 86, 1, 27, "Input"],
Cell[17909, 634, 95, 1, 27, "Input"],
Cell[18007, 637, 104, 2, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[18148, 644, 130, 3, 46, "Subsection",
  Evaluatable->False],
Cell[18281, 649, 245, 6, 46, "Text",
  Evaluatable->False],
Cell[18529, 657, 69, 1, 27, "Input"],
Cell[18601, 660, 52, 1, 27, "Input"],
Cell[18656, 663, 53, 1, 27, "Input"],
Cell[18712, 666, 155, 5, 30, "Text",
  Evaluatable->False],
Cell[18870, 673, 52, 1, 27, "Input"],
Cell[18925, 676, 52, 1, 27, "Input"],
Cell[18980, 679, 56, 1, 27, "Input"],
Cell[19039, 682, 59, 1, 27, "Input"],
Cell[19101, 685, 81, 1, 27, "Input"],
Cell[19185, 688, 59, 1, 27, "Input"],
Cell[19247, 691, 56, 1, 27, "Input"],
Cell[19306, 694, 70, 1, 27, "Input"],
Cell[19379, 697, 68, 1, 27, "Input"],
Cell[19450, 700, 635, 11, 94, "Text",
  Evaluatable->False],
Cell[20088, 713, 62, 1, 27, "Input"],
Cell[20153, 716, 95, 1, 27, "Input"],
Cell[20251, 719, 63, 1, 27, "Input"],
Cell[20317, 722, 165, 5, 30, "Text",
  Evaluatable->False],
Cell[20485, 729, 89, 1, 27, "Input"],
Cell[20577, 732, 248, 6, 46, "Text",
  Evaluatable->False],
Cell[20828, 740, 69, 1, 27, "Input"],
Cell[20900, 743, 56, 1, 27, "Input"],
Cell[20959, 746, 92, 1, 27, "Input"],
Cell[21054, 749, 183, 5, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[21274, 759, 147, 3, 46, "Subsection",
  Evaluatable->False],
Cell[21424, 764, 355, 7, 62, "Text",
  Evaluatable->False],
Cell[21782, 773, 75, 1, 27, "Input"],
Cell[21860, 776, 69, 1, 27, "Input"],
Cell[21932, 779, 133, 4, 27, "Input"],
Cell[22068, 785, 63, 1, 27, "Input"],
Cell[22134, 788, 200, 5, 46, "Text",
  Evaluatable->False],
Cell[22337, 795, 69, 1, 27, "Input"],
Cell[22409, 798, 52, 1, 27, "Input"],
Cell[22464, 801, 184, 5, 30, "Text",
  Evaluatable->False],
Cell[22651, 808, 52, 1, 27, "Input"],
Cell[22706, 811, 74, 1, 27, "Input"],
Cell[22783, 814, 67, 1, 27, "Input"],
Cell[22853, 817, 95, 1, 27, "Input"],
Cell[22951, 820, 151, 5, 30, "Text",
  Evaluatable->False],
Cell[23105, 827, 55, 1, 27, "Input"],
Cell[23163, 830, 53, 1, 27, "Input"],
Cell[23219, 833, 77, 1, 27, "Input"],
Cell[23299, 836, 60, 1, 27, "Input"],
Cell[23362, 839, 62, 1, 27, "Input"],
Cell[23427, 842, 64, 1, 27, "Input"],
Cell[23494, 845, 95, 1, 27, "Input"],
Cell[23592, 848, 148, 5, 30, "Text",
  Evaluatable->False],
Cell[23743, 855, 56, 1, 27, "Input"],
Cell[23802, 858, 69, 1, 27, "Input"],
Cell[23874, 861, 91, 1, 27, "Input"],
Cell[23968, 864, 125, 2, 30, "Text",
  Evaluatable->False],
Cell[24096, 868, 72, 1, 27, "Input"],
Cell[24171, 871, 173, 5, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[24381, 881, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[24504, 886, 397, 9, 64, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

