(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19462,        699]*)
(*NotebookOutlinePosition[     44554,       1606]*)
(*  CellTagsIndexPosition[     44510,       1602]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 8\
\>", "Title"],

Cell["\<\
Orbit Trapping
and
Index Theory\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "arrowflag, arrowvec, classify2D, colorvec, dasher, dirfield, dirpt, \
display, index, labon, limcyc, ncurpoinst, orbcross,  parmval, parmvec, \
period, phaser, plotcurve, plotreset, plrange, setcolor, setparm, setstate, \
show, slopevec, statevec, and sysid.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of System Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The functions illustrated here are for two-dimensional systems.  As \
examples, we use several simple linear and nonlinear systems.  We show how to \
define curves, how to determine whether a curve traps orbits, and how to find \
the index of a closed curve with respect to a given system.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["How to Define a Curve",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "As described in detail in Section 2, a curve is a collection of connected \
smooth arcs.  We define each arc parametrically, and then we define the curve \
as the union.  We carry that procedure out here, and we plot the curve at \
each stage of construction.  The curve we construct is a quarter-circle with \
center at {x0,y0} and radius r0.  We begin by defining arc1, the arc of the \
quarter circle."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear[u];\)\)], "Input"],

Cell["arc1 = {{x0+r0*Cos[u],y0+r0*Sin[u]},{u,0,N[Pi/2]}};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The first part of the expression gives x and y in terms of the parameter u.  \
The second part of the expression gives the name of the parameter and its \
range.  In order to use this, we must assign numerical values to x0, y0, and \
r0."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["x0 = 1.0; y0 = 1.0; r0 = 2.0; ", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The object arc1 is an arc.  A curve is a list of arcs, which, as a special \
case, can be a single arc.  Thus to make arc1 a curve, named firstcurve, we \
type"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["firstcurve = {arc1};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Let's plot this curve.  We set plrange, and then we use the function \
plotcurve to plot it.  Even though arc1 is not specifically connected with \
any differential equation, we must define state vector before plotting, \
because it is used for labels of the plot axes."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{0,4},{0,4}};", "Input",
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labon\  = \ False;\)\)], "Input"],

Cell["graph1 = plotcurve[firstcurve];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we continue to build our curve by defining an arc which is a \
straight line dropping down to the quarter-circle center.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["arc2 = {{x0,y0+r0*(1-u)},{u,0,1}};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We re-define our curve to include this and plot it again."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["firstcurve = {arc1,arc2};", "Input",
  AspectRatioFixed->True],

Cell["graph2 = plotcurve[firstcurve];", "Input",
  AspectRatioFixed->True],

Cell["\tWe add one last piece to make it a closed curve.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["arc3 = {{x0+r0*u,y0},{u,0,1}};", "Input",
  AspectRatioFixed->True],

Cell["firstcurve = {arc1,arc2,arc3};", "Input",
  AspectRatioFixed->True],

Cell["graph3 = plotcurve[firstcurve];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tTo continue this exercise in defining curves, we define a family \
of circles which will be used in an orbit-trapping example below.  These are \
circles with center at the origin and a radius rad which we may vary.  Note \
the extra curly brackets around the definition to convert the arc to a curve.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
trappercurve[rad_]:= \
{{{rad*Cos[u],rad*Sin[u]},{u,0,N[2*Pi]}}};\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData["We plot two of these on the same graph."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["display = False;", "Input",
  AspectRatioFixed->True],

Cell["circin = plotcurve[trappercurve[0.75]];", "Input",
  AspectRatioFixed->True],

Cell["circout = plotcurve[trappercurve[5.0]];", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-5,5},{-5,5}};", "Input",
  AspectRatioFixed->True],

Cell["graph4 = show[circin,circout];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Trapping a Limit Cycle",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tNow we illustrate an application of the \
Poincar\[EAcute]-Bendixson theorem by trapping a limit cycle.  We first \
define our system, a two-dimensional polynomial nonlinear system.\
\>", "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}]; ", "Input",
  AspectRatioFixed->True],

Cell["setparm[{}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y-x*(x^2+y^2-2*x-3),-x-y*(x^2+y^2-2*x-3)};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {};", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe now ask whether orbits are trapped by either of our two \
circles.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbcross[trappercurve[0.75]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We see that the crossings are all in the positive N direction which is \
outward (the closed curve is positively oriented).  Now we check the outer \
curve."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbcross[trappercurve[5.0]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now the crossings are all in the negative N direction.  Thus no orbit can \
leave the region bounded by the two circles.  The Poincar\[EAcute]-Bendixson \
theorem says that either there is an equilibrium point or a periodic solution \
inside.  A little algebra shows that the only equilibrium point for this \
system is at the origin, so we conclude that there must be a periodic \
solution inside.  Can we bound it more closely?  Let's try."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbcross[trappercurve[1.0]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now we have a tangency, so we are probably at the limit for the inner curve. \
 We can verify that by trying rad = 1.1."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbcross[trappercurve[1.1]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now we get crossings in both directions.  So rad = 1.0 is the best we can do \
for the inner boundary with this family of curves.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tNow let's try to move the outer boundary in.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["orbcross[trappercurve[4.0]]", "Input",
  AspectRatioFixed->True],

Cell["orbcross[trappercurve[3.0]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We are at the limit.  The best statement we can make with this family of \
circles is that there is a periodic solution in the range 1.0 <= rad <= \
3.0."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tLet's plot the direction field for this system and display it \
with our two optimal bounding circles.  We increase the number of grid points \
in the direction field to 25 x 25 by setting the variable dirpt to 25.  We \
use red and dashing for the trapping curves.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange = {{-3,3},{-3,3}};", "Input",
  AspectRatioFixed->True],

Cell["dirpt = 25;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Cobalt}];\)\)], "Input"],

Cell["graph5 = dirfield;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(setdash[{\ {0.05, 0.05}}];\)\)], "Input"],

Cell["graph6 = plotcurve[trappercurve[1.0]];", "Input",
  AspectRatioFixed->True],

Cell["graph7 = plotcurve[trappercurve[3.0]];", "Input",
  AspectRatioFixed->True],

Cell["graph8 = show[graph5,graph6,graph7];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe Poincar\[EAcute]-Bendixson theorem says there is at least one \
periodic solution in this region.  As the computer shows, there is exactly \
one -- a limit cycle, which shows up clearly on the above direction field.  \
Let's construct the limit cycle and add it to the picture with the two \
bounding circles. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {2.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell["persol = limcyc[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["period[persol]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(setdash[{\ {}}];\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/2};\)\)], "Input"],

Cell["graph9 = phaser[persol];", "Input",
  AspectRatioFixed->True],

Cell["show[graph6,graph7,graph9];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see clearly how the limit cycle is trapped by the two circles, \
and that it is tangent to both. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Index Theory",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe index of a closed curve with respect to a vector field is the \
number of full rotations of the vector fields as the curve is traversed.  The \
usefulness of the concept is based on part on several theorems.  The first is \
that the index of a periodic solution is always 1.  The second is that the \
index of a curve enclosing a finite number isolated equilibrium points, all \
of which are elementary (i.e., the determinant of the derivative matrix is \
nonzero), is given by I = (number of nodes) + (number of spirals) + (number \
of centers) - (number of saddles).  Combining these two theorems leads to the \
interesting statements that one a periodic solution must enclose at least one \
equilibrium, and if it encloses only one elementary equilibrium and no \
others, that one cannot be a saddle.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe will illustrate these ideas by a few simple calculations, \
using the routine index[curve] which calculates the index for curve.  \
\>", 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tIn the above trapping calculation, the two trapping circles \
contain no equilibria between them.  Therefore they should have the same \
index.  Because the periodic solution must have index 1, we conclude by the \
same reasoning that each of the trapping curves must have index 1.  Let's \
verify this.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["index[trappercurve[1.0]]", "Input",
  AspectRatioFixed->True],

Cell["index[trappercurve[5.0]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow let's verify the theorem on the relation between the index \
and the nature of the enclosed equilibria.  We do this for a very simple \
linear system with a single parameter.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{alpha}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {alpha*y,-x-2*y};", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"This system has a single equilibrium point at the origin, and the character \
of the equilibrium depends on the value of the parameter a.  We will take as \
our test curve the unit circle."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["unitarc = {{Cos[u],Sin[u]},{u,0,N[2*Pi]}};", "Input",
  AspectRatioFixed->True],

Cell["unitcurve = {unitarc};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {-1};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell[TextData["With a saddle, we expect to get an index of -1."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["index[unitcurve]", "Input",
  AspectRatioFixed->True],

Cell[TextData["So far so good.  Now we set a = 0.5."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {0.5};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell[TextData["This should give an index of 1."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["index[unitcurve]", "Input",
  AspectRatioFixed->True],

Cell[TextData["Now set a = 2.0."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {2.0};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["index[unitcurve]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe index does not depend on the stability of the equilibrium.  \
We can verify that for this case by reversing the sign of the slope vector \
(effectively reversing time), and turning our stable node and spiral into \
unstable ones.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["slopevec = -slopevec;", "Input",
  AspectRatioFixed->True],

Cell["parmval = {0.5};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["index[unitcurve]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {2.0};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["index[unitcurve]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe number of points used in the calculation of an index (and the \
number of points used in an orbit trapping check) is taken from the variable \
ncurpoints.  The default value is\
\>", "Text"],

Cell[BoxData[
    \(ncurpoints\)], "Input"],

Cell["\<\
In difficult situations, this may have to be increased.  We \
consider an example.  The equations are\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)\)]],
  "  =  (",
  StyleBox["x",
    FontSlant->"Italic"],
  " - 1",
  Cell[BoxData[
      \(TraditionalForm\`\()\^3\)\)]],
  "+",
  StyleBox["x",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)\)]],
  "  =  ",
  StyleBox["y",
    FontSlant->"Italic"],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`y\^3\)]],
  "."
}], "Text",
  TextAlignment->Center],

Cell[BoxData[
    \(setstate[{x, y}]; setparm[{}]; 
    slopevec = {\((x - 1)\)\^3 + x\ y\^2, y + y\^3};\)], "Input"],

Cell["\<\
We are going to calculate the index of the equilibrium at (1,0).  \
To do this, we use a circle of radius rad, with center at the \
equilibrium.\
\>", "Text"],

Cell[BoxData[
    \(circ[
        rad_] := {{{1 + rad*Cos[u], Sin[u]}, {u, 0\ , 2\ \[Pi]}}}\)], "Input"],

Cell["\<\
We start with a circle not too close to the equilibrium, so that we \
can be reasonably confident that the answer is correct with 100 points used \
in the calculation.\
\>", "Text"],

Cell[BoxData[
    \(index[circ[0.5]]\)], "Input"],

Cell["Now we move much closer.", "Text"],

Cell[BoxData[
    \(index[circ[0.1]]\)], "Input"],

Cell["\<\
A wildly inaccurate answer!  We increase the number of \
points.\
\>", "Text"],

Cell[BoxData[
    \(\(ncurpoints = 500;\)\)], "Input"],

Cell[BoxData[
    \(index[circ[0.1]]\)], "Input"],

Cell["Once more.", "Text"],

Cell[BoxData[
    \(\(ncurpoints = 2000;\)\)], "Input"],

Cell[BoxData[
    \(index[circ[0.1]]\)], "Input"],

Cell["\<\
Of course the real lesson here is to not get too close to the \
equilibrium.  \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tConstruct a linear system with an equilibrium which is a center, \
and verify that the index for any enclosing curve is 1.  Construct a system \
with several equilibria, and verify the index theorem for a curve enclosing \
all of them.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 3, 152, "Title"],
Cell[1795, 56, 107, 6, 118, "Subtitle",
  Evaluatable->False],
Cell[1905, 64, 48, 1, 27, "Input"],
Cell[1956, 67, 46, 1, 27, "Input"],
Cell[2005, 70, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2077, 75, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2237, 80, 383, 9, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2657, 94, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2815, 99, 413, 9, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3265, 113, 133, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3401, 118, 526, 11, 80, "Text",
  Evaluatable->False],
Cell[3930, 131, 46, 1, 27, "Input"],
Cell[3979, 134, 94, 1, 27, "Input"],
Cell[4076, 137, 312, 6, 46, "Text",
  Evaluatable->False],
Cell[4391, 145, 73, 1, 27, "Input"],
Cell[4467, 148, 234, 5, 46, "Text",
  Evaluatable->False],
Cell[4704, 155, 63, 1, 27, "Input"],
Cell[4770, 158, 344, 6, 62, "Text",
  Evaluatable->False],
Cell[5117, 166, 52, 1, 27, "Input"],
Cell[5172, 169, 53, 1, 27, "Input"],
Cell[5228, 172, 67, 1, 27, "Input"],
Cell[5298, 175, 59, 1, 27, "Input"],
Cell[5360, 178, 55, 1, 27, "Input"],
Cell[5418, 181, 74, 1, 27, "Input"],
Cell[5495, 184, 198, 5, 46, "Text",
  Evaluatable->False],
Cell[5696, 191, 77, 1, 27, "Input"],
Cell[5776, 194, 132, 3, 30, "Text",
  Evaluatable->False],
Cell[5911, 199, 68, 1, 27, "Input"],
Cell[5982, 202, 74, 1, 27, "Input"],
Cell[6059, 205, 114, 2, 30, "Text",
  Evaluatable->False],
Cell[6176, 209, 73, 1, 27, "Input"],
Cell[6252, 212, 73, 1, 27, "Input"],
Cell[6328, 215, 74, 1, 27, "Input"],
Cell[6405, 218, 377, 8, 62, "Text",
  Evaluatable->False],
Cell[6785, 228, 116, 4, 27, "Input"],
Cell[6904, 234, 113, 2, 30, "Text",
  Evaluatable->False],
Cell[7020, 238, 59, 1, 27, "Input"],
Cell[7082, 241, 82, 1, 27, "Input"],
Cell[7167, 244, 82, 1, 27, "Input"],
Cell[7252, 247, 69, 1, 27, "Input"],
Cell[7324, 250, 73, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7434, 256, 134, 3, 46, "Subsection",
  Evaluatable->False],
Cell[7571, 261, 257, 7, 46, "Text",
  Evaluatable->False],
Cell[7831, 270, 60, 1, 27, "Input"],
Cell[7894, 273, 55, 1, 27, "Input"],
Cell[7952, 276, 97, 1, 27, "Input"],
Cell[8052, 279, 56, 1, 27, "Input"],
Cell[8111, 282, 143, 5, 30, "Text",
  Evaluatable->False],
Cell[8257, 289, 71, 1, 27, "Input"],
Cell[8331, 292, 231, 5, 46, "Text",
  Evaluatable->False],
Cell[8565, 299, 70, 1, 27, "Input"],
Cell[8638, 302, 516, 8, 78, "Text",
  Evaluatable->False],
Cell[9157, 312, 70, 1, 27, "Input"],
Cell[9230, 315, 194, 4, 30, "Text",
  Evaluatable->False],
Cell[9427, 321, 70, 1, 27, "Input"],
Cell[9500, 324, 206, 4, 46, "Text",
  Evaluatable->False],
Cell[9709, 330, 110, 2, 30, "Text",
  Evaluatable->False],
Cell[9822, 334, 70, 1, 27, "Input"],
Cell[9895, 337, 70, 1, 27, "Input"],
Cell[9968, 340, 228, 5, 46, "Text",
  Evaluatable->False],
Cell[10199, 347, 339, 7, 62, "Text",
  Evaluatable->False],
Cell[10541, 356, 69, 1, 27, "Input"],
Cell[10613, 359, 54, 1, 27, "Input"],
Cell[10670, 362, 56, 1, 27, "Input"],
Cell[10729, 365, 61, 1, 27, "Input"],
Cell[10793, 368, 53, 1, 27, "Input"],
Cell[10849, 371, 63, 1, 27, "Input"],
Cell[10915, 374, 81, 1, 27, "Input"],
Cell[10999, 377, 81, 1, 27, "Input"],
Cell[11083, 380, 79, 1, 27, "Input"],
Cell[11165, 383, 388, 8, 62, "Text",
  Evaluatable->False],
Cell[11556, 393, 63, 1, 27, "Input"],
Cell[11622, 396, 52, 1, 27, "Input"],
Cell[11677, 399, 52, 1, 27, "Input"],
Cell[11732, 402, 56, 1, 27, "Input"],
Cell[11791, 405, 80, 1, 27, "Input"],
Cell[11874, 408, 57, 1, 27, "Input"],
Cell[11934, 411, 54, 1, 27, "Input"],
Cell[11991, 414, 53, 1, 27, "Input"],
Cell[12047, 417, 54, 1, 27, "Input"],
Cell[12104, 420, 54, 1, 27, "Input"],
Cell[12161, 423, 67, 1, 27, "Input"],
Cell[12231, 426, 70, 1, 27, "Input"],
Cell[12304, 429, 174, 5, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[12515, 439, 124, 3, 46, "Subsection",
  Evaluatable->False],
Cell[12642, 444, 883, 14, 126, "Text",
  Evaluatable->False],
Cell[13528, 460, 210, 6, 46, "Text",
  Evaluatable->False],
Cell[13741, 468, 377, 8, 62, "Text",
  Evaluatable->False],
Cell[14121, 478, 67, 1, 27, "Input"],
Cell[14191, 481, 67, 1, 27, "Input"],
Cell[14261, 484, 252, 6, 46, "Text",
  Evaluatable->False],
Cell[14516, 492, 59, 1, 27, "Input"],
Cell[14578, 495, 60, 1, 27, "Input"],
Cell[14641, 498, 71, 1, 27, "Input"],
Cell[14715, 501, 263, 5, 46, "Text",
  Evaluatable->False],
Cell[14981, 508, 85, 1, 27, "Input"],
Cell[15069, 511, 65, 1, 27, "Input"],
Cell[15137, 514, 58, 1, 27, "Input"],
Cell[15198, 517, 60, 1, 27, "Input"],
Cell[15261, 520, 121, 2, 30, "Text",
  Evaluatable->False],
Cell[15385, 524, 59, 1, 27, "Input"],
Cell[15447, 527, 110, 2, 30, "Text",
  Evaluatable->False],
Cell[15560, 531, 59, 1, 27, "Input"],
Cell[15622, 534, 60, 1, 27, "Input"],
Cell[15685, 537, 105, 2, 30, "Text",
  Evaluatable->False],
Cell[15793, 541, 59, 1, 27, "Input"],
Cell[15855, 544, 90, 2, 30, "Text",
  Evaluatable->False],
Cell[15948, 548, 59, 1, 27, "Input"],
Cell[16010, 551, 60, 1, 27, "Input"],
Cell[16073, 554, 59, 1, 27, "Input"],
Cell[16135, 557, 307, 7, 46, "Text",
  Evaluatable->False],
Cell[16445, 566, 64, 1, 27, "Input"],
Cell[16512, 569, 59, 1, 27, "Input"],
Cell[16574, 572, 60, 1, 27, "Input"],
Cell[16637, 575, 59, 1, 27, "Input"],
Cell[16699, 578, 59, 1, 27, "Input"],
Cell[16761, 581, 60, 1, 27, "Input"],
Cell[16824, 584, 59, 1, 27, "Input"],
Cell[16886, 587, 206, 4, 46, "Text"],
Cell[17095, 593, 43, 1, 27, "Input"],
Cell[17141, 596, 125, 3, 30, "Text"],
Cell[17269, 601, 513, 25, 32, "Text"],
Cell[17785, 628, 117, 2, 31, "Input"],
Cell[17905, 632, 168, 4, 46, "Text"],
Cell[18076, 638, 104, 2, 27, "Input"],
Cell[18183, 642, 191, 4, 46, "Text"],
Cell[18377, 648, 49, 1, 27, "Input"],
Cell[18429, 651, 40, 0, 30, "Text"],
Cell[18472, 653, 49, 1, 27, "Input"],
Cell[18524, 656, 88, 3, 30, "Text"],
Cell[18615, 661, 54, 1, 27, "Input"],
Cell[18672, 664, 49, 1, 27, "Input"],
Cell[18724, 667, 26, 0, 30, "Text"],
Cell[18753, 669, 55, 1, 27, "Input"],
Cell[18811, 672, 49, 1, 27, "Input"],
Cell[18863, 675, 102, 3, 30, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19002, 683, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[19125, 688, 309, 7, 46, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

