(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16002,        579]*)
(*NotebookOutlinePosition[     41148,       1488]*)
(*  CellTagsIndexPosition[     41104,       1484]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 9\
\>", "Title"],

Cell[TextData["Phase Portraits"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "asprat, boxrat, colorvec, display, dots, dots3D, integrate, intreset, \
labshift, limcyc,  parmval, parmvec, period, phaser, phaseseq, phaseseq3D, \
plotreset, plrange, plrange3D, portrait, portrait3D, restoresys, savesys, \
setcolor, setparm, setstate, show, slopevec, statevec, sysid, and sysreport.  \
 "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of System Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, we illustrate the production of phase portraits from a \
given set of initial conditions.  We also show how to construct a sequence of \
graphs which, when animated, gives a dynamic view of the orbits in time.  For \
a two-dimensional example, we use the van der Pol equation.  For a \
three-dimensional example, we use the van der Pol equation embedded in a \
three-dimensional system.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThere are many graphs in this tutorial.  You may need to delete some or \
all of the graphs created in the first part before running the second part, \
unless you have a lot of memory allotted to your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Front End."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Reference",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The van der Pol system is discussed in most texts on dynamical systems.  \
For a brief introduction, see Chapter 7 of ",
  StyleBox["Nonlinear Dynamical Systems and Chaos",
    FontWeight->"Bold"],
  ", S.H. Strogatz, Addison-Wesley, 1994."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\tWe define both systems here.  First the 2D van der Pol.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{mu}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y, -x -mu*(x*x-1)*y};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {1};", "Input",
  AspectRatioFixed->True],

Cell["savesys[van2D];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now the three dimensional version.  This is defined so that all orbits \
starting off z = 0 approach z = 0, and the van der Pol limit cycle is in the \
x-y plane."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{mu}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y, -x -mu*(x*x-1)*y,-z};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {1};", "Input",
  AspectRatioFixed->True],

Cell["savesys[van3D];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Phase Portrait for 2D van der Pol",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We are going to construct, on a modest scale, a phase portrait for the van \
der Pol limit cycle.  The portrait will show how a few selected initial \
conditions, starting inside the cycle,  reach the limit cycle.  We will first \
do this by the tools we already have, and then we will repeat the calculation \
using the function portrait, which automates the process somewhat."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(labshift\  = \ 10;\)\)], "Input"],

Cell["restoresys[van2D];", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 600;", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1,0};", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe begin by constructing the limit cycle.  Then we will construct \
the transient approaches.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sol0 = limcyc[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(asprat = 1; plrange = {{\(-3.1\), 3.1}, {\(-3.1\), 3.1}};\)], "Input"],

Cell["graph0 = phaser[sol0];", "Input",
  AspectRatioFixed->True],

Cell["period[sol0]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we construct four orbits showing transient approach to the \
limit cycle.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labshift\  = \ 10;\)\)], "Input"],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-3,3},{-3,3}};", "Input",
  AspectRatioFixed->True],

Cell["display = False;", "Input",
  AspectRatioFixed->True],

Cell["graph1 = phaser[sol1];", "Input",
  AspectRatioFixed->True],

Cell["initvec = {0,1};", "Input",
  AspectRatioFixed->True],

Cell["sol2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph2 = phaser[sol2];", "Input",
  AspectRatioFixed->True],

Cell["initvec = {-1,0};", "Input",
  AspectRatioFixed->True],

Cell["sol3 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph3 = phaser[sol3];", "Input",
  AspectRatioFixed->True],

Cell["initvec = {0,-1};", "Input",
  AspectRatioFixed->True],

Cell["sol4 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph4 = phaser[sol4];", "Input",
  AspectRatioFixed->True],

Cell["display = True;", "Input",
  AspectRatioFixed->True],

Cell["show[graph1,graph2,graph3,graph4];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we produce the same graph with a single command, portrait.  \
The first argument of portrait is the list of initial conditions to be used.  \
The next three arguments are exactly the same as the last three of integrate, \
and the last two arguments are the indices of the components to be plotted. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intlist = {{1,0},{0,1},{-1,0},{0,-1}};", "Input",
  AspectRatioFixed->True],

Cell["port1 = portrait[intlist,t0,h,nsteps,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe advantage of portrait is that once you have decided (usually \
as the result of some experimental integrations) which initial conditions to \
use, and what time step and the number of steps, you can perform a lengthy \
final construction in an unattended mode by using portrait.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe can add a dot at any point.  For example, to add a dot at the \
equilibrium point {0,0}, we construct a graph with the dot and then combine \
it with the portrait.  We make the dot red and fairly large.\
\>", "Text"],

Cell[BoxData[
    \(\(eq = {0, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(ptsize = 0.03;\)\)], "Input"],

Cell[BoxData[
    \(\(display = False;\)\)], "Input"],

Cell[BoxData[
    \(\(dotgraph = dots[{eq}];\)\)], "Input"],

Cell[BoxData[
    \(\(display\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(show[port1, dotgraph];\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Dynamic Orbits for 2D van der Pol",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We now show how to construct a sequence of graphs which, when animated, \
will simulate the travel of the phase point in time around the orbit.  To \
keep the picture relatively uncluttered, we construct only two such orbits.  \
The routine that does this construction is phaseseq.  Phaseseq has the \
following arguments:  a list of initial conditions, initlist; the initial \
time, t0; the time step, h; the number of time steps per incremental picture, \
nstepic; the number of pictures, npics; the indices of the components to be \
plotted.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe numbers below have been selected so that we get 26 pictures, \
at equal time increments, which trace exactly one period of the limit cycle.  \
We use two initial conditions on the cycle (taken from sol0), on opposite \
sides.  We use colorvec to make the plot red.  After the calculation is \
complete, you should group the 26 pictures together (the command Closed Group \
in the Cell Menu), and then animate them (the command Animate Selected \
Graphics in the Graph Menu).  The animation will show the production of the \
limit cycle from the given initial condtions, followed by the two phase \
points moving around the cycle.  If you want to see just the steady-state \
motion around the limit cycle, just select the only the last half of the \
graphs and then animate that selection.  If you have time and memory enough, \
try this with many more pictures and a smaller time interval per picture.   \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initlist = {{-2.00818,-0.0431826},{2.00607,0.106488}};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.031827;", "Input",
  AspectRatioFixed->True],

Cell["nstepic = 8;", "Input",
  AspectRatioFixed->True],

Cell["npics = 26;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(asprat = 1; plrange = {{\(-3.1\), 3.1}, {\(-3.1\), 3.1}};\)], "Input"],

Cell["dyngraph = phaseseq[initlist,t0,h,nstepic,npics,1,2];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Black}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Phase Portrait for 3D van der Pol",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  AnimationDisplayTime->0.0833333],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this case, orbits starting off the plane z = 0 decay exponentially to z \
= 0.  The projection of the orbits in the x-y plane are identical to the \
orbits of the 2D system.  We construct a phase portrait for two different \
initial conditions, both starting at z = 3. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  AnimationDisplayTime->0.0833333],

Cell["restoresys[van3D];", "Input",
  AspectRatioFixed->True],

Cell["sysreport", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-4,4},{-4,4},{0,4}};", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["intlist = {{3,3,3},{-3,-3,3}};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 600;", "Input",
  AspectRatioFixed->True],

Cell["port3D = portrait3D[intlist,t0,h,nsteps,1,2,3];", "Input",
  AspectRatioFixed->True],

Cell["\tWe add a red dot at the equilibrium position.", "Text"],

Cell[BoxData[
    \(\(display\  = \ False;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(eq = {0, 0, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(ptsize = 0.03;\)\)], "Input"],

Cell[BoxData[
    \(\(dotgraph = dots3D[{eq}];\)\)], "Input"],

Cell[BoxData[
    \(\(display = True;\)\)], "Input"],

Cell[BoxData[
    \(\(show3D[port3D, dotgraph];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Dynamic Orbit for 3D van der Pol",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "As our last calculation in this tutorial, we construct a dynamic view of \
an orbit starting at {1,0,3}.  The projection of this orbit in the x-y plane \
will spiral outward toward the limit cycle.  At the same time, the orbit \
decays exponentially in z from 3 to 0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intlist = {1,0,3};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["nstepic = 12;", "Input",
  AspectRatioFixed->True],

Cell["npics = 25;", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-3,3},{-3,3},{0,3}};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Black, Magenta}]\ ;\)\)], "Input"],

Cell["dyngraph3D = phaseseq3D[intlist,t0,h,nstepic,npics,1,2,3];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Construct a phase portrait and a dynamical orbit sequence for the system \
given by statevec = {x,y,z}, parmvec = {eps}, parmval = {0.2}, slopevec = \
{y,-x - 2.0*eps*y,-z}."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@00000000000000kV0801T1T00000000000
00000000000000=;jU00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 3, 152, "Title"],
Cell[1795, 56, 93, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1891, 60, 48, 1, 27, "Input"],
Cell[1942, 63, 46, 1, 27, "Input"],
Cell[1991, 66, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2063, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2223, 76, 428, 10, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2688, 91, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2846, 96, 529, 11, 80, "Text",
  Evaluatable->False],
Cell[3378, 109, 352, 9, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3767, 123, 121, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3891, 128, 361, 10, 50, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4289, 143, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[4421, 148, 121, 2, 30, "Text",
  Evaluatable->False],
Cell[4545, 152, 59, 1, 27, "Input"],
Cell[4607, 155, 57, 1, 27, "Input"],
Cell[4667, 158, 76, 1, 27, "Input"],
Cell[4746, 161, 57, 1, 27, "Input"],
Cell[4806, 164, 58, 1, 27, "Input"],
Cell[4867, 167, 237, 5, 46, "Text",
  Evaluatable->False],
Cell[5107, 174, 61, 1, 27, "Input"],
Cell[5171, 177, 57, 1, 27, "Input"],
Cell[5231, 180, 79, 1, 27, "Input"],
Cell[5313, 183, 57, 1, 27, "Input"],
Cell[5373, 186, 58, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5468, 192, 145, 3, 46, "Subsection",
  Evaluatable->False],
Cell[5616, 197, 499, 10, 80, "Text",
  Evaluatable->False],
Cell[6118, 209, 52, 1, 27, "Input"],
Cell[6173, 212, 47, 1, 27, "Input"],
Cell[6223, 215, 55, 1, 27, "Input"],
Cell[6281, 218, 61, 1, 27, "Input"],
Cell[6345, 221, 52, 1, 27, "Input"],
Cell[6400, 224, 52, 1, 27, "Input"],
Cell[6455, 227, 52, 1, 27, "Input"],
Cell[6510, 230, 56, 1, 27, "Input"],
Cell[6569, 233, 59, 1, 27, "Input"],
Cell[6631, 236, 167, 5, 30, "Text",
  Evaluatable->False],
Cell[6801, 243, 78, 1, 27, "Input"],
Cell[6882, 246, 90, 1, 27, "Input"],
Cell[6975, 249, 65, 1, 27, "Input"],
Cell[7043, 252, 55, 1, 27, "Input"],
Cell[7101, 255, 151, 5, 30, "Text",
  Evaluatable->False],
Cell[7255, 262, 81, 1, 27, "Input"],
Cell[7339, 265, 53, 1, 27, "Input"],
Cell[7395, 268, 55, 1, 27, "Input"],
Cell[7453, 271, 56, 1, 27, "Input"],
Cell[7512, 274, 69, 1, 27, "Input"],
Cell[7584, 277, 59, 1, 27, "Input"],
Cell[7646, 280, 65, 1, 27, "Input"],
Cell[7714, 283, 59, 1, 27, "Input"],
Cell[7776, 286, 81, 1, 27, "Input"],
Cell[7860, 289, 65, 1, 27, "Input"],
Cell[7928, 292, 60, 1, 27, "Input"],
Cell[7991, 295, 81, 1, 27, "Input"],
Cell[8075, 298, 65, 1, 27, "Input"],
Cell[8143, 301, 60, 1, 27, "Input"],
Cell[8206, 304, 81, 1, 27, "Input"],
Cell[8290, 307, 65, 1, 27, "Input"],
Cell[8358, 310, 58, 1, 27, "Input"],
Cell[8419, 313, 77, 1, 27, "Input"],
Cell[8499, 316, 378, 8, 62, "Text",
  Evaluatable->False],
Cell[8880, 326, 81, 1, 27, "Input"],
Cell[8964, 329, 85, 1, 27, "Input"],
Cell[9052, 332, 356, 7, 62, "Text",
  Evaluatable->False],
Cell[9411, 341, 231, 4, 46, "Text"],
Cell[9645, 347, 49, 1, 27, "Input"],
Cell[9697, 350, 53, 1, 27, "Input"],
Cell[9753, 353, 51, 1, 27, "Input"],
Cell[9807, 356, 53, 1, 27, "Input"],
Cell[9863, 359, 59, 1, 27, "Input"],
Cell[9925, 362, 56, 1, 27, "Input"],
Cell[9984, 365, 59, 1, 27, "Input"],
Cell[10046, 368, 47, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10130, 374, 145, 3, 46, "Subsection",
  Evaluatable->False],
Cell[10278, 379, 668, 13, 96, "Text",
  Evaluatable->False],
Cell[10949, 394, 984, 16, 142, "Text",
  Evaluatable->False],
Cell[11936, 412, 97, 1, 27, "Input"],
Cell[12036, 415, 52, 1, 27, "Input"],
Cell[12091, 418, 56, 1, 27, "Input"],
Cell[12150, 421, 55, 1, 27, "Input"],
Cell[12208, 424, 54, 1, 27, "Input"],
Cell[12265, 427, 53, 1, 27, "Input"],
Cell[12321, 430, 90, 1, 27, "Input"],
Cell[12414, 433, 96, 1, 27, "Input"],
Cell[12513, 436, 55, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12605, 442, 180, 4, 46, "Subsection",
  Evaluatable->False],
Cell[12788, 448, 429, 10, 64, "Text",
  Evaluatable->False],
Cell[13220, 460, 61, 1, 27, "Input"],
Cell[13284, 463, 52, 1, 27, "Input"],
Cell[13339, 466, 52, 1, 27, "Input"],
Cell[13394, 469, 53, 1, 27, "Input"],
Cell[13450, 472, 77, 1, 27, "Input"],
Cell[13530, 475, 60, 1, 27, "Input"],
Cell[13593, 478, 73, 1, 27, "Input"],
Cell[13669, 481, 52, 1, 27, "Input"],
Cell[13724, 484, 52, 1, 27, "Input"],
Cell[13779, 487, 56, 1, 27, "Input"],
Cell[13838, 490, 90, 1, 27, "Input"],
Cell[13931, 493, 63, 0, 30, "Text"],
Cell[13997, 495, 57, 1, 27, "Input"],
Cell[14057, 498, 53, 1, 27, "Input"],
Cell[14113, 501, 52, 1, 27, "Input"],
Cell[14168, 504, 51, 1, 27, "Input"],
Cell[14222, 507, 61, 1, 27, "Input"],
Cell[14286, 510, 52, 1, 27, "Input"],
Cell[14341, 513, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14440, 519, 144, 3, 46, "Subsection",
  Evaluatable->False],
Cell[14587, 524, 389, 9, 64, "Text",
  Evaluatable->False],
Cell[14979, 535, 61, 1, 27, "Input"],
Cell[15043, 538, 52, 1, 27, "Input"],
Cell[15098, 541, 52, 1, 27, "Input"],
Cell[15153, 544, 56, 1, 27, "Input"],
Cell[15212, 547, 54, 1, 27, "Input"],
Cell[15269, 550, 77, 1, 27, "Input"],
Cell[15349, 553, 66, 1, 27, "Input"],
Cell[15418, 556, 101, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15556, 562, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[15679, 567, 295, 8, 48, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

