(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17347,        633]*)
(*NotebookOutlinePosition[     42493,       1542]*)
(*  CellTagsIndexPosition[     42449,       1538]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 10\
\>", "Title"],

Cell[TextData["Bifurcation Sequences"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "arrowflag, arrowvec, asprat, bifurc, bifurc3D, boxrat, classify, \
classify2D, colorvec, intreset, labshift, limbifurc, limbifurc3D, parmval, \
parmvec, plotreset, plrange, plrange3D, rangeflag, ranger, savesys, setcolor, \
setparm, setstate, slopevec, statevec, sysid, and sysname.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, we construct sequences of phase portraits corresponding \
to a sequence of system parameter values.  As examples, we use two simple \
linear systems depending on a single parameter, and we use the van der Pol \
equation in both two and three dimensions.  The graph sequences produced, \
when animated, give a dynamic view of the bifurcations.     "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Reference",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "For a brief introduction to the van der Pol equation, see ",
  StyleBox["Nonlinear Dynamical Systems and Chaos",
    FontWeight->"Bold"],
  ", S.H. Strogatz, Addison-Wesley, 1994, Chapter 7."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Bifurcation Sequence for a 2D Linear System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We define a simple linear system, with an equilbrium at x = y = 0, with \
the system depending on one parameter a."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{a}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {a*y, -x - 2*y};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"Linear2D\";", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe look at the eigenvalues to determine the bifurcation points.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermat]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"It is not hard to show from the above formula that the bifurcation points \
are a = 0 and a = 1.  We use classify2D to verify this."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {-0.5};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {0.0};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {0.5};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {1.0};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {1.5};", "Input",
  AspectRatioFixed->True],

Cell["classify2D[{0,0}]", "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus we have a transition from unstable to stable at a = 0 (a \
saddle to a node), and a transition from stable node to stable spiral at a = \
1.  We now construct a sequence of phase portraits showing one of these \
transitions.  The routine which does this is bifurc.  The arguments of bifurc \
are a list of initial conditions intlist, the intial time t0, the time step \
h, the number of time steps nsteps, the components to be plotted (1 and 2 in \
this case), and the list parmlist of parameter values to be used.  For each \
set of parameter values in parmlist, the routine constructs a phase portrait \
using all the initial conditions in intlist. Although it is interesting to do \
a long sequence showing both transitions, this takes a lot of computer time, \
so for now we just look at the saddle node transition at a = 0.  We select \
five values of a centered on a = 0.   \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.1;", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-2,2},{-2,2}};", "Input",
  AspectRatioFixed->True],

Cell["rangeflag = True;", "Input",
  AspectRatioFixed->True],

Cell["ranger = plrange;", "Input",
  AspectRatioFixed->True],

Cell["\<\
intlist = {{1,0},{1,1},{0,1},{-1,1},{-1,0},
\t\t   {-1,-1},{0,-1},{1,-1}};\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
parmlist = \
{{-0.5},{-0.4},{-0.3},{-0.2},{-0.1},{0.0},{0.1},{0.2},{0.3},{0.4},{0.5}};\
\>\
", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labshift\  = \ 10;\)\)], "Input"],

Cell["\<\
\tWe will plot each solution in a different color, by using \
setcolor.  We add an arrow to the one-quarter point of each orbit.  \
Preliminary exploration shows that 200 steps is enough, except for the values \
of a near zero, in which case around 800 steps are needed.  We could do all \
of the integrations at 800 steps, but that is wasteful.  Instead, we set \
nsteps equal to a function of the parameter a, which provides the correct \
number of steps.\
\>", "Text"],

Cell[BoxData[
    \(\(step[a_] := 
        If[\((\((\(-0.25\) < a)\) && \((a < 
                  0.25)\))\), \((800)\), \((200)\)];\)\)], "Input"],

Cell["We check this for a few values.", "Text"],

Cell[BoxData[
    \(step[\(-0.3\)]\)], "Input"],

Cell[BoxData[
    \(step[0.1]\)], "Input"],

Cell[BoxData[
    \(step[0.3]\)], "Input"],

Cell["Now we assign this function to nsteps.", "Text"],

Cell[BoxData[
    \(nsteps := step[a]\)], "Input"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/4};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[\ {Red, Blue, Green, Cyan, \ Magenta, Green, Yellow, 
          Orange}];\)\)], "Input"],

Cell["bifurc[intlist,t0,h,nsteps,1,2,parmlist];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tBy animating these graphs, you can get a dynamic view of the \
bifurcation sequence.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["savesys[Linear2D];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Dependence of van der Pol Limit Cycle on Parameter - 2D",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We now use limbifurc to study how the van der Pol cycle changes with the \
damping parameter.  We define the system and set the integration and plotting \
parameters.  The routine that produces the sequence is limbifurc.  The \
arguments of limbifurc are an initial vector ivec (chosen close to the cycle \
if that information is available), the initial time t0, the time step h, the \
number of time steps nsteps, the components to be plotted 1 and 2, and the \
list of parameter values mulist. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{mu}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y, -x -mu*(x*x-1)*y};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {1};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"vanderPol\";", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-4.0,4.0},{-4.0,4.0}};", "Input",
  AspectRatioFixed->True],

Cell["mulist = {{0.0},{0.5},{1.0},{1.5},{2.0}};", "Input",
  AspectRatioFixed->True],

Cell["ivec = {2.0,0.0};", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 250;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(labshift\  = \ 10;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell["limbifurc[ivec,t0,h,nsteps,1,2,mulist];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tBy animating these graphs, you can get some idea of the \
continuous change of the cycle as the parameter increases.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["savesys[vanderPol];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Bifurcation Sequence for a 3D Linear System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We consider here a simple linear system which goes through a saddle-node \
transition.  We produce this system by embedding our earlier 2D system in 3D, \
by adding a \"stable\" z-equation.  The bifurcations occur at the same \
a-values as before.  Here again we just look at the saddle-node bifurcation \
at a = 0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{a}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {a*y, -x - 2*y,-z};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"Linear3D\";", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe verify the character of the equilibrium for several a \
values.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {-0.5};", "Input",
  AspectRatioFixed->True],

Cell["classify[{0,0,0}]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[{0,0,0}]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThus for a = -0.5 we have a saddle with a two-dimensional stable \
manifold and a one-dimensional unstable manifold.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {0.5};", "Input",
  AspectRatioFixed->True],

Cell["classify[{0,0,0}]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[{0,0,0}]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe saddle is now a stable node.  We illustrate the transition by \
using bifurc3D with 8 initial conditions and 5 parameter values.  (A more \
interesting sequence can be obtained with more parameter values, more closely \
spaced, but the calculations take a long time and much memory.)  After the \
graphs are constructed, double click on any one of them to animate the \
sequence. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plrange3D = {{-2,2},{-2,2},{0,1}};", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["rangeflag = True;", "Input",
  AspectRatioFixed->True],

Cell["ranger = plrange3D;", "Input",
  AspectRatioFixed->True],

Cell["\<\
intlist = {{1,0,1},{1,1,1},{0,1,1},{-1,1,1},{-1,0,1},
\t\t   {-1,-1,1},{0,-1,1},{1,-1,1}};\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
parmlist = {{-0.5},{-0.25},{0.0},{0.25},
\t\t\t{0.50}};\
\>", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.1;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[\ {Red, Blue, Green, Cyan, \ Magenta, Green, Yellow, 
          Orange}];\)\)], "Input"],

Cell["bifurc3D[intlist,t0,h,nsteps,1,2,3,parmlist];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Dependence of van der Pol Limit Cycle on Parameter -- 3D",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "To illustrate the use of limbifurc3D in the construction of a sequence of \
limit cycles formed from a sequence of parameter values, we use a version of \
the van der Pol system.  This version was constructed by first embedding the \
2D x-y system in 3D, by adding an exponential decay in the third dimension -- \
dz/dt = -z.  Then the system was rotated 45 degrees about the x-axis.  The \
resulting system is defined below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{mu}];", "Input",
  AspectRatioFixed->True],

Cell["\<\
slopevec = {y/2^(1/2) + z/2^(1/2), -(x/2^(1/2)) + 
 
   (1/2 - (mu*(-1 + x^2))/2)*y + (-1/2 - (mu*(-1 + x^2))/2)*z
 
   , -(x/2^(1/2)) + (-1/2 - (mu*(-1 + x^2))/2)*y + 
 
   (1/2 - (mu*(-1 + x^2))/2)*z};\
\>", "Input",
  AspectRatioFixed->True],

Cell["\tNext we set the plotting variables.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-3,3},{-3,3},{-3,3}};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"van3D\"; ", "Input",
  AspectRatioFixed->True],

Cell["\tWe look at five values of the parameter mu. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmlist = {{0.0},{0.5},{1.0},{1.5},{2.0}};", "Input",
  AspectRatioFixed->True],

Cell["initvec = {2,0,0};", "Input",
  AspectRatioFixed->True],

Cell["h = 0.05;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Green}];\)\)], "Input"],

Cell["\<\
\tNow we call limbifurc3D, which produces a limit cycle for each \
parameter list in parmlist.  After the graphs are constructed, select them \
and animate them to get a dynamical view of the change of the cycle shape \
with parameter.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["limbifurc3D[initvec,t0,h,nsteps,1,2,3,parmlist];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercise",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "Consider the two-dimensional autonomous system given by   dx/dt = a*x - \
x^3, dy/dt = -y.  (The system is artificially simple but is a prototype for \
more complicated nonlinear systems with similar behavior.  The system has \
what is known as a pitchfork bifurcation at a = 0.)  Show that this system \
has one equilibrium point for a<0 and three equilibria for a>0.  Find the \
stability of the equilibria in all cases.  Use bifurc to study the dependence \
of the solutions on the parameter a.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@=;i`0000000000kf0801T1T00000000000
00000000000000=;k]00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 3, 152, "Title"],
Cell[1796, 56, 99, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1898, 60, 48, 1, 27, "Input"],
Cell[1949, 63, 47, 1, 27, "Input"],
Cell[1999, 66, 46, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2070, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2230, 76, 407, 9, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2674, 90, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2833, 95, 487, 10, 80, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3357, 110, 121, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3481, 115, 312, 9, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3830, 129, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3988, 134, 236, 7, 48, "Text",
  Evaluatable->False],
Cell[4227, 143, 59, 1, 27, "Input"],
Cell[4289, 146, 56, 1, 27, "Input"],
Cell[4348, 149, 70, 1, 27, "Input"],
Cell[4421, 152, 66, 1, 27, "Input"],
Cell[4490, 155, 139, 5, 30, "Text",
  Evaluatable->False],
Cell[4632, 162, 62, 1, 27, "Input"],
Cell[4697, 165, 206, 4, 46, "Text",
  Evaluatable->False],
Cell[4906, 171, 60, 1, 27, "Input"],
Cell[4969, 174, 60, 1, 27, "Input"],
Cell[5032, 177, 59, 1, 27, "Input"],
Cell[5094, 180, 60, 1, 27, "Input"],
Cell[5157, 183, 59, 1, 27, "Input"],
Cell[5219, 186, 60, 1, 27, "Input"],
Cell[5282, 189, 59, 1, 27, "Input"],
Cell[5344, 192, 60, 1, 27, "Input"],
Cell[5407, 195, 59, 1, 27, "Input"],
Cell[5469, 198, 60, 1, 27, "Input"],
Cell[5532, 201, 957, 15, 142, "Text",
  Evaluatable->False],
Cell[6492, 218, 52, 1, 27, "Input"],
Cell[6547, 221, 51, 1, 27, "Input"],
Cell[6601, 224, 52, 1, 27, "Input"],
Cell[6656, 227, 53, 1, 27, "Input"],
Cell[6712, 230, 56, 1, 27, "Input"],
Cell[6771, 233, 69, 1, 27, "Input"],
Cell[6843, 236, 60, 1, 27, "Input"],
Cell[6906, 239, 60, 1, 27, "Input"],
Cell[6969, 242, 125, 4, 42, "Input"],
Cell[7097, 248, 139, 5, 57, "Input"],
Cell[7239, 255, 55, 1, 27, "Input"],
Cell[7297, 258, 481, 8, 78, "Text"],
Cell[7781, 268, 147, 3, 27, "Input"],
Cell[7931, 273, 47, 0, 30, "Text"],
Cell[7981, 275, 47, 1, 27, "Input"],
Cell[8031, 278, 42, 1, 27, "Input"],
Cell[8076, 281, 42, 1, 27, "Input"],
Cell[8121, 284, 54, 0, 30, "Text"],
Cell[8178, 286, 50, 1, 27, "Input"],
Cell[8231, 289, 54, 1, 27, "Input"],
Cell[8288, 292, 54, 1, 27, "Input"],
Cell[8345, 295, 119, 2, 27, "Input"],
Cell[8467, 299, 84, 1, 27, "Input"],
Cell[8554, 302, 158, 5, 30, "Text",
  Evaluatable->False],
Cell[8715, 309, 61, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8813, 315, 168, 4, 46, "Subsection",
  Evaluatable->False],
Cell[8984, 321, 618, 12, 96, "Text",
  Evaluatable->False],
Cell[9605, 335, 59, 1, 27, "Input"],
Cell[9667, 338, 57, 1, 27, "Input"],
Cell[9727, 341, 76, 1, 27, "Input"],
Cell[9806, 344, 57, 1, 27, "Input"],
Cell[9866, 347, 67, 1, 27, "Input"],
Cell[9936, 350, 52, 1, 27, "Input"],
Cell[9991, 353, 53, 1, 27, "Input"],
Cell[10047, 356, 56, 1, 27, "Input"],
Cell[10106, 359, 77, 1, 27, "Input"],
Cell[10186, 362, 84, 1, 27, "Input"],
Cell[10273, 365, 60, 1, 27, "Input"],
Cell[10336, 368, 52, 1, 27, "Input"],
Cell[10391, 371, 52, 1, 27, "Input"],
Cell[10446, 374, 56, 1, 27, "Input"],
Cell[10505, 377, 55, 1, 27, "Input"],
Cell[10563, 380, 53, 1, 27, "Input"],
Cell[10619, 383, 82, 1, 27, "Input"],
Cell[10704, 386, 190, 5, 46, "Text",
  Evaluatable->False],
Cell[10897, 393, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10996, 399, 155, 3, 46, "Subsection",
  Evaluatable->False],
Cell[11154, 404, 437, 10, 64, "Text",
  Evaluatable->False],
Cell[11594, 416, 52, 1, 27, "Input"],
Cell[11649, 419, 53, 1, 27, "Input"],
Cell[11705, 422, 61, 1, 27, "Input"],
Cell[11769, 425, 56, 1, 27, "Input"],
Cell[11828, 428, 73, 1, 27, "Input"],
Cell[11904, 431, 66, 1, 27, "Input"],
Cell[11973, 434, 140, 5, 30, "Text",
  Evaluatable->False],
Cell[12116, 441, 60, 1, 27, "Input"],
Cell[12179, 444, 60, 1, 27, "Input"],
Cell[12242, 447, 74, 1, 27, "Input"],
Cell[12319, 450, 190, 5, 46, "Text",
  Evaluatable->False],
Cell[12512, 457, 59, 1, 27, "Input"],
Cell[12574, 460, 60, 1, 27, "Input"],
Cell[12637, 463, 74, 1, 27, "Input"],
Cell[12714, 466, 458, 9, 78, "Text",
  Evaluatable->False],
Cell[13175, 477, 77, 1, 27, "Input"],
Cell[13255, 480, 60, 1, 27, "Input"],
Cell[13318, 483, 60, 1, 27, "Input"],
Cell[13381, 486, 62, 1, 27, "Input"],
Cell[13446, 489, 141, 4, 42, "Input"],
Cell[13590, 495, 106, 4, 42, "Input"],
Cell[13699, 501, 52, 1, 27, "Input"],
Cell[13754, 504, 51, 1, 27, "Input"],
Cell[13808, 507, 56, 1, 27, "Input"],
Cell[13867, 510, 119, 2, 27, "Input"],
Cell[13989, 514, 88, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14114, 520, 169, 4, 46, "Subsection",
  Evaluatable->False],
Cell[14286, 526, 547, 11, 80, "Text",
  Evaluatable->False],
Cell[14836, 539, 52, 1, 27, "Input"],
Cell[14891, 542, 61, 1, 27, "Input"],
Cell[14955, 545, 57, 1, 27, "Input"],
Cell[15015, 548, 254, 9, 117, "Input"],
Cell[15272, 559, 101, 2, 30, "Text",
  Evaluatable->False],
Cell[15376, 563, 53, 1, 27, "Input"],
Cell[15432, 566, 60, 1, 27, "Input"],
Cell[15495, 569, 78, 1, 27, "Input"],
Cell[15576, 572, 64, 1, 27, "Input"],
Cell[15643, 575, 110, 2, 30, "Text",
  Evaluatable->False],
Cell[15756, 579, 86, 1, 27, "Input"],
Cell[15845, 582, 61, 1, 27, "Input"],
Cell[15909, 585, 52, 1, 27, "Input"],
Cell[15964, 588, 52, 1, 27, "Input"],
Cell[16019, 591, 56, 1, 27, "Input"],
Cell[16078, 594, 55, 1, 27, "Input"],
Cell[16136, 597, 307, 7, 46, "Text",
  Evaluatable->False],
Cell[16446, 606, 91, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16574, 612, 120, 3, 46, "Subsection",
  Evaluatable->False],
Cell[16697, 617, 622, 12, 96, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

