(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15018,        544]*)
(*NotebookOutlinePosition[     40165,       1453]*)
(*  CellTagsIndexPosition[     40121,       1449]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 12\
\>", "Title"],

Cell["Coloring and Dashing", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "bifurc3D, boxrat, colorvec, dashalt, dashlong, dashort, dashvec, dotted, \
integrate, labshift, parmval, parmvec, phaseplot, plotreset, plrange3D, \
pointcon, portrait, restoresys, savesys, setcolor, setdash, setparm, \
setstate, slopevec, solid, statevec, sysid, sysname, and timeplot.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, our objective is to demonstrate the various ways in \
which color and dashing are controlled.  The system used to do this is a \
simple damped linear oscillator, in both two and three dimensions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Logic of Coloring and Dashing",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
 \tColors are controlled by the vector colorvec.  This vector \
contains a list of RGB colors.   If there is only one element in the list, \
all graphs are made with that color.  If there are several, the colors are \
used cyclically.  To assign the list named colist to colorvec, one uses the \
function colorset:  colorset[colist].  The default is the single color Black \
-- equivalently, RGBColor[0,0,0].  Dashing is controlled by the vector \
dashvec, which contains a list of dashing patterns.  If there is only one \
pattern in the list, it is used for all curves.  If there are several \
patterns, they are used cyclically.  To assign the list patlist to dashvec, \
type setdash[patlist].  The default for dashvec is {{}}, the empty list which \
causes curves to be solid.  There are four patterns defined by name:  dashort \
(short dashes), dashlong (long dashes), dashalt (alternate long and short \
dashes), and solid (solid curve).    \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definitions",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{eps}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {y, -x - 2.0*eps*y};", "Input",
  AspectRatioFixed->True],

Cell["parmval = {0.1};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(savesys[Osc2D];\)\)], "Input"],

Cell[BoxData[
    \(\(setstate[{x, y, z}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{eps}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec\  = \ {y, \(-x\) - 2.0*eps*y, \(-z\)};\)\)], "Input"],

Cell[BoxData[
    \(\(parmval\  = \ {0.1};\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[Osc3D];\)\)], "Input"],

Cell[BoxData[
    \(\(restoresys[Osc2D];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Color in Two Dimensions",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe current color list is stored in the vector colorvec, and it is used \
by the plotting routines as an argument for RGBColor.  The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " option RGBColor[a,b,c] produces a color with relative amounts a of red, b \
of green and c of blue.  Each argument runs from zero to one.  With all \
zeros, we get no color and the result is a black curve.  With all ones, we \
get white, which doesn't show up on the default white background.  Pure red \
is [1,0,0], pure green is [0,1,0], and pure blue is [0,0,1].  To get yellow, \
we use blue plus green, or [0,1,1].  For convenience, we have predefined six \
colors:  red, green, yellow, blue, magenta, and cyan.  To check the default \
for colorvec, we do a plotreset and then look at its value. "
}], "Text"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(colorvec\)], "Input"],

Cell["\<\
which is black.  Let's check this out by constructing a solution \
and a phase plane plot.\
\>", "Text"],

Cell[BoxData[
    \(\(t0\  = \ 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h\  = \ 0.04;\)\)], "Input"],

Cell[BoxData[
    \(\(initvec = {1, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps\  = \ 500;\)\)], "Input"],

Cell[BoxData[
    \(\(sol1\  = \ integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(labshift = 5;\)\)], "Input"],

Cell[BoxData[
    \(\(graph1\  = \ phaseplot[sol1, 1, 2];\)\)], "Input"],

Cell["\<\
As we expected the curve is black.  To make it red, we can set the \
color to red and replot. \
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(graph1red\  = \ phaseplot[sol1, 1, 2];\)\)], "Input"],

Cell["\<\
\tLet's construct and plot a second solution.  We set the color to \
blue.  \
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(initvec\  = \ {1.5, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(sol2\  = \ integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(graph12\  = \ phaseplot[{sol1, sol2}, 1, 2];\)\)], "Input"],

Cell["\<\
\tTo show the two curves in different colors, we set two colors and \
then plot.  The two colors will be used cyclically.  \
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Green}];\)\)], "Input"],

Cell["\<\
Now we expect the first graph plotted to be red, and the second to \
be green.  Let's try it.\
\>", "Text"],

Cell[BoxData[
    \(\(graphrg = phaseplot[{sol1, sol2}, 1, 2];\)\)], "Input"],

Cell["If we reverse the order, the colors will be reversed.", "Text"],

Cell[BoxData[
    \(\(graphgr\  = \ phaseplot[{sol2, sol1}, 1, 2];\)\)], "Input"],

Cell["\<\
This also works for timeplots.  If we plot more than one component, \
the colors will be taken cyclically from colorvec. \
\>", "Text"],

Cell[BoxData[
    \(\(asprat\  = \ 0.5;\)\)], "Input"],

Cell[BoxData[
    \(\(timegraph\  = \ timeplot[sol1, {1, 2}];\)\)], "Input"],

Cell["Now we construct a third solution, and we set three colors.", "Text"],

Cell[BoxData[
    \(\(initvec\  = \ {1.25, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(sol3\  = \ integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(asprat\  = \ 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Cyan, Yellow, Magenta}];\)\)], "Input"],

Cell[BoxData[
    \(\(graphrgb\  = \ phaseplot[{sol1, sol2, sol3}, 1, 2];\)\)], "Input"],

Cell["\<\
Everything is as predicted.  All of this works if we are plotting \
dots rather than lines.\
\>", "Text"],

Cell[BoxData[
    \(\(pointcon\  = \ False;\)\)], "Input"],

Cell[BoxData[
    \(\(ptsize\  = \ 0.01;\)\)], "Input"],

Cell[BoxData[
    \(\(graphrgbdot\  = \ phaseplot[{sol2, sol1, sol3}, 1, 2];\)\)], "Input"],

Cell["\<\
\tAs a grand finale with color in two dimensions, we construct a \
phase portrait with six initial conditions, using six different colors.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(pointcon\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red, Green, Blue, Magenta, Cyan, Yellow}];\)\)], "Input"],

Cell[BoxData[
    \(\(intlist\  = \ {{2, 0}, {2.5, 0}, {3, 0}, {3.5, 0}, {4, 0}, {4.5, 
            0}};\)\)], "Input"],

Cell[BoxData[
    \(\(portrait[intlist, t0, h, nsteps, 1, 2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Color in Three Dimensions",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBecause the ideas are identical, we content ourselves with one \
calculation -- a bifurcation diagram as eps changes.  We look at four \
solutions for each parameter value.  This time we define colors via a \
numerical RGB vector.\
\>", "Text"],

Cell[BoxData[
    \(\(restoresys[Osc3D];\)\)], "Input"],

Cell[BoxData[
    \(\(intlist\  = \ {{1, 1, 1}, {1, \(-1\), 1}, {\(-1\), 1, 
            1}, {\(-1\), \(-1\), 1}};\)\)], "Input"],

Cell[BoxData[
    \(\(t0\  = \ 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h\  = \ 0.04;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps\  = \ 500;\)\)], "Input"],

Cell[BoxData[
    \(\(parmlist\  = \ {{0.0}, {0.05}, {0.1}, {0.15}, {0.2}};\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Purple, Orange, EmeraldGreen, Cobalt}];\)\)], "Input"],

Cell[BoxData[
    \(\(boxrat\  = \ {1, 1, 1};\)\)], "Input"],

Cell[BoxData[
    \(\(plrange3D\  = \ {{\(-2\), 2}, {\(-2\), 2}, {0, 1}};\)\)], "Input"],

Cell[BoxData[
    \(\(bifurc3D[intlist, t0, h, nsteps, 1, 2, 3, parmlist];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Dashing",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tDashing has been implemented here only for two dimensional plots.  There \
are some problems with dashing in three dimensions with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " which make it difficult to get consistent results.  In particular, plots \
of closely spaced points which are supposed to be dashed often are solid.  In \
two dimension, it works as expected.  The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " option Dashing takes a dashing pattern as an argument.  In the present \
package, that pattern is stored in the variable dasher.  If the pattern is an \
empty list, then the curve is plotted as solid.  That is the default here:"
}], "Text"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(\(labshift\  = \ 4;\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(dashvec\)], "Input"],

Cell["\<\
In general, a dashing pattern has the form {r1,r2,r3,r4,...rn}.  \
Each r is a positive number less than 1, and is interpreted as a fraction of \
the width of the entire graph.  The dashing is done by alternating plots of a \
dash and a gap, with the lengths controlled by a cyclic passage through the \
pattern.  Thus for example {0.05} produces alternate dashes and gaps of \
relative length 0.05.  The pattern {0.05,0.02,0.02,0.02}will produce long \
dash, short gap, short dash, short gap, repeat.  Let's try this out.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(restoresys[Osc2D];\)\)], "Input"],

Cell[BoxData[
    \(\(parmval\  = \ {0.1};\)\)], "Input"],

Cell[BoxData[
    \(\(t0\  = \ 0.0;\)\)], "Input"],

Cell[BoxData[
    \(\(h\  = \ 0.04;\)\)], "Input"],

Cell[BoxData[
    \(\(nsteps\  = \ 500;\)\)], "Input"],

Cell[BoxData[
    \(\(init\  = \ {1, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(sola\  = \ integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell[BoxData[
    \(\(init\  = \ {2, 0};\)\)], "Input"],

Cell[BoxData[
    \(\(solb\  = \ integrate[init, t0, h, nsteps];\)\)], "Input"],

Cell["\<\
\tNow we will plot both of these dashed with the same pattern, by \
setting the variable dasher to that pattern.\
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{{0.05, 0.02, 0.02, 0.02}}];\)\)], "Input"],

Cell[BoxData[
    \(\(phasedash\  = \ phaseplot[{sola, solb}, 1, 2];\)\)], "Input"],

Cell["\<\
Now we set a different dashing pattern for each.  We also set some \
colors.\
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{{0.01}, {0.05}}];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Magenta, Cyan}];\)\)], "Input"],

Cell[BoxData[
    \(\(phasedash\  = \ phaseplot[{sola, solb}, 1, 2];\)\)], "Input"],

Cell["\<\
We try one last pattern, incorporating two different lengths of \
dashes.\
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{{0.05, 0.02, 0.02, 0.02}}];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell[BoxData[
    \(\(phaseredash\  = \ phaseplot[sola, 1, 2];\)\)], "Input"],

Cell["\<\
\tFinally, we use the predefined dashing patterns.  First we use \
short and long dashing.\
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{dashort, dashlong}];\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.5;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, {1, 2}];\)\)], "Input"],

Cell["\tNow we use alternate short/long and solid. ", "Text"],

Cell[BoxData[
    \(\(setdash[{dashalt, solid}];\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, {1, 2}];\)\)], "Input"],

Cell["\<\
\tIn these last examples, we will use dotted lines, with different \
line thicknesses.\
\>", "Text"],

Cell[BoxData[
    \(\(setdash[{dotted}];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Magenta}];\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["\<\
Let's check the line thickness on this plot, and then increase \
it.\
\>", "Text"],

Cell[BoxData[
    \(lnthick\)], "Input"],

Cell[BoxData[
    \(\(lnthick = 0.008;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, -3}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00/0004/0B`000002nX9H?nbokD<V@V[7b<5:@?l0040004/0B`000002nX9H04/
02d5X5k/02H20@4101P00BL?00400@>M91000000000000010000000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 3, 152, "Title"],
Cell[1796, 56, 88, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1887, 60, 48, 1, 27, "Input"],
Cell[1938, 63, 46, 1, 27, "Input"],
Cell[1987, 66, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2059, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2219, 76, 411, 9, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2667, 90, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2826, 95, 335, 8, 48, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3198, 108, 141, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3342, 113, 1019, 16, 142, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4398, 134, 130, 3, 46, "Subsection",
  Evaluatable->False],
Cell[4531, 139, 59, 1, 27, "Input"],
Cell[4593, 142, 58, 1, 27, "Input"],
Cell[4654, 145, 74, 1, 27, "Input"],
Cell[4731, 148, 59, 1, 27, "Input"],
Cell[4793, 151, 52, 1, 27, "Input"],
Cell[4848, 154, 57, 1, 27, "Input"],
Cell[4908, 157, 52, 1, 27, "Input"],
Cell[4963, 160, 84, 1, 27, "Input"],
Cell[5050, 163, 57, 1, 27, "Input"],
Cell[5110, 166, 52, 1, 27, "Input"],
Cell[5165, 169, 55, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5257, 175, 135, 3, 46, "Subsection",
  Evaluatable->False],
Cell[5395, 180, 827, 13, 128, "Text"],
Cell[6225, 195, 47, 1, 27, "Input"],
Cell[6275, 198, 41, 1, 27, "Input"],
Cell[6319, 201, 114, 3, 30, "Text"],
Cell[6436, 206, 50, 1, 27, "Input"],
Cell[6489, 209, 50, 1, 27, "Input"],
Cell[6542, 212, 54, 1, 27, "Input"],
Cell[6599, 215, 54, 1, 27, "Input"],
Cell[6656, 218, 82, 1, 27, "Input"],
Cell[6741, 221, 50, 1, 27, "Input"],
Cell[6794, 224, 72, 1, 27, "Input"],
Cell[6869, 227, 118, 3, 30, "Text"],
Cell[6990, 232, 53, 1, 27, "Input"],
Cell[7046, 235, 75, 1, 27, "Input"],
Cell[7124, 238, 100, 3, 30, "Text"],
Cell[7227, 243, 54, 1, 27, "Input"],
Cell[7284, 246, 60, 1, 27, "Input"],
Cell[7347, 249, 82, 1, 27, "Input"],
Cell[7432, 252, 81, 1, 27, "Input"],
Cell[7516, 255, 147, 3, 46, "Text"],
Cell[7666, 260, 60, 1, 27, "Input"],
Cell[7729, 263, 117, 3, 30, "Text"],
Cell[7849, 268, 77, 1, 27, "Input"],
Cell[7929, 271, 69, 0, 30, "Text"],
Cell[8001, 273, 81, 1, 27, "Input"],
Cell[8085, 276, 145, 3, 30, "Text"],
Cell[8233, 281, 54, 1, 27, "Input"],
Cell[8290, 284, 76, 1, 27, "Input"],
Cell[8369, 287, 75, 0, 30, "Text"],
Cell[8447, 289, 61, 1, 27, "Input"],
Cell[8511, 292, 82, 1, 27, "Input"],
Cell[8596, 295, 54, 1, 27, "Input"],
Cell[8653, 298, 71, 1, 27, "Input"],
Cell[8727, 301, 88, 1, 27, "Input"],
Cell[8818, 304, 115, 3, 30, "Text"],
Cell[8936, 309, 58, 1, 27, "Input"],
Cell[8997, 312, 55, 1, 27, "Input"],
Cell[9055, 315, 91, 1, 27, "Input"],
Cell[9149, 318, 165, 4, 46, "Text"],
Cell[9317, 324, 57, 1, 27, "Input"],
Cell[9377, 327, 89, 1, 27, "Input"],
Cell[9469, 330, 119, 2, 27, "Input"],
Cell[9591, 334, 76, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9704, 340, 137, 3, 46, "Subsection",
  Evaluatable->False],
Cell[9844, 345, 256, 5, 46, "Text"],
Cell[10103, 352, 55, 1, 27, "Input"],
Cell[10161, 355, 129, 2, 27, "Input"],
Cell[10293, 359, 50, 1, 27, "Input"],
Cell[10346, 362, 50, 1, 27, "Input"],
Cell[10399, 365, 54, 1, 27, "Input"],
Cell[10456, 368, 90, 1, 27, "Input"],
Cell[10549, 371, 86, 1, 27, "Input"],
Cell[10638, 374, 60, 1, 27, "Input"],
Cell[10701, 377, 88, 1, 27, "Input"],
Cell[10792, 380, 89, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10918, 386, 119, 3, 46, "Subsection",
  Evaluatable->False],
Cell[11040, 391, 707, 13, 100, "Text"],
Cell[11750, 406, 47, 1, 27, "Input"],
Cell[11800, 409, 64, 1, 27, "Input"],
Cell[11867, 412, 40, 1, 27, "Input"],
Cell[11910, 415, 549, 9, 94, "Text"],
Cell[12462, 426, 55, 1, 27, "Input"],
Cell[12520, 429, 57, 1, 27, "Input"],
Cell[12580, 432, 50, 1, 27, "Input"],
Cell[12633, 435, 50, 1, 27, "Input"],
Cell[12686, 438, 54, 1, 27, "Input"],
Cell[12743, 441, 55, 1, 27, "Input"],
Cell[12801, 444, 79, 1, 27, "Input"],
Cell[12883, 447, 55, 1, 27, "Input"],
Cell[12941, 450, 79, 1, 27, "Input"],
Cell[13023, 453, 136, 3, 30, "Text"],
Cell[13162, 458, 73, 1, 27, "Input"],
Cell[13238, 461, 83, 1, 27, "Input"],
Cell[13324, 464, 100, 3, 30, "Text"],
Cell[13427, 469, 63, 1, 27, "Input"],
Cell[13493, 472, 63, 1, 27, "Input"],
Cell[13559, 475, 83, 1, 27, "Input"],
Cell[13645, 478, 97, 3, 30, "Text"],
Cell[13745, 483, 73, 1, 27, "Input"],
Cell[13821, 486, 53, 1, 27, "Input"],
Cell[13877, 489, 77, 1, 27, "Input"],
Cell[13957, 492, 114, 3, 30, "Text"],
Cell[14074, 497, 66, 1, 27, "Input"],
Cell[14143, 500, 50, 1, 27, "Input"],
Cell[14196, 503, 60, 1, 27, "Input"],
Cell[14259, 506, 61, 0, 30, "Text"],
Cell[14323, 508, 63, 1, 27, "Input"],
Cell[14389, 511, 60, 1, 27, "Input"],
Cell[14452, 514, 110, 3, 30, "Text"],
Cell[14565, 519, 55, 1, 27, "Input"],
Cell[14623, 522, 57, 1, 27, "Input"],
Cell[14683, 525, 55, 1, 27, "Input"],
Cell[14741, 528, 92, 3, 30, "Text"],
Cell[14836, 533, 40, 1, 27, "Input"],
Cell[14879, 536, 53, 1, 27, "Input"],
Cell[14935, 539, 55, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

