(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33927,       1199]*)
(*NotebookOutlinePosition[     59073,       2108]*)
(*  CellTagsIndexPosition[     59029,       2104]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 13\
\>", "Title"],

Cell[TextData["Lorenz Equations"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "asprat, boxrat, classify, dermatval, dival,eqstateval, fastflag, \
findpolyeq, integrate, intreset, joinsol, lastt, lastx,  parmval, parmvec, \
phaseplot, phaser3D, plotreset, plrange, plrange3D, portrait3D, rangeflag, \
ranger, setparm, setstate, show3D, slopevec, staterange, statevec, sysid, \
sysname, and timeplot.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, we look at some of the interesting features of solutions \
of Lorenz equations.  The mode is not that of exploration, but rather \
verification and visualization of some results that are known for these \
equations.  The three parameters of the Lorenz equations are sigma, r, and b. \
 Here we take the frequently used values of sigma = 10.0 and b = 8/3, and \
then look at properties of the solutions for selected values of r.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["References",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tFor a basic treatment of the Lorenz equations, see Chapter 9 of ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontWeight->"Bold"],
  ", S.H. Strogatz, Addison-Wesley, 1994.  For a general work containing a \
more advanced treatment, see ",
  StyleBox[
  "Nonlinear Oscillations, Dynamical Systems, and Bifurcations of Vector \
Fields",
    FontWeight->"Bold"],
  ", J. Guckenheimer and P. Holmes, Springer-Verlag, 1983.  For a book-length \
treatment containing many detailed results, see ",
  StyleBox[
  "The Lorenz Equations:  Bifurcations, Chaos, and Strange Attractors",
    FontWeight->"Bold"],
  ", C. Sparrow, Springer-Verlag, 1982.  For some historical perspective on \
the discovery of the Lorenz equations, see ",
  StyleBox["The Essence of Chaos",
    FontWeight->"Bold"],
  ", E.N. Lorenz, University of Washington Press, 1993.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definition",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We denote the three state variables of the Lorenz system by x, y, and z.  \
The parameters of the system are sigma, r, and b.  For now, we leave these as \
symbols, by setting parmval to the symbols.  When we do use numerical values, \
we will take sigma = 10.0 and b = 8/3 throughout.    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{x,y,z}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{sigma,r,b}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {sigma*(y-x),r*x-y-x*z,x*y-b*z};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"Lorenz\";", "Input",
  AspectRatioFixed->True],

Cell["parmval = {sigma,r,b};", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The Range 0 < r < 1.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\n\t",
    FontWeight->"Bold"],
  "We begin by looking for equilibrium points."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["eqpoints = findpolyeq", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see that for this range of r, there is a single real \
equilibrium at the origin, but for r values greater than 1, there are three \
real equilibria.  We will need all three eventually, so we name them now:  \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["C0 = eqpoints[[1]]", "Input",
  AspectRatioFixed->True],

Cell["C1 = eqpoints[[2]]", "Input",
  AspectRatioFixed->True],

Cell["C2 = eqpoints[[3]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we take the standard values for sigma and b, and a typical \
value for r in this range.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,0.5,8/3};", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe examine the stability of the equilibrium at the origin by \
calculating the eigenvalues.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThus we have a stable node.  It is possible to show that for the \
r-range (0,1) this node is a global attractor for the system.  We use \
portrait3D to construct a simple phase portrait.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
intlist = {{5,5,10},{5,-5,10},{-5,-5,10},{-5,5,10},
\t\t\t{0,5,10},{5,0,10},{-5,0,10},{0,-5,10}};\
\>", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.015;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 200;", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-5,5},{-5,5},{0,10}};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(setcolor[{Red, Blue, Green, Cyan, Magenta, Yellow, BurntSienna, 
        Purple}]\)], "Input"],

Cell["portrait3D[intlist,t0,h,nsteps,1,2,3];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The Pitchfork Bifurcation at r = 1.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "For r < 1, there is one real equilibrium.  For r > 1, there are three.  At \
r = 1, the three equilibria are all at the origin.  We examine the stability \
near r = 1.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,1.01,8/3};", "Input",
  AspectRatioFixed->True],

Cell["classify[C0]", "Input",
  AspectRatioFixed->True],

Cell["classify[C1]", "Input",
  AspectRatioFixed->True],

Cell["classify[C2]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C2]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Thus the origin (C0) goes from stable to unstable at the bifurcation, and \
the two new equilibria are stable nodes, so we have a pitchfork bifurcation.  \
For r near 1, the new equilibria are close to the origin:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["N[eqstateval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["N[eqstateval[C2]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Here we have used the function eqstateval, which evaluates its argument by \
substituting current values of parmval for the symbols of parmvec.  "], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe symmetry in x and y, showing in the eigenvalues and in the \
coordinates of the equilibria, is not accidental.  It is easy to show that \
the Lorenz equations are invariant to a simultaneous change of signs of x and \
y.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The Node-Spiral Transition at r = 1.346.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "The next event along the r-trail is a change in character of the \
equilibria C1 and C2 from nodes to spirals.  As shown below, this occurs at \
about r = 1.346.  This is the first appearance of oscillatory behavior in the \
system as r increases from 0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,1.345,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {10.0,1.347,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tLet's look at a typical solution well into this oscillatory \
range.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0, 10.0,8/3};", "Input",
  AspectRatioFixed->True],

Cell["N[eqstateval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["initvec = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 400;", "Input",
  AspectRatioFixed->True],

Cell["sol1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{LawnGreen}];\)\)], "Input"],

Cell["graph1 = phaser3D[sol1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tA nice spiral into the equilbrium C2.  Let's look at the x-y \
phase plane plot, followed by a plot of x versus time.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph1xy = phaseplot[sol1,1,2];", "Input",
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell["graph1time = timeplot[sol1,1];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The Homoclinic Orbit at r = 13.926.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "For values of r < 13.926, the solution leaving the origin along the local \
unstable manifold spirals into the nearest of C1 and C2.  For values of r > \
13.926, the solution leaving the origin loops around the nearer spiral \
equilibrium and then settles into the further one.  Let's verify that.  We \
begin by finding the local direction of the unstable manifold leaving the \
origin."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0, 12.0, 8/3};", "Input",
  AspectRatioFixed->True],

Cell["eiger = Eigensystem[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now we take an initial condition slightly displaced from the origin, along \
the eigenvector of the unstable manifold."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 600;", "Input",
  AspectRatioFixed->True],

Cell["startvec = h*eiger[[2,2]]", "Input",
  AspectRatioFixed->True],

Cell["sol2 = integrate[startvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Magenta}];\)\)], "Input"],

Cell["graph2 = phaser3D[sol2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see that the solution leaving the origin spirals into the \
nearest equilibrium (C1 in this case).  Let's look at a 2D view -- in the xy \
phase plane.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["graph2xy = phaseplot[sol2,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow we look at the same sequence of calculations for r = 16.\
\>",
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0, 16.0, 8/3};", "Input",
  AspectRatioFixed->True],

Cell["eiger2 = Eigensystem[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["startvec = h*eiger2[[2,2]]", "Input",
  AspectRatioFixed->True],

Cell["sol3 = integrate[startvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["graph3 = phaser3D[sol3];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow the solution leaving the origin makes one loop around the \
nearest equilibrium (C1), and then travels to C2 where it spirals in.  The 2D \
view is given below.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["graph3xy = phaseplot[sol3,1,2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWhat is the transition case between the two cases we have just \
looked at?  As numerical exploration has shown, the transition occurs for r = \
13.926..., and the solution leaving the origin along the local unstable \
manifold returns to the origin along the local stable manifold (tangent to \
the z-axis).  It is hard to construct this homoclinic orbit numerically, \
because it is unstable.  We take an indirect approach, and look at a sequence \
of plots for a range of r values bracketing 13.926.  We construct the orbits \
using in each case an initial point displaced h from the origin along the \
local unstable manifold. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec := h*Part[Part[Eigensystem[dermatval[C0]],2],2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
parmlist = {{10.0, 13.84, 8/3},{10.0, 13.88, 8/3},
\t\t\t{10.0, 13.92, 8/3},{10.0, 13.96, 8/3},
\t\t\t{10.0, 14.00, 8/3}}; \
\>", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.01;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 300;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{-15,15},{0,25}};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Peacock}];\)\)], "Input"],

Cell["\<\
Do[(parmval = parmlist[[q]];startvec = initvec;
\tphaseplot[integrate[startvec,t0,h,nsteps],1,3]),
\t{q,1,Length[parmlist]}]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tFrom these graphs, it is clear that somewhere between r = 13.92 \
and r = 13.96 there is a homoclinic orbit.  When r exceeds the value \
corresponding to the homoclinic orbit, there exists an unstable limit cycle, \
which is difficult to find numerically.    \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tBy symmetry, we get the mirror image of the above picture if we \
start on the other side of the origin.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"The Range 13.926 < r < 24.06 and Pre-Chaotic Transients.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe main event in this parameter range is the increasingly \
oscillatory nature of the solution as r increases.  For larger values of r in \
this range, some solutions go back and forth between C1 and C2 many times \
before spiraling into one of them.  These kinds of solutions are called \
pre-chaotic transients.  We will look at one of them shortly.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe other event in this range (beyond our capabilities here to \
look at numerically) is the shrinking of the unstable limit cycles around C1 \
and C2.  The cycles are heading for a Hopf bifurcation which occurs at r = \
24.74...  .\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe look at a pre-chaotic transient now.  This is a LONG \
integration, so it might be a good time for a coffee break.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,20.0,8/3};", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 2500;", "Input",
  AspectRatioFixed->True],

Cell["initvec = {14.0,12.0,10.0};", "Input",
  AspectRatioFixed->True],

Cell["chaotrans = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["plrange = {{0,50},{-15,15}};", "Input",
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell["chaotranstimex = timeplot[chaotrans,1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tWe see eight zero crossings, meaning eight transitions between C1 \
and C2, with the system eventually settling into C2.  Now let's do this \
integration again with a smaller time step and the same final time.  (This \
will take TWICE as long as the above integration, so you can, if you prefer, \
just read the conclusion below the calculation.)\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = 0.01;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 5000;", "Input",
  AspectRatioFixed->True],

Cell["chaotrans2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["trans2timex = timeplot[chaotrans2,1];", "Input",
  AspectRatioFixed->True],

Cell["\<\
 \tNow we have 19 transitions, and the system settling into C1 -- a \
different final state than before.  What a sobering example!  Halving the \
time step produced a completely different solution.  We don't even know the \
true final fate of the system -- does it go to C1 or C2?  The main lesson in \
these calculations is that these pre-chaotic transients share some properties \
with their even more difficult chaotic cousins.  Perhaps you would want to \
explore the question of whether we can overcome the uncertainty here with a \
sufficiently small time step.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tLet's finish this off by looking at the 3D phase plot of this \
solution.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = Automatic;", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Maroon}];\)\)], "Input"],

Cell["transgraph3D = phaser3D[chaotrans2];", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThis is starting to look a lot like the famous Lorenz chaotic \
attractor.
     \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Point and Chaotic Attractors in 24.06 < r < 24.74.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "As r takes on values beyond 24.06, some of the pre-chaotic transients slip \
over the brink into true chaos.  Interestingly enough, the equilibria C1 and \
C2 remain stable for 24.06 < r < 24.74.  Thus in this small range, the system \
has three attractors:  a chaotic attractor, and two stable spiral equilibria. \
 We will verify the nature of the equilibria, and then look at a few \
interesting orbits.     "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,24.4,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues [dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {10.0,24.73,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]] ", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["parmval = {10.0,24.75,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tThe above calculations verify that the equilibria C1 and C2 are \
stable spirals until we reach r = 24.74, at which point they become unstable \
spirals.  Although the calculations of unstable limit cycles are beyond our \
capabilities here, it can be shown that in fact r = 24.74 is a subcritical \
Hopf bifurcation in which, as r is increased, the unstable limit cycles are \
absorbed by the equilibria which then become unstable themselves.  The \
character of the equilibrium at the origin is unchanged.  It remains a saddle \
with a one-dimensional unstable manifold.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe set an r value midway in this range, and see if we can find \
orbits leading to each of three attractors (by symmetry, we can just do one \
of C1 or C2).  For the spiral point attractor, we will cheat a little by \
starting very near the attractor, and then integrating backwards in time, to \
construct in that way an orbit which goes from some distant point to the \
attractor.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,24.4,8/3};", "Input",
  AspectRatioFixed->True],

Cell["N[eqstateval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["initvec = % + 0.001*{1,1,1}", "Input",
  AspectRatioFixed->True],

Cell["h = -0.001;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 1000;", "Input",
  AspectRatioFixed->True],

Cell["rangeflag = True;", "Input",
  AspectRatioFixed->True],

Cell["ranger = {{-30,30},{-30,30},{-50,50}};", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = ranger;", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["ans1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{DeepPink}];\)\)], "Input"],

Cell["graphans1 = phaser3D[ans1];", "Input",
  AspectRatioFixed->True],

Cell["\tLet's see where this solution went out of bounds.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["First[ans1]", "Input",
  AspectRatioFixed->True],

Cell[TextData["The x-coordinate went out of bounds."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe stable spirals have eigenvalues with very small real parts.  \
The one large negative real eigenvalue tells us that the solutions rapidly \
approach the plane of the spiral, after which they slowly spiral in.  Let's \
try to observe at least part of the spiral by integrating forward in time, \
and magnifying our view.  For this direction in time, we can turn off range \
checking to speed up the integration.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["rangeflag = False;", "Input",
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["ans2 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["staterange[ans2]", "Input",
  AspectRatioFixed->True],

Cell["plrange3D = {{-7.92,-7.88},{-7.92,-7.88},{23.2,23.6}};", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{PeachPuff}];\)\)], "Input"],

Cell["graphans2 = phaser3D[ans2];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"A VERY slow spiral, which we could have predicted from the eigenvalues."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tNow we look for a chaotic solution.  We will use plots of x \
versus time to track our progress.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = 0.02;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 1000;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["initvec = {10,10,10};", "Input",
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["asprat = 0.5;", "Input",
  AspectRatioFixed->True],

Cell["cha1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Cobalt}];\)\)], "Input"],

Cell["chagraph1 = timeplot[cha1,1];", "Input",
  AspectRatioFixed->True],

Cell[TextData["We continue the integration."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["cha2 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["chagraph2 = timeplot[cha2,1];", "Input",
  AspectRatioFixed->True],

Cell[TextData["One more time."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["cha3 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["chagraph3 = timeplot[cha3,1];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"At this point, we can be reasonably sure that this is a chaotic solution.  \
Let's combine our three pieces and make a phase plot."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["bigcha = joinsol[cha1,joinsol[cha2,cha3]];", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell["bigchagraph = phaser3D[bigcha];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Let's add to this picture our earlier orbit which reached the attractor at \
C1."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["show3D[graphans1,bigchagraph];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Chaos (r = 28).",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We begin by resetting our plotting and integration defaults.  Then we set \
our parameter values and examine the three equilibrium points.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["intreset;", "Input",
  AspectRatioFixed->True],

Cell["plotreset;", "Input",
  AspectRatioFixed->True],

Cell["parmval = {10.0,28.0,8/3};", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C2]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
\tNow all three equilibrium points are unstable.  The system is \
bounded, so this raises the very interesting question of where it spends its \
time.  Of course there are other possible attractors such as limit cycles, \
but as discussed in the literature, there are strong arguments against the \
existence of stable limit cycles for this parameter range.  Whatever set the \
solutions live on must have zero volume.  This follows directly from \
Liouville's Theorem and the fact that the slope vector has a negative \
divergence:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["dival[slopevec] ", "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus volumes in phase space contract exponentially with an \
e-folding time of 1/13.6667.  The resolution of the question of the attractor \
for this system came from the pioneering work of Lorenz.  The attractor in \
this case is a fractal set on which orbits wander forever.  We will content \
ourselves here with getting some two- and three-dimensional views of our \
numerical approximation to this fractal.  We start with a lengthy integration \
of 2000 points.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["h = 0.015;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 2000;", "Input",
  AspectRatioFixed->True],

Cell["fastflag = True;", "Input",
  AspectRatioFixed->True],

Cell["initvec = {10,10,10};", "Input",
  AspectRatioFixed->True],

Cell["lor1 = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{Red}];\)\)], "Input"],

Cell["lorgraph1 = phaser3D[lor1];", "Input",
  AspectRatioFixed->True],

Cell["asprat = 1.0;", "Input",
  AspectRatioFixed->True],

Cell["lorgraph2 = phaseplot[lor1,1,2];", "Input",
  AspectRatioFixed->True],

Cell["lorgraph3 = phaseplot[lor1,1,3];", "Input",
  AspectRatioFixed->True],

Cell["lorgraph4 = phaseplot[lor1,2,3];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A Large r Limit Cycle.",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe have seen that as we increased r, chaos first appeared at r = \
24.06, and by the time r = 24.74, it was the only possibility.  One might \
think that the larger r, the more chaotic the solution, but nonlinear sytems \
are full of surprises.  It turns out that there are narrow windows of large r \
values in which the solutions are not chaotic, and the attractor is a stable \
limit cycle!  We explore one such case here, namely r = 100.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["parmval = {10.0,100.0,8/3};", "Input",
  AspectRatioFixed->True],

Cell[TextData["Now we check the equilibrium states."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C0]]", "Input",
  AspectRatioFixed->True],

Cell["Eigenvalues[dermatval[C1]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"All three are unstable.  We begin an integration with a more or less \
arbitrary initial condition."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["initvec = {10.0,10.0,10.0};", "Input",
  AspectRatioFixed->True],

Cell["h = 0.01;", "Input",
  AspectRatioFixed->True],

Cell["t0 = 0.0;", "Input",
  AspectRatioFixed->True],

Cell["nsteps = 1000;", "Input",
  AspectRatioFixed->True],

Cell["lorlim = integrate[initvec,t0,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["boxrat = {1,1,1};", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(setcolor[{TurquoiseBlue}];\)\)], "Input"],

Cell["limgraph1 = phaser3D[lorlim];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Hard to tell if there is a limit cycle because of the transients.  We \
continue the integration to get a better idea."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["lorlim2 = integrate[lastx,lastt,h,nsteps];", "Input",
  AspectRatioFixed->True],

Cell["limgraph2 = phaser3D[lorlim2];", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now we clearly have a rather exotic-looking limit cycle.  We could clean it \
up a little by using a smaller time step and integrating once more, but the \
picture wouldn't change much."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercises",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["In all the exercises below, use sigma = 10.0, b = 8/3.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"(1) Study the phenomenon of sensitive dependence on initial conditions for \
chaotic solutions by plotting x versus t for two solutions of the Lorenz \
equations with slightly different initial conditions.  Do this for r = 28.    \
"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"(2) Use the routine animate to construct a sequence of rotated views of the \
chaotic Lorenz attractor for r = 28.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"(3)  Look for a stable limit cycle solution for r = 400."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"(4)  We noted earlier that the Lorenz equations are invariant to a \
simultaneous change of signs of x and y.  Does the limit cycle obtained above \
for r = 100 have this symmetry?  If not, find the second cycle implied by the \
symmetry."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 433},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@=;i`0000000000lV0801T1T00000000000
00000000000000=;fH00000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 3, 152, "Title"],
Cell[1796, 56, 94, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1893, 60, 48, 1, 27, "Input"],
Cell[1944, 63, 46, 1, 27, "Input"],
Cell[1993, 66, 47, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2065, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2225, 76, 444, 10, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[2706, 91, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2865, 96, 569, 11, 80, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3471, 112, 122, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3596, 117, 929, 22, 138, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4562, 144, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[4694, 149, 411, 9, 64, "Text",
  Evaluatable->False],
Cell[5108, 160, 61, 1, 27, "Input"],
Cell[5172, 163, 64, 1, 27, "Input"],
Cell[5239, 166, 86, 1, 27, "Input"],
Cell[5328, 169, 64, 1, 27, "Input"],
Cell[5395, 172, 65, 1, 27, "Input"],
Cell[5463, 175, 52, 1, 27, "Input"],
Cell[5518, 178, 53, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5608, 184, 132, 3, 46, "Subsection",
  Evaluatable->False],
Cell[5743, 189, 167, 6, 50, "Text",
  Evaluatable->False],
Cell[5913, 197, 64, 1, 27, "Input"],
Cell[5980, 200, 287, 7, 46, "Text",
  Evaluatable->False],
Cell[6270, 209, 61, 1, 27, "Input"],
Cell[6334, 212, 61, 1, 27, "Input"],
Cell[6398, 215, 61, 1, 27, "Input"],
Cell[6462, 218, 165, 5, 30, "Text",
  Evaluatable->False],
Cell[6630, 225, 68, 1, 27, "Input"],
Cell[6701, 228, 165, 5, 30, "Text",
  Evaluatable->False],
Cell[6869, 235, 69, 1, 27, "Input"],
Cell[6941, 238, 263, 6, 46, "Text",
  Evaluatable->False],
Cell[7207, 246, 148, 4, 42, "Input"],
Cell[7358, 252, 52, 1, 27, "Input"],
Cell[7413, 255, 53, 1, 27, "Input"],
Cell[7469, 258, 56, 1, 27, "Input"],
Cell[7528, 261, 60, 1, 27, "Input"],
Cell[7591, 264, 78, 1, 27, "Input"],
Cell[7672, 267, 114, 2, 43, "Input"],
Cell[7789, 271, 81, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7907, 277, 147, 3, 46, "Subsection",
  Evaluatable->False],
Cell[8057, 282, 291, 8, 48, "Text",
  Evaluatable->False],
Cell[8351, 292, 69, 1, 27, "Input"],
Cell[8423, 295, 55, 1, 27, "Input"],
Cell[8481, 298, 55, 1, 27, "Input"],
Cell[8539, 301, 55, 1, 27, "Input"],
Cell[8597, 304, 69, 1, 27, "Input"],
Cell[8669, 307, 69, 1, 27, "Input"],
Cell[8741, 310, 69, 1, 27, "Input"],
Cell[8813, 313, 288, 5, 46, "Text",
  Evaluatable->False],
Cell[9104, 320, 60, 1, 27, "Input"],
Cell[9167, 323, 60, 1, 27, "Input"],
Cell[9230, 326, 222, 5, 46, "Text",
  Evaluatable->False],
Cell[9455, 333, 300, 7, 46, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[9792, 345, 152, 3, 46, "Subsection",
  Evaluatable->False],
Cell[9947, 350, 376, 9, 64, "Text",
  Evaluatable->False],
Cell[10326, 361, 70, 1, 27, "Input"],
Cell[10399, 364, 69, 1, 27, "Input"],
Cell[10471, 367, 70, 1, 27, "Input"],
Cell[10544, 370, 69, 1, 27, "Input"],
Cell[10616, 373, 142, 5, 30, "Text",
  Evaluatable->False],
Cell[10761, 380, 70, 1, 27, "Input"],
Cell[10834, 383, 60, 1, 27, "Input"],
Cell[10897, 386, 69, 1, 27, "Input"],
Cell[10969, 389, 61, 1, 27, "Input"],
Cell[11033, 392, 52, 1, 27, "Input"],
Cell[11088, 395, 52, 1, 27, "Input"],
Cell[11143, 398, 56, 1, 27, "Input"],
Cell[11202, 401, 81, 1, 27, "Input"],
Cell[11286, 404, 53, 1, 27, "Input"],
Cell[11342, 407, 60, 1, 27, "Input"],
Cell[11405, 410, 59, 1, 27, "Input"],
Cell[11467, 413, 67, 1, 27, "Input"],
Cell[11537, 416, 191, 5, 30, "Text",
  Evaluatable->False],
Cell[11731, 423, 74, 1, 27, "Input"],
Cell[11808, 426, 56, 1, 27, "Input"],
Cell[11867, 429, 53, 1, 27, "Input"],
Cell[11923, 432, 73, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12033, 438, 147, 3, 46, "Subsection",
  Evaluatable->False],
Cell[12183, 443, 509, 11, 80, "Text",
  Evaluatable->False],
Cell[12695, 456, 71, 1, 27, "Input"],
Cell[12769, 459, 77, 1, 27, "Input"],
Cell[12849, 462, 193, 4, 30, "Text",
  Evaluatable->False],
Cell[13045, 468, 52, 1, 27, "Input"],
Cell[13100, 471, 52, 1, 27, "Input"],
Cell[13155, 474, 56, 1, 27, "Input"],
Cell[13214, 477, 68, 1, 27, "Input"],
Cell[13285, 480, 82, 1, 27, "Input"],
Cell[13370, 483, 57, 1, 27, "Input"],
Cell[13430, 486, 67, 1, 27, "Input"],
Cell[13500, 489, 228, 6, 46, "Text",
  Evaluatable->False],
Cell[13731, 497, 56, 1, 27, "Input"],
Cell[13790, 500, 74, 1, 27, "Input"],
Cell[13867, 503, 137, 5, 30, "Text",
  Evaluatable->False],
Cell[14007, 510, 71, 1, 27, "Input"],
Cell[14081, 513, 78, 1, 27, "Input"],
Cell[14162, 516, 69, 1, 27, "Input"],
Cell[14234, 519, 82, 1, 27, "Input"],
Cell[14319, 522, 67, 1, 27, "Input"],
Cell[14389, 525, 238, 6, 46, "Text",
  Evaluatable->False],
Cell[14630, 533, 74, 1, 27, "Input"],
Cell[14707, 536, 705, 12, 110, "Text",
  Evaluatable->False],
Cell[15415, 550, 99, 1, 27, "Input"],
Cell[15517, 553, 174, 5, 57, "Input"],
Cell[15694, 560, 52, 1, 27, "Input"],
Cell[15749, 563, 52, 1, 27, "Input"],
Cell[15804, 566, 56, 1, 27, "Input"],
Cell[15863, 569, 71, 1, 27, "Input"],
Cell[15937, 572, 57, 1, 27, "Input"],
Cell[15997, 575, 175, 5, 57, "Input"],
Cell[16175, 582, 333, 7, 62, "Text",
  Evaluatable->False],
Cell[16511, 591, 178, 5, 30, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[16726, 601, 169, 4, 46, "Subsection",
  Evaluatable->False],
Cell[16898, 607, 426, 8, 62, "Text",
  Evaluatable->False],
Cell[17327, 617, 306, 7, 46, "Text",
  Evaluatable->False],
Cell[17636, 626, 191, 5, 46, "Text",
  Evaluatable->False],
Cell[17830, 633, 69, 1, 27, "Input"],
Cell[17902, 636, 52, 1, 27, "Input"],
Cell[17957, 639, 52, 1, 27, "Input"],
Cell[18012, 642, 57, 1, 27, "Input"],
Cell[18072, 645, 70, 1, 27, "Input"],
Cell[18145, 648, 86, 1, 27, "Input"],
Cell[18234, 651, 53, 1, 27, "Input"],
Cell[18290, 654, 71, 1, 27, "Input"],
Cell[18364, 657, 56, 1, 27, "Input"],
Cell[18423, 660, 54, 1, 27, "Input"],
Cell[18480, 663, 82, 1, 27, "Input"],
Cell[18565, 666, 420, 8, 62, "Text",
  Evaluatable->False],
Cell[18988, 676, 52, 1, 27, "Input"],
Cell[19043, 679, 57, 1, 27, "Input"],
Cell[19103, 682, 87, 1, 27, "Input"],
Cell[19193, 685, 80, 1, 27, "Input"],
Cell[19276, 688, 641, 11, 94, "Text",
  Evaluatable->False],
Cell[19920, 701, 149, 5, 30, "Text",
  Evaluatable->False],
Cell[20072, 708, 53, 1, 27, "Input"],
Cell[20128, 711, 60, 1, 27, "Input"],
Cell[20191, 714, 65, 1, 27, "Input"],
Cell[20259, 717, 56, 1, 27, "Input"],
Cell[20318, 720, 79, 1, 27, "Input"],
Cell[20400, 723, 154, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[20591, 734, 162, 3, 46, "Subsection",
  Evaluatable->False],
Cell[20756, 739, 533, 11, 80, "Text",
  Evaluatable->False],
Cell[21292, 752, 69, 1, 27, "Input"],
Cell[21364, 755, 69, 1, 27, "Input"],
Cell[21436, 758, 70, 1, 27, "Input"],
Cell[21509, 761, 70, 1, 27, "Input"],
Cell[21582, 764, 70, 1, 27, "Input"],
Cell[21655, 767, 69, 1, 27, "Input"],
Cell[21727, 770, 70, 1, 27, "Input"],
Cell[21800, 773, 69, 1, 27, "Input"],
Cell[21872, 776, 69, 1, 27, "Input"],
Cell[21944, 779, 648, 11, 94, "Text",
  Evaluatable->False],
Cell[22595, 792, 458, 9, 78, "Text",
  Evaluatable->False],
Cell[23056, 803, 69, 1, 27, "Input"],
Cell[23128, 806, 60, 1, 27, "Input"],
Cell[23191, 809, 70, 1, 27, "Input"],
Cell[23264, 812, 54, 1, 27, "Input"],
Cell[23321, 815, 52, 1, 27, "Input"],
Cell[23376, 818, 57, 1, 27, "Input"],
Cell[23436, 821, 60, 1, 27, "Input"],
Cell[23499, 824, 81, 1, 27, "Input"],
Cell[23583, 827, 62, 1, 27, "Input"],
Cell[23648, 830, 60, 1, 27, "Input"],
Cell[23711, 833, 81, 1, 27, "Input"],
Cell[23795, 836, 58, 1, 27, "Input"],
Cell[23856, 839, 70, 1, 27, "Input"],
Cell[23929, 842, 115, 2, 30, "Text",
  Evaluatable->False],
Cell[24047, 846, 54, 1, 27, "Input"],
Cell[24104, 849, 110, 2, 30, "Text",
  Evaluatable->False],
Cell[24217, 853, 488, 9, 78, "Text",
  Evaluatable->False],
Cell[24708, 864, 61, 1, 27, "Input"],
Cell[24772, 867, 52, 1, 27, "Input"],
Cell[24827, 870, 81, 1, 27, "Input"],
Cell[24911, 873, 59, 1, 27, "Input"],
Cell[24973, 876, 97, 1, 27, "Input"],
Cell[25073, 879, 60, 1, 27, "Input"],
Cell[25136, 882, 59, 1, 27, "Input"],
Cell[25198, 885, 70, 1, 27, "Input"],
Cell[25271, 888, 149, 4, 30, "Text",
  Evaluatable->False],
Cell[25423, 894, 172, 5, 30, "Text",
  Evaluatable->False],
Cell[25598, 901, 52, 1, 27, "Input"],
Cell[25653, 904, 57, 1, 27, "Input"],
Cell[25713, 907, 52, 1, 27, "Input"],
Cell[25768, 910, 64, 1, 27, "Input"],
Cell[25835, 913, 52, 1, 27, "Input"],
Cell[25890, 916, 53, 1, 27, "Input"],
Cell[25946, 919, 56, 1, 27, "Input"],
Cell[26005, 922, 81, 1, 27, "Input"],
Cell[26089, 925, 56, 1, 27, "Input"],
Cell[26148, 928, 72, 1, 27, "Input"],
Cell[26223, 931, 102, 2, 30, "Text",
  Evaluatable->False],
Cell[26328, 935, 82, 1, 27, "Input"],
Cell[26413, 938, 72, 1, 27, "Input"],
Cell[26488, 941, 88, 2, 30, "Text",
  Evaluatable->False],
Cell[26579, 945, 82, 1, 27, "Input"],
Cell[26664, 948, 72, 1, 27, "Input"],
Cell[26739, 951, 205, 4, 46, "Text",
  Evaluatable->False],
Cell[26947, 957, 85, 1, 27, "Input"],
Cell[27035, 960, 60, 1, 27, "Input"],
Cell[27098, 963, 74, 1, 27, "Input"],
Cell[27175, 966, 155, 4, 30, "Text",
  Evaluatable->False],
Cell[27333, 972, 73, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27443, 978, 127, 3, 46, "Subsection",
  Evaluatable->False],
Cell[27573, 983, 263, 7, 48, "Text",
  Evaluatable->False],
Cell[27839, 992, 52, 1, 27, "Input"],
Cell[27894, 995, 53, 1, 27, "Input"],
Cell[27950, 998, 69, 1, 27, "Input"],
Cell[28022, 1001, 69, 1, 27, "Input"],
Cell[28094, 1004, 69, 1, 27, "Input"],
Cell[28166, 1007, 69, 1, 27, "Input"],
Cell[28238, 1010, 604, 11, 94, "Text",
  Evaluatable->False],
Cell[28845, 1023, 59, 1, 27, "Input"],
Cell[28907, 1026, 538, 10, 78, "Text",
  Evaluatable->False],
Cell[29448, 1038, 53, 1, 27, "Input"],
Cell[29504, 1041, 52, 1, 27, "Input"],
Cell[29559, 1044, 57, 1, 27, "Input"],
Cell[29619, 1047, 59, 1, 27, "Input"],
Cell[29681, 1050, 64, 1, 27, "Input"],
Cell[29748, 1053, 81, 1, 27, "Input"],
Cell[29832, 1056, 60, 1, 27, "Input"],
Cell[29895, 1059, 53, 1, 27, "Input"],
Cell[29951, 1062, 70, 1, 27, "Input"],
Cell[30024, 1065, 56, 1, 27, "Input"],
Cell[30083, 1068, 75, 1, 27, "Input"],
Cell[30161, 1071, 75, 1, 27, "Input"],
Cell[30239, 1074, 75, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30351, 1080, 134, 3, 46, "Subsection",
  Evaluatable->False],
Cell[30488, 1085, 515, 9, 78, "Text",
  Evaluatable->False],
Cell[31006, 1096, 70, 1, 27, "Input"],
Cell[31079, 1099, 110, 2, 30, "Text",
  Evaluatable->False],
Cell[31192, 1103, 69, 1, 27, "Input"],
Cell[31264, 1106, 69, 1, 27, "Input"],
Cell[31336, 1109, 174, 4, 30, "Text",
  Evaluatable->False],
Cell[31513, 1115, 70, 1, 27, "Input"],
Cell[31586, 1118, 52, 1, 27, "Input"],
Cell[31641, 1121, 52, 1, 27, "Input"],
Cell[31696, 1124, 57, 1, 27, "Input"],
Cell[31756, 1127, 83, 1, 27, "Input"],
Cell[31842, 1130, 60, 1, 27, "Input"],
Cell[31905, 1133, 63, 1, 27, "Input"],
Cell[31971, 1136, 72, 1, 27, "Input"],
Cell[32046, 1139, 193, 4, 30, "Text",
  Evaluatable->False],
Cell[32242, 1145, 85, 1, 27, "Input"],
Cell[32330, 1148, 73, 1, 27, "Input"],
Cell[32406, 1151, 260, 5, 46, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[32703, 1161, 121, 3, 46, "Subsection",
  Evaluatable->False],
Cell[32827, 1166, 118, 2, 30, "Text",
  Evaluatable->False],
Cell[32948, 1170, 307, 6, 46, "Text",
  Evaluatable->False],
Cell[33258, 1178, 191, 4, 30, "Text",
  Evaluatable->False],
Cell[33452, 1184, 131, 3, 30, "Text",
  Evaluatable->False],
Cell[33586, 1189, 313, 6, 46, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

