(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14892,        556]*)
(*NotebookOutlinePosition[     40039,       1465]*)
(*  CellTagsIndexPosition[     39995,       1461]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 15\
\>", "Title"],

Cell["Graph Labels", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tarrowflag, arrowvec, axlabon, asprat, decdig, imsize, integrate, \
intreset, labon, labshift, parmunits, parmunitsclear, parmval, phaser, \
plotreset, restoresys, savesys, sciflag,  setparm, setstate, slopevec, \
stateunits, stateunitsclear, sysid, sysname, sysreport, timeplot, timeunit, \
timeunitclear, totdig, transol, and unitsclear. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, our sole objective is to illustrate the options for \
graph labels.  Many of these options have been illustrated earlier in other \
tutorials, but it seemed useful to unify the discussion in this tutorial.  We \
use two systems here -- a freely oscillating RLC circuit, and a driven, \
damped linear spring-mass system."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["System Definitions",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "We start with the RLC circuit.  It is a simple series circuit with no \
driving voltage.  The state variables are the current ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and the charge ",
  StyleBox["q",
    FontSlant->"Italic"],
  ".  The parameters are the resistance ",
  StyleBox["R",
    FontSlant->"Italic"],
  ", the inductance ",
  StyleBox["L",
    FontSlant->"Italic"],
  ", and the capacitance ",
  StyleBox["C",
    FontSlant->"Italic"],
  ".  The equations are obtained from Kirchhoff's voltage law.   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["setstate[{i,q}];", "Input",
  AspectRatioFixed->True],

Cell["setparm[{R,L,C}];", "Input",
  AspectRatioFixed->True],

Cell["slopevec = {-(R/L)*i - (1/(L*C))*q,i};", "Input",
  AspectRatioFixed->True],

Cell["sysname = \"RLC\";", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(parmval = {1122.0, \ 503.2, \ 1.981\[Times]10\^\(-5\)};\)\)], "Input"],

Cell[BoxData[
    \(\(stateunits = {"\<amps\>", "\<coulombs\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(parmunits = {"\<ohms\>", "\<henries\>", "\<farads\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(timeunit = "\<s\>";\)\)], "Input"],

Cell[BoxData[
    \(\(savesys[RLC];\)\)], "Input"],

Cell[TextData[{
  "\tNow we define the driven spring-mass system.  The basic equation comes \
from Newton's law applied to a mass attached to a linear spring and a linear \
damper, driven by an oscillating force.  The state variables are the \
displacement x and the velocity v.  The parameters are the mass m, the \
damping constant c, the spring constant k, the force amplitude ",
  StyleBox["F",
    FontSlant->"Italic"],
  ", the force frequency \[Omega], and the force phase \[Phi]."
}], "Text"],

Cell[BoxData[
    \(\(setstate[{x, v}];\)\)], "Input"],

Cell[BoxData[
    \(\(setparm[{m, c, k, F, \[Omega], \[Phi]}];\)\)], "Input"],

Cell[BoxData[
    \(\(slopevec = {v, \(-\((c/m)\)\)*v - \((k/m)\)*x + \((F/m)\)*
              Cos[\[Omega]*t\  + \ \[Phi]]};\)\)], "Input"],

Cell[BoxData[
    \(\(sysname = "\<Oscillator\>";\)\)], "Input"],

Cell[BoxData[
    \(\(parmval = {2.0, 4.0, 105.2, 203.4, 8.2, 0.0};\)\)], "Input"],

Cell[BoxData[
    \(\(stateunits = {"\<m\>", "\<m/s\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(parmunits = {"\<kg\>", "\<N\[CenterDot]s/m\>", "\<N/m\>", "\<N\>", \
\*"\"\<\!\(s\^\(-1\)\)\>\"", "\<\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(timeunit = "\<s\>";\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell[BoxData[
    \(\(savesys[Oscillator];\)\)], "Input"],

Cell["Now we restore our circuit system and check its definition.", "Text"],

Cell[BoxData[
    \(\(restoresys[RLC];\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Axis Label Options Illustrated with RLC System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe generate a basic solution to use in plotting.  We solve the \
initial value problem with an initial current of 2 amps, and a zero initial \
charge.\
\>", "Text"],

Cell[BoxData[
    \(initvec = {2.0, 0.0}; \ t0 = 0.0; h = 0.01; nsteps = 500;\)], "Input"],

Cell[BoxData[
    \(\(sol1 = integrate[initvec, t0, h, nsteps];\)\)], "Input"],

Cell["\<\
We concentrate for now on axes labels, so we turn off the plot \
label by setting \
\>", "Text"],

Cell[BoxData[
    \(\(asprat = \ 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(labon\  = \ False;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["\<\
We see that the units have been added to the axis labels.  This \
occurs automatically for any state variable which has been assigned a unit.  \
If we prefer not to show the units, we can reset the stateunits vector to \
blank and the timeunit to blank:  \
\>", "Text"],

Cell[BoxData[
    \(\(stateunitsclear;\)\)], "Input"],

Cell[BoxData[
    \(\(timeunitclear;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["We restore the units.", "Text"],

Cell[BoxData[
    \(\(stateunits = {"\<amps\>", "\<coulombs\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(timeunit = "\<s\>";\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = \ 1.0;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowflag = True;\)\)], "Input"],

Cell[BoxData[
    \(\(arrowvec = {1/10, 4/7};\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[sol1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Plot Label Options Illustrated with RLC System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tThe basic variable controlling the plot label is labon.  When \
labon = True, the plot label, as defined by DynPac, is shown.  When labon = \
False, no plot label is shown.  When labon = \"anything else\", the label \
shown is \"anything else.\"  The present setting of labon is\
\>", "Text"],

Cell[BoxData[
    \(labon\)], "Input"],

Cell["\<\
and that is why no plot labels have been shown so far.  We set \
labon to true, to get the predefined plot label.\
\>", "Text"],

Cell[BoxData[
    \(\(labon\  = \ True;\)\)], "Input"],

Cell["\<\
We make the image size a little larger to accommodate the rather \
long label in this case.\
\>", "Text"],

Cell[BoxData[
    \(\(imsize\  = \ 420;\)\)], "Input"],

Cell[BoxData[
    \(\(asprat\  = \ 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell[TextData[{
  "Unfortunately we see once again the annoying ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " bug in which the plot label and the axis label coincide.  We also see \
that the number displayed are not satisfactory.  The default display in \
DynPac is a fixed notation rather than scientific.  We can switch to \
scientific by setting sciflag:"
}], "Text"],

Cell[BoxData[
    \(\(sciflag\  = \ True;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["\<\
Now we get better representations of the parameter values for this \
case.  The number of digits displayed to the right of the decimal point is \
controlled by the variable decdig.\
\>", "Text"],

Cell[BoxData[
    \(decdig\)], "Input"],

Cell["The current value is 2.  We reset it to 3 and replot.", "Text"],

Cell[BoxData[
    \(\(decdig\  = \ 3;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["Now we get three digits to the right of the decimal place.  ", "Text"],

Cell["\<\
\tWe can ameliorate somewhat the axeslabel/plotlabel collision by \
inserting spaces between the system name and the parameter values.  The \
number of spaces to be inserted is stored in the variable labshift:\
\>", 
  "Text"],

Cell[BoxData[
    \(\(labshift\  = \ 5;\)\)], "Input"],

Cell[BoxData[
    \(\(imsize\  = \ 480;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["This helps.  ", "Text"],

Cell["\<\
\tSuppose we want a label which just has the value of the \
resistance in it, and suppose we also want a more descriptive name for the \
system.  Here's how we do that.\
\>", "Text"],

Cell[BoxData[
    \(\(labon = 
        SequenceForm["\<RLC Series Circuit With\>", "\< R =\>", 
          PaddedForm[parmval[\([1]\)], {6, 1}], "\< Ohms\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(imsize\  = \ 380;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"],

Cell["Now we return to the default label by setting ", "Text"],

Cell[BoxData[
    \(\(labon\  = \ True;\)\)], "Input"],

Cell["\<\
\tWe can omit the units in the parameter vector, by setting \
parmunits to blanks:\
\>", "Text"],

Cell[BoxData[
    \(\(parmunitsclear;\)\)], "Input"],

Cell["We now reset the inserted blanks to zero:", "Text"],

Cell[BoxData[
    \(\(labshift = 0;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol1, 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"Axes Label Options and transol Illustrated With the Spring Mass System",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tWe do a reset to default integration and plotting parameters, and \
then recall our spring-mass system.\
\>", "Text"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(restoresys[Oscillator];\)\)], "Input"],

Cell["We check to see what we have:", "Text"],

Cell[BoxData[
    \(\(sysreport;\)\)], "Input"],

Cell["\<\
Let's look at an undriven system by setting the force amplitude to \
zero.\
\>", "Text"],

Cell[BoxData[
    \(\(parmval = {2.0, 4.0, 105.2, 0.0, 8.2, 0.0};\)\)], "Input"],

Cell["We integrate the system:", "Text"],

Cell[BoxData[
    \(\(sol2 = integrate[{1, 0}, 0.0, 0.005, 1200];\)\)], "Input"],

Cell["We blank the system name to make our plot label shorter:", "Text"],

Cell[BoxData[
    \(\(sysname = "\<\>";\)\)], "Input"],

Cell[BoxData[
    \(\(asprat = 0.7;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[sol2, 1];\)\)], "Input"],

Cell["\<\
\tNow we will use transol to calculate and plot the energy of this \
oscillator for the solution sol2 already calculated.  The function transol \
takes two arguments.  The first is the solution to be transformed, and the \
second is a list containing one or more expressions in the state variables, \
the parameters and time.  In this case, the function list will have a single \
expression, namely the energy:\
\>", "Text"],

Cell[BoxData[
    \(\(funclist = {\((m*v^2)\)/2\  + \ \((k*x^2)\)/2};\)\)], "Input"],

Cell[BoxData[
    \(\(engsol = transol[sol2, funclist];\)\)], "Input"],

Cell["\<\
Now we plot the energy as a function of time.  First we turn off \
the plot label.\
\>", "Text"],

Cell[BoxData[
    \(\(labon = False;\)\)], "Input"],

Cell["Now we calculate the initial energy:", "Text"],

Cell[BoxData[
    \(evalparm[\((k)\)/2]\)], "Input"],

Cell["We check this against engsol:", "Text"],

Cell[BoxData[
    \(engsol[\([1]\)]\)], "Input"],

Cell["\<\
We plot the energy for the first 3 seconds.   The plot range \
is\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0, 3}, {0, 55}};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[engsol, 1];\)\)], "Input"],

Cell["\<\
We see that the axis labels are wrong, because the defaults are for \
the state variables.  One option is to simply turn the axis labels off.\
\>", 
  "Text"],

Cell[BoxData[
    \(\(axlabon\  = \ False;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[engsol, 1];\)\)], "Input"],

Cell["A better option is to set them to something appropriate:", "Text"],

Cell[BoxData[
    \(\(axlabon = {"\<t (s)\>", \ "\<E (J)\>"};\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[engsol, 1];\)\)], "Input"],

Cell["\<\
The energy dissipation is proportional to the square of the \
velocity, so the plateaus in the above curve mark the times at which the \
oscillator has maximum extension and at which the velocity is zero.\
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exercises",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tPlot the energy versus time for the driven spring mass system for \
several values of the parameters.  In particular, look at the case of a \
lightly damped oscillator driven at the natural frequency.\
\>", "Text"],

Cell["\tPlot the energy versus time for the RLC circuit.", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 436},
WindowMargins->{{1, Automatic}, {Automatic, -4}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@<^_h0000000000c60801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 3, 152, "Title"],
Cell[1796, 56, 80, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1879, 60, 48, 1, 27, "Input"],
Cell[1930, 63, 47, 1, 27, "Input"],
Cell[1980, 66, 46, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2051, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2211, 76, 365, 6, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2613, 87, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2772, 92, 459, 10, 64, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3268, 107, 130, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3401, 112, 642, 22, 66, "Text",
  Evaluatable->False],
Cell[4046, 136, 59, 1, 27, "Input"],
Cell[4108, 139, 60, 1, 27, "Input"],
Cell[4171, 142, 81, 1, 27, "Input"],
Cell[4255, 145, 61, 1, 27, "Input"],
Cell[4319, 148, 92, 1, 31, "Input"],
Cell[4414, 151, 79, 1, 27, "Input"],
Cell[4496, 154, 91, 1, 27, "Input"],
Cell[4590, 157, 56, 1, 27, "Input"],
Cell[4649, 160, 50, 1, 27, "Input"],
Cell[4702, 163, 500, 9, 82, "Text"],
Cell[5205, 174, 54, 1, 27, "Input"],
Cell[5262, 177, 77, 1, 27, "Input"],
Cell[5342, 180, 140, 2, 27, "Input"],
Cell[5485, 184, 64, 1, 27, "Input"],
Cell[5552, 187, 82, 1, 27, "Input"],
Cell[5637, 190, 71, 1, 27, "Input"],
Cell[5711, 193, 143, 2, 31, "Input"],
Cell[5857, 197, 56, 1, 27, "Input"],
Cell[5916, 200, 42, 1, 27, "Input"],
Cell[5961, 203, 57, 1, 27, "Input"],
Cell[6021, 206, 75, 0, 30, "Text"],
Cell[6099, 208, 53, 1, 27, "Input"],
Cell[6155, 211, 42, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6234, 217, 158, 3, 46, "Subsection",
  Evaluatable->False],
Cell[6395, 222, 176, 4, 46, "Text"],
Cell[6574, 228, 90, 1, 27, "Input"],
Cell[6667, 231, 78, 1, 27, "Input"],
Cell[6748, 234, 106, 3, 30, "Text"],
Cell[6857, 239, 52, 1, 27, "Input"],
Cell[6912, 242, 55, 1, 27, "Input"],
Cell[6970, 245, 55, 1, 27, "Input"],
Cell[7028, 248, 279, 5, 46, "Text"],
Cell[7310, 255, 53, 1, 27, "Input"],
Cell[7366, 258, 51, 1, 27, "Input"],
Cell[7420, 261, 55, 1, 27, "Input"],
Cell[7478, 264, 37, 0, 30, "Text"],
Cell[7518, 266, 79, 1, 27, "Input"],
Cell[7600, 269, 56, 1, 27, "Input"],
Cell[7659, 272, 52, 1, 27, "Input"],
Cell[7714, 275, 54, 1, 27, "Input"],
Cell[7771, 278, 60, 1, 27, "Input"],
Cell[7834, 281, 50, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7921, 287, 158, 3, 46, "Subsection",
  Evaluatable->False],
Cell[8082, 292, 304, 5, 62, "Text"],
Cell[8389, 299, 38, 1, 27, "Input"],
Cell[8430, 302, 137, 3, 30, "Text"],
Cell[8570, 307, 54, 1, 27, "Input"],
Cell[8627, 310, 115, 3, 30, "Text"],
Cell[8745, 315, 54, 1, 27, "Input"],
Cell[8802, 318, 54, 1, 27, "Input"],
Cell[8859, 321, 55, 1, 27, "Input"],
Cell[8917, 324, 383, 8, 64, "Text"],
Cell[9303, 334, 56, 1, 27, "Input"],
Cell[9362, 337, 55, 1, 27, "Input"],
Cell[9420, 340, 204, 4, 46, "Text"],
Cell[9627, 346, 39, 1, 27, "Input"],
Cell[9669, 349, 69, 0, 30, "Text"],
Cell[9741, 351, 52, 1, 27, "Input"],
Cell[9796, 354, 55, 1, 27, "Input"],
Cell[9854, 357, 76, 0, 30, "Text"],
Cell[9933, 359, 236, 5, 46, "Text"],
Cell[10172, 366, 54, 1, 27, "Input"],
Cell[10229, 369, 54, 1, 27, "Input"],
Cell[10286, 372, 55, 1, 27, "Input"],
Cell[10344, 375, 29, 0, 30, "Text"],
Cell[10376, 377, 192, 4, 46, "Text"],
Cell[10571, 383, 172, 3, 43, "Input"],
Cell[10746, 388, 54, 1, 27, "Input"],
Cell[10803, 391, 55, 1, 27, "Input"],
Cell[10861, 394, 62, 0, 30, "Text"],
Cell[10926, 396, 54, 1, 27, "Input"],
Cell[10983, 399, 106, 3, 30, "Text"],
Cell[11092, 404, 52, 1, 27, "Input"],
Cell[11147, 407, 57, 0, 30, "Text"],
Cell[11207, 409, 50, 1, 27, "Input"],
Cell[11260, 412, 55, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11352, 418, 183, 4, 46, "Subsection",
  Evaluatable->False],
Cell[11538, 424, 129, 3, 30, "Text"],
Cell[11670, 429, 46, 1, 27, "Input"],
Cell[11719, 432, 47, 1, 27, "Input"],
Cell[11769, 435, 60, 1, 27, "Input"],
Cell[11832, 438, 45, 0, 30, "Text"],
Cell[11880, 440, 47, 1, 27, "Input"],
Cell[11930, 443, 98, 3, 30, "Text"],
Cell[12031, 448, 80, 1, 27, "Input"],
Cell[12114, 451, 40, 0, 30, "Text"],
Cell[12157, 453, 80, 1, 27, "Input"],
Cell[12240, 456, 72, 0, 30, "Text"],
Cell[12315, 458, 54, 1, 27, "Input"],
Cell[12372, 461, 50, 1, 27, "Input"],
Cell[12425, 464, 55, 1, 27, "Input"],
Cell[12483, 467, 434, 7, 78, "Text"],
Cell[12920, 476, 84, 1, 27, "Input"],
Cell[13007, 479, 70, 1, 27, "Input"],
Cell[13080, 482, 106, 3, 30, "Text"],
Cell[13189, 487, 51, 1, 27, "Input"],
Cell[13243, 490, 52, 0, 30, "Text"],
Cell[13298, 492, 52, 1, 27, "Input"],
Cell[13353, 495, 45, 0, 30, "Text"],
Cell[13401, 497, 48, 1, 27, "Input"],
Cell[13452, 500, 89, 3, 30, "Text"],
Cell[13544, 505, 65, 1, 27, "Input"],
Cell[13612, 508, 57, 1, 27, "Input"],
Cell[13672, 511, 168, 4, 46, "Text"],
Cell[13843, 517, 57, 1, 27, "Input"],
Cell[13903, 520, 57, 1, 27, "Input"],
Cell[13963, 523, 72, 0, 30, "Text"],
Cell[14038, 525, 76, 1, 27, "Input"],
Cell[14117, 528, 57, 1, 27, "Input"],
Cell[14177, 531, 231, 5, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14445, 541, 121, 3, 46, "Subsection",
  Evaluatable->False],
Cell[14569, 546, 226, 4, 46, "Text"],
Cell[14798, 552, 66, 0, 30, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

