(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35999,       1254]*)
(*NotebookOutlinePosition[     61146,       2163]*)
(*  CellTagsIndexPosition[     61102,       2159]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
DYNAMICAL SYSTEMS
Tutorial 17\
\>", "Title"],

Cell["Iterated Maps", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sysid", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(plotreset;\)\)], "Input"],

Cell[BoxData[
    \(\(intreset;\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Functions and Variables Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tasprat, bifurcmap, bifurc3Dmap, bimap, boxrat, classifymap, \
cobweb,  eigsysmap, eigvalmap, findpolyfix, imsize, intreset, iterate, jacob, \
jacobval, mapcomp, mapval, nfindfix, nfindpolyfix, parmval, periodmap, \
phaser, phaser3D, plotreset, plrange, plrange3D, pointcon, portraitmap, \
portrait3Dmap, ptsize, rangeflag, ranger, residualfix, setback, setcolor, \
setmap, setde, setparm, setstate, slopevec, stripsol, sysid, sysreport, \
timeplot, and viewmap.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description of Systems Used in This Tutorial",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "In this tutorial, our objective is to illustrate the use of the functions \
defined for iterated mappings.  For examples, we will use the logistic map \
for a 1D case, the Henon map for a 2D case, and a combination of the two for \
a 3D case.  In many cases, it is useful to apply some of the functions \
directly to iterates of the map.  For example, if we are studying a map f[x], \
then one way of finding orbits of period two is to look for fixed points of \
f[f[x]].  Most of the functions used in DynPac for mappings allow an optional \
final argument which is the level of composition desired.  We will see a \
number of examples of this below.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Logistic Map",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe logistic map is discussed in many references.  A very complete and \
readable discussion is given in Chapter 10 of ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontWeight->"Bold"],
  " by Steven Strogatz, Addison-Wesley, 1994.  Many of the interesting \
properties of the map were discovered by the mathematical biologist Robert \
May (\"Simple Mathematical Models with Very Complicated Dynamics,\" Nature ",
  StyleBox["261",
    FontWeight->"Bold"],
  ", 459, 1976.)  ",
  "The basic form of the map is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\)\)]],
  " =  ",
  StyleBox["r",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "(1 - ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  ")  ."
}], "Text",
  TextAlignment->Center],

Cell[TextData[{
  "As is well-known this map exhibits a wide and interesting range of \
behavior as ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "is varied.  We define the system for DynPac, starting by the setmap \
command. "
}], "Text"],

Cell[BoxData[
    \(\(setmap;\)\)], "Input"],

Cell[BoxData[
    \(setstate[{x}]; setparm[{r}]; parmval = {3.2}; 
    slopevec = {r*x*\((1 - x)\)};\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
\tWe could use this same function as the slope for a differential \
equation.  The command set de switches back to differential equation mode.  \
The primary difference in the two modes is the actual stepping algorithm used \
in constructing solutions -- a Runge-Kutta step for a differential equation, \
and a map iteration for the mapping.  It is only at that basic level of code \
that the two modes differ.\
\>", "Text"],

Cell[BoxData[
    \(\(setde;\)\)], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["We return to the map setting.", "Text"],

Cell[BoxData[
    \(\(setmap;\)\)], "Input"],

Cell["We start by viewing the map.", "Text"],

Cell[BoxData[
    \(\(viewmap[];\)\)], "Input"],

Cell["\<\
The picture suggests that there are two fixed points -- one at 0 \
and one between 0.6 and 0.8.  We find these.  Because the mapping is a \
polynomial, we can use findpolyfix or nfindpolyfix.  We can also use the more \
general nfindfix, which requires an initial guess.\
\>", "Text"],

Cell[BoxData[
    \(findpolyfix[]\)], "Input"],

Cell["\<\
This gives the answer in terms of the parameter r.  To find \
numerical values we can use nfindpolyfix or nfindfix:\
\>", "Text"],

Cell[BoxData[
    \(nfindpolyfix[]\)], "Input"],

Cell[BoxData[
    \(nfindfix[0.5]\)], "Input"],

Cell["\<\
\tWe can check the accuracy of the fixed point by finding the \
residual with residualfix.\
\>", "Text"],

Cell[BoxData[
    \(residualfix[{0.6875}]\)], "Input"],

Cell["Alternatively, we can evaluate the map at the fixed point.", "Text"],

Cell[BoxData[
    \(mapval[{0.6875}]\)], "Input"],

Cell["We check the stability of these two fixed points.", "Text"],

Cell[BoxData[
    \(classifymap[{0}]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.6875}]\)], "Input"],

Cell["\<\
Thus both of the fixed points are unstable.  This could also be \
determined by the eigenvalues at those points.  Any eigenvalue greater than \
one in magnitude indicates instability.\
\>", "Text"],

Cell[BoxData[
    \(eigvalmap[{0}]\)], "Input"],

Cell[BoxData[
    \(eigvalmap[{0.6875}]\)], "Input"],

Cell[TextData[{
  "\tAs neither fixed point is stable for this value of ",
  StyleBox["r",
    FontSlant->"Italic"],
  ", there might be a periodic orbit.  Let's perform a short iteration with a \
more or less arbitrary intial condition of 0.23.  We ask for 20 iterates with \
none thrown away."
}], "Text"],

Cell[BoxData[
    \(sol1 = iterate[0.23, 0.0, 20, 0]\)], "Input"],

Cell["\<\
The answer is in the form of a list pairs, with the first element \
in each pair being the time coordinate, the second the iterate value.  All of \
the functions in DynPac expect solution lists in this form.  If it is desired \
to form a list without the time coordinate, this can be accomplished by the \
function stripsol[sol,n], which removes the nth state variable from the list. \
 The time coordinate is associated with n = 0.  We try this.\
\>", "Text"],

Cell[BoxData[
    \(stripsol[sol1, 0]\)], "Input"],

Cell["\<\
It is clear from the solution list that we have an orbit of period \
2.  DynPac can tell us this also.\
\>", "Text"],

Cell[BoxData[
    \(periodmap[sol1]\)], "Input"],

Cell["\<\
Another approach to finding this periodic orbit is to consider the \
fixed points of the first iterated mapping.  First we graph it.\
\>", "Text"],

Cell[BoxData[
    \(\(viewmap[2];\)\)], "Input"],

Cell["\<\
We see four fixed points.  Of course two will be the fixed points \
of the original map, but the other two should be the points on the period-two \
orbit of the original map.  We check this.\
\>", "Text"],

Cell[BoxData[
    \(nfindpolyfix[2]\)], "Input"],

Cell["\<\
We see the same two values that showed up explicitly in the orbit \
calculated above.  We check the stability of the period two orbit by checking \
the stability of these as fixed points of the second iterated mapping.\
\>", \
"Text"],

Cell[BoxData[
    \(classifymap[{0.513045}, 2]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.799455}, 2]\)], "Input"],

Cell["Thus the period two orbit is stable.  ", "Text"],

Cell["\<\
\tThe last few function evaluations have provided examples of \
applying functions to higher compositions of the map -- in this case the \
second composition.  It is the optional last argument 2 that causes this.  We \
haven't yet looked explicitly at the second composition, although we can do \
that easily with mapcomp[n], which returns the nth composition.\
\>", "Text"],

Cell[BoxData[
    \(mapcomp[2]\)], "Input"],

Cell["\<\
\tNow we look at something new.  We construct a cobweb plot to show \
the approach to the stable orbit of period 2.  The function to do this is \
cobweb[initval,niter,ntoss], where initval is the starting point for the \
iteration, niter is the number of iterations to plot, and ntoss is the the \
number to calculate and throw away first (to eliminate transients).  We start \
with an initial condition 0.23, and we ask for 100 iterations, throwing none \
away before plotting.\
\>", "Text"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 100, 0];\)\)], "Input"],

Cell["\<\
We see the eventual approach to the orbit.  We can get the pure \
orbit by throwing away the transients.  We perform the same calculation, only \
now throwing away 100 points first.  \
\>", "Text"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 100, 100];\)\)], "Input"],

Cell["Now we get the pure orbit.  ", "Text"],

Cell[TextData[{
  "\tLet's increase the value of ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "to 3.5, and carry out a short iteration."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {3.5};\)\)], "Input"],

Cell[BoxData[
    \(sol2 = iterate[{0.23}, 0.0, 30, 0]\)], "Input"],

Cell["\<\
A close inspection shows an orbit of period 4.  We verify \
that.\
\>", "Text"],

Cell[BoxData[
    \(periodmap[sol2]\)], "Input"],

Cell["\<\
The points on the 4-orbit should be fixed points of the fourth \
composition of the map.\
\>", "Text"],

Cell[BoxData[
    \(nfindpolyfix[4]\)], "Input"],

Cell["\<\
We find lots of roots.  In the interpretation, it helps to look \
also at the fixed points of the basic mapping and the mapping iterated \
once.\
\>", "Text"],

Cell[BoxData[
    \(nfindpolyfix[2]\)], "Input"],

Cell[BoxData[
    \(nfindpolyfix[]\)], "Input"],

Cell["\<\
By comparing these, we conclude that (1) the basic map has fixed \
points\
\>", "Text"],

Cell[BoxData[
    \(f11 = 0.0; f12 = 0.714286;\)], "Input"],

Cell["\<\
(2) the second composition has in addition a period two orbit\
\>", \
"Text"],

Cell[BoxData[
    \(f21 = 0.428571; f22 = 0.857143;\)], "Input"],

Cell["and (3) the fourth composition has a period four orbit", "Text"],

Cell[BoxData[
    \(f41 = 0.38282; f42 = 0.500884; f43 = 0.826941; 
    f44 = 0.874997;\)], "Input"],

Cell[TextData[{
  "Thus for ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 3.5, the map has two fixed points, a period two orbit and a period four \
orbit.  Yet all we saw in the iteration was the period four orbit.  This \
strongly suggests that it is the only stable attractor.  We check the \
stability of all of these now."
}], "Text"],

Cell[BoxData[
    \(classifymap[{f11}]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f12}]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f21}, 2]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f22}, 2]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f41}, 4]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f42}, 4]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f43}, 4]\)], "Input"],

Cell[BoxData[
    \(classifymap[{f44}, 4]\)], "Input"],

Cell["\tLet's look at a cobweb of this stable period four orbit.", "Text"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 100, 0];\)\)], "Input"],

Cell["Now we look at the pure orbit.", "Text"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 100, 100];\)\)], "Input"],

Cell[TextData[{
  "\tWe increase ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "again, this time to 3.7."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {3.7};\)\)], "Input"],

Cell[BoxData[
    \(sol3 = iterate[{0.23}, 0, 100, 0]\)], "Input"],

Cell["\<\
Now there is no obvious repetition.  We check it for periodicity \
anyway.\
\>", "Text"],

Cell[BoxData[
    \(periodmap[sol3]\)], "Input"],

Cell["Are there fixed points?", "Text"],

Cell[BoxData[
    \(nfindpolyfix[]\)], "Input"],

Cell[BoxData[
    \(nfindpolyfix[2]\)], "Input"],

Cell[BoxData[
    \(nfindpolyfix[4]\)], "Input"],

Cell[TextData[{
  "There are two fixed points, a period two orbit and a period four orbit.  \
Presumably they are all unstable, since they don't show up in our iteration.  \
Are there orbits of higher period?  If we try nfindpolyfix[8], ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " goes away for a very long time and returns with a large list of roots, \
mostly complex, and missing most of the real roots that we already know from \
above.  Let's look at the stability of the orbits we have found.  It is \
sufficient to check just one point on each orbit if that one point is \
unstable."
}], "Text"],

Cell[BoxData[
    \(classifymap[{0}]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.72973}]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.390022}, 2]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.321626}, 4]\)], "Input"],

Cell[TextData[{
  "\tIf this system with ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 3.7 has a stable attractor, we haven't found it yet.  We try a cobweb \
plot."
}], "Text"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 200, 0];\)\)], "Input"],

Cell["\<\
This could be chaotic.  Let's do a fancy cobweb plot now with \
color, showing the sensitive dependence on initial conditions.  We take 26 \
initial points in the range [0.20,0.25], and we assign a gradually varying \
color from red to blue.  First we construct the color list.  \
\>", "Text"],

Cell[BoxData[
    \(\(collist = 
        Table[RGBColor[\((1 - i)\), 0, i], {i, 0, 1, 0.04}];\)\)], "Input"],

Cell[BoxData[
    \(\(setcolor[collist];\)\)], "Input"],

Cell["Now we construct a list of initial conditions.", "Text"],

Cell[BoxData[
    \(\(initvec = Table[0.2\  + \ i, {i, 0, 0.05, 0.002}];\)\)], "Input"],

Cell["Now we construct the cobweb plot.", "Text"],

Cell[BoxData[
    \(plrange = {{0, 1}, {0, 1}}; asprat = 1;\)], "Input"],

Cell[BoxData[
    \(\(cobweb[initvec, 6, 0];\)\)], "Input"],

Cell[TextData[{
  "\tWe can also make a plot of ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "versus time by using timeplot.  We construct a solution with 50 iterates \
and then plot it as a function of time."
}], "Text"],

Cell[BoxData[
    \(plrange = {{0, 50}, {0, 1}}; asprat = 0.7; 
    setcolor[{Black}];\)], "Input"],

Cell[BoxData[
    \(\(soltime = iterate[{0.23}, 0, 50, 0];\)\)], "Input"],

Cell[BoxData[
    \(\(pointcon = True;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[soltime, 1];\)\)], "Input"],

Cell[BoxData[
    \(pointcon = False; plrange = {{0, 1}, {0, 1}};\)], "Input"],

Cell[TextData[{
  "\tBoth the time plot and the cobweb plot show the chaotic nature of this \
orbit.  In particular the cobweb plot shows clearly the spread of an \
initially compact set of initial conditions.",
  StyleBox["  ",
    FontSlant->"Italic"],
  "We can get an overview of the behavior of the system with a bifurcation \
diagram.  This produces a graph in which the abcissa is the parameter being \
varied, and along the ordinate, the iterates are plotted.  If we throw away \
initial transients, the result is a plot of the attractor of the system as a \
function of the parameter.  The function which does this is "
}], "Text"],

Cell["\<\
bimap[npts,ntoss,nparm,xname,xrange,initvec,pname,prange,ncomp].  \
\
\>", "Text",
  TextAlignment->Center],

Cell[TextData[{
  "The arguments are npts, the number of iterates plotted at each parameter \
value npts and ntoss, the number of transient iterates thrown away before \
plotting.  The number of parameter values plotted is nparm.  The name of the \
state variable plotted is xname, and its plotting range is xrange.  The \
initial condition for the iteration is initvec, which may contain parameter \
symbols.  The name of the parameter being varied is pname, and it is varied \
through the range prange.  The final argument ncomp is optional and specifies \
the level of function composition of the basic map.  Generally for the \
logistic map about 200 iterates have to be thrown away to get good results, \
and about 100 to 200 iterates have to be plotted, at about 100 to 200 \
parameter values.  We carry this out for ",
  StyleBox["r",
    FontSlant->"Italic"],
  " in the range 2.8 to 4.  We ask for a larger image size, for a background \
color of Wheat, and points plotted in Blue. "
}], "Text"],

Cell[BoxData[
    \(setback[Wheat]; imsize = 400; setcolor[{Blue}];\)], "Input"],

Cell[BoxData[
    \(ptsize = 0.002; asprat = 0.7;\)], "Input"],

Cell[BoxData[
    \(\(\(biout = 
        bimap[200, 200, 200, x, {0, 1}, {0.23}, 
          r, {2.8, 4.0}];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "We see clearly the bifurcation from a stable fixed point to a stable orbit \
of period 2 at ",
  StyleBox["r",
    FontSlant->"Italic"],
  " = 3, and  then the bifurcation from period two to period four at ",
  StyleBox["r",
    FontSlant->"Italic"],
  " between 3.4 and 3.5.  The further period doublings occur at decreasing \
increments in r, and the orbit becomes chaotic for ",
  StyleBox["r",
    FontSlant->"Italic"],
  " \[TildeTilde] 3.57.  Note the intriguing window just beyond 3.8.  Let's \
explore this briefly.  We set ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "to 3.83.  We iterate and throw away 100 initial points in an effort to get \
rid of the transients."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {3.83};\)\)], "Input"],

Cell[BoxData[
    \(sol4 = iterate[{0.23}, 0, 30, 100]\)], "Input"],

Cell["A surprising result -- a period 3 orbit! ", "Text"],

Cell[BoxData[
    \(periodmap[sol4]\)], "Input"],

Cell["\<\
Because we saw it, it surely is stable, but we can check \
that.\
\>", "Text"],

Cell[BoxData[
    \(classifymap[{0.504666}, 3]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.957414}, 3]\)], "Input"],

Cell[BoxData[
    \(classifymap[{0.156149}, 3]\)], "Input"],

Cell["Let's look at the cobweb plot for this.", "Text"],

Cell[BoxData[
    \(\(asprat = 1;\)\)], "Input"],

Cell[BoxData[
    \(\(plrange = {{0, 1}, {0, 1}};\)\)], "Input"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 50, 0];\)\)], "Input"],

Cell["\<\
Now we throw away the transients and look at the periodic \
orbit.\
\>", "Text"],

Cell[BoxData[
    \(\(cobweb[{0.23}, 15, 100];\)\)], "Input"],

Cell["We look at the third iterated mapping.", "Text"],

Cell[BoxData[
    \(\(viewmap[3];\)\)], "Input"],

Cell[BoxData[
    \(nfindpolyfix[1]\)], "Input"],

Cell[BoxData[
    \(nfindpolyfix[3]\)], "Input"],

Cell["\<\
The third iterated map has 8 fixed points.  Two of these are \
unstable fixed points of the basic map.  The other six turn out to be the \
components of two period 3 orbits, one stable and one unstable.  From the \
iteration carried out above, we know that the components of the stable orbit \
are 0.156149, 0.504666, and 0.957417.  The unstable period 3 orbit then is \
{0.16357, 0.524001, and 0.955294}.  Let's start on this orbit and iterate, \
and see what happens.\
\>", "Text"],

Cell[BoxData[
    \(sol6 = iterate[{0.16357}, 0.0, 100, 0]\)], "Input"],

Cell["\<\
Although it isn't very strongly unstable, we can see that it is \
drifting off the orbit.  Here's a longer run.\
\>", "Text"],

Cell[BoxData[
    \(\(sol7 = iterate[{0.16357}, 0.0, 1000, 0];\)\)], "Input"],

Cell[BoxData[
    \(lastx\)], "Input"],

Cell["\<\
Thus after a 1000 steps starting on the unstable period 3 orbit, we \
end up on the stable period 3 orbit.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["H\[EAcute]non Map",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe H\[EAcute]non map is a two-dimensional map  developed by Michel H\
\[EAcute]non to study chaos and strange attractors (\"A Two-Dimensional \
Mapping with a Strange Attractor,\" Commun. Math. Phys. ",
  StyleBox["50",
    FontWeight->"Bold"],
  ", 69, 1976)",
  ".  It is discussed in many books on dynamical systems -- for example in \
section 12.2 of ",
  StyleBox["Nonlinear Dynamics and Chaos",
    FontWeight->"Bold"],
  " by Steven Strogatz, Addison-Wesley, 1994.  ",
  "The H\[EAcute]non mapping provides a computationally straightforward way \
to study the complexities of chaos.  The mapping has two parameters ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  ".  It is given by",
  "  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`y\_n\)]],
  " + 1 - ",
  StyleBox["a",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\%2\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n + 1\)\)]],
  " =  ",
  StyleBox["b",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  "  ."
}], "Text",
  TextAlignment->Center],

Cell["We define the system for DynPac.", "Text"],

Cell[BoxData[{
    \(setstate[{x, y}]; setparm[{a, b}]; sysname = "\<Henon\>"; 
    setmap;\), "\[IndentingNewLine]", 
    \(slopevec = {y + 1 - a\ x\^2, b\ x}; parmval = {1.4, 0.3};\)}], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
These parameter values were found by H\[EAcute]non to produce a \
chaotic attractor.\
\>", "Text"],

Cell["\tWe begin by calculating the Jacobian of the map.", "Text"],

Cell[BoxData[
    \(jacob\)], "Input"],

Cell[BoxData[
    \(jacobval\)], "Input"],

Cell[TextData[{
  "Thus the map will be dissipative (giving contracting areas in phase space) \
when \[VerticalSeparator]",
  StyleBox["b",
    FontSlant->"Italic"],
  "\[VerticalSeparator] < 1. We construct a ",
  StyleBox["very",
    FontWeight->"Bold"],
  " lengthy iteration -- 50000 points.  We throw away the first 100 points.  \
One reason for calculating so many points is that we plan to zoom in on the \
structure of the attractor produced.  Notice how much quicker this is than \
solving a differential equation  for the same number of time steps.   "
}], "Text"],

Cell[BoxData[
    \(\(solhen = iterate[{0, 0}, 0.0, 50000, 100];\)\)], "Input"],

Cell["We use staterange to determine a suitable plotting window.", "Text"],

Cell[BoxData[
    \(staterange[solhen]\)], "Input"],

Cell[BoxData[
    \(plrange = {{\(-1.5\), 1.5}, {\(-0.5\), 0.5}}; axon = False; 
    frameon = True; asprat = 0.7;\)], "Input"],

Cell[BoxData[
    \(\(hengraph1 = phaser[solhen];\)\)], "Input"],

Cell["\<\
This graph shows the chaotic attractor for the map.  There is an \
incredible fine structure which does not show up on this scale.  We zoom in \
by choosing a plotting window near the point {0.5, 0.2}.  In this zoom \
process, we follow closely the presentation in Strogatz' book of \
H\[EAcute]non's work.  We define a graphics zoombox that will put a box on a \
graph to show the window used in the following graph.\
\>", "Text"],

Cell[BoxData[
    \(zoombox[rng_] := 
      Graphics[{GrayLevel[0.7], Rectangle[First[rng], Last[rng]]}, 
        DisplayFunction -> Identity]\)], "Input"],

Cell[BoxData[
    \(\(show[zoombox[{{0.54, 0.15}, {0.71, 0.21}}], hengraph1];\)\)], "Input"],

Cell["\<\
The grey rectangle is the entire window for the next zoomed \
graph.\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0.54, 0.71}, {0.15, 0.21}};\)\)], "Input"],

Cell[BoxData[
    \(\(hengraph2 = phaser[solhen];\)\)], "Input"],

Cell["We zoom in once again. ", "Text"],

Cell[BoxData[
    \(\(show[zoombox[{{0.62, 0.185}, {0.64, 0.191}}], 
        hengraph2];\)\)], "Input"],

Cell["\<\
Once again, the grey rectangle is the window for the next (and \
last) plot.\
\>", "Text"],

Cell[BoxData[
    \(\(plrange = {{0.62, 0.64}, {0.185, 0.191}};\)\)], "Input"],

Cell[BoxData[
    \(\(phaser[solhen];\)\)], "Input"],

Cell["\<\
The unfolding of structure is amazing.  In each case what appears \
to be three lines, becomes, when viewed more closesly, a set of 6 lines, \
grouped as three, two and one.  The fractal nature of the attractor is such \
that this unfolding continues forever.  Of course whether or not we see it in \
our graphs depends on how many iterates we have calculated.  With our 50000 \
points we can't go much further than we have here.    \
\>", "Text"],

Cell["\<\
\tWe can explore the sensitive dependence on initial position by \
looking at two orbits starting close together.  We use red and blue for the \
orbit colors, and we carry out the construction using the function \
portraitmap.  W throw away the first 100 iterations.\
\>", "Text"],

Cell[BoxData[
    \(\(setcolor[{Red, Blue}];\)\)], "Input"],

Cell[BoxData[
    \(ptsize = 0.008; 
    plrange = {{\(-1.5\), 1.5}, {\(-0.5\), 0.5}};\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["portraitmap",
          FontWeight->"Bold"], "[", \({{0, 0}, {0.01, 0.01}}, 0.0, 1000, 100, 
        1, 2\), "]"}], ";"}]], "Input"],

Cell["\<\
We can see from the colors that both orbits are spread over the \
attractor.  We can also see the sensitive dependence from a time plot.\
\>", \
"Text"],

Cell[BoxData[
    \(\(plrange = {{0, 50}, {\(-1.52\), 1.52}};\)\)], "Input"],

Cell[BoxData[
    \(\(solt1 = iterate[{0, 0}, 0.0, 50, 0];\)\)], "Input"],

Cell[BoxData[
    \(\(solt2 = iterate[{0.01, 0.01}, 0.0, 50, 0];\)\)], "Input"],

Cell[BoxData[
    \(\(pointcon = True;\)\)], "Input"],

Cell[BoxData[
    \(\(timeplot[{solt1, solt2}, 1];\)\)], "Input"],

Cell[BoxData[
    \(plrange = {{\(-1.5\), 1.5}, {\(-0.5\), 0.5}}; 
    pointcon = False;\)], "Input"],

Cell[TextData[{
  "\tIt is of interest to see how the iterates of the H\[EAcute]non map \
depend on the parameter ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  We leave ",
  StyleBox["b",
    FontSlant->"Italic"],
  " fixed and vary ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "through 5 values, constructing a phase plot for each value.  We accomplish \
this in an automated way by using the function \
bifurcmap[intlist,t0,niter,ntoss,i,j,parmlist,ncomp].  The argument intlist \
is the list of initial conditions to be used in each graph.  In this case, we \
use only one initial condition.  The initial time is t0 and the number of \
interations is niter, with ntoss being thrown away first.  The components  ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  " are to be plotted.  The list of parameter values to be used is in \
parmlist.  The final argument ncomp is optional.  It is the level of function \
composition to be used with the basic map, and the default is 1."
}], "Text"],

Cell[BoxData[
    \(\(parmlist = {{0.4, 0.3}, {0.6, 0.3}, {0.8, 0.3}, {1.0, 0.3}, {1.2, 
            0.3}, {1.4, 0.3}};\)\)], "Input"],

Cell[BoxData[
    \(ptsize = 0.008; setcolor[{Black}];\)], "Input"],

Cell[BoxData[
    \(\(bifurcmap[{{0, 0}}, 0.0, 1000, 100, 1, 2, parmlist];\)\)], "Input"],

Cell[TextData[{
  "An interesting sequence.  Looks like stable period two orbits for ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 0.4, 0.6, and 0.8, followed by a period four orbit for ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 1.0, and then chaotic orbits for ",
  StyleBox["a",
    FontSlant->"Italic"],
  " = 1.2 and 1.4.  Let's look in more detail at the period four orbit."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {1.0, 0.3};\)\)], "Input"],

Cell[BoxData[
    \(henfour = iterate[{0, 0}, 0.0, 20, 200]\)], "Input"],

Cell["Clearly period 4, as DynPac also tells us:", "Text"],

Cell[BoxData[
    \(periodmap[henfour]\)], "Input"],

Cell["We name the four points of the orbit.", "Text"],

Cell[BoxData[
    \(pt1 = Drop[First[henfour], 1]\)], "Input"],

Cell[BoxData[
    \(pt2 = Drop[henfour[\([2]\)], 1]\)], "Input"],

Cell[BoxData[
    \(pt3 = Drop[henfour[\([3]\)], 1]\)], "Input"],

Cell[BoxData[
    \(pt4 = Drop[henfour[\([4]\)], 1]\)], "Input"],

Cell["We check by hand the orbit.", "Text"],

Cell[BoxData[
    \(mapval[pt1]\)], "Input"],

Cell[BoxData[
    \(mapval[pt2]\)], "Input"],

Cell[BoxData[
    \(mapval[pt3]\)], "Input"],

Cell[BoxData[
    \(mapval[pt4]\)], "Input"],

Cell["\<\
From the calculation above, It is clear that the orbit is stable, \
but we check one point on it anyway.\
\>", "Text"],

Cell[BoxData[
    \(classifymap[pt1, 4]\)], "Input"],

Cell[BoxData[
    \(eigvalmap[pt1, 4]\)], "Input"],

Cell[BoxData[
    \(eigsysmap[pt1, 4]\)], "Input"],

Cell[TextData[{
  "From what we have found, it appears that the H\[EAcute]non map goes \
through a period-doubling sequence to chaos.  We construct a view of this \
with a bifurcation diagram, varying ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "from 0.2 to 1.4, and plotting x versus a.  We throw away the first 300 \
points and then plot 200, for each of 200 values of the parameter.    "
}], "Text"],

Cell[BoxData[
    \(asprat = 0.7; ptsize = 0.002;\)], "Input"],

Cell[BoxData[
    \(\(setcolor[{Blue}];\)\)], "Input"],

Cell[BoxData[
    \(\(biouthen = 
        bimap[200, 300, 200, x, {\(-1.5\), 1.5}, {0, 0}, 
          a, {0.4, 1.4}];\)\)], "Input"],

Cell["\<\
This diagram suggests lots of other things to explore later, but we \
leave it for now.\
\>", "Text"],

Cell["\<\
\tOne final point on the H\[EAcute]non map.  Not all of the \
solutions are bounded.  For some initial conditions and some parameter \
values, the iterates run off to infinity.  We explore this briefly.\
\>", \
"Text"],

Cell[BoxData[
    \(\(parmval = {1.7, 0.3};\)\)], "Input"],

Cell[BoxData[
    \(iterate[{1, 1}, 0.0, 20, 0]\)], "Input"],

Cell["\<\
This is clearly heading for an overflow!  To prevent overflows and \
possible crashes, we can use range checking, in which we specify a box (named \
ranger) to contain the solution.  The iteration is stopped as soon as the \
solution leaves the box.  To turn on range checking, we set rangeflag = True.\
\
\>", "Text"],

Cell[BoxData[
    \(rangeflag = True; 
    ranger = {{\(-1000\), 1000}, {\(-1000\), 1000}};\)], "Input"],

Cell[BoxData[
    \(iterate[{1, 1}, 0.0, 20, 0]\)], "Input"],

Cell["\<\
We see that the iteration was stopped when a solution point first \
left the box.  The last point inside the box is stored in the variable \
outbound. \
\>", "Text"],

Cell[BoxData[
    \(outbound\)], "Input"],

Cell[BoxData[
    \(\(rangeflag = False;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A Three-Dimensional Map",
  FontWeight->"Bold"]], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\tMost published work on iterated maps deals with one- and \
two-dimensional maps.  Such maps can exhibit the full range of complexities, \
unlike the situation with sets of autonomous differential equations where \
dimension three is the minimum dimension for chaos.  All of this is by way of \
saying that there is no natural or well-studied example to use here.  In \
order to illustrate some of the 3D plotting features for maps, we define a \
somewhat artificial 3D map consisting of the logistic map in one dimension \
and the H\[EAcute]non map in the other two.  The mapping is defined by   \
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\_\(n + 1\)\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`y\_n\)]],
  " + 1 - ",
  StyleBox["a",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\%2\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(n + 1\)\)]],
  " =  ",
  StyleBox["b",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`z\_\(n + 1\)\)]],
  "=",
  StyleBox["r",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  "(1 - ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  ")  ."
}], "Text",
  TextAlignment->Center],

Cell["We define this system for Dynpac.", "Text"],

Cell[BoxData[{
    \(setstate[{x, y, z}]; setparm[{a, b, r}]; \ sysname = "\<Hybrid\>"; 
    parmval = {0.8, 0.3, 2.8};\), "\[IndentingNewLine]", 
    \(slopevec = {y\  + \ 1\  - \ a\ x\^2, \ b\ x, \ r\ z\ \((1\  - \ z)\)}; 
    setmap;\)}], "Input"],

Cell[BoxData[
    \(sysreport\)], "Input"],

Cell["\<\
On the basis of work done earlier, we expect for the present \
parameter values to get an orbit of period 2, in which z is stationary.  \
Let's try it.\
\>", "Text"],

Cell[BoxData[
    \(solhy1 = iterate[{0, 0, 0.5}, 0.0, 75, 0]\)], "Input"],

Cell[BoxData[
    \(periodmap[solhy1]\)], "Input"],

Cell["Let's plot the approach to this in 3D.", "Text"],

Cell[BoxData[
    \(plotreset; pointcon = False; boxrat = {1, 1, 1}; ptsize = 0.01; 
    plrange3D = {{\(-1.5\), 1.5}, {\(-0.5\), 0.5}, {0, 1}};\)], "Input"],

Cell[BoxData[
    \(\(phaser3D[solhy1];\)\)], "Input"],

Cell["A projection on the xy plane:", "Text"],

Cell[BoxData[
    \(frameon = True; asprat = 1; axon = False;\)], "Input"],

Cell[BoxData[
    \(\(phaseplot[solhy1, 1, 2];\)\)], "Input"],

Cell["\<\
To get the pure orbit, we iterate again, this time throwing away \
the first 100 iterates.\
\>", "Text"],

Cell[BoxData[
    \(\(solhy2 = iterate[{0, 0, 0.5}, 0.0, 20, 100];\)\)], "Input"],

Cell[BoxData[
    \(periodmap[solhy2]\)], "Input"],

Cell[BoxData[
    \(\(phaseplot[solhy2, 1, 2];\)\)], "Input"],

Cell[TextData[{
  "We see the two points of the orbit in diagonally opposite corners.  Now we \
try a portrait in 3D with several different initial conditions.  We also \
change ",
  StyleBox["a ",
    FontSlant->"Italic"],
  "so that the H\[EAcute]non map is chaotic."
}], "Text"],

Cell[BoxData[
    \(\(parmval = {1.4, 0.3, 2.8};\)\)], "Input"],

Cell[BoxData[
    \(plotreset; ptsize = 0.008; pointcon = False; boxrat = {1, 1, 1}; 
    setcolor[{Red, Blue}]; 
    plrange3D = {{\(-1.5\), 1.5}, {\(-0.5\), 0.5}, {0, 1}};\)], "Input"],

Cell[BoxData[
    \(\(portrait3Dmap[{{0, 0, 0.5}, {0.01, 0.01, 0.5}}, 0.0, 1000, 100, 1, 2, 
        3];\)\)], "Input"],

Cell[TextData[{
  "\tFinally we will do a short bifurcation sequence, letting both ",
  StyleBox["r ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["a",
    FontSlant->"Italic"],
  " vary, using the command bifurc3Dmap."
}], "Text"],

Cell[BoxData[
    \(\(setback[Wheat];\)\)], "Input"],

Cell[BoxData[
    \(\(parmlist = {{1.0, 0.3, 2.8}, {1.2, 0.3, 3.5}, {1.4, 0.3, 
            3.7}};\)\)], "Input"],

Cell[BoxData[
    \(\(bifurc3Dmap[{{0, 0, 0.23}, {0.01, 0.01, 0.25}}, 0.0, 2000, 200, 1, 2, 
        3, parmlist];\)\)], "Input"],

Cell["\<\
\tThis last graph shows a kind of double chaos, and perhaps that is \
as good a place to quit as any.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{786, 663},
WindowMargins->{{4, Automatic}, {21, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0.333333]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<300000BL?00400@=c6K0000000000c60801T1T00000000000
00000000000000000000000000800000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 3, 152, "Title"],
Cell[1796, 56, 81, 2, 56, "Subtitle",
  Evaluatable->False],
Cell[1880, 60, 48, 1, 27, "Input"],
Cell[1931, 63, 47, 1, 27, "Input"],
Cell[1981, 66, 46, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2052, 71, 157, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2212, 76, 487, 8, 82, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2736, 89, 156, 3, 46, "Subsection",
  Evaluatable->False],
Cell[2895, 94, 775, 14, 100, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3707, 113, 124, 3, 46, "Subsection",
  Evaluatable->False],
Cell[3834, 118, 547, 12, 68, "Text"],
Cell[4384, 132, 285, 13, 32, "Text"],
Cell[4672, 147, 241, 7, 49, "Text"],
Cell[4916, 156, 44, 1, 27, "Input"],
Cell[4963, 159, 113, 2, 27, "Input"],
Cell[5079, 163, 42, 1, 27, "Input"],
Cell[5124, 166, 434, 7, 65, "Text"],
Cell[5561, 175, 43, 1, 27, "Input"],
Cell[5607, 178, 42, 1, 27, "Input"],
Cell[5652, 181, 45, 0, 31, "Text"],
Cell[5700, 183, 44, 1, 27, "Input"],
Cell[5747, 186, 44, 0, 31, "Text"],
Cell[5794, 188, 47, 1, 27, "Input"],
Cell[5844, 191, 294, 5, 48, "Text"],
Cell[6141, 198, 46, 1, 27, "Input"],
Cell[6190, 201, 139, 3, 31, "Text"],
Cell[6332, 206, 47, 1, 27, "Input"],
Cell[6382, 209, 46, 1, 27, "Input"],
Cell[6431, 212, 114, 3, 31, "Text"],
Cell[6548, 217, 54, 1, 27, "Input"],
Cell[6605, 220, 74, 0, 31, "Text"],
Cell[6682, 222, 49, 1, 27, "Input"],
Cell[6734, 225, 65, 0, 31, "Text"],
Cell[6802, 227, 49, 1, 27, "Input"],
Cell[6854, 230, 54, 1, 27, "Input"],
Cell[6911, 233, 207, 4, 48, "Text"],
Cell[7121, 239, 47, 1, 27, "Input"],
Cell[7171, 242, 52, 1, 27, "Input"],
Cell[7226, 245, 307, 7, 49, "Text"],
Cell[7536, 254, 65, 1, 27, "Input"],
Cell[7604, 257, 470, 7, 65, "Text"],
Cell[8077, 266, 50, 1, 27, "Input"],
Cell[8130, 269, 126, 3, 31, "Text"],
Cell[8259, 274, 48, 1, 27, "Input"],
Cell[8310, 277, 156, 3, 31, "Text"],
Cell[8469, 282, 48, 1, 27, "Input"],
Cell[8520, 285, 214, 4, 48, "Text"],
Cell[8737, 291, 48, 1, 27, "Input"],
Cell[8788, 294, 244, 5, 48, "Text"],
Cell[9035, 301, 59, 1, 27, "Input"],
Cell[9097, 304, 59, 1, 27, "Input"],
Cell[9159, 307, 54, 0, 31, "Text"],
Cell[9216, 309, 384, 6, 65, "Text"],
Cell[9603, 317, 43, 1, 27, "Input"],
Cell[9649, 320, 502, 8, 82, "Text"],
Cell[10154, 330, 60, 1, 27, "Input"],
Cell[10217, 333, 207, 4, 48, "Text"],
Cell[10427, 339, 62, 1, 27, "Input"],
Cell[10492, 342, 44, 0, 31, "Text"],
Cell[10539, 344, 151, 5, 32, "Text"],
Cell[10693, 351, 53, 1, 27, "Input"],
Cell[10749, 354, 67, 1, 27, "Input"],
Cell[10819, 357, 89, 3, 31, "Text"],
Cell[10911, 362, 48, 1, 27, "Input"],
Cell[10962, 365, 112, 3, 31, "Text"],
Cell[11077, 370, 48, 1, 27, "Input"],
Cell[11128, 373, 168, 4, 31, "Text"],
Cell[11299, 379, 48, 1, 27, "Input"],
Cell[11350, 382, 47, 1, 27, "Input"],
Cell[11400, 385, 97, 3, 31, "Text"],
Cell[11500, 390, 59, 1, 27, "Input"],
Cell[11562, 393, 87, 3, 31, "Text"],
Cell[11652, 398, 64, 1, 27, "Input"],
Cell[11719, 401, 70, 0, 31, "Text"],
Cell[11792, 403, 100, 2, 27, "Input"],
Cell[11895, 407, 343, 8, 49, "Text"],
Cell[12241, 417, 51, 1, 27, "Input"],
Cell[12295, 420, 51, 1, 27, "Input"],
Cell[12349, 423, 54, 1, 27, "Input"],
Cell[12406, 426, 54, 1, 27, "Input"],
Cell[12463, 429, 54, 1, 27, "Input"],
Cell[12520, 432, 54, 1, 27, "Input"],
Cell[12577, 435, 54, 1, 27, "Input"],
Cell[12634, 438, 54, 1, 27, "Input"],
Cell[12691, 441, 74, 0, 31, "Text"],
Cell[12768, 443, 60, 1, 27, "Input"],
Cell[12831, 446, 46, 0, 31, "Text"],
Cell[12880, 448, 62, 1, 27, "Input"],
Cell[12945, 451, 119, 5, 32, "Text"],
Cell[13067, 458, 53, 1, 27, "Input"],
Cell[13123, 461, 66, 1, 27, "Input"],
Cell[13192, 464, 98, 3, 31, "Text"],
Cell[13293, 469, 48, 1, 27, "Input"],
Cell[13344, 472, 39, 0, 31, "Text"],
Cell[13386, 474, 47, 1, 27, "Input"],
Cell[13436, 477, 48, 1, 27, "Input"],
Cell[13487, 480, 48, 1, 27, "Input"],
Cell[13538, 483, 616, 11, 83, "Text"],
Cell[14157, 496, 49, 1, 27, "Input"],
Cell[14209, 499, 55, 1, 27, "Input"],
Cell[14267, 502, 59, 1, 27, "Input"],
Cell[14329, 505, 59, 1, 27, "Input"],
Cell[14391, 508, 182, 6, 32, "Text"],
Cell[14576, 516, 60, 1, 27, "Input"],
Cell[14639, 519, 303, 5, 48, "Text"],
Cell[14945, 526, 108, 2, 27, "Input"],
Cell[15056, 530, 55, 1, 27, "Input"],
Cell[15114, 533, 62, 0, 31, "Text"],
Cell[15179, 535, 87, 1, 27, "Input"],
Cell[15269, 538, 49, 0, 31, "Text"],
Cell[15321, 540, 72, 1, 27, "Input"],
Cell[15396, 543, 59, 1, 27, "Input"],
Cell[15458, 546, 224, 6, 32, "Text"],
Cell[15685, 554, 99, 2, 27, "Input"],
Cell[15787, 558, 73, 1, 27, "Input"],
Cell[15863, 561, 53, 1, 27, "Input"],
Cell[15919, 564, 58, 1, 27, "Input"],
Cell[15980, 567, 78, 1, 27, "Input"],
Cell[16061, 570, 640, 11, 83, "Text"],
Cell[16704, 583, 117, 4, 31, "Text"],
Cell[16824, 589, 1004, 16, 117, "Text"],
Cell[17831, 607, 80, 1, 27, "Input"],
Cell[17914, 610, 62, 1, 27, "Input"],
Cell[17979, 613, 130, 3, 27, "Input"],
Cell[18112, 618, 712, 18, 68, "Text"],
Cell[18827, 638, 54, 1, 27, "Input"],
Cell[18884, 641, 67, 1, 27, "Input"],
Cell[18954, 644, 57, 0, 31, "Text"],
Cell[19014, 646, 48, 1, 27, "Input"],
Cell[19065, 649, 88, 3, 31, "Text"],
Cell[19156, 654, 59, 1, 27, "Input"],
Cell[19218, 657, 59, 1, 27, "Input"],
Cell[19280, 660, 59, 1, 27, "Input"],
Cell[19342, 663, 55, 0, 31, "Text"],
Cell[19400, 665, 48, 1, 27, "Input"],
Cell[19451, 668, 64, 1, 27, "Input"],
Cell[19518, 671, 59, 1, 27, "Input"],
Cell[19580, 674, 90, 3, 31, "Text"],
Cell[19673, 679, 61, 1, 27, "Input"],
Cell[19737, 682, 54, 0, 31, "Text"],
Cell[19794, 684, 48, 1, 27, "Input"],
Cell[19845, 687, 48, 1, 27, "Input"],
Cell[19896, 690, 48, 1, 27, "Input"],
Cell[19947, 693, 493, 8, 82, "Text"],
Cell[20443, 703, 71, 1, 27, "Input"],
Cell[20517, 706, 135, 3, 31, "Text"],
Cell[20655, 711, 77, 1, 27, "Input"],
Cell[20735, 714, 38, 1, 27, "Input"],
Cell[20776, 717, 130, 3, 31, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20943, 725, 129, 3, 46, "Subsection",
  Evaluatable->False],
Cell[21075, 730, 783, 21, 85, "Text"],
Cell[21861, 753, 461, 21, 32, "Text"],
Cell[22325, 776, 48, 0, 31, "Text"],
Cell[22376, 778, 196, 3, 47, "Input"],
Cell[22575, 783, 42, 1, 27, "Input"],
Cell[22620, 786, 108, 3, 31, "Text"],
Cell[22731, 791, 66, 0, 31, "Text"],
Cell[22800, 793, 38, 1, 27, "Input"],
Cell[22841, 796, 41, 1, 27, "Input"],
Cell[22885, 799, 574, 12, 66, "Text"],
Cell[23462, 813, 79, 1, 27, "Input"],
Cell[23544, 816, 74, 0, 31, "Text"],
Cell[23621, 818, 51, 1, 27, "Input"],
Cell[23675, 821, 127, 2, 27, "Input"],
Cell[23805, 825, 64, 1, 27, "Input"],
Cell[23872, 828, 441, 7, 65, "Text"],
Cell[24316, 837, 155, 3, 43, "Input"],
Cell[24474, 842, 92, 1, 27, "Input"],
Cell[24569, 845, 92, 3, 31, "Text"],
Cell[24664, 850, 76, 1, 27, "Input"],
Cell[24743, 853, 64, 1, 27, "Input"],
Cell[24810, 856, 39, 0, 31, "Text"],
Cell[24852, 858, 103, 2, 27, "Input"],
Cell[24958, 862, 100, 3, 31, "Text"],
Cell[25061, 867, 78, 1, 27, "Input"],
Cell[25142, 870, 52, 1, 27, "Input"],
Cell[25197, 873, 457, 7, 65, "Text"],
Cell[25657, 882, 290, 5, 48, "Text"],
Cell[25950, 889, 59, 1, 27, "Input"],
Cell[26012, 892, 99, 2, 27, "Input"],
Cell[26114, 896, 192, 5, 27, "Input"],
Cell[26309, 903, 162, 4, 31, "Text"],
Cell[26474, 909, 76, 1, 27, "Input"],
Cell[26553, 912, 73, 1, 27, "Input"],
Cell[26629, 915, 79, 1, 27, "Input"],
Cell[26711, 918, 53, 1, 27, "Input"],
Cell[26767, 921, 65, 1, 27, "Input"],
Cell[26835, 924, 101, 2, 27, "Input"],
Cell[26939, 928, 1049, 25, 101, "Text"],
Cell[27991, 955, 134, 2, 27, "Input"],
Cell[28128, 959, 67, 1, 27, "Input"],
Cell[28198, 962, 89, 1, 27, "Input"],
Cell[28290, 965, 404, 11, 50, "Text"],
Cell[28697, 978, 58, 1, 27, "Input"],
Cell[28758, 981, 72, 1, 27, "Input"],
Cell[28833, 984, 58, 0, 31, "Text"],
Cell[28894, 986, 51, 1, 27, "Input"],
Cell[28948, 989, 53, 0, 31, "Text"],
Cell[29004, 991, 62, 1, 27, "Input"],
Cell[29069, 994, 64, 1, 27, "Input"],
Cell[29136, 997, 64, 1, 27, "Input"],
Cell[29203, 1000, 64, 1, 27, "Input"],
Cell[29270, 1003, 43, 0, 31, "Text"],
Cell[29316, 1005, 44, 1, 27, "Input"],
Cell[29363, 1008, 44, 1, 27, "Input"],
Cell[29410, 1011, 44, 1, 27, "Input"],
Cell[29457, 1014, 44, 1, 27, "Input"],
Cell[29504, 1017, 128, 3, 31, "Text"],
Cell[29635, 1022, 52, 1, 27, "Input"],
Cell[29690, 1025, 50, 1, 27, "Input"],
Cell[29743, 1028, 50, 1, 27, "Input"],
Cell[29796, 1031, 406, 8, 66, "Text"],
Cell[30205, 1041, 62, 1, 27, "Input"],
Cell[30270, 1044, 54, 1, 27, "Input"],
Cell[30327, 1047, 132, 3, 27, "Input"],
Cell[30462, 1052, 111, 3, 31, "Text"],
Cell[30576, 1057, 228, 5, 48, "Text"],
Cell[30807, 1064, 58, 1, 27, "Input"],
Cell[30868, 1067, 60, 1, 27, "Input"],
Cell[30931, 1070, 328, 6, 48, "Text"],
Cell[31262, 1078, 104, 2, 27, "Input"],
Cell[31369, 1082, 60, 1, 27, "Input"],
Cell[31432, 1085, 175, 4, 31, "Text"],
Cell[31610, 1091, 41, 1, 27, "Input"],
Cell[31654, 1094, 55, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31746, 1100, 135, 3, 46, "Subsection",
  Evaluatable->False],
Cell[31884, 1105, 624, 10, 82, "Text"],
Cell[32511, 1117, 692, 32, 32, "Text"],
Cell[33206, 1151, 49, 0, 31, "Text"],
Cell[33258, 1153, 250, 4, 47, "Input"],
Cell[33511, 1159, 42, 1, 27, "Input"],
Cell[33556, 1162, 175, 4, 31, "Text"],
Cell[33734, 1168, 74, 1, 27, "Input"],
Cell[33811, 1171, 50, 1, 27, "Input"],
Cell[33864, 1174, 54, 0, 31, "Text"],
Cell[33921, 1176, 157, 2, 43, "Input"],
Cell[34081, 1180, 54, 1, 27, "Input"],
Cell[34138, 1183, 45, 0, 31, "Text"],
Cell[34186, 1185, 74, 1, 27, "Input"],
Cell[34263, 1188, 61, 1, 27, "Input"],
Cell[34327, 1191, 114, 3, 31, "Text"],
Cell[34444, 1196, 81, 1, 27, "Input"],
Cell[34528, 1199, 50, 1, 27, "Input"],
Cell[34581, 1202, 61, 1, 27, "Input"],
Cell[34645, 1205, 281, 7, 50, "Text"],
Cell[34929, 1214, 63, 1, 27, "Input"],
Cell[34995, 1217, 186, 3, 43, "Input"],
Cell[35184, 1222, 119, 2, 27, "Input"],
Cell[35306, 1226, 234, 8, 32, "Text"],
Cell[35543, 1236, 52, 1, 27, "Input"],
Cell[35598, 1239, 113, 2, 27, "Input"],
Cell[35714, 1243, 129, 2, 27, "Input"],
Cell[35846, 1247, 125, 3, 31, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

